@@ -21,6 +21,7 @@ static char rcsid[]="$Header: /ufs/repository/magic/calma/CalmaWrite.c,v 1.4 200
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <string.h>
 #include <ctype.h>
 #include <sys/types.h>
 #ifdef	SYSV
@@ -55,8 +56,14 @@ extern int calmaWriteInitFunc();
 extern int calmaWriteMarkFunc();
 extern int calmaWritePaintFunc();
 extern int calmaWriteUseFunc();
-extern void calmaOutR8();
+extern void calmaOutFunc();
+extern void calmaOutStructName();
+extern void calmaWriteLabelFunc();
+extern void calmaOutHeader();
+extern void calmaOutDate();
+extern void calmaOutStringRecord();
 extern void calmaOut8();
+extern void calmaOutR8();
 
 /* Number assigned to each cell */
 int calmaCellNum;
@@ -362,11 +369,12 @@ calmaProcessDef(def, outf)
  * ----------------------------------------------------------------------------
  */
 
+void
 calmaOutFunc(def, f)
     CellDef *def;	/* Pointer to cell def to be written */
     FILE *f;		/* Open output file */
 {
-    register Label *lab;
+    Label *lab;
     CIFLayer *layer;
     Rect bigArea;
     int type;
@@ -462,9 +470,9 @@ calmaWriteUseFunc(use, f)
 {
     /*
      * r90, r180, and r270 are Calma 8-byte real representations
-     * of the angles 90, 180, and 270 degrees.  This is faster than
-     * using calmaOutR8(), since there are only four possible values
-     * and they can be pre-computed.
+     * of the angles 90, 180, and 270 degrees.  Because there are
+     * only 4 possible values, it is faster to have them pre-computed
+     * than to format with calmaOutR8().
      */
     static unsigned char r90[] = { 0x42, 0x5a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
     static unsigned char r180[] = { 0x42, 0xb4, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
@@ -472,7 +480,7 @@ calmaWriteUseFunc(use, f)
     unsigned char *whichangle;
     int x, y, topx, topy, rows, cols, xxlate, yxlate, hdrsize;
     int rectype, stransflags;
-    register Transform *t;
+    Transform *t;
     bool isArray = FALSE;
     Point p, p2;
 
@@ -648,14 +656,15 @@ calmaWriteUseFunc(use, f)
  * ----------------------------------------------------------------------------
  */
 
+void
 calmaOutStructName(type, def, f)
     int type;
     CellDef *def;
     FILE *f;
 {
     char defname[CALMANAMELENGTH+1];
-    register unsigned char c;
-    register char *cp;
+    unsigned char c;
+    char *cp;
     int calmanum;
     char *table;
 
@@ -710,7 +719,7 @@ bad:
 
 int
 calmaWritePaintFunc(tile, f)
-    register Tile *tile;		/* Tile to be written out. */
+    Tile *tile;		/* Tile to be written out. */
     FILE *f;				/* File in which to write. */
 {
     Rect r;
@@ -815,6 +824,7 @@ calmaWritePaintFunc(tile, f)
  * ----------------------------------------------------------------------------
  */
 
+void
 calmaWriteLabelFunc(lab, type, f)
     Label *lab;	/* Label to output */
     int type;	/* CIF layer number, or -1 if not attached to a layer */
@@ -867,7 +877,7 @@ calmaWriteLabelFunc(lab, type, f)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 calmaOutHeader(rootDef, f)
     CellDef *rootDef;
     FILE *f;
@@ -890,9 +900,15 @@ calmaOutHeader(rootDef, f)
     /*
      * Units.
      * User units are microns; this is really unimportant.
-     * Database units are millimicrons, since there are lots
-     * of programs that don't understand anything else.
+     *
+     * Database units are nanometers, since there are
+     * programs that don't understand anything else.  If
+     * the database units are *smaller* than nanometers, use
+     * the actual database units.  Otherwise, stick with
+     * nanometers, because anything larger may not input
+     * properly with other software.
      */
+
     calmaOutRH(20, CALMA_UNITS, CALMA_R8, f);
     calmaOutR8(useru, f);	/* User units per database unit */
     calmaOutR8(mum, f);		/* Meters per database unit */
@@ -916,6 +932,7 @@ calmaOutHeader(rootDef, f)
  * ----------------------------------------------------------------------------
  */
 
+void
 calmaOutDate(t, f)
     time_t t;	/* Time (UNIX format) to be output */
     FILE *f;	/* Stream file */
@@ -950,13 +967,14 @@ calmaOutDate(t, f)
  * ----------------------------------------------------------------------------
  */
 
+void
 calmaOutStringRecord(type, str, f)
     int type;		/* Type of this record (data type is ASCII string) */
-    register char *str;	/* String to be output (<= CALMANAMELENGTH chars) */
-    register FILE *f;	/* Stream file */
+    char *str;	/* String to be output (<= CALMANAMELENGTH chars) */
+    FILE *f;	/* Stream file */
 {
     int len;
-    register unsigned char c;
+    unsigned char c;
     char *table;
 
     if(CIFCurStyle->cs_flags & CWF_PERMISSIVE_LABELS) 
@@ -994,7 +1012,6 @@ calmaOutStringRecord(type, str, f)
 	}
     }
 }
-
 
 /*
  * ----------------------------------------------------------------------------
@@ -1015,12 +1032,12 @@ calmaOutStringRecord(type, str, f)
 
 void
 calmaOutR8(d, f)
-    double d;	/* Value to write to output */
+    double d;	/* Double value to write to output */
     FILE *f;	/* Stream file */
 {
     int c, i, sign, expon;
 
-    /* mantiss must be 64 bits for this routine to work correctly */
+    /* mantissa must be 64 bits for this routine to work correctly */
 #if SIZEOF_UNSIGNED_LONG == 8
     unsigned long mantissa;
 #else
@@ -1075,6 +1092,7 @@ calmaOutR8(d, f)
     }
 }
 
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1093,10 +1111,10 @@ calmaOutR8(d, f)
 
 void
 calmaOut8(str, f)
-    register char *str;	/* 8-byte string to be output */
-    register FILE *f;	/* Stream file */
+    char *str;	/* 8-byte string to be output */
+    FILE *f;	/* Stream file */
 {
-    register i;
+    int i;
 
     for (i = 0; i < 8; i++)
 	(void) putc(*str++, f);
