@@ -22,12 +22,13 @@ static char rcsid[] = "$Header: /ufs/repository/magic/cif/CIFrdtech.c,v 1.5 2001
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <ctype.h>
 #ifdef SYSV
 #include <string.h>
 #endif
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -385,7 +386,7 @@ CIFReadTechStyleInit()
  *	in the "cifinput" section of the technology file.
  *
  * Results:
- *	None.
+ *	Always return TRUE.
  *
  * Side effects:
  *	Sets up information in the tables used to read CIF, and prints
@@ -980,7 +981,7 @@ CIFSetReadStyle(name)
 
 int
 cifParseCalmaNums(str, numArray, numNums)
-    register char *str;	/* String to parse */
+    char *str;	/* String to parse */
     int *numArray;	/* Array to fill in */
     int numNums;	/* Maximum number of entries in numArray */
 {
@@ -1035,7 +1036,7 @@ cifParseCalmaNums(str, numArray, numNums)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 CIFTechInputScale(n, d)
     int n, d;
 {
