@@ -39,6 +39,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/cif/CIFtech.c,v 1.4 2001/0
 #include "calma/calmaInt.h"
 #include "textio/textio.h"
 #include "utils/malloc.h"
+#include "cif/cif.h"
 
 /* The following points to a list of all CIF styles currently
  * understood:
@@ -256,18 +257,15 @@ okpaint:
 		TechError("\"Space\" layer not permitted in CIF rules.\n");
 	    else
 	    {
+		TileType rtype;
+
 		TTMaskSetMask(paintMask, &curPaintMask);
 
 		/* Add residues from '*' notation */
 		if (allResidues)
-		{
-		    TileTypeBitMask rmask;
-		    DBResidueMask(paintType, &rmask);
-		    TTMaskSetMask(paintMask, &rmask);
-
-		    /* Restrict to the plane of paintType */
-		    TTMaskAndMask(paintMask, &DBPlaneTypes[DBPlane(paintType)]);
-		}
+		    for (rtype = TT_TECHDEPBASE; rtype < DBNumUserLayers; rtype++)
+			if (TTMaskHasType(DBResidueMask(rtype), paintType))
+			    TTMaskSetType(paintMask, rtype);
 	    } 
 	}
 	else if (!TTMaskEqual(&curCifMask, &DBZeroTypeBits))
@@ -295,7 +293,7 @@ okpaint:
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 CIFTechInit()
 {
     CIFKeep *style;
@@ -333,7 +331,7 @@ CIFTechInit()
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 CIFTechStyleInit()
 {
     CalmaTechInit();
@@ -362,6 +360,7 @@ CIFTechStyleInit()
  *
  * ----------------------------------------------------------------------------
  */
+
 int
 CIFParseScale(true_scale, expander)
     char *true_scale;
@@ -403,7 +402,8 @@ CIFParseScale(true_scale, expander)
  *	section of the technology file.
  *
  * Results:
- *	None.
+ *	TRUE if line parsed correctly; FALSE if fatal error condition
+ *	encountered.
  *
  * Side effects:
  *	Sets up information in the tables of CIF layers, and
@@ -412,7 +412,6 @@ CIFParseScale(true_scale, expander)
  * ----------------------------------------------------------------------------
  */
 
-	/* ARGSUSED */
 bool
 CIFTechLine(sectionName, argc, argv)
     char *sectionName;		/* The name of this section. */
@@ -488,8 +487,9 @@ CIFTechLine(sectionName, argc, argv)
 	if ((argc < 2) || (argc > 4))
 	{
 wrongNumArgs:
-	    TechError("Wrong number of arguments in cif %s statement\nDo you have a space in a list of layers?\n\n",
-	        argv[0]);
+	    TechError("Wrong number of arguments in cif %s statement\n"
+			"Do you have a space in a list of layers?\n\n",
+			argv[0]);
 	    errorReturn:
 	    if (newOp != NULL) freeMagic((char *) newOp);
 	    return TRUE;
@@ -829,7 +829,6 @@ wrongNumArgs:
 	
 	case CIFOP_SQUARES_G:
 	    local_bloats[3] = 1; /* set default grid and fall through */
-	    local_bloats[4] = 1;
 	case CIFOP_SQUARES:
 	    if (argc == 2)
 	    {
@@ -845,8 +844,8 @@ wrongNumArgs:
 		local_bloats[2] = i;
 		local_bloats[3] = 0;	/* placeholder; not used by SQUARES */
 	    }
-	    else if (argc == 4 || ((argc == 5 || argc == 6) 
-			&& newOp->co_opcode==CIFOP_SQUARES_G))
+	    else if (argc == 4 || 
+		      (argc==5 && newOp->co_opcode==CIFOP_SQUARES_G))
 	    {
 		local_bloats[0] = atoi(argv[1]);
 		if (local_bloats[0] < 0)
@@ -866,23 +865,14 @@ wrongNumArgs:
 		    TechError("Square separation must be positive.\n");
 		    goto errorReturn;
 		}
-		if (argc >= 5)
-		{
-		    local_bloats[3] = local_bloats[4] = atoi(argv[4]);
+		if ( argc == 5 ) {
+		    local_bloats[3] = atoi(argv[4]);
 		    if (local_bloats[3] <= 0)
 		    {
 		        TechError("Square grid must be positive.\n");
 		        goto errorReturn;
 		    }
-		}
-		if (argc == 6)
-		{
-		    local_bloats[4] = atoi(argv[5]);
-		    if (local_bloats[4] <= 0)
-		    {
-		        TechError("Square y-grid must be positive.\n");
-		        goto errorReturn;
-		    }
+		 
 		}
 	    }
 	    else goto wrongNumArgs;
@@ -896,15 +886,11 @@ wrongNumArgs:
     switch (newOp->co_opcode)
     {
 	case CIFOP_SQUARES:
+	case CIFOP_SQUARES_G:
 	    newOp->co_bloats = (int *) mallocMagic(4 * sizeof(int));
 	    for (i = 0; i < 4; i++)
 		newOp->co_bloats[i] = local_bloats[i];
 	    break;
-	case CIFOP_SQUARES_G:
-	    newOp->co_bloats = (int *) mallocMagic(5 * sizeof(int));
-	    for (i = 0; i < 5; i++)
-		newOp->co_bloats[i] = local_bloats[i];
-	    break;
 	case CIFOP_BLOAT:
 	case CIFOP_BLOATMAX:
 	case CIFOP_BLOATMIN:
@@ -924,7 +910,6 @@ wrongNumArgs:
 
     return TRUE;
 }
-
 
 /*
  * ----------------------------------------------------------------------------
@@ -1103,7 +1088,7 @@ cifComputeRadii(layer, des)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 CIFTechFinal()
 {
     CIFStyle *style = CIFCurStyle;
@@ -1155,7 +1140,7 @@ CIFTechFinal()
 	    }
 	    if (op->co_bloats)
 	    {
-		if (op->co_opcode == CIFOP_SQUARES)
+		if (op->co_opcode == CIFOP_SQUARES || op->co_opcode == CIFOP_SQUARES_G)
 		{
 		    for (j = 0; j < 4; j++)
 		    {
@@ -1176,8 +1161,7 @@ CIFTechFinal()
 		}
 		else
 		{
-		    for (j = 0; j < ((op->co_opcode == CIFOP_SQUARES_G)
-				? 5 : TT_MAXTYPES); j++)
+		    for (j = 0; j < TT_MAXTYPES; j++)
 		    {
 			if (op->co_bloats[j] != 0)
 			{
@@ -1347,6 +1331,7 @@ CIFTechFinal()
  *
  * ----------------------------------------------------------------------------
  */
+
 void
 CIFLoadStyle(stylename)
     char *stylename;
@@ -1393,7 +1378,7 @@ CIFLoadStyle(stylename)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 CIFTechOutputScale(n, d)
     int n, d;
 {
@@ -1410,7 +1395,8 @@ CIFTechOutputScale(n, d)
 	{
 	    cl = ostyle->cs_layers[i];
 	    for (op = cl->cl_ops; op != NULL; op = op->co_next)
-		if (op->co_opcode == CIFOP_SQUARES)
+		if ((op->co_opcode == CIFOP_SQUARES)
+				|| (op->co_opcode == CIFOP_SQUARES_G))
 		    if ((op->co_bloats[1] & 0x01) || (op->co_bloats[2] & 0x01))
 		    {
 			has_odd_space = TRUE;
@@ -1448,7 +1434,8 @@ CIFTechOutputScale(n, d)
 	    if (op->co_bloats)
 	    {
 		int bvalue;
-		if (op->co_opcode == CIFOP_SQUARES)
+		if ((op->co_opcode == CIFOP_SQUARES) || (op->co_opcode ==
+				CIFOP_SQUARES_G))
 		{
 		    for (j = 0; j < 4; j++)
 		    {
@@ -1464,8 +1451,7 @@ CIFTechOutputScale(n, d)
 		}
 		else
 		{
-		    for (j = 0; j < ((op->co_opcode == CIFOP_SQUARES_G)
-				? 5 : TT_MAXTYPES); j++)
+		    for (j = 0; j < TT_MAXTYPES; j++)
 		    {
 			if (op->co_bloats[j] != 0)
 			{
@@ -1509,18 +1495,9 @@ CIFTechOutputScale(n, d)
 
 	    if (op->co_bloats)
 	    {
-		int nlayers;
-		switch (op->co_opcode) {
-		    case CIFOP_SQUARES:
-			nlayers = 4;
-			break;
-		    case CIFOP_SQUARES_G:
-			nlayers = 5;
-			break;
-		    default:
-			nlayers = TT_MAXTYPES;
-			break;
-		}
+		int nlayers = TT_MAXTYPES;
+		if (op->co_opcode == CIFOP_SQUARES || op->co_opcode ==
+				CIFOP_SQUARES_G) nlayers = 4;
 		for (j = 0; j < nlayers; j++)
 		    if (op->co_bloats[j] != 0)
 			op->co_bloats[j] /= lexpand;
