@@ -21,8 +21,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdAB.c,v 1.4 200
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <string.h>
+#include <stdlib.h>
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -67,13 +69,11 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdAB.c,v 1.4 200
  */
  /*ARGSUSED*/
 
-Void
+void
 CmdAddPath( w, cmd )
     MagWindow *w;
     TxCommand *cmd;
 {
-    char *new;
-
     if (cmd->tx_argc != 2) {
 	TxError("Usage: %s appended_search_path\n", cmd->tx_argv[0]);
 	return;
@@ -127,7 +127,7 @@ typedef struct LA1
 #define ARRAY_HELP	5
 #define ARRAY_DEFAULT	6
 
-    /* ARGSUSED */
+void
 CmdArray(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -147,7 +147,6 @@ CmdArray(w, cmd)
     ArrayInfo a;
     Rect toolRect;
     LinkedArray *lahead = NULL, *la;
-    CellUse *use;
     int xval, yval;
 
     extern int selGetArrayFunc();
@@ -481,6 +480,7 @@ selGetArrayFunc(selUse, use, trans, arg)
 #define BOX_HELP	9
 #define BOX_DEFAULT	10
 
+void
 CmdBox(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -501,8 +501,8 @@ CmdBox(w, cmd)
 
     CellDef *rootBoxDef;
     Rect rootBox, editbox, *boxptr;
-    int option, direction, distancex, distancey;
-    int width, height, area, llx, lly, urx, ury;
+    int option, direction, distance;
+    int width, height, area, llx, lly;
     int argc;
     float iscale, oscale;
     bool needBox = TRUE;		/* require that box be defined */
@@ -592,10 +592,10 @@ CmdBox(w, cmd)
     {
 	Rect r;
 
-	r.r_xbot = cmdParseCoord(w, cmd->tx_argv[argc - 4], FALSE, TRUE);
-	r.r_ybot = cmdParseCoord(w, cmd->tx_argv[argc - 3], FALSE, FALSE);
-	r.r_xtop = cmdParseCoord(w, cmd->tx_argv[argc - 2], FALSE, TRUE);
-	r.r_ytop = cmdParseCoord(w, cmd->tx_argv[argc - 1], FALSE, FALSE);
+	r.r_xbot = cmdParseCoord(cmd->tx_argv[argc - 4]);
+	r.r_ybot = cmdParseCoord(cmd->tx_argv[argc - 3]);
+	r.r_xtop = cmdParseCoord(cmd->tx_argv[argc - 2]);
+	r.r_ytop = cmdParseCoord(cmd->tx_argv[argc - 1]);
 
 	rootBoxDef = ((CellUse *) w->w_surfaceID)->cu_def;
 	if (refEdit)
@@ -624,30 +624,8 @@ CmdBox(w, cmd)
 	    if (argc != 4) goto badusage;
 	    direction = GeoNameToPos(cmd->tx_argv[2], FALSE, TRUE);
 	    if (direction < 0) return;
-	    if (DBWSnapToGrid != DBW_SNAP_USER)
-	    {
-		distancex = cmdParseCoord(w, cmd->tx_argv[3], TRUE, FALSE);
-		distancey = distancex;
-	    }
-	    else
-	    {
-		switch(direction)
-		{
-		    case GEO_EAST: case GEO_WEST:
-			distancex = cmdParseCoord(w, cmd->tx_argv[3], TRUE, TRUE);
-			distancey = distancex;
-			break;
-		    case GEO_NORTH: case GEO_SOUTH:
-			distancey = cmdParseCoord(w, cmd->tx_argv[3], TRUE, FALSE);
-			distancex = distancey;
-			break;
-		    default:
-			distancex = cmdParseCoord(w, cmd->tx_argv[3], TRUE, TRUE);
-			distancey = cmdParseCoord(w, cmd->tx_argv[3], TRUE, FALSE);
-			break;
-		}
-	    }
-	    if ((distancex == 0) && (distancey == 0)) return;
+	    distance = cmdParseCoord(cmd->tx_argv[3]);
+	    if (distance == 0) return;
 	    break;
     }
 
@@ -671,7 +649,7 @@ CmdBox(w, cmd)
 		return;
 	    }
 	    else if (argc != 3) goto badusage;
-	    width = cmdParseCoord(w, cmd->tx_argv[2], TRUE, TRUE);
+	    width = cmdParseCoord(cmd->tx_argv[2]);
 	    rootBox.r_xtop = rootBox.r_xbot + width;
 	    break;
 
@@ -691,7 +669,7 @@ CmdBox(w, cmd)
 		return;
 	    }
 	    else if (argc != 3) goto badusage;
-	    height = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
+	    height = cmdParseCoord(cmd->tx_argv[2]);
 	    rootBox.r_ytop = rootBox.r_ybot + height;
 	    break;
 
@@ -713,8 +691,8 @@ CmdBox(w, cmd)
 		return;
 	    }
 	    else if (argc != 4) goto badusage;
-	    width = cmdParseCoord(w, cmd->tx_argv[2], TRUE, TRUE);
-	    height = cmdParseCoord(w, cmd->tx_argv[3], TRUE, FALSE);
+	    width = cmdParseCoord(cmd->tx_argv[2]);
+	    height = cmdParseCoord(cmd->tx_argv[3]);
 	    rootBox.r_xtop = rootBox.r_xbot + width;
 	    rootBox.r_ytop = rootBox.r_ybot + height;
 	    break;
@@ -737,8 +715,8 @@ CmdBox(w, cmd)
 	    else if (argc != 4) goto badusage;
 	    width = rootBox.r_xtop - rootBox.r_xbot;
 	    height = rootBox.r_ytop - rootBox.r_ybot;
-	    llx = cmdParseCoord(w, cmd->tx_argv[2], FALSE, TRUE);
-	    lly = cmdParseCoord(w, cmd->tx_argv[3], FALSE, FALSE);
+	    llx = cmdParseCoord(cmd->tx_argv[2]);
+	    lly = cmdParseCoord(cmd->tx_argv[3]);
 	    boxptr->r_xbot = llx;
 	    boxptr->r_ybot = lly;
 	    boxptr->r_xtop = boxptr->r_xbot + width;
@@ -769,44 +747,44 @@ CmdBox(w, cmd)
 	    switch (direction)
 	    {
 		case GEO_NORTH:
-		    rootBox.r_ybot += distancey;
-		    rootBox.r_ytop += distancey;
+		    rootBox.r_ybot += distance;
+		    rootBox.r_ytop += distance;
 		    break;
 		case GEO_SOUTH:
-		    rootBox.r_ybot -= distancey;
-		    rootBox.r_ytop -= distancey;
+		    rootBox.r_ybot -= distance;
+		    rootBox.r_ytop -= distance;
 		    break;
 		case GEO_EAST:
-		    rootBox.r_xbot += distancex;
-		    rootBox.r_xtop += distancex;
+		    rootBox.r_xbot += distance;
+		    rootBox.r_xtop += distance;
 		    break;
 		case GEO_WEST:
-		    rootBox.r_xbot -= distancex;
-		    rootBox.r_xtop -= distancex;
+		    rootBox.r_xbot -= distance;
+		    rootBox.r_xtop -= distance;
 		    break;
 		case GEO_NORTHEAST:
-		    rootBox.r_ybot += distancey;
-		    rootBox.r_ytop += distancey;
-		    rootBox.r_xbot += distancex;
-		    rootBox.r_xtop += distancex;
+		    rootBox.r_ybot += distance;
+		    rootBox.r_ytop += distance;
+		    rootBox.r_xbot += distance;
+		    rootBox.r_xtop += distance;
 		    break;
 		case GEO_NORTHWEST:
-		    rootBox.r_ybot += distancey;
-		    rootBox.r_ytop += distancey;
-		    rootBox.r_xbot -= distancex;
-		    rootBox.r_xtop -= distancex;
+		    rootBox.r_ybot += distance;
+		    rootBox.r_ytop += distance;
+		    rootBox.r_xbot -= distance;
+		    rootBox.r_xtop -= distance;
 		    break;
 		case GEO_SOUTHEAST:
-		    rootBox.r_ybot -= distancey;
-		    rootBox.r_ytop -= distancey;
-		    rootBox.r_xbot += distancex;
-		    rootBox.r_xtop += distancex;
+		    rootBox.r_ybot -= distance;
+		    rootBox.r_ytop -= distance;
+		    rootBox.r_xbot += distance;
+		    rootBox.r_xtop += distance;
 		    break;
 		case GEO_SOUTHWEST:
-		    rootBox.r_ybot -= distancey;
-		    rootBox.r_ytop -= distancey;
-		    rootBox.r_xbot -= distancex;
-		    rootBox.r_xtop -= distancex;
+		    rootBox.r_ybot -= distance;
+		    rootBox.r_ytop -= distance;
+		    rootBox.r_xbot -= distance;
+		    rootBox.r_xtop -= distance;
 		    break;
 	    }
 	    break;
@@ -815,38 +793,38 @@ CmdBox(w, cmd)
 	    switch (direction)
 	    {
 		case GEO_NORTH:
-		    rootBox.r_ytop += distancey;
+		    rootBox.r_ytop += distance;
 		    break;
 		case GEO_SOUTH:
-		    rootBox.r_ybot -= distancey;
+		    rootBox.r_ybot -= distance;
 		    break;
 		case GEO_EAST:
-		    rootBox.r_xtop += distancex;
+		    rootBox.r_xtop += distance;
 		    break;
 		case GEO_WEST:
-		    rootBox.r_xbot -= distancex;
+		    rootBox.r_xbot -= distance;
 		    break;
 		case GEO_NORTHEAST:
-		    rootBox.r_ytop += distancey;
-		    rootBox.r_xtop += distancex;
+		    rootBox.r_ytop += distance;
+		    rootBox.r_xtop += distance;
 		    break;
 		case GEO_NORTHWEST:
-		    rootBox.r_ytop += distancey;
-		    rootBox.r_xbot -= distancex;
+		    rootBox.r_ytop += distance;
+		    rootBox.r_xbot -= distance;
 		    break;
 		case GEO_SOUTHEAST:
-		    rootBox.r_ybot -= distancey;
-		    rootBox.r_xtop += distancex;
+		    rootBox.r_ybot -= distance;
+		    rootBox.r_xtop += distance;
 		    break;
 		case GEO_SOUTHWEST:
-		    rootBox.r_ybot -= distancey;
-		    rootBox.r_xbot -= distancex;
+		    rootBox.r_ybot -= distance;
+		    rootBox.r_xbot -= distance;
 		    break;
 		case GEO_CENTER:
-		    rootBox.r_ytop += distancey;
-		    rootBox.r_ybot -= distancey;
-		    rootBox.r_xtop += distancex;
-		    rootBox.r_xbot -= distancex;
+		    rootBox.r_ytop += distance;
+		    rootBox.r_ybot -= distance;
+		    rootBox.r_xtop += distance;
+		    rootBox.r_xbot -= distance;
 		    break;
 	    }
 	    break;
@@ -855,38 +833,38 @@ CmdBox(w, cmd)
 	    switch (direction)
 	    {
 		case GEO_NORTH:
-		    rootBox.r_ytop -= distancey;
+		    rootBox.r_ytop -= distance;
 		    break;
 		case GEO_SOUTH:
-		    rootBox.r_ybot += distancey;
+		    rootBox.r_ybot += distance;
 		    break;
 		case GEO_EAST:
-		    rootBox.r_xtop -= distancex;
+		    rootBox.r_xtop -= distance;
 		    break;
 		case GEO_WEST:
-		    rootBox.r_xbot += distancex;
+		    rootBox.r_xbot += distance;
 		    break;
 		case GEO_NORTHEAST:
-		    rootBox.r_ytop -= distancey;
-		    rootBox.r_xtop -= distancex;
+		    rootBox.r_ytop -= distance;
+		    rootBox.r_xtop -= distance;
 		    break;
 		case GEO_NORTHWEST:
-		    rootBox.r_ytop -= distancey;
-		    rootBox.r_xbot += distancex;
+		    rootBox.r_ytop -= distance;
+		    rootBox.r_xbot += distance;
 		    break;
 		case GEO_SOUTHEAST:
-		    rootBox.r_ybot += distancey;
-		    rootBox.r_xtop -= distancex;
+		    rootBox.r_ybot += distance;
+		    rootBox.r_xtop -= distance;
 		    break;
 		case GEO_SOUTHWEST:
-		    rootBox.r_ybot += distancey;
-		    rootBox.r_xbot += distancex;
+		    rootBox.r_ybot += distance;
+		    rootBox.r_xbot += distance;
 		    break;
 		case GEO_CENTER:
-		    rootBox.r_ytop -= distancey;
-		    rootBox.r_xtop -= distancex;
-		    rootBox.r_ybot += distancey;
-		    rootBox.r_xbot += distancex;
+		    rootBox.r_ytop -= distance;
+		    rootBox.r_xtop -= distance;
+		    rootBox.r_ybot += distance;
+		    rootBox.r_xbot += distance;
 		    break;
 	    }
 	    break;
