@@ -21,11 +21,12 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdCD.c,v 1.5 200
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
 #ifdef SYSV
 #include <string.h>
 #endif
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -46,7 +47,6 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdCD.c,v 1.5 200
 #include "router/rtrDcmpose.h"
 #include "select/select.h"
 #include "utils/malloc.h"
-#include "signals/signals.h"
 #include "cif/CIFint.h"
 
 #ifdef NONMANHATTAN
@@ -107,7 +107,7 @@ int cmdDumpFunc();
 
 #define CALMA_WARN_HELP CIF_WARN_END	/* undefined by CIF module */
 
-	/* ARGSUSED */
+void
 CmdCalma(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -397,7 +397,7 @@ outputCalma:
 
 	/* ARGSUSED */
 
-Void
+void
 CmdCellname(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -513,156 +513,6 @@ badusage:
     return;
 }
 
-#ifdef MAGIC_WRAPPER
-/*
- * ----------------------------------------------------------------------------
- *
- * CmdCellsearch --
- *
- *	This is a low-level search command that allows a hierarchical cell
- *	search to execute a TCL procedure on each cell definition or cell
- *	use found.
- *
- *	Use: cellsearch [instances] <tcl_procedure>
- *
- *	If "instances" is present, then the cell search is over all cell
- *	uses, and <tcl_procedure> takes a list containing 4 integer values
- *	representing the bounding box (llx, lly, urx, ury) of the cell,
- *	and two string values containing the name of the cell use and the
- *	cell definition, respectively.
- *
- *	If "instances" is *not* present, then the cell search is over each
- *	cell definition, and <tcl_procedure> takes one value, which is the
- *	name of the cell.
- *
- * ----------------------------------------------------------------------------
- */
-
-void
-CmdCellsearch(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
-{
-    SearchContext scx;
-    int xMask, windowMask;
-    char *tclproc, *pptr;
-    CellDef *rootBoxDef;
-    MagWindow *window;
-
-    int cmdTclProcSrCellFunc();     /* Fwd declarations */
-    int cmdTclProcCellDefFunc();
-
-    bzero(&scx, sizeof(SearchContext));
-    if (!ToolGetBox (&rootBoxDef, NULL))
-    {
-	TxError ("Box tool must be present\n");
-	return;
-    }
-    window = ToolGetBoxWindow (&scx.scx_area, &windowMask);
-    if (!window)
-    {
-	TxError ("Box tool does not exist in any window\n");
-	return;
-    }
-    xMask = ((DBWclientRec *)window->w_clientData)->dbw_bitmask;
-    if ((windowMask & ~xMask) != 0)
-    {
-	window = CmdGetRootPoint((Point *) NULL, (Rect *) NULL);
-	xMask = ((DBWclientRec *) window->w_clientData)->dbw_bitmask;
-	if ((windowMask & xMask) == 0)
-	{
-	    TxPrintf("The box is in more than one window;  use the cursor\n");
-	    TxPrintf("to select the one you want to select from.\n");
-	    return;
-	}
-    }
-    scx.scx_use = (CellUse *) window->w_surfaceID;
-    scx.scx_trans = GeoIdentityTransform;
-
-    if ((cmd->tx_argc == 1) || (cmd->tx_argc > 3))
-    {
-	TxError("Usage: cellsearch [instances] <tcl_procedure>\n");
-	return;
-    }
-
-    pptr = cmd->tx_argv[cmd->tx_argc - 1];
-    if (*pptr == '{')           /* in-line procedure */
-    {
-	tclproc = StrDup(NULL, pptr + 1);
-	pptr = tclproc + strlen(tclproc) - 1;
-	if (*pptr == '}') *pptr = '\0';
-    }
-    else
-	tclproc = StrDup(NULL, cmd->tx_argv[cmd->tx_argc - 1]);
-
-    if ((cmd->tx_argc == 3) && (!strncmp(cmd->tx_argv[1], "inst", 4)))
-    {
-	DBTreeSrTiles(&scx, xMask, cmdTclProcSrCellFunc,
-		(ClientData) tclproc);
-    }
-    else
-    {
-	DBCellSrDefs(0, cmdTclProcCellDefFunc, (ClientData) tclproc);
-    }
-    freeMagic(tclproc);
-}   
-
-/*
- * cmdTclProcSrCellFunc --
- *  
- * Filter procedure applied to cell instances by cmdCellsearch() above.
- */ 
-  
-int
-cmdTclProcSrCellFunc(scx, tclproc)
-    SearchContext *scx;
-    char *tclproc;
-{
-    Rect rootRect;
-    char evalstr[512];
-    int rval;
-    CellDef *def;
-
-    def = scx->scx_use->cu_def;
-    GeoTransRect(&scx->scx_trans, &def->cd_bbox, &rootRect);
-
-    sprintf(evalstr, "%s %d %d %d %d %s %s", tclproc, rootRect.r_xbot,
-		rootRect.r_ybot, rootRect.r_xtop, rootRect.r_ytop,
-		def->cd_name, scx->scx_use->cu_id);
-
-    rval = Tcl_EvalEx(magicinterp, evalstr, -1, 0);
-    if (rval != TCL_OK) return 1;
-
-    /* Allow interrupts in case something goes wrong with the Tcl procedure */
-    if (SigInterruptPending) return 1;
-    return 0;
-}   
-
-/*
- * cmdTclProcCellDefFunc --
- *  
- * Filter procedure applied to celldefs by cmdCellsearch() above.
- */ 
-  
-int
-cmdTclProcCellDefFunc(def, tclproc)
-    CellDef *def;
-    char *tclproc;
-{
-    char evalstr[512];
-    int rval;
-
-    sprintf(evalstr, "%s %s", tclproc, def->cd_name);
-
-    rval = Tcl_EvalEx(magicinterp, evalstr, -1, 0);
-    if (rval != TCL_OK) return 1;
-
-    /* Allow interrupts in case something goes wrong with the Tcl procedure */
-    if (SigInterruptPending) return 1;
-    return 0;
-}   
-
-#endif
 /*
  * ----------------------------------------------------------------------------
  *
@@ -710,8 +560,7 @@ cmdTclProcCellDefFunc(def, tclproc)
 
 #define CIF_WARN_HELP  CIF_WARN_END	/* undefined by CIF module */
 
-	/* ARGSUSED */
-
+void
 CmdCif(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -725,7 +574,6 @@ CmdCif(w, cmd)
     bool flatCif = FALSE;
     bool dolist = FALSE;
     bool doforall = FALSE;
-    int limit;
     float curscale;
     int argc = cmd->tx_argc;
     char **argv = cmd->tx_argv;
@@ -1149,8 +997,8 @@ CmdCif(w, cmd)
  *
  * ----------------------------------------------------------------------------
  */
-    /* ARGSUSED */
 
+void
 CmdClockwise(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1236,8 +1084,8 @@ CmdClockwise(w, cmd)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 CmdCopy(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1257,15 +1105,15 @@ CmdCopy(w, cmd)
 
     if (cmd->tx_argc > 1)
     {
-	int indx, amountx, amounty;
+	int indx, amount;
 	int xdelta, ydelta;
 
 	if (strcmp(cmd->tx_argv[1], "to") == 0)
 	{
 	    if (cmd->tx_argc != 4)
 		goto badUsage;
-	    editPoint.p_x = cmdParseCoord(w, cmd->tx_argv[2], FALSE,TRUE);
-	    editPoint.p_y = cmdParseCoord(w, cmd->tx_argv[3], FALSE, FALSE);
+	    editPoint.p_x = cmdParseCoord(cmd->tx_argv[2]);
+	    editPoint.p_y = cmdParseCoord(cmd->tx_argv[3]);
 	    GeoTransPoint(&EditToRootTransform, &editPoint, &rootPoint);
 	    goto copyToPoint;
 	}
@@ -1275,65 +1123,43 @@ CmdCopy(w, cmd)
 	    return;
 	if (cmd->tx_argc == 3)
 	{
-	    if (DBWSnapToGrid != DBW_SNAP_USER)
-	    {
-		amountx = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
-		amounty = amountx;
-	    }
-	    else
-	    {
-		switch (indx)
-		{
-		    case GEO_EAST: case GEO_WEST:
-			amountx = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
-			amounty = amountx;
-			break;
-		    case GEO_NORTH: case GEO_SOUTH:
-			amounty = cmdParseCoord(w, cmd->tx_argv[2], TRUE, TRUE);
-			amountx = amounty;
-			break;
-		    default:
-			amountx = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
-			amounty = cmdParseCoord(w, cmd->tx_argv[2], TRUE, TRUE);
-			break;
-		}
-	    }
+	    amount = cmdParseCoord(cmd->tx_argv[2]);
 	}
-	else amountx = amounty = 1;
+	else amount = 1;
 
 	switch (indx)
 	{
 	    case GEO_NORTH:
 		xdelta = 0;
-		ydelta = amounty;
+		ydelta = amount;
 		break;
 	    case GEO_SOUTH:
 		xdelta = 0;
-		ydelta = -amounty;
+		ydelta = -amount;
 		break;
 	    case GEO_EAST:
-		xdelta = amountx;
+		xdelta = amount;
 		ydelta = 0;
 		break;
 	    case GEO_WEST:
-		xdelta = -amountx;
+		xdelta = -amount;
 		ydelta = 0;
 		break;
 	    case GEO_NORTHWEST:
-		xdelta = -amountx;
-		ydelta = amounty;
+		xdelta = -amount;
+		ydelta = amount;
 		break;
 	    case GEO_NORTHEAST:
-		xdelta = amountx;
-		ydelta = amounty;
+		xdelta = amount;
+		ydelta = amount;
 		break;
 	    case GEO_SOUTHWEST:
-		xdelta = -amountx;
-		ydelta = -amounty;
+		xdelta = -amount;
+		ydelta = -amount;
 		break;
 	    case GEO_SOUTHEAST:
-		xdelta = amountx;
-		ydelta = -amounty;
+		xdelta = amount;
+		ydelta = -amount;
 		break;
 	    case GEO_CENTER:
 		xdelta = 0;
@@ -1438,8 +1264,7 @@ typedef struct nmcornerpath
 
 #endif
 
-	/*ARGSUSED*/
-Void
+void
 CmdCorner(w, cmd)
     MagWindow *w;	/* Window in which command was invoked. */
     TxCommand *cmd;	/* Describes the command that was invoked. */
@@ -2328,8 +2153,7 @@ cmdBevelFunc(tile, cxp)
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
+void
 CmdDelete(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -2370,7 +2194,7 @@ CmdDelete(w, cmd)
 
 static bool cmdFoundNewDown;
 
-Void
+void
 CmdDown(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -2435,7 +2259,6 @@ cmdDownEnumFunc(selUse, use, transform, area)
 				 */
 {
     Rect defArea, useArea;
-    int xhi, xlo, yhi, ylo;
 
     /* Save this use as the default next edit cell, regardless of whether
      * or not it overlaps the area we're interested in.
@@ -2493,7 +2316,7 @@ cmdDownEnumFunc(selUse, use, transform, area)
 #define STATISTICS	11
 #define WHY		12
 
-	/* ARGSUSED */
+void
 CmdDrc(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -2562,7 +2385,7 @@ CmdDrc(w, cmd)
 	
 	case SHOWINT:
 	    if (cmd->tx_argc != 3) goto badusage;
-	    radius = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
+	    radius = cmdParseCoord(cmd->tx_argv[2]);
 	    if (radius < 0)
 	    {
 		TxPrintf("Radius must not be negative\n");
@@ -2711,7 +2534,7 @@ CmdDrc(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-	/* ARGSUSED */
+void
 CmdDump(w, cmd)
     MagWindow *w;		/* Window in which command was invoked. */
     TxCommand *cmd;		/* Describes command arguments. */
