@@ -21,8 +21,12 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdE.c,v 1.4 2001
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 
-#include "tcltk/tclmagic.h"
+#ifdef MAGIC_WRAPPER
+#include "magic/tclmagic.h"
+#endif
 #include "misc/magic.h"
 #include "misc/styles.h"
 #include "utils/geometry.h"
@@ -69,9 +73,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdE.c,v 1.4 2001
 
 static bool cmdFoundNewEdit;
 
-	/*ARGSUSED*/
-
-Void
+void
 CmdEdit(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -180,7 +182,6 @@ cmdEditRedisplayFunc(w, area)
  * better is found.
  */
 
-    /* ARGSUSED */
 int
 cmdEditEnumFunc(selUse, use, transform, area)
     CellUse *selUse;		/* Use from selection (not used). */
@@ -260,14 +261,14 @@ cmdEditEnumFunc(selUse, use, transform, area)
 #define OPTION_POSITION	2
 #define OPTION_FLAGS	3
 
-Void
+void
 CmdElement(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
 
     int option, type;
-    char **msg, *text;
+    char **msg;
     Rect area;
     int style;
     CellDef *def;
@@ -399,7 +400,7 @@ CmdElement(w, cmd)
 	    DBWElementDelete(w, cmd->tx_argv[2]);
 	    break;
 	case ELEMENT_CONFIG:
-	    if (cmd->tx_argc < 4)
+	    if (cmd->tx_argc < 3)
 	    {
 		TxError("Usage:  element configure <name> <option...>\n");
 		return;
@@ -583,7 +584,7 @@ badusage:
 static CellUse *cmdEraseCells[MAXCELLS];
 static int cmdEraseCount;
 
-Void
+void
 CmdErase(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -669,7 +670,6 @@ CmdErase(w, cmd)
     DBReComputeBbox(EditCellUse->cu_def);
 }
 
-	/* ARGSUSED */
 int
 cmdEraseCellsFunc(scx, cdarg)
 SearchContext *scx;		/* Indicates cell found. */
@@ -708,7 +708,7 @@ ClientData cdarg;		/* Not used. */
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 CmdExpand(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -813,8 +813,7 @@ cmdExpandFunc(use, windowMask)
 #define	LENDRIVER	1
 #define	LENRECEIVER	2
 
-	/* ARGSUSED */
-Void
+void
 CmdExtract(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
