@@ -21,6 +21,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdFI.c,v 1.4 200
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 
 #ifdef USE_READLINE
@@ -33,7 +34,9 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdFI.c,v 1.4 200
 #endif
 #endif
 
-#include "tcltk/tclmagic.h"
+#ifdef MAGIC_WRAPPER
+#include "magic/tclmagic.h"
+#endif
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
@@ -97,9 +100,7 @@ struct cmdFillArea
 #define SAVE		5
 #define WHY		6
 
-	/* ARGSUSED */
-
-Void
+void
 CmdFeedback(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -314,7 +315,7 @@ int cmdFillDir;				/* Direction in which to fill. */
 Rect cmdFillRootBox;			/* Root coords of box. */
 struct cmdFillArea *cmdFillList;	/* List of areas to fill. */
 
-Void
+void
 CmdFill(w, cmd)
     MagWindow *w;		/* Window in which command was invoked. */
     TxCommand *cmd;	/* Describes the command that was invoked. */
@@ -467,7 +468,7 @@ cmdFillFunc(tile, cxp)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 CmdFindBox(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -547,45 +548,40 @@ usage:
  * Find a label and set the box to it.
  *
  * Usage:
- *	findlabel [-glob] name
+ *	findlabel name
  *
  * Results:
- *	None.  In TCL, the -glob option will generate a list of matching
- *	nodes returned in the interpreter result.
+ *	None.
  *
  * Side effects:
- *	The box may be moved.  If "-glob" is used, in the non-Tcl version,
- *	matching label names are  printed. 
+ *	The box may be moved.
  *
  * ----------------------------------------------------------------------------
  */
 
+Rect cmdFindLabelRect;
+
 int cmdFindLabelFunc(rect, name, label, cdarg) 
     Rect *rect;
     char *name;
     Label *label;
-    Rect *cdarg;
+    ClientData cdarg;
 {
-    *cdarg = *rect;
+    cmdFindLabelRect = *rect;
     return 1;
 }
 
-Void
+void
 CmdFindLabel(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
     CellDef *boxDef;
-    Rect box, cmdFindLabelRect;
+    Rect box;
     char *labname;
     int found;
-    bool doglob = FALSE;   /* csh-style glob matching (see utils/match.c) */
-    int dbListLabels();	   /* forward declaration */
 
-    if ((cmd->tx_argc == 3) && !strncmp(cmd->tx_argv[1], "-glob", 5))
-	doglob = TRUE;
-    else if (cmd->tx_argc > 2)
-	goto usage;
+    if (cmd->tx_argc != 2) goto usage;
 
     if (w == NULL)
     {
@@ -606,84 +602,25 @@ CmdFindLabel(w, cmd)
 	return;
     };
 
-    if (cmd->tx_argc == 1)
-    {
-	/* Find all labels in the current edit cell under the	*/
-	/* box and print or return a list			*/
-	Label *slab;
-	for (slab = boxDef->cd_labels; slab; slab = slab->lab_next)
-	{
-	    if (GEO_OVERLAP(&slab->lab_rect, &box))
-#ifdef MAGIC_WRAPPER
-		Tcl_AppendElement(magicinterp, slab->lab_text);
-#else
-		TxPrintf("%s\n", slab->lab_text);
-#endif
-	}
-	return;
+    labname = cmd->tx_argv[1];
+    found = DBSrLabelLoc(EditCellUse, labname, cmdFindLabelFunc, (ClientData) 0);
+    if (found) {
+	if (cmdFindLabelRect.r_xbot == cmdFindLabelRect.r_xtop) 
+	    cmdFindLabelRect.r_xtop++;
+	if (cmdFindLabelRect.r_ybot == cmdFindLabelRect.r_ytop) 
+	    cmdFindLabelRect.r_ytop++;
+	ToolMoveBox(TOOL_BL,&cmdFindLabelRect.r_ll,FALSE,EditCellUse->cu_def);
+	ToolMoveCorner(TOOL_TR,&cmdFindLabelRect.r_ur,FALSE,EditCellUse->cu_def);
+    } else {
+	TxError("Couldn't find label %s\n", labname);
     }
 
-    labname = (cmd->tx_argc == 3) ? cmd->tx_argv[2] : cmd->tx_argv[1];
-
-    if (doglob)
-    {
-	/* Pattern-matching label search */
-
-	SearchContext scx;
-
-	scx.scx_use  = EditCellUse;
-	scx.scx_area = EditCellUse->cu_def->cd_bbox;
-	scx.scx_trans = GeoIdentityTransform;
-
-	DBSearchLabel(&scx, &DBAllButSpaceAndDRCBits, 0, labname,
-		dbListLabels, (ClientData) 0);
-    }
-    else
-    {
-	/* Exact-match label search */
-
-	found = DBSrLabelLoc(EditCellUse, labname, cmdFindLabelFunc,
-			(ClientData) &cmdFindLabelRect);
-	if (found) {
-	    if (cmdFindLabelRect.r_xbot == cmdFindLabelRect.r_xtop) 
-		cmdFindLabelRect.r_xtop++;
-	    if (cmdFindLabelRect.r_ybot == cmdFindLabelRect.r_ytop) 
-		cmdFindLabelRect.r_ytop++;
-	    ToolMoveBox(TOOL_BL,&cmdFindLabelRect.r_ll,FALSE,EditCellUse->cu_def);
-	    ToolMoveCorner(TOOL_TR,&cmdFindLabelRect.r_ur,FALSE,EditCellUse->cu_def);
-	} else
-	    TxError("Couldn't find label %s\n", labname);
-    }
     return;
 
+
 usage:
-    TxError("Usage: findlabel [-glob] label_name\n");
+    TxError("Usage: findlabel label_name\n");
 }
-
-/*
- * Callback routine for listing pattern-matched labels
- * Always return zero to keep the search going.
- */
-
-int
-dbListLabels(scx, label, tpath, cdarg)
-    SearchContext *scx;
-    Label *label;			/* Pointer to label structure	*/
-    TerminalPath *tpath;		/* Full pathname of terminal	*/
-    ClientData cdarg;			/* (unused)			*/
-{
-    char *n = tpath->tp_next;
-    char c = *n;
-    strcpy(n, label->lab_text);
-#ifdef MAGIC_WRAPPER
-    Tcl_AppendElement(magicinterp, tpath->tp_first);
-#else
-    TxPrintf("%s\n", tpath->tp_first);
-#endif
-    *n = c;
-    return 0;
-}
-
 
 /*
  * ----------------------------------------------------------------------------
@@ -707,9 +644,8 @@ dbListLabels(scx, label, tpath, cdarg)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
-Void
+void
 CmdFlush(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -778,7 +714,7 @@ CmdFlush(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-	/* ARGSUSED */
+void
 CmdGetcell(w, cmd)
     MagWindow *w;			/* Window in which command was invoked. */
     TxCommand *cmd;		/* Describes command arguments. */
@@ -842,9 +778,10 @@ CmdGetcell(w, cmd)
  *
  * Usage:
  *  	getnode
- *	getnode abort [string]
- *      getnode alias [on | off]
- *      getnode globals [on | off]
+ *	getnode abort
+ *	getnode abort string
+ *      getnode alias on
+ *      getnode alias off
  *      getnode fast
  *
  * Results:
@@ -854,7 +791,8 @@ CmdGetcell(w, cmd)
  *	The GetNode hash tables may be modified.
  * ----------------------------------------------------------------------------
  */
-Void
+
+void
 CmdGetnode(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -883,17 +821,7 @@ CmdGetnode(w, cmd)
 		is_fast = TRUE;
 	    }
 	    else {
-		if (!strcmp("alias", cmd->tx_argv[1])) {
-		    TxPrintf("Aliases %s\n", (SimGetnodeAlias) ?  "on" : "off");
-		    return;
-		}
-		else if (strncmp("global", cmd->tx_argv[1], 6) == 0) {
-		    TxPrintf("Node names ending in ! are %s\n",
-				(SimIgnoreGlobals) ? "local (off)" : "global (on)");
-		    return;
-		}
-		else
-		    goto badusage;
+		goto badusage;
 	    }
 	    break;
 
@@ -916,18 +844,6 @@ CmdGetnode(w, cmd)
 		else
 		    goto badusage;
 	    }
-	    else if (strncmp("global", cmd->tx_argv[1], 6) == 0) {
-		if (strcmp("off", cmd->tx_argv[2]) == 0) {
-		    SimIgnoreGlobals = TRUE;
-		    return;
-		}
-		else if (strcmp("on", cmd->tx_argv[2]) == 0) {
-		    SimIgnoreGlobals = FALSE;
-		    return;
-		}
-		else
-		    goto badusage;
-            }
 	    else if (strcmp("abort", cmd->tx_argv[1]) == 0) {
 		if (SimInitGetnode) {
 		    HashInit(&SimGetnodeTbl, TBLSIZE, STRINGS);
@@ -969,8 +885,8 @@ CmdGetnode(w, cmd)
 
 badusage:
     TxError("Usage: getnode [abort [str]]\n");
-    TxError("   or: getnode alias [on | off]\n");
-    TxError("   or: getnode globals [on | off]\n");
+    TxError("   or: getnode alias on\n");
+    TxError("   or: getnode alias off\n");
     TxError("   or: getnode fast\n");
 }
 #endif
@@ -996,7 +912,7 @@ badusage:
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 CmdGrid(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1021,7 +937,7 @@ CmdGrid(w, cmd)
 	crec->dbw_flags &= ~DBW_GRID;
     else if (cmd->tx_argc >= 2)
     {
-	xSpacing = cmdParseCoord(w, cmd->tx_argv[1], TRUE, TRUE);
+	xSpacing = cmdParseCoord(cmd->tx_argv[1]);
 	if (xSpacing <= 0)
 	{
 	    TxError("Grid spacing must be greater than zero.\n");
@@ -1032,7 +948,7 @@ CmdGrid(w, cmd)
 
 	if (cmd->tx_argc >= 3)
 	{
-	    ySpacing = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
+	    ySpacing = cmdParseCoord(cmd->tx_argv[2]);
 	    if (ySpacing <= 0)
 	    {
 		TxError("Grid spacing must be greater than zero.\n");
@@ -1041,8 +957,8 @@ CmdGrid(w, cmd)
 
 	    if (cmd->tx_argc == 5)
 	    {
-		xOrig = cmdParseCoord(w, cmd->tx_argv[3], FALSE, TRUE);
-		yOrig = cmdParseCoord(w, cmd->tx_argv[4], FALSE, FALSE);
+		xOrig = cmdParseCoord(cmd->tx_argv[3]);
+		yOrig = cmdParseCoord(cmd->tx_argv[4]);
 	    }
 	}
 
@@ -1057,7 +973,7 @@ CmdGrid(w, cmd)
 }
 
 #ifdef USE_READLINE
-Void
+void
 CmdHistory(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1137,9 +1053,8 @@ CmdHistory(w, cmd)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
-Void
+void
 CmdIdentify(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1209,33 +1124,16 @@ cmdIdFunc(selUse, use, transform, newId)
  * Implements goto command
  *
  * Usage:
- *	goto nodename [-nocomplain]
+ *	goto nodename
  *
  * Results:
- *	None.  In TCL version, returns the material type
- *	of the node, so that the node can be uniquely determined
- *	by an automated script.	  If the node cannot be found, a
- *	null list is returned.
+ *	changes box location.
  *
- * Side Effects:
- *	changes box location.  Prints an error message if the node
- *	cannot be found, unless switch "-nocomplain" is set.
- *
- * Notes:
- *	Due to the way global node names are handled, "getnode" and
- *	"goto" are not necessarily reversible if "getnode globals on"
- *	is set!  In this case, use the glob option for findlabel
- *	to determine any valid local label belonging to the global
- *	node (a node cannot be global unless it is labeled).  This
- *	method, although awkward, can be much faster for large layouts
- *	due to the time required for "getnode" to uniquely determine
- *	the name of a large network such as power or ground.
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
-Void
+void
 CmdGoto(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1247,12 +1145,10 @@ CmdGoto(w, cmd)
     Transform		trans, newtrans, tmp;
     Label		*label;
     Rect		localrect, rect;
-    Point		pt;
     CellDef		*rootdef;
-    int			pnum, xpos, ypos, locargc;
+    int			pnum, xpos, ypos;
     char 		*xstr, *ystr;
     bool		locvalid;
-    bool		nocomplain = FALSE;
     TileType		ttype;
      
     windCheckOnlyWindow(&w, DBWclientID);
@@ -1264,19 +1160,9 @@ CmdGoto(w, cmd)
     scx.scx_use = (CellUse  *) w->w_surfaceID;
     rootdef = scx.scx_use->cu_def;
     scx.scx_trans = GeoIdentityTransform;
-
-    locargc = cmd->tx_argc;
-    if (locargc == 3)
+    if (cmd->tx_argc != 2)
     {
-	if (!strncmp(cmd->tx_argv[2], "-nocom", 5))
-	{
-	    nocomplain = TRUE;
-	    locargc--;
-	}
-    }
-    if (locargc != 2)
-    {
-     	TxError("usage: goto nodename [-nocomplain]\n");
+     	TxError("usage: goto nodename\n");
 	return;
     }
     s = nodename;
@@ -1285,16 +1171,16 @@ CmdGoto(w, cmd)
     while (s2 = strchr(s,'/'))
     {
      	*s2 = '\0';
-	DBTreeFindUse(s, scx.scx_use, &scx2);
+	DBTreeFindUse(s,scx.scx_use,&scx2);
 	use = scx2.scx_use;
 	if (use == NULL)
 	{
 	    TxError("Couldn't find use %s\n",s);
 	    return;
 	}
-	GeoTransTrans(DBGetArrayTransform(use, scx2.scx_x, scx2.scx_y),
-	  		&use->cu_transform, &tmp);
-	GeoTransTrans(&tmp, &trans, &newtrans);
+	GeoTransTrans(DBGetArrayTransform(use,scx2.scx_x,scx2.scx_y)
+	  		,&use->cu_transform,&tmp);
+	GeoTransTrans(&tmp,&trans,&newtrans);
 	trans = newtrans;
 	scx = scx2;
         *s2 = '/';
@@ -1362,10 +1248,10 @@ CmdGoto(w, cmd)
     /* coordinates that is no longer generated by magic.  It is kept	*/
     /* here for backward compatibility.					*/
 
-    if ((locvalid == FALSE) && (sscanf(s, "%d_%d_%d", &pnum, &xpos, &ypos) == 3))
+    if ((locvalid == FALSE) && (sscanf(s,"%d_%d_%d",&pnum,&xpos,&ypos) == 3))
     {
-	xpos = ((xpos & 0x1) ? -1 : 1) * xpos / 2;
-	ypos = ((ypos & 0x1) ? -1 : 1) * ypos / 2;
+	xpos = ((xpos & 0x1)?-1:1)*xpos/2;
+	ypos = ((ypos & 0x1)?-1:1)*ypos/2;
 	localrect.r_xbot = xpos;
 	localrect.r_ybot = ypos;
 	localrect.r_xtop = xpos + 1;
@@ -1388,9 +1274,9 @@ CmdGoto(w, cmd)
     }
     else
     {
-	for (label = scx.scx_use->cu_def->cd_labels; label; label = label->lab_next)
+	for (label = scx.scx_use->cu_def->cd_labels;label;label=label->lab_next)
 	{
-	    if (strcmp(label->lab_text, s) == 0) break;
+	    if (strcmp(label->lab_text,s) == 0) break;
 	}
 	if (label)
 	{
@@ -1399,8 +1285,7 @@ CmdGoto(w, cmd)
 	}
 	else
 	{
-	    if (!nocomplain)
-		TxError("Couldn't find label %s\n",s);
+     	    TxError("Couldn't find label %s\n",s);
 	    return;
 	}
     }
@@ -1431,17 +1316,7 @@ findTile(tile, rtype)
 {
     TileType ttype;
 
-#ifdef NONMANHATTAN
-    if (IsSplit(tile))  
-    {   
-	if (SplitSide(tile))
-	    ttype = SplitRightType(tile);
-	else
-	    ttype = SplitLeftType(tile);
-    }
-    else
-#endif  
-	ttype = TiGetTypeExact(tile);
+    ttype = TiGetTypeExact(tile);
     *rtype = ttype;
     return 1;			/* stop search */
 }
@@ -1463,9 +1338,8 @@ findTile(tile, rtype)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
-Void
+void
 CmdFlatten(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1531,8 +1405,8 @@ FlatCopyAllLabels(scx, mask, xMask, targetUse)
     /*ARGSUSED*/
 int
 flatCopyAllLabels(scx, lab, tpath, targetUse)
-    register SearchContext *scx;
-    register Label *lab;
+    SearchContext *scx;
+    Label *lab;
     TerminalPath *tpath;
     CellUse	*targetUse;
 {
