@@ -21,12 +21,13 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdLQ.c,v 1.11 20
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
 #ifdef SYSV
 #include <string.h>
 #endif
 #include <ctype.h>
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
@@ -140,9 +141,7 @@ CmdLabelProc(text, pos, type)
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
-Void
+void
 CmdLabel(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -221,7 +220,7 @@ CmdLabel(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 CmdLoad(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -244,7 +243,7 @@ CmdLoad(w, cmd)
 	    n = atoi(cmd->tx_argv[3]);
  	    if (cmd->tx_argc == 5 && StrIsInt(cmd->tx_argv[4]))
 	        d = atoi(cmd->tx_argv[4]);
-	    else if (cmd->tx_argc != 4)
+	    else
 	    {
 		TxError("Usage: %s name scaled n [d]\n", cmd->tx_argv[0]);
 		return;
@@ -268,9 +267,9 @@ CmdLoad(w, cmd)
 
 	if ((n > 1) || (d > 1))
 	{
-	    /* We don't want to save and restore DBLambda, because	*/
-	    /* loading the file may change their values.  Instead, we	*/
-	    /* invert the scaling factor and reapply.			*/
+	    /* We don't want to save and restore DBLambda, because      */
+	    /* loading the file may change their values.  Instead, we   */
+	    /* invert the scaling factor and reapply.                   */
 
 	    DBLambda[0] *= n;
 	    DBLambda[1] *= d;
@@ -300,9 +299,7 @@ CmdLoad(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
-Void
+void
 CmdMove(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -322,15 +319,15 @@ CmdMove(w, cmd)
 
     if (cmd->tx_argc > 1)
     {
-	int indx, amountx, amounty;
+	int indx, amount;
 	int xdelta, ydelta;
 
 	if (strcmp(cmd->tx_argv[1], "to") == 0)
 	{
 	    if (cmd->tx_argc != 4)
 		goto badUsage;
-	    editPoint.p_x = cmdParseCoord(w, cmd->tx_argv[2], FALSE, TRUE);
-	    editPoint.p_y = cmdParseCoord(w, cmd->tx_argv[3], FALSE, TRUE);
+	    editPoint.p_x = cmdParseCoord(cmd->tx_argv[2]);
+	    editPoint.p_y = cmdParseCoord(cmd->tx_argv[3]);
 	    GeoTransPoint(&EditToRootTransform, &editPoint, &rootPoint);
 	    goto moveToPoint;
 	}
@@ -340,64 +337,43 @@ CmdMove(w, cmd)
 	    return;
 	if (cmd->tx_argc == 3)
 	{
-	    if (DBWSnapToGrid != DBW_SNAP_USER)
-	    {
-		amountx = amounty = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
-	    }
-	    else
-	    {
-		switch (indx) 
-		{
-		    case GEO_EAST: case GEO_WEST:
-			amountx = cmdParseCoord(w, cmd->tx_argv[2], TRUE, TRUE);
-			amounty = amountx;
-			break;
-		    case GEO_NORTH: case GEO_SOUTH:
-			amounty = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
-			amountx = amounty;
-			break;
-		    default:
-			amountx = cmdParseCoord(w, cmd->tx_argv[2], TRUE, TRUE);
-			amounty = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
-			break;
-		}
-	    }
-        }
-        else amountx = amounty = 1;
+	    amount = cmdParseCoord(cmd->tx_argv[2]);
+	}
+	else amount = 1;
 
 	switch (indx)
 	{
 	    case GEO_NORTH:
 		xdelta = 0;
-		ydelta = amounty;
+		ydelta = amount;
 		break;
 	    case GEO_SOUTH:
 		xdelta = 0;
-		ydelta = -amounty;
+		ydelta = -amount;
 		break;
 	    case GEO_EAST:
-		xdelta = amountx;
+		xdelta = amount;
 		ydelta = 0;
 		break;
 	    case GEO_WEST:
-		xdelta = -amountx;
+		xdelta = -amount;
 		ydelta = 0;
 		break;
 	    case GEO_NORTHEAST:
-		xdelta = amountx;
-		ydelta = amounty;
+		xdelta = amount;
+		ydelta = amount;
 		break;
 	    case GEO_NORTHWEST:
-		xdelta = -amountx;
-		ydelta = amounty;
+		xdelta = -amount;
+		ydelta = amount;
 		break;
 	    case GEO_SOUTHEAST:
-		xdelta = amountx;
-		ydelta = -amounty;
+		xdelta = amount;
+		ydelta = -amount;
 		break;
 	    case GEO_SOUTHWEST:
-		xdelta = -amountx;
-		ydelta = -amounty;
+		xdelta = -amount;
+		ydelta = -amount;
 		break;
 	    default:
 		ASSERT(FALSE, "Bad direction in CmdMove");
@@ -475,9 +451,7 @@ moveToPoint:
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
-Void
+void
 CmdPaint(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -540,7 +514,7 @@ CmdPaint(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 CmdPaintButton(w, butPoint)
     MagWindow *w;
     Point *butPoint;	/* Screen location at which button was raised */
@@ -618,15 +592,12 @@ CmdPaintButton(w, butPoint)
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
 #define PATHSEARCH	0
 #define PATHCELL	1
 #define PATHSYSTEM	2
 #define PATHHELP	3
 
-
-int
+void
 CmdPath(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -651,7 +622,7 @@ CmdPath(w, cmd)
 	TxPrintf("Search path for cells is \"%s\"\n", Path);
 	TxPrintf("Cell library search path is \"%s\"\n", CellLibPath);
 	TxPrintf("System search path is \"%s\"\n", SysLibPath);
-	return 0;
+	return;
     }
     option = Lookup(cmd->tx_argv[1], cmdPathOption);
     if (option == -1)
@@ -673,7 +644,7 @@ CmdPath(w, cmd)
 #else
 		TxPrintf("Search path for cells is \"%s\"\n", Path);
 #endif
-		return 0;
+		return;
 	    }
 	    else
 	        srcptr = cmd->tx_argv[2];
@@ -687,7 +658,7 @@ CmdPath(w, cmd)
 #else
 		TxPrintf("Cell library search path is \"%s\"\n", CellLibPath);
 #endif
-		return 0;
+		return;
 	    }
 	    else
 	        srcptr = cmd->tx_argv[2];
@@ -701,7 +672,7 @@ CmdPath(w, cmd)
 #else
 		TxPrintf("System search path is \"%s\"\n", SysLibPath);
 #endif
-		return 0;
+		return;
 	    }
 	    else
 	        srcptr = cmd->tx_argv[2];
@@ -725,11 +696,10 @@ CmdPath(w, cmd)
     {
 	(void) StrDup(pathptr, srcptr);
     }
-    return 0;
+    return;
 	
 usage:
     TxError("Usage: %s [search|cell|sys] [[+]path]\n", cmd->tx_argv[0]);
-    return 0;
 }
 
 /*
@@ -781,20 +751,18 @@ usage:
 #define PORT_REMOVE	6
 #define PORT_HELP	7
 
-    /* ARGSUSED */
-
-Void
+void
 CmdPort(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
     char **msg;
-    int posmask, posstart;
+    int posstart;
     int i, idx, pos, type, option;
     unsigned short dirmask;
     bool found;
     Label *lab, *sl;
-    Rect r, editBox;
+    Rect editBox;
     CellDef *editDef = EditCellUse->cu_def;
 
     static char *cmdPortOption[] =
@@ -1220,7 +1188,7 @@ parsepositions:
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 CmdProperty(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
