@@ -27,7 +27,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdRS.c,v 1.8 200
 #include <string.h>
 #endif
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/stack.h"
 #include "utils/geometry.h"
@@ -48,7 +48,6 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdRS.c,v 1.8 200
 #include "netlist/netlist.h"
 #include "netmenu/netmenu.h"
 #include "select/select.h"
-#include "signals/signals.h"
 #include "sim/sim.h"
 
 extern void DisplayWindow();
@@ -71,7 +70,7 @@ extern void DisplayWindow();
  * ----------------------------------------------------------------------------
  */
   
-
+void
 CmdRsim(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -124,8 +123,7 @@ CmdRsim(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
+void
 CmdSave(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -180,6 +178,7 @@ CmdSave(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
+void
 CmdScaleGrid(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -243,6 +242,12 @@ CmdScaleGrid(w, cmd)
 
 	WireTechScale(scalen, scaled);
 
+	/* Scale LEF parameters */
+
+#ifdef LEF_MODULE
+	LefTechScale(scalen, scaled);
+#endif
+
 	/* Scale router parameters */
 
 #ifdef ROUTE_MODULE
@@ -293,134 +298,6 @@ scalegridusage:
     return;
 }
 
-#ifdef MAGIC_WRAPPER
-/*     
- * ----------------------------------------------------------------------------
- * 
- * CmdSearch --
- *
- *	This is a low-level search command that allows a hierarchical tile
- *	search to execute a TCL procedure on each tile found.
- *
- *	Use: search [layers] <tcl_procedure>
- *
- *	<tcl_procedure> takes 4 integer arguments representing the bounding
- *	box (llx, lly, urx, ury) of the tile, and a 5th argument which is
- *	either a string containing the type name of the tile, or a list of
- *	two layers in the case of a split tile, representing LEFT and RIGHT
- *	types, respectively.
- *
- * ----------------------------------------------------------------------------
- */
-CmdSearch(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
-{
-    SearchContext scx;
-    TileTypeBitMask visitMask;
-    int xMask, windowMask;
-    char *tclproc, *pptr;
-    int cmdTclProcSrFunc();     /* Fwd declaration */
-    CellDef *rootBoxDef;
-    MagWindow *window;
-
-    bzero(&scx, sizeof(SearchContext));
-    if (!ToolGetBox (&rootBoxDef, NULL))
-    {
-	TxError ("Box tool must be present\n");
-	return 0;
-    }
-    window = ToolGetBoxWindow (&scx.scx_area, &windowMask);
-    if (!window)
-    {
-	TxError ("Box tool does not exist in any window\n");
-	return 0;
-    }
-    xMask = ((DBWclientRec *)window->w_clientData)->dbw_bitmask;
-    if ((windowMask & ~xMask) != 0)
-    {
-	window = CmdGetRootPoint((Point *) NULL, (Rect *) NULL);
-	xMask = ((DBWclientRec *) window->w_clientData)->dbw_bitmask;
-	if ((windowMask & xMask) == 0)
-	{
-	    TxPrintf("The box is in more than one window;  use the cursor\n");
-	    TxPrintf("to select the one you want to select from.\n");
-	    return;
-	}
-    }
-    scx.scx_use = (CellUse *) window->w_surfaceID;
-    scx.scx_trans = GeoIdentityTransform;
-    
-    if ((cmd->tx_argc == 1) || (cmd->tx_argc > 3))
-    {
-	TxError("Usage: search [layers] <tcl_procedure>\n");
-	return 0;
-    }
-    
-    if (cmd->tx_argc == 3)
-    {
-	if (!CmdParseLayers(cmd->tx_argv[1], &visitMask))
-	    return;
-    }
-    else visitMask = DBAllButSpaceAndDRCBits;
-    pptr = cmd->tx_argv[cmd->tx_argc - 1];
-    if (*pptr == '{')           /* in-line procedure */
-    {
-	tclproc = StrDup(NULL, pptr + 1);
-	pptr = tclproc + strlen(tclproc) - 1;
-	if (*pptr == '}') *pptr = '\0';
-    }
-    else
-	tclproc = StrDup(NULL, cmd->tx_argv[cmd->tx_argc - 1]);
-
-    (void) DBTreeSrTiles(&scx, &visitMask, xMask,
-		cmdTclProcSrFunc, (ClientData) tclproc);
-   
-    freeMagic(tclproc);
-}   
-
-/*
- * cmdTclProcSrFunc --
- *  
- * Filter procedure applied to tiles by cmdSearch() above.
- */ 
-  
-int
-cmdTclProcSrFunc(tile, cxp)
-    Tile *tile;
-    TreeContext *cxp;
-{   
-    Rect tileRect, rootRect;
-    SearchContext *scx = cxp->tc_scx;
-    char *tclproc = (char *)cxp->tc_filter->tf_arg;
-    char evalstr[512], *eptr;
-    int rval;
-    
-    TiToRect(tile, &tileRect);
-    GeoTransRect(&scx->scx_trans, &tileRect, &rootRect);
-    if (GEO_OVERLAP((&tileRect), &cxp->tc_scx->scx_area))
-    {
-	sprintf(evalstr, "%s %d %d %d %d ", tclproc, rootRect.r_xbot,
-		rootRect.r_ybot, rootRect.r_xtop, rootRect.r_ytop);
-	eptr = evalstr + strlen(evalstr);
-#ifdef NONMANHATTAN
-	if (IsSplit(tile))
-	    sprintf(eptr, "{%s %s}\n", DBTypeLongNameTbl[SplitLeftType(tile)],
-			DBTypeLongNameTbl[SplitRightType(tile)]);
-	else
-#endif
-	    sprintf(eptr, "%s\n", DBTypeLongNameTbl[TiGetType(tile)]);
-
-	rval = Tcl_EvalEx(magicinterp, evalstr, -1, 0);
-	if (rval != TCL_OK) return 1;
-    }
-    /* Allow interrupts in case something goes wrong with the Tcl procedure */
-    if (SigInterruptPending) return 1;
-    return 0;
-}   
-
-#endif
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -444,8 +321,7 @@ cmdTclProcSrFunc(tile, cxp)
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
+void
 CmdSee(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -715,8 +591,8 @@ cmdSelectVisible(layers, less)
  *
  * ----------------------------------------------------------------------------
  */
-    /* ARGSUSED */
-int
+
+void
 CmdSelect(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -827,7 +703,7 @@ CmdSelect(w, cmd)
     if ((w == (MagWindow *) NULL) || (w->w_client != DBWclientID))
     {
 	TxError("Put the cursor in a layout window\n");
-	return 0;
+	return;
     }
 
     /* See if "more" was given.  If so, just strip off the "more" from
@@ -908,13 +784,13 @@ CmdSelect(w, cmd)
 		usageError:
 		TxError("Bad arguments:\n    select %s\n",
 			cmdSelectMsg[option+1]);
-		return 0;
+		return;
 	    }
 	    if (!(more || less)) SelectClear();
 	    if (cmd->tx_argc == 3)
 		cmdSelectArea(optionArgs[1], less);
 	    else cmdSelectArea("*,label,subcell", less);
-	    return 0;
+	    return;
 	
 	/*--------------------------------------------------------------------
 	 * Select everything under the box, perhaps looking only at
@@ -928,7 +804,7 @@ CmdSelect(w, cmd)
 	    if (cmd->tx_argc == 3)
 		cmdSelectVisible(optionArgs[1], less);
 	    else cmdSelectVisible("*,label,subcell", less);
-	    return 0;
+	    return;
 	
 	/*--------------------------------------------------------------------
 	 * Clear out all of the material in the selection.
@@ -938,7 +814,7 @@ CmdSelect(w, cmd)
 	case SCLEAR:
 	    if ((more) || (less) || (cmd->tx_argc > 2)) goto usageError;
 	    SelectClear();
-	    return 0;
+	    return;
 	
 	/*--------------------------------------------------------------------
 	 * Print out help information.
@@ -949,7 +825,7 @@ CmdSelect(w, cmd)
 	    TxPrintf("Selection commands are:\n");
 	    for (msg = &(cmdSelectMsg[0]); *msg != NULL; msg++)
 		TxPrintf("    select %s\n", *msg);
-	    return 0;
+	    return;
 
 	/*--------------------------------------------------------------------
 	 * Save the selection as a new Magic cell on disk.
@@ -972,7 +848,7 @@ CmdSelect(w, cmd)
 
 	    DBUpdateStamps();
 	    cmdSaveCell(SelectDef, cmd->tx_argv[2], FALSE, FALSE);
-	    return 0;
+	    return;
 	
 	case SBOX: case CHUNK: case REGION: case NET:
 	    if (cmd->tx_argc > 3) goto usageError;
@@ -1010,7 +886,7 @@ Okay:
 
 		if (!ToolGetBox (&rootBoxDef, NULL)) {
 		    TxError ("Box tool must be present\n");
-		    return 0;
+		    return;
 		}
 		window = ToolGetBoxWindow (&scx.scx_area, &windowMask);
 		if (!window)
@@ -1022,7 +898,7 @@ Okay:
 		    if (windowMask & xMask == 0) {
 			TxError("Box present in multiple windows; use the"
 				"cursor\nto select the one you want\n");
-			return 0;
+			return;
 		    }
 		}
 		scx.scx_area.r_xtop = scx.scx_area.r_xbot + 1;
@@ -1032,7 +908,7 @@ Okay:
 	    {
 	        window = CmdGetRootPoint((Point *) NULL, &scx.scx_area);
 	    }
-	    if (window == NULL) return 0;
+	    if (window == NULL) return;
 	    scx.scx_use = (CellUse *) window->w_surfaceID;
 	    scx.scx_trans = GeoIdentityTransform;
 	    crec = (DBWclientRec *) window->w_clientData;
@@ -1079,7 +955,7 @@ Okay:
 		    else
 		    {
 			TxError ("Invalid layer specification\n");
-			return 0;
+			return;
 		    }
 
 		    TTMaskAndMask (&mask, &uMask);
@@ -1087,7 +963,7 @@ Okay:
 		    if (TTMaskIsZero (&mask))
 		    {
 			TxError ("No paint of this type under the cursor/box\n");
-			return 0;
+			return;
 		    }
 		}
 
@@ -1153,7 +1029,7 @@ Okay:
 		}
 		if (level == NET)
 		    SelectNet(&scx, type, crec->dbw_bitmask, (Rect *) NULL, less);
-		return 0;
+		return;
 	    }
 
 	/*--------------------------------------------------------------------
@@ -1175,7 +1051,7 @@ Okay:
 		{
 		    TxError ("Invalid layer specification\n");
 		}
-		return 0;
+		return;
 	    }
 
 	    if (cmd->tx_argc > 3) goto usageError;
@@ -1204,7 +1080,7 @@ Okay:
 		{
 		    TxError("Couldn't find a cell use named \"%s\"\n",
 			    optionArgs[1]);
-		    return 0;
+		    return;
 		}
 		trans = scx2.scx_trans;
 		p.p_x = scx2.scx_x;
@@ -1276,7 +1152,7 @@ Okay:
 	    TxPrintf("Selected cell is %s (%s)\n", use->cu_def->cd_name,
 		    printPath);
 #endif
-	    return 0;
+	    return;
     }
 }
 
@@ -1300,8 +1176,7 @@ Okay:
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
+void
 CmdSideways(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1362,6 +1237,7 @@ CmdSideways(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
+void
 CmdShell(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1406,9 +1282,10 @@ CmdShell(w, cmd)
  */
 
 #ifdef	LLNL
-Void (*CmdStretchCmd)() = NULL;
+int (*CmdStretchCmd)() = NULL;
     /* ARGSUSED */
 
+void
 CmdSgraph(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1443,6 +1320,7 @@ CmdSgraph(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
+void
 CmdStartRsim(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1489,6 +1367,7 @@ CmdStartRsim(w, cmd)
  * ---------------------------------------------------------------------------- 
  */
 
+void
 CmdSimCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1567,6 +1446,7 @@ CmdSimCmd(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
+void
 CmdSnap(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1619,6 +1499,7 @@ printit:
  * ----------------------------------------------------------------------------
  */
 
+void
 CmdSplit(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1710,6 +1591,7 @@ CmdSplit(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
+void
 CmdSplitErase(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1800,9 +1682,7 @@ CmdSplitErase(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
-Void
+void
 CmdStretch(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1814,78 +1694,54 @@ CmdStretch(w, cmd)
 
     if (cmd->tx_argc > 3)
     {
-	badUsage:
 	TxError("Usage: %s [direction [amount]]\n", cmd->tx_argv[0]);
 	return;
     }
 
     if (cmd->tx_argc > 1)
     {
-	int indx, amountx, amounty;
+	int indx, amount;
 
 	indx = GeoNameToPos(cmd->tx_argv[1], FALSE, TRUE);
 	if (indx < 0)
 	    return;
 	if (cmd->tx_argc == 3)
-	{
-	    if (DBWSnapToGrid != DBW_SNAP_USER)
-	    {
-		amountx = amounty = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
-	    }
-	    else
-	    {
-		switch (indx)
-		{  
-		    case GEO_EAST: case GEO_WEST:
-			amountx = cmdParseCoord(w, cmd->tx_argv[2], TRUE, TRUE);
-			amounty = amountx;
-			break;
-		    case GEO_NORTH: case GEO_SOUTH:
-			amounty = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
-			amountx = amounty;
-			break;
-		    default:
-			amountx = cmdParseCoord(w, cmd->tx_argv[2], TRUE, TRUE);
-			amounty = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
-			break;
-		}
-	    }
-        }
-        else amountx = amounty = 1;
+	    amount = cmdParseCoord(cmd->tx_argv[2]);
+	else amount = 1;
 
 	switch (indx)
 	{
 	    case GEO_NORTH:
 		xdelta = 0;
-		ydelta = amounty;
+		ydelta = amount;
 		break;
 	    case GEO_SOUTH:
 		xdelta = 0;
-		ydelta = -amounty;
+		ydelta = -amount;
 		break;
 	    case GEO_EAST:
-		xdelta = amountx;
+		xdelta = amount;
 		ydelta = 0;
 		break;
 	    case GEO_WEST:
-		xdelta = -amountx;
+		xdelta = -amount;
 		ydelta = 0;
 		break;
 	    case GEO_NORTHEAST:
-		xdelta = amountx;
-		ydelta = amounty;
+		xdelta = amount;
+		ydelta = amount;
 		break;
 	    case GEO_NORTHWEST:
-		xdelta = -amountx;
-		ydelta = amounty;
+		xdelta = -amount;
+		ydelta = amount;
 		break;
 	    case GEO_SOUTHEAST:
-		xdelta = amountx;
-		ydelta = -amounty;
+		xdelta = amount;
+		ydelta = -amount;
 		break;
 	    case GEO_SOUTHWEST:
-		xdelta = -amountx;
-		ydelta = -amounty;
+		xdelta = -amount;
+		ydelta = -amount;
 		break;
 	    default:
 		ASSERT(FALSE, "Bad direction in CmdStretch");
