@@ -23,7 +23,9 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdSubrs.c,v 1.5
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <ctype.h>
+
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
@@ -70,14 +72,6 @@ TileTypeBitMask CmdYMAllButSpace;
  *    Units without any suffix are assumed to be in lambda if "snap"
  * (DBWSnapToGrid) is set to lambda, and internal units otherwise.
  *
- *    MagWindow argument w is used only with grid-based snapping, to find
- * the value of the grid for the given window.  In this case, because the
- * grid specifies an offset, "is_relative" specifies whether the given
- * coordinate is a relative measurement (ignore offset) or an absolute
- * position.  Because the grid can be different in X and Y, "is_x"
- * specifies whether the given distance is in the X (TRUE) or Y (FALSE)
- * direction.
- *
  * Results:
  *      Integer representing the given coordinate in internal units
  *
@@ -88,15 +82,12 @@ TileTypeBitMask CmdYMAllButSpace;
  */
 
 int
-cmdParseCoord(w, arg, is_relative, is_x)
-    MagWindow *w;
+cmdParseCoord(arg)
     char *arg;
-    bool is_relative, is_x;
 {
     char *endptr;
     double dval = 0;
     int mscale;
-    DBWclientRec *crec;
 
     dval = strtod(arg, &endptr);
 
@@ -116,38 +107,11 @@ cmdParseCoord(w, arg, is_relative, is_x)
 	return round(dval);
     }
     else if ((*endptr == 'i')
-		|| ((*endptr == '\0') && (DBWSnapToGrid == DBW_SNAP_INTERNAL)))
+		|| ((*endptr == '\0') && (DBWSnapToGrid != DBW_SNAP_LAMBDA)))
     {
 	/* internal units */
 	return round(dval);
     }
-    else if ((*endptr == 'g')
-		|| ((*endptr == '\0') && (DBWSnapToGrid == DBW_SNAP_USER)))
-    {
-	/* grid units */
-	if (w == (MagWindow *)NULL)
-	{
-	    windCheckOnlyWindow(&w, DBWclientID);
-	    if (w == (MagWindow *)NULL)
-		return round(dval);		/* Default, if window is unknown */
-	}
-	crec = (DBWclientRec *) w->w_clientData;
-	if (is_x)
-	{
-	    dval *= (double)(crec->dbw_gridRect.r_xtop
-			- crec->dbw_gridRect.r_xbot);
-	    if (!is_relative)
-		dval += (double)crec->dbw_gridRect.r_xbot;
-	}
-	else
-	{
-	    dval *= (double)(crec->dbw_gridRect.r_ytop
-			- crec->dbw_gridRect.r_ybot);
-	    if (!is_relative)
-		dval += (double)crec->dbw_gridRect.r_ybot;
-	}
-	return round(dval);
-    }
     else
     {
         /* natural units referred to the current cifoutput style */
@@ -207,6 +171,7 @@ cmdParseCoord(w, arg, is_relative, is_x)
  * ----------------------------------------------------------------------------
  */
 
+void
 CmdInit()
 {
     TTMaskZero(&CmdYMLabel);
@@ -240,6 +205,7 @@ CmdInit()
  * ----------------------------------------------------------------------------
  */
 
+void
 cmdFlushCell(def)
     CellDef *def;
 {
@@ -315,7 +281,7 @@ CmdParseLayers(s, mask)
     TileTypeBitMask *mask;
 {
     TileTypeBitMask newmask, tempmask;
-    register char *dp, c;
+    char *dp, c;
     char name[50];
     TileType type;
     Rect rootRect;
@@ -513,6 +479,7 @@ cmdMaskToType(mask)
  * ----------------------------------------------------------------------------
  */
 
+void
 cmdSaveCell(cellDef, newName, noninteractive, tryRename)
     CellDef *cellDef;	/* Pointer to def of cell to be saved */
     char *newName;	/* Pointer to name of file in which cell is to be
@@ -669,13 +636,13 @@ again:
 		prompt = TxPrintString("File %s already exists.\n"
 			"  Overwrite it with %s? ", filename, def->cd_name);
 		code = TxDialog(prompt, yesno, 0);
-	    }
 
-	    if (code == 0)
-	    {
-		/* No -- don't overwrite */
-		newName = NULL;
-		goto again;
+		if (code == 0)
+		{
+		    /* No -- don't overwrite */
+		    newName = NULL;
+		    goto again;
+		}
 	    }
 	}
 
@@ -707,7 +674,7 @@ again:
  *	def [NOT BEING EDITED]
  *
  * Results:
- *	0.
+ *	Always 0 to keep the search going.
  *
  * Side effects:
  *	Modifies captions and clientData for the window
@@ -800,7 +767,7 @@ CmdSetWindCaption(newEditUse, rootDef)
  *	RootDef [NOT BEING EDITED]
  *
  * Results:
- *	0.
+ *	Always 0 to keep the function going.
  *
  * Side effects:
  *	Modifies captions and clientData for the window
@@ -919,8 +886,8 @@ CmdGetEditPoint(point, rect)
  * user whether he wants to stay in magic or lose all these cells.
  *
  * Results:
- *	1 if the user wishes to continue anyway without writing the
- *	modified cells out to disk, 0 if not.
+ *	TRUE if the user wishes to continue anyway without writing the
+ *	modified cells out to disk, FALSE if not.
  *
  * Side effects:
  *	None.
@@ -928,7 +895,7 @@ CmdGetEditPoint(point, rect)
  * ----------------------------------------------------------------------------
  */
 
-int
+bool
 CmdWarnWrite()
 {
     int count, code;
@@ -940,17 +907,16 @@ CmdWarnWrite()
     (void) DBCellSrDefs(CDMODIFIED|CDBOXESCHANGED|CDSTAMPSCHANGED,
 	cmdWarnWriteFunc, (ClientData) &count);
     if (count == 0)
-	return (1);
+	return TRUE;
 
     prompt = TxPrintString("%d Magic cell%s been modified.\n  Do you"
 		" want to exit magic and lose %s? ", count,
 		count == 1 ? " has" : "s have",
 		count == 1 ? "it" : "them");		
     code = TxDialog(prompt, yesno, 0);
-    return (code);
+    return (code) ? TRUE : FALSE;
 }
 
-    /*ARGSUSED*/
 int
 cmdWarnWriteFunc(cellDef, pcount)
     CellDef *cellDef;
@@ -977,7 +943,7 @@ cmdWarnWriteFunc(cellDef, pcount)
  * ----------------------------------------------------------------------------
  */
 
-int
+void
 cmdExpandOneLevel(cu, bitmask, expand)
     CellUse *cu;
     int bitmask;
@@ -993,6 +959,7 @@ cmdExpandOneLevel(cu, bitmask, expand)
 	(void) DBCellEnum(cu->cu_def, cmdExpand1func, (ClientData) bitmask);
 }
 
+int
 cmdExpand1func(cu, bitmask)
     CellUse *cu;
     ClientData bitmask;
@@ -1081,7 +1048,7 @@ CmdIllegalChars(string, illegal, msg)
 				 * printing error messages.
 				 */
 {
-    register char *p, *bad;
+    char *p, *bad;
 
     for (p = string; *p != 0; p++)
     {
