@@ -21,10 +21,12 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdTZ.c,v 1.7 200
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <ctype.h>
 #include <math.h>
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
@@ -84,8 +86,7 @@ extern void DisplayWindow();
 #define TECH_PLANES	6
 #define TECH_LAYERS	7
 
-	/* ARGSUSED */
-Void
+void
 CmdTech(w, cmd)
     MagWindow *w;		/* Window in which command was invoked. */
     TxCommand *cmd;		/* Info about command options. */
@@ -153,7 +154,6 @@ CmdTech(w, cmd)
 		DBLambda[0] = atoi(cmd->tx_argv[3]);
 		ReduceFraction(&DBLambda[0], &DBLambda[1]);
 	    }
-
 	    lobj = Tcl_NewListObj(0, NULL);
  	    Tcl_ListObjAppendElement(magicinterp, lobj,
 			Tcl_NewIntObj(DBLambda[0]));
@@ -186,7 +186,6 @@ CmdTech(w, cmd)
 		DBLambda[0] = atoi(cmd->tx_argv[3]);
 		ReduceFraction(&DBLambda[0], &DBLambda[1]);
 	    }
-
 	    TxPrintf("Internal units per Lambda = %d / %d\n",
 		DBLambda[0], DBLambda[1]);
 	    break;
@@ -278,24 +277,27 @@ CmdTech(w, cmd)
 		break;
 	    }
 
-	    /* If internal scalefactor is not the default 1:1, then we	*/
-	    /* need to scale the techfile numbers accordingly.		*/
+	    /* If internal scalefactor is not the default 1:1, then we  */
+	    /* need to scale the techfile numbers accordingly.          */
 
 	    if ((DBLambda[0] != 1) || (DBLambda[1] != 1))
 	    {
 		int d = DBLambda[0];
 		int n = DBLambda[1];
 
-		CIFTechInputScale(d, n);
+		CIFTechInputScale(d, n);      
 		CIFTechOutputScale(d, n);
 		DRCTechScale(d, n);
 		ExtTechScale(d, n);
 		WireTechScale(d, n);
+#ifdef LEF_MODULE
+		LefTechScale(d, n);
+#endif
 #ifdef ROUTE_MODULE
 		RtrTechScale(d, n);
 #endif
-		TxPrintf("Scaled tech values by %d / %d to"
-			" match internal grid scaling\n", n, d);
+		TxPrintf("Scaled tech values by %d / %d to" 
+				" match internal grid scaling\n", n, d);
 	    }
 
 	    if (saveNumPlanes != DBNumPlanes)
@@ -399,8 +401,7 @@ changePlanesFunc(cellDef, arg)
  * ----------------------------------------------------------------------------
  */
 
-	/* ARGSUSED */
-Void
+void
 CmdTool(w, cmd)
     MagWindow *w;		/* Window in which command was invoked. */
     TxCommand *cmd;		/* Info about command options. */
@@ -442,6 +443,7 @@ CmdTool(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
+void
 CmdUnexpand(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -489,7 +491,6 @@ cmdUnexpandFunc(use, windowMask)
 	    (TileTypeBitMask *) NULL);
     return 0;
 }
-
 
 /*
  * ----------------------------------------------------------------------------
@@ -511,8 +512,7 @@ cmdUnexpandFunc(use, windowMask)
  * ----------------------------------------------------------------------------
  */
     
-    /* ARGSUSED */
-
+void
 CmdUpsidedown(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -584,16 +584,17 @@ typedef struct labelstore
 static int moreLabelEntries, labelEntryCount;
 static LabelStore *labelBlockTop, *labelEntry;
 
-    /* ARGSUSED */
-
+void
 CmdWhat(w, cmd)
     MagWindow *w;		/* Window in which command was invoked. */
     TxCommand *cmd;		/* Information about the command. */
 {
+    int i;
     bool foundAny;
     TileTypeBitMask layers;
     extern int cmdWhatPaintFunc(), cmdWhatLabelFunc(), cmdWhatCellFunc();
     extern int cmdWhatLabelPreFunc(), orderLabelFunc();
+
     if (cmd->tx_argc > 1)
     {
 	TxError("Usage: what\n");
@@ -605,10 +606,23 @@ CmdWhat(w, cmd)
     TTMaskZero(&layers);
     (void) SelEnumPaint(&DBAllButSpaceAndDRCBits, FALSE, (bool *) NULL,
 	    cmdWhatPaintFunc, (ClientData) &layers);
+
     if (!TTMaskIsZero(&layers))
     {
-	int i;
+	/* If there are any stacked types in the list, decompose them	*/
+	/* into their residues (which are the two contact types that	*/
+	/* are stacked).						*/
 
+	for (i = DBNumUserLayers; i < DBNumTypes; i++)
+	{
+	    if (TTMaskHasType(&layers, i))
+		TTMaskSetMask(&layers, DBResidueMask(i));
+	    TTMaskClearType(&layers, i);
+	}
+    }
+
+    if (!TTMaskIsZero(&layers))
+    {
 	TxPrintf("Selected mask layers:\n");
 	for (i = TT_SELECTBASE; i < DBNumUserLayers; i++)
 	{
@@ -627,8 +641,6 @@ CmdWhat(w, cmd)
     foundAny = FALSE;
     if (labelBlockTop)
     {
-	int i;
-
 	qsort(labelBlockTop, labelEntryCount, sizeof(LabelStore), orderLabelFunc);
     		/* now print them out */
 	for (labelEntry = labelBlockTop; labelEntryCount-- > 0; labelEntry++)
@@ -815,7 +827,7 @@ cmdWhatCellFunc(selUse, realUse, transform, foundAny)
 #define TYPE		4
 #define VERTICAL	5
 
-	/* ARGSUSED */
+void
 CmdWire(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -891,7 +903,7 @@ CmdWire(w, cmd)
 			    cmd->tx_argv[2]);
 		    return;
 		}
-		width = cmdParseCoord(w, cmd->tx_argv[3], TRUE, TRUE);
+		width = cmdParseCoord(cmd->tx_argv[3]);
 		WireAddContact(type, width);
 		return;
 	    }
@@ -922,7 +934,7 @@ CmdWire(w, cmd)
 			    cmd->tx_argv[2]);
 		    return;
 		}
-		width = cmdParseCoord(w, cmd->tx_argv[3], TRUE, TRUE);
+		width = cmdParseCoord(cmd->tx_argv[3]);
 		WirePickType(type, width);
 		return;
 	    }
@@ -962,8 +974,7 @@ CmdWire(w, cmd)
 
 static bool cmdWriteAllForce;  	/* If true, the user specified 'force' */
 
-    /* ARGSUSED */
-
+void
 CmdWriteall(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1081,7 +1092,7 @@ cmdWriteallFunc(def, autoWrite)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 CmdXload(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
