@@ -24,8 +24,11 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdWizard.c,v 1.2
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <sys/types.h>
 #include <sys/times.h>
+
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/malloc.h"
@@ -43,6 +46,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdWizard.c,v 1.2
 #include "utils/utils.h"
 #include "textio/txcommands.h"
 
+/* Forward declarations */
+
+extern void cmdPsearchStats();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -65,8 +72,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdWizard.c,v 1.2
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
+void
 CmdCoord(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -168,6 +174,7 @@ CmdCoord(w, cmd)
  */
 
 #ifndef NO_EXT
+void
 CmdExtractTest(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -197,8 +204,7 @@ CmdExtractTest(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
+void
 CmdShowtech(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -407,7 +413,7 @@ showTech(outf, verbose)
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
+void
 CmdTilestats(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -491,12 +497,13 @@ int totalTiles[TT_MAXTYPES];
  * ----------------------------------------------------------------------------
  */
 
+int
 cmdStatsFunc(def, outf)
     CellDef *def;
     FILE *outf;
 {
     int cmdStatsCount(), cmdStatsOutput();
-    Void cmdStatsHier();
+    int cmdStatsHier();
     struct countClient cc;
     int total;
     TileType t;
@@ -544,7 +551,7 @@ cmdStatsFunc(def, outf)
  * ----------------------------------------------------------------------------
  */
 
-	/* ARGSUSED */
+int
 cmdStatsCount(def, cc)
     CellDef *def;
     struct countClient *cc;
@@ -577,10 +584,9 @@ cmdStatsCount(def, cc)
 
 int
 cmdStatsCountTile(tile, ci)
-    register Tile *tile;
-    register struct cellInfo *ci;
+    Tile *tile;
+    struct cellInfo *ci;
 {
-    char *pagep;
     TileType type = TiGetType(tile);
 
     /*
@@ -619,12 +625,13 @@ cmdStatsCountTile(tile, ci)
  * ----------------------------------------------------------------------------
  */
 
+void
 cmdStatsHier(parent, nuses, child)
     CellDef *parent, *child;
-    register int nuses;
+    int nuses;
 {
-    register struct cellInfo *pi, *ci;
-    register TileType t;
+    struct cellInfo *pi, *ci;
+    TileType t;
 
     pi = (struct cellInfo *) parent->cd_client;
     if (pi->ci_countedHier)
@@ -665,12 +672,13 @@ cmdStatsHier(parent, nuses, child)
  * ----------------------------------------------------------------------------
  */
 
+int
 cmdStatsOutput(def, cc)
     CellDef *def;
     struct countClient *cc;
 {
-    register TileType t;
-    register struct cellInfo *ci;
+    TileType t;
+    struct cellInfo *ci;
     int count, hiercount;
 
     if (def->cd_client == (ClientData) NULL)
@@ -729,8 +737,7 @@ cmdStatsOutput(def, cc)
  * ----------------------------------------------------------------------------
  */
 
- /* ARGSUSED */
-
+void
 CmdPsearch(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -740,8 +747,8 @@ CmdPsearch(w, cmd)
     Point p;
     Plane *plane;
     Rect rtool;
-    register Rect *ebox;
-    register Tile *tp;
+    Rect *ebox;
+    Tile *tp;
     Tile *TiSrPointNew();
     int i, pNum, count;
 
@@ -789,13 +796,14 @@ CmdPsearch(w, cmd)
     /* Macro search */
     for (p = ebox->r_ll, i = count; i-- > 0; )
     {
-	register Tile *txp = tp;
+	Tile *txp = tp;
 	BUMP(p, ebox);
 	GOTOPOINT(txp, &p);
     }
     cmdPsearchStats("macro", &tlast, &tdelta, count);
 }
 
+void
 cmdPsearchStats(str, tl, td, count)
     char *str;
     struct tms *tl, *td;
@@ -840,8 +848,7 @@ cmdPsearchStats(str, tl, td, count)
 int numTilesFound;
 bool cmdTsearchDebug = FALSE;
 
-  /*ARGSUSED*/
-
+void
 CmdTsearch(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -986,6 +993,7 @@ cmdTsrFunc(tp)
  * ----------------------------------------------------------------------------
  */
 
+void
 CmdWatch(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
