@@ -49,9 +49,9 @@ static PaintResultType (*dbCurPaintTbl)[NT][NT] = DBPaintResultTbl;
  * DBPaintPlaneMergeOnce instead of the standard version.
  */
 #ifdef NONMANHATTAN
-static Void (*dbCurPaintPlane)() = DBNMPaintPlane;
+static void (*dbCurPaintPlane)() = DBNMPaintPlane;
 #else
-static Void (*dbCurPaintPlane)() = DBPaintPlane;
+static void (*dbCurPaintPlane)() = DBPaintPlane;
 #endif
 
     /* Structure passed to DBTreeSrTiles() */
@@ -225,8 +225,8 @@ DBCellCopyAllLabels(scx, mask, xMask, targetUse, pArea)
     /*ARGSUSED*/
 int
 dbCopyAllLabels(scx, lab, tpath, arg)
-    register SearchContext *scx;
-    register Label *lab;
+    SearchContext *scx;
+    Label *lab;
     TerminalPath *tpath;
     struct copyLabelArg *arg;
 {
@@ -347,7 +347,7 @@ DBCellCopyLabels(scx, mask, xMask, targetUse, pArea)
 				 * if no labels are copied.
 				 */
 {
-    register Label *lab;
+    Label *lab;
     CellDef *def = targetUse->cu_def;
     Rect labTargetRect;
     Rect *rect = &scx->scx_area;
@@ -393,11 +393,11 @@ DBCellCopyLabels(scx, mask, xMask, targetUse, pArea)
 
 int
 dbCopyManhattanPaint(tile, cxp)
-    register Tile *tile;	/* Pointer to tile to copy */
+    Tile *tile;	/* Pointer to tile to copy */
     TreeContext *cxp;		/* Context from DBTreeSrTiles */
 {
-    register SearchContext *scx = cxp->tc_scx;
-    register struct copyAllArg *arg;
+    SearchContext *scx = cxp->tc_scx;
+    struct copyAllArg *arg;
     Rect sourceRect, targetRect;
     PaintUndoInfo ui;
     CellDef *def;
@@ -447,11 +447,11 @@ dbCopyManhattanPaint(tile, cxp)
 
 int
 dbCopyAllPaint(tile, cxp)
-    register Tile *tile;	/* Pointer to tile to copy */
+    Tile *tile;	/* Pointer to tile to copy */
     TreeContext *cxp;		/* Context from DBTreeSrTiles */
 {
-    register SearchContext *scx = cxp->tc_scx;
-    register struct copyAllArg *arg;
+    SearchContext *scx = cxp->tc_scx;
+    struct copyAllArg *arg;
     Rect sourceRect, targetRect;
     PaintUndoInfo ui;
     CellDef *def;
@@ -758,7 +758,7 @@ DBCellCopyCells(scx, targetUse, pArea)
  * DBCellCopyCells() above.
  *
  * Results:
- *	None.
+ *	Always return 2.
  *
  * Side effects:
  *	Updates the cell plane in arg->caa_targetUse->cu_def.
@@ -768,11 +768,11 @@ DBCellCopyCells(scx, targetUse, pArea)
 
 int
 dbCellCopyCellsFunc(scx, arg)
-    register SearchContext *scx;	/* Pointer to search context containing
+    SearchContext *scx;	/* Pointer to search context containing
 					 * ptr to cell use to be copied,
 					 * and transform to the target def.
 					 */
-    register struct copyAllArg *arg;	/* Client data from caller */
+    struct copyAllArg *arg;	/* Client data from caller */
 {
     CellUse *use, *newUse;
     CellDef *def;
@@ -894,9 +894,9 @@ DBNewPaintTable(newTable))[NT][NT]
 
 VoidProc
 DBNewPaintPlane(newProc)
-    Void (*newProc)();		/* Address of new procedure */
+    void (*newProc)();		/* Address of new procedure */
 {
-    Void (*oldProc)() = dbCurPaintPlane;
+    void (*oldProc)() = dbCurPaintPlane;
     dbCurPaintPlane = newProc;
     return (oldProc);
 }
