@@ -25,7 +25,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcellname.c,v 1.
 #include <string.h>
 #endif
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/hash.h"
 #include "utils/utils.h"
@@ -57,14 +57,18 @@ bool dbWarnUniqueIds;
 /*
  * Routines used before defined
  */
-CellDef *DBCellDefAlloc();
-int dbLinkFunc();
-static void dbUsePrintInfo();
+extern CellDef *DBCellDefAlloc();
+extern int dbLinkFunc();
+extern void dbUsePrintInfo();
+extern void DBsetUseIdHash();
+extern void DBUnLinkCell();
 
 /*
  * Routines from other database modules
  */
+
 extern void dbComputeBbox();
+extern void DBSetUseIdHash();
 
 /*
  * ----------------------------------------------------------------------------
@@ -333,7 +337,7 @@ dbGetUseName(celluse)
  * ----------------------------------------------------------------------------
  */
 
-static void
+void
 dbCellPrintInfo(StartDef, who, dolist)
     CellDef *StartDef;
     int who;
@@ -735,16 +739,13 @@ DBCellPrint(CellName, who, dolist)
  * ----------------------------------------------------------------------------
  */
 
-static void
+void
 dbUsePrintInfo(StartUse, who, dolist)
     CellUse *StartUse;
     int who;
     bool dolist;
 {
-    HashSearch hs;
-    HashEntry *entry;
     CellDef *celldef;
-    CellUse *celluse;
     char *cu_name;
 
     int dbCellUsePrintFunc();
@@ -1306,7 +1307,7 @@ DBCellDefFree(cellDef)
 
 {
     int pNum;
-    register Label *lab;
+    Label *lab;
 
     if (cellDef->cd_file != (char *) NULL)
 	FREE(cellDef->cd_file);
@@ -1545,9 +1546,9 @@ DBLinkCell(use, parentDef)
 int
 dbLinkFunc(cellUse, defname)
     CellUse *cellUse;
-    register char *defname;
+    char *defname;
 {
-    register char *usep = cellUse->cu_id;
+    char *usep = cellUse->cu_id;
 
     /* Skip in the unlikely event that this cell has no use-id */
     if (usep == (char *) NULL)
@@ -1667,7 +1668,7 @@ DBFindUse(id, parentDef)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 DBGenerateUniqueIds(def, warn)
     CellDef *def;
     bool warn;		/* If TRUE, warn user when we assign new ids */
@@ -1710,10 +1711,10 @@ DBGenerateUniqueIds(def, warn)
 
 int
 dbFindNamesFunc(use, parentDef)
-    register CellUse *use;
+    CellUse *use;
     CellDef *parentDef;
 {
-    register HashEntry *he;
+    HashEntry *he;
 
     if (use->cu_id)
     {
@@ -1764,11 +1765,11 @@ dbFindNamesFunc(use, parentDef)
 
 int
 dbGenerateUniqueIdsFunc(use, parentDef)
-    register CellUse *use;
+    CellUse *use;
     CellDef *parentDef;
 {
-    register HashEntry *hedef, *hename;
-    register int suffix;
+    HashEntry *hedef, *hename;
+    int suffix;
     char name[1024];
 
     if (use->cu_id)
@@ -1811,6 +1812,7 @@ setHash:
  * ----------------------------------------------------------------------------
  */
 
+void
 DBSetUseIdHash(use, parentDef)
     CellUse *use;
     CellDef *parentDef;
@@ -1838,6 +1840,7 @@ DBSetUseIdHash(use, parentDef)
  * ----------------------------------------------------------------------------
  */
 
+void
 DBUnLinkCell(use, parentDef)
     CellUse *use;
     CellDef *parentDef;
@@ -1847,6 +1850,7 @@ DBUnLinkCell(use, parentDef)
     if (he = HashLookOnly(&parentDef->cd_idHash, use->cu_id))
 	HashSetValue(he, (ClientData) NULL);
 }
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -1867,6 +1871,7 @@ DBUnLinkCell(use, parentDef)
  * ----------------------------------------------------------------------------
  */
 
+void
 DBNewYank(yname, pyuse, pydef)
     char *yname;	/* Name of yank buffer */
     CellUse **pyuse;	/* Pointer to new cell use is stored in *pyuse */
