@@ -21,6 +21,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcellsrch.c,v 1.
 #endif  /* not lint */
 
 #include <stdio.h>
+
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
@@ -104,18 +105,9 @@ DBTreeSrTiles(scx, mask, xMask, func, cdarg)
     ClientData cdarg;		/* Client data for above function */
 {
     int dbCellTileSrFunc();
-    TreeContext context;
     TreeFilter filter;
-    CellUse *cellUse = scx->scx_use;
-    CellDef *def = cellUse->cu_def;
-    int pNum;
 
-    ASSERT(def != (CellDef *) NULL, "DBTreeSrTiles");
-    if (!DBIsExpand(cellUse, xMask))
-	return 0;
-
-    if ((def->cd_flags & CDAVAILABLE) == 0)
-	if (!DBCellRead(def, (char *) NULL, TRUE)) return 0;
+    /* Set up the filter and call the recursive filter function */
 
     filter.tf_func = func;
     filter.tf_arg = cdarg;
@@ -123,42 +115,19 @@ DBTreeSrTiles(scx, mask, xMask, func, cdarg)
     filter.tf_xmask = xMask;
     filter.tf_planes = DBTechTypesToPlanes(mask);
 
-    context.tc_scx = scx;
-    context.tc_filter = &filter;
-
-    /*
-     * Apply the function first to any of the tiles in the planes
-     * for this CellUse's CellDef that match the mask.
-     */
-
-    for (pNum = PL_PAINTBASE; pNum < DBNumPlanes; pNum++)
-	if (PlaneMaskHasPlane(filter.tf_planes, pNum))
-	{
-	    if (DBSrPaintArea((Tile *) NULL, def->cd_planes[pNum],
-		    &scx->scx_area, mask, func, (ClientData) &context))
-		return 1;
-	}
-
-    /*
-     * Now apply ourselves recursively to each of the CellUses
-     * in our tile plane.
-     */
-
-    if (DBCellSrArea(scx, dbCellTileSrFunc, (ClientData) &filter))
-	return 1;
-    else return 0;
+    return dbCellTileSrFunc(scx, &filter);
 }
 
 /*
  * dbCellTileSrFunc --
  *
- * Filter procedure applied to subcells by DBTreeSrTiles().
+ * Recursive filter procedure applied to the cell by DBTreeSrTiles().
  */
 
 int
 dbCellTileSrFunc(scx, fp)
-    register SearchContext *scx;
-    register TreeFilter *fp;
+    SearchContext *scx;
+    TreeFilter *fp;
 {
     TreeContext context;
     CellDef *def = scx->scx_use->cu_def;
@@ -196,6 +165,119 @@ dbCellTileSrFunc(scx, fp)
 	return 1;
     else return 0;
 }
+
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * DBTreeSrUniqueTiles --
+ *
+ * Recursively search downward from the supplied CellUse for
+ * all visible paint tiles matching the supplied type mask.
+ * This routine is like DBTreeSrTiles, above, except that it will
+ * only call the specified routine ONCE for each contact type, in
+ * the home plane of that contact type.  Stacked contact types will
+ * only be processed if the current search plane matches the home
+ * plane of one of the stacked contact type's residues.
+ *
+ * Results:
+ *	0 is returned if the search finished normally.  1 is returned
+ *	if the search was aborted.
+ *
+ * Side effects:
+ *	Whatever side effects are brought about by applying the
+ *	procedure supplied.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+int
+DBTreeSrUniqueTiles(scx, mask, xMask, func, cdarg)
+    SearchContext *scx;		/* Pointer to search context specifying
+				 * a cell use to search, an area in the
+				 * coordinates of the cell's def, and a
+				 * transform back to "root" coordinates.
+				 */
+    TileTypeBitMask *mask;	/* Only tiles with a type for which
+				 * a bit in this mask is on are processed.
+				 */
+    int xMask;			/* All subcells are visited recursively
+				 * until we encounter uses whose flags,
+				 * when anded with xMask, are not
+				 * equal to xMask.
+				 */
+    int (*func)();		/* Function to apply at each qualifying tile */
+    ClientData cdarg;		/* Client data for above function */
+{
+    int dbCellTileSrFunc();
+    TreeFilter filter;
+
+    /* Set up the filter and call the recursive filter function */
+
+    filter.tf_func = func;
+    filter.tf_arg = cdarg;
+    filter.tf_mask = mask;
+    filter.tf_xmask = xMask;
+    filter.tf_planes = DBTechTypesToPlanes(mask);
+
+    return dbCellUniqueTileSrFunc(scx, &filter);
+}
+
+/*
+ * dbCellTileSrFunc --
+ *
+ * Recursive filter procedure applied to the cell by DBTreeSrUniqueTiles().
+ * This is similar to dbCellTileSrFunc, except that for each plane searched,
+ * only the tile types having that plane as their home plane will be passed
+ * to the filter function.  Contacts will therefore be processed only once.
+ */
+
+int
+dbCellUniqueTileSrFunc(scx, fp)
+    SearchContext *scx;
+    TreeFilter *fp;
+{
+    TreeContext context;
+    TileTypeBitMask uMask;
+    CellDef *def = scx->scx_use->cu_def;
+    int pNum;
+
+    ASSERT(def != (CellDef *) NULL, "dbCellTileSrFunc");
+    if (!DBIsExpand(scx->scx_use, fp->tf_xmask))
+	return 0;
+    if ((def->cd_flags & CDAVAILABLE) == 0)
+	if (!DBCellRead(def, (char *) NULL, TRUE)) return 0;
+
+    context.tc_scx = scx;
+    context.tc_filter = fp;
+
+    /*
+     * Apply the function first to any of the tiles in the planes
+     * for this CellUse's CellDef that match the mask.
+     */
+
+    for (pNum = PL_PAINTBASE; pNum < DBNumPlanes; pNum++)
+	if (PlaneMaskHasPlane(fp->tf_planes, pNum))
+	{
+	    uMask = DBHomePlaneTypes(pNum);
+	    TTMaskAndMask(&uMask, fp->tf_mask);
+
+	    if (DBSrPaintArea((Tile *) NULL, def->cd_planes[pNum],
+		    &scx->scx_area, &uMask,
+		    fp->tf_func, (ClientData) &context))
+		return 1;
+	}
+
+    /*
+     * Now apply ourselves recursively to each of the CellUses
+     * in our tile plane.
+     */
+
+    if (DBCellSrArea(scx, dbCellUniqueTileSrFunc, (ClientData) fp))
+	return 1;
+    else return 0;
+}
+
 
 /*
  *-----------------------------------------------------------------------------
@@ -365,8 +447,8 @@ DBTreeSrLabels(scx, mask, xMask, tpath, func, cdarg)
     ClientData cdarg;		/* Client data for above function */
 {
     SearchContext scx2;
-    register Label *lab;
-    register Rect *r = &scx->scx_area;
+    Label *lab;
+    Rect *r = &scx->scx_area;
     CellUse *cellUse = scx->scx_use;
     CellDef *def = cellUse->cu_def;
     TreeFilter filter;
@@ -420,12 +502,12 @@ DBTreeSrLabels(scx, mask, xMask, tpath, func, cdarg)
 
 int
 dbCellLabelSrFunc(scx, fp)
-    register SearchContext *scx;
-    register TreeFilter *fp;
+    SearchContext *scx;
+    TreeFilter *fp;
 {
-    register Label *lab;
-    register Rect *r = &scx->scx_area;
-    register TileTypeBitMask *mask = fp->tf_mask;
+    Label *lab;
+    Rect *r = &scx->scx_area;
+    TileTypeBitMask *mask = fp->tf_mask;
     CellDef *def = scx->scx_use->cu_def;
     char *tnext;
     int result;
@@ -437,7 +519,7 @@ dbCellLabelSrFunc(scx, fp)
     
     if (fp->tf_tpath != (TerminalPath *) NULL)
     {
-	register TerminalPath *tp = fp->tf_tpath;
+	TerminalPath *tp = fp->tf_tpath;
 
 	tnext = tp->tp_next;
 	tp->tp_next = DBPrintUseId(scx, tp->tp_next, tp->tp_last-tp->tp_next);
@@ -563,14 +645,14 @@ DBTreeSrCells(scx, xMask, func, cdarg)
     /*ARGSUSED*/
 int
 dbTreeCellSrFunc(scx, fp)
-    register SearchContext *scx;	/* Pointer to context containing a
+    SearchContext *scx;	/* Pointer to context containing a
 					 * CellUse and a transform from coord-
 					 * inates of the def of the use to the
 					 * "root" of the search.
 					 */
-    register TreeFilter *fp;
+    TreeFilter *fp;
 {
-    register CellUse *use = scx->scx_use;
+    CellUse *use = scx->scx_use;
     int result;
 
     /* DBIsExpand treats a zero expand mask as "expanded everywhere",
@@ -609,6 +691,7 @@ dbTreeCellSrFunc(scx, fp)
  *-----------------------------------------------------------------------------
  */
 
+void
 DBSeeTypesAll(rootUse, rootRect, xMask, mask)
     CellUse *rootUse;	/* CellUse from which to begin search */
     Rect *rootRect;	/* Clipping rectangle in coordinates of CellUse's def */
@@ -637,15 +720,16 @@ DBSeeTypesAll(rootUse, rootRect, xMask, mask)
 
 int
 dbSeeTypesAllSrFunc(tile, cxp)
-    register Tile *tile;
-    register TreeContext *cxp;
+    Tile *tile;
+    TreeContext *cxp;
 {
     Rect tileRect;
     TileTypeBitMask *mask = (TileTypeBitMask *) cxp->tc_filter->tf_arg;
-    register Rect *area = &cxp->tc_scx->scx_area;
+    Rect *area = &cxp->tc_scx->scx_area;
 
     TiToRect(tile, &tileRect);
     if (GEO_OVERLAP((&tileRect), area))
+    {
 #ifdef NONMANHATTAN 
 	if (IsSplit(tile))
 	    TTMaskSetType(mask, SplitSide(tile) ?
@@ -653,6 +737,7 @@ dbSeeTypesAllSrFunc(tile, cxp)
         else
 #endif
 	TTMaskSetType(mask, TiGetType(tile));
+    }
     return 0;
 }
 
@@ -675,6 +760,7 @@ dbSeeTypesAllSrFunc(tile, cxp)
  *-----------------------------------------------------------------------------
  */
 
+void
 DBSeeTypes(rootUse, rootRect, mask)
     CellUse *rootUse;	/* CellUse to search */
     Rect *rootRect;	/* Clipping rectangle in coordinates of CellUse's def */
@@ -762,7 +848,7 @@ DBSrRoots(baseDef, transform, func, cdarg)
     int (*func)();		/* Function to apply at each root cellUse */
     ClientData cdarg;		/* Client data for above function */
 {
-    register CellUse *parentUse;
+    CellUse *parentUse;
     int xoff, yoff, x, y;
     Transform baseToParent, t;
 
@@ -879,7 +965,7 @@ DBIsAncestor(cellDef1, cellDef2)
 
 int
 DBCellSrArea(scx, func, cdarg)
-    register SearchContext *scx;
+    SearchContext *scx;
 			/* Pointer to search context specifying a cell use to
 			 * search, an area in the coordinates of the cell's
 			 * def, and a transform back to "root" coordinates.
@@ -950,13 +1036,13 @@ DBCellSrArea(scx, func, cdarg)
 
 int
 dbCellSrFunc(tile, cxp)
-    register Tile *tile;
-    register TreeContext *cxp;
+    Tile *tile;
+    TreeContext *cxp;
 {
-    register TreeFilter *fp = cxp->tc_filter;
-    register SearchContext *scx = cxp->tc_scx;
-    register CellUse *use;
-    register Rect *bbox;
+    TreeFilter *fp = cxp->tc_filter;
+    SearchContext *scx = cxp->tc_scx;
+    CellUse *use;
+    Rect *bbox;
     CellTileBody *body;
     SearchContext newScx;
     Transform t, tinv;
@@ -1107,11 +1193,11 @@ DBCellEnum(cellDef, func, cdarg)
 int
 dbEnumFunc(tile, fp)
     Tile *tile;
-    register TreeFilter *fp;
+    TreeFilter *fp;
 {
-    register CellUse *use;
-    register CellTileBody *body;
-    register Rect *bbox;
+    CellUse *use;
+    CellTileBody *body;
+    Rect *bbox;
 
     for (body = (CellTileBody *) TiGetBody(tile);
 	    body != NULL;
