@@ -249,7 +249,7 @@ dbSrConnectFunc(tile, csa)
     Tile *tile;			/* Tile that is connected. */
     struct conSrArg *csa;	/* Contains information about the search. */
 {
-    register Tile *t2;
+    Tile *t2;
     Rect tileArea;
     int i;
     TileTypeBitMask *connectMask;
@@ -305,7 +305,6 @@ dbSrConnectFunc(tile, csa)
 
     /* Left side: */
 
-leftside:
 #ifdef NONMANHATTAN
     if (IsSplit(tile) && SplitSide(tile)) goto bottomside;
 #endif
@@ -473,8 +472,6 @@ dbcUnconnectFunc(tile, connectMask)
     TileTypeBitMask *connectMask;
     
 {
-    Rect tileArea;
-
 #ifdef NONMANHATTAN
     TileType loctype;
 
@@ -671,9 +668,16 @@ dbcConnectFunc(tile, cx)
      * must be constituents of the contact before we punt
      */
 
-    if (TTMaskHasType(&DBContactBits, loctype))
+    if (DBIsContact(loctype))
     {
+	TileType ctype;
+
 	TTMaskSetOnlyType(&notConnectMask, loctype);
+
+	/* The mask of contact types must include all stacked contacts */
+	for (ctype = DBNumUserLayers; ctype < DBNumTypes; ctype++)
+	    if TTMaskHasType(DBResidueMask(ctype), loctype)
+		TTMaskSetType(&notConnectMask, ctype);
 	TTMaskCom(&notConnectMask);
     }
     else
