@@ -243,9 +243,9 @@ DBCellRead(cellDef, name, setFileName)
     char line[2048], tech[50], layername[50];
     PaintResultType *ptable;
     bool result = TRUE;
-    register FILE *f;
-    register Rect *rp;
-    register c;
+    FILE *f;
+    Rect *rp;
+    int c;
     TileType type;
     Plane *plane;
     Rect r;
@@ -307,7 +307,6 @@ DBCellRead(cellDef, name, setFileName)
 	
 	if (line[0] == 'm')
 	{
-	    int throwAway;
 	    if (!strncmp(line, "magscale", 8))
 	    {
 		if (sscanf(line, "magscale %d %d", &n, &d) != 2)
@@ -351,6 +350,9 @@ DBCellRead(cellDef, name, setFileName)
 	DRCTechScale(1, d);
 	ExtTechScale(1, d);
 	WireTechScale(1, d);
+#ifdef LEF_MODULE
+	LefTechScale(1, d);
+#endif
 #ifdef ROUTE_MODULE
 	RtrTechScale(1, d);
 #endif
@@ -435,8 +437,8 @@ nextrect:
 #ifdef NONMANHATTAN 
 	while (((c = getc(f)) == 'r') || (c == 't'))
 	{
-	    register TileType dinfo;
-	    register dir;
+	    TileType dinfo;
+	    int dir;
 #else
 	while (((c = getc(f)) == 'r') || (c == 't'))
 	{
@@ -495,10 +497,11 @@ nextrect:
 		/* If a contact, paint it on all connected planes */
 		if (DBConnPlanes[type])
 		{
-		    register pNum;
+		    int pNum;
 
 		    for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
 			if (PlaneMaskHasPlane(DBConnPlanes[type], pNum))
+			{
 #ifdef NONMANHATTAN
 			    if (c == 't')
 			    {
@@ -511,6 +514,7 @@ nextrect:
 			    DBPaintPlane(cellDef->cd_planes[pNum], rp,
 				    DBStdPaintTbl(type, pNum),
 				    (PaintUndoInfo *) NULL);
+			}
 		}
 	    }
 	}
@@ -667,7 +671,7 @@ dbReadOpen(cellDef, name, setFileName)
 	else {
 	    TxError("Cell %s couldn't be found\n", cellDef->cd_name);
 #ifdef FILE_LOCKS
-	    MALLOC(char *, realname, strlen(cellDef->cd_name)+strlen(DBSuffix)+1);
+	    MALLOC(char *, realname, strlen(cellDef->cd_name) + strlen(DBSuffix) + 1);
 	    (void) sprintf(realname, "%s%s", cellDef->cd_name, DBSuffix);
 	    cellDef->cd_file = StrDup(&cellDef->cd_file, realname);
 #endif
@@ -1216,7 +1220,7 @@ dbReadLabels(cellDef, line, len, f, scale)
 	    if (((lab = cellDef->cd_lastLabel) == NULL) ||
 			(lab->lab_flags & PORT_DIR_MASK) ||
 			(((ntok = sscanf(line, "port %d %4s %49s %49s",
-				&idx, &ppos, &port_use, &port_class)) != 2) &&
+				&idx, ppos, port_use, port_class)) != 2) &&
 			(ntok != 4)))
 	    {
 		TxError("Skipping bad \"port\" line: %s", line);
@@ -1355,11 +1359,11 @@ char *
 dbFgets(line, len, f)
     char *line;
     int len;
-    register FILE *f;
+    FILE *f;
 {
-    register char *cs;
-    register int l;
-    register c;
+    char *cs;
+    int l;
+    int c;
 
     do
     {
@@ -1405,7 +1409,7 @@ DBCellFindScale(cellDef)
     TileTypeBitMask typeMask;
     int pNum;
     int ggcf;
-    register Label *lab;
+    Label *lab;
 
     /* We only care about preventing magic from making the grid spacing finer	*/
     /* and finer.  If the current scale is lambda = 1 magic unit or larger,	*/
@@ -1457,7 +1461,6 @@ dbFindGCFFunc(tile, ggcf)
     Tile *tile;
     int *ggcf;
 {
-    int lgcf;
     Rect r;
 
     TiToRect(tile, &r);
@@ -1479,8 +1482,8 @@ dbFindCellGCFFunc(cellUse, ggcf)
     CellUse *cellUse;	/* Cell use whose "call" is to be written to a file	*/
     int *ggcf;		/* Greatest common denominator for all geometry		*/
 {
-    register Transform *t;
-    register Rect *b;
+    Transform *t;
+    Rect *b;
 
     t = &(cellUse->cu_transform);
     b = &(cellUse->cu_def->cd_bbox);
@@ -1551,10 +1554,10 @@ DBCellWriteFile(cellDef, f)
     FILE *f;		/* The FILE to write to */
 {
     int dbWritePaintFunc(), dbWriteCellFunc(), dbWritePropFunc();
-    register Label *lab;
+    Label *lab;
     struct writeArg arg;
     int pNum;
-    TileType type;
+    TileType type, stype;
     TileTypeBitMask typeMask;
     int reducer;
     char *estring;
@@ -1600,10 +1603,12 @@ DBCellWriteFile(cellDef, f)
     /*
      * Output the paint of the cell.
      * Note that we only output up to the last layer appearing
-     * in the technology file (DBNumUserLayers-1), not any of the
-     * automatically generated contact layers (DBNumUserLayers
-     * through DBNumTypes-1).
+     * in the technology file (DBNumUserLayers-1).  Automatically
+     * generated stacked contact types are added to typeMask and
+     * will be decomposed into the residue appropriate for the
+     * plane being searched.
      */
+
     arg.wa_file = f;
     arg.wa_reducer = reducer;
     for (type = TT_PAINTBASE; type < DBNumUserLayers; type++)
@@ -1612,7 +1617,16 @@ DBCellWriteFile(cellDef, f)
 	    continue;
 	arg.wa_found = FALSE;
 	arg.wa_type = type;
+	arg.wa_plane = pNum;
 	TTMaskSetOnlyType(&typeMask, type);
+
+	/* Add to the mask all generated (stacking) types which	*/
+	/* have this type as a residue.				*/
+
+	for (stype = DBNumUserLayers; stype < DBNumTypes; stype++)
+	    if (TTMaskHasType(DBResidueMask(stype), type))
+		TTMaskSetType(&typeMask, stype);
+
 	if (DBSrPaintArea((Tile *) NULL, cellDef->cd_planes[pNum],
 		&TiPlaneRect, &typeMask, dbWritePaintFunc, (ClientData) &arg))
 	    goto ioerror;
@@ -1712,7 +1726,7 @@ DBCellWriteFile(cellDef, f)
     }
 
     /* And any properties */
-    if (cellDef->cd_props != (ClientData) NULL)
+    if (cellDef->cd_props != (ClientData)NULL)
     {
 	FPRINTF(f, "<< properties >>\n");
 	DBPropEnum(cellDef, dbWritePropFunc, (ClientData)f);
@@ -1864,14 +1878,17 @@ DBCellWrite(cellDef, fileName)
 	expandname = realname;
 
     /*
-     * If the locking logic works, this should not happen.  But it is
+     * If the locking logic works, this should not happen.  Files which
+     * are not editable should never be set to MODIFIED.  But it is
      * better to be extra safe.  If it does happen, it would be good to
-     * figure out why. */
+     * figure out why.
+     */
+
     if(cellDef->cd_flags & CDNOEDIT)
     {
 #ifdef FILE_LOCKS
-	TxPrintf("File %s is locked by another user or is read_only "
-		"and cannot be written\n", realname);
+	TxPrintf("File %s is locked by another user or "
+		"is read_only and cannot be written\n", realname);
 #else
 	TxPrintf("File %s is read_only and cannot be written\n", realname);
 #endif
@@ -2054,19 +2071,37 @@ dbWritePaintFunc(tile, cdarg)
     TileType type = TiGetType(tile);
 
 #ifdef NONMANHATTAN
+    int dir;
+
     if (IsSplit(tile))      
     { 
-	if (SplitLeftType(tile) == arg->wa_type)
-	    type = SplitLeftType(tile);
-	else if (SplitRightType(tile) == arg->wa_type)
-	    type = SplitRightType(tile);
-	else 
-    return 0;
+	if ((SplitLeftType(tile) == arg->wa_type) ||
+		((SplitLeftType(tile) >= DBNumUserLayers) &&
+		TTMaskHasType(DBResidueMask(SplitLeftType(tile)), arg->wa_type)))
+	{
+	    type = arg->wa_type;
+	    dir = 0x0;
+	}
+	else if ((SplitRightType(tile) == arg->wa_type) ||
+		((SplitRightType(tile) >= DBNumUserLayers) &&
+		TTMaskHasType(DBResidueMask(SplitRightType(tile)), arg->wa_type)))
+	{
+	    type = arg->wa_type;
+	    dir = 0x2;
+	}
+	else
+	    return 0;
     }
     else  
 #endif   
     if (type != arg->wa_type)
-	return 0;
+    {
+	if ((type < DBNumUserLayers) ||
+	    	(!TTMaskHasType(DBResidueMask(type), arg->wa_type)))
+	    return 0;
+
+	type = arg->wa_type;
+    }
 
     if (!arg->wa_found)
     {
@@ -2079,8 +2114,7 @@ dbWritePaintFunc(tile, cdarg)
     if (IsSplit(tile))
     {
 	static char *pos_diag[] = {"nw", "sw", "se", "ne"};
-	int dir = SplitDirection(tile) |
-		((SplitLeftType(tile) == arg->wa_type) ? 0x0 : 0x2);
+	dir |= SplitDirection(tile);
 	sprintf(pstring, "tri %d %d %d %d %s\n",
 	    	LEFT(tile) / arg->wa_reducer, BOTTOM(tile) / arg->wa_reducer,
 		RIGHT(tile) / arg->wa_reducer, TOP(tile) / arg->wa_reducer,
@@ -2119,8 +2153,8 @@ dbWriteCellFunc(cellUse, cdarg)
     ClientData cdarg;
 {
     struct writeArg *arg = (struct writeArg *) cdarg;
-    register Transform *t;
-    register Rect *b;
+    Transform *t;
+    Rect *b;
     char     cstring[256];
 
     t = &(cellUse->cu_transform);
@@ -2181,8 +2215,9 @@ DBGetTech(cellName)
     static char line[512];
     char *p;
 
-    // The use of "rb" below is a kludge to prevent this call from checking
-    // if the cell is locked. mdg 09/14/03
+    /* The use of "rb" below is a kludge to prevent this call from	*/
+    /* checking if the cell is locked. mdg 09/14/03			*/
+
     f = PaOpen(cellName, "rb", DBSuffix, Path, CellLibPath, (char **) NULL);
     if (f == NULL) return NULL;
 
