@@ -29,7 +29,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBtechname.c,v 1.
 #include <string.h>
 #endif
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
@@ -68,7 +68,8 @@ DBTechNameType(typename)
 {
     char *slash;
     TileType type;
-    int plane, i;
+    int plane;
+    LayerInfo *lp;
 
     slash = index(typename, '/');
     if (slash != NULL) *slash = 0;
@@ -77,20 +78,16 @@ DBTechNameType(typename)
     *slash = '/';
     if (type < 0) return type;
 
-    /* There's a plane qualification.  Locate the image. */
+    /* There's a plane qualification.  Make sure the type exists */
+    /* on the indicated plane.  If not, return an error.	 */
 
-    plane = (int) dbTechNameLookup(slash+1, &dbPlaneNameLists);
+    plane = (int) dbTechNameLookup(slash + 1, &dbPlaneNameLists);
     if (plane < 0) return -2;
-    if (DBPlane(type) == plane) return type;
 
-    for (i = DBNumUserLayers; i < DBNumTypes; i++)
-    {
-	if (TTMaskHasType(&DBLayerTypeMaskTbl[type], i)
-		&& (DBTypePlaneTbl[i] == plane))
-	{
-	    return (TileType) i;
-	}
-    }
+    lp = &dbLayerInfo[type];
+    if (PlaneMaskHasPlane(lp->l_pmask, plane))
+	return type;
+
     return -2;
 }
 
@@ -114,8 +111,9 @@ DBTechNameTypes(typename,bitmask)
     TileTypeBitMask	*bitmask;
 {
     char *slash;
-    TileType type,returntype;
-    int plane, i;
+    TileType type;
+    int plane;
+    LayerInfo *lp;
 
     TTMaskZero(bitmask);
     slash = index(typename, '/');
@@ -131,25 +129,18 @@ DBTechNameTypes(typename,bitmask)
 
     /* There's a plane qualification.  Locate the image. */
 
-    plane = (int) dbTechNameLookup(slash+1, &dbPlaneNameLists);
+    plane = (int) dbTechNameLookup(slash + 1, &dbPlaneNameLists);
     if (plane < 0) return -2;
-    if (DBPlane(type) == plane)
+
+    lp = &dbLayerInfo[type];
+    if (PlaneMaskHasPlane(lp->l_pmask, plane))
     {
-    	 TTMaskSetType(bitmask,type);
+    	 TTMaskSetType(bitmask, type);
     	 return type;
     } 
-    returntype = -2;
-    for (i = DBNumUserLayers; i < DBNumTypes; i++)
-    {
-	if (TTMaskHasType(&DBLayerTypeMaskTbl[type], i)
-		&& (DBTypePlaneTbl[i] == plane))
-	{
-	    TTMaskSetType(bitmask,i);
-	    if (returntype == -2) returntype = i;
-	}
-    }
-    return returntype;
+    return -2;
 }
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -208,6 +199,7 @@ DBTechNoisyNameType(typename)
  * ----------------------------------------------------------------------------
  */
 
+int
 DBTechNamePlane(planename)
     char *planename;	/* The name of the plane */
 {
@@ -277,7 +269,7 @@ char *
 DBTypeShortName(type)
     TileType type;
 {
-    register NameList *tbl;
+    NameList *tbl;
 
     for (tbl = dbTypeNameLists.sn_next;
 	    tbl != &dbTypeNameLists;
@@ -297,7 +289,7 @@ char *
 DBPlaneShortName(pNum)
     int pNum;
 {
-    register NameList *tbl;
+    NameList *tbl;
 
     for (tbl = dbPlaneNameLists.sn_next;
 	    tbl != &dbPlaneNameLists;
@@ -332,6 +324,7 @@ DBPlaneShortName(pNum)
  * ----------------------------------------------------------------------------
  */
 
+int
 DBTechTypesToPlanes(mask)
     TileTypeBitMask *mask;
 {
@@ -376,7 +369,7 @@ DBTechPrintTypes(dolist)
 {
     TileType i;
     NameList *p;
-    bool first, found;
+    bool first;
     DefaultType *dtp;
     char *keepname;
 
@@ -521,21 +514,19 @@ DBTechPrintCanonicalType(layername)
  *	a parenthesized group.  For example, ~(x,y)/foo refers to
  *	all layers on plane "foo" except "x" and "y".
  *
- *	This routine has been modified from the original to return a
- *	plane mask of the planes specified.  This allows the DRC tech
- *	parser to determine a plane for a specification such as
- *	"~(gv1)/via1" where such a specification results in only "space"
- *	bits, from which a single plane cannot be recovered.  This
- *	modification prevents the necessity of explicitly stating the
- *	plane of "OKtypes" in the DRC "edge4way" rule.
+ *	Finally, magic version 7.3 defines *x to mean "x and all
+ *	contact layers containing x as a residue".  Thus, for example,
+ *	*metal1 expands to m1,pc,ndc,pdc,nsc,psc,m2c,...  Because many
+ *	connect, cif, extract, and drc rules list all these layers,
+ *	the asterisk notation makes the techfile shorter and more
+ *	readable.
  *
  * Results:
- *	Plane mask of the planes affected by the list of types.
+ *	Returns a plane mask of all the planes specified.
  *
  * Side effects:
  *	Error messages are output if layers aren't understood.
  *	Sets the TileTypeBitMask 'mask' to all the layer names indicated.
- *	Sets the plane mask 'plane_return' to all the planes specified.
  *
  * ----------------------------------------------------------------------------
  */
@@ -545,14 +536,14 @@ DBTechNoisyNameMask(layers, mask)
     char *layers;			/* String to be parsed. */
     TileTypeBitMask *mask;		/* Where to store the layer mask. */
 {
-    register char *p, *p2, c;
-    int plane_return = 0;
-    TileTypeBitMask m2;            /* Each time around the loop, we will
-                                         * form the mask for one section of
-                                         * the layer string.
-                                         */
+    char *p, *p2, c;
+    TileTypeBitMask m2;        /* Each time around the loop, we will
+				* form the mask for one section of
+				* the layer string.
+				*/
     char save;
     bool allBut;
+    int planemask = 0;
 
     TTMaskZero(mask);
     p = layers;
@@ -600,7 +591,7 @@ DBTechNoisyNameMask(layers, mask)
 	    }
 	    save = *p2;
 	    *p2 = 0;
-	    plane_return |= DBTechNoisyNameMask(p, &m2);
+	    planemask |= DBTechNoisyNameMask(p, &m2);
 	    *p2 = save;
 	    if (save == ')') p = p2 + 1;
 	    else p = p2;
@@ -608,7 +599,6 @@ DBTechNoisyNameMask(layers, mask)
 	else
 	{
 	    TileType t, rtype;
-	    TileTypeBitMask rmask;
 	    bool allResidues = FALSE;
 
 	    /* No parenthesis, so just parse off a single name.  Layer
@@ -629,35 +619,27 @@ DBTechNoisyNameMask(layers, mask)
 		save = *p2;
 		*p2 = 0;
 
-		/* Check for asterisk notation */
+		/* Check for asterisk notation, meaning to include	*/
+		/* all types which have this type as a residue.		*/
 		if (*p == '*')
 		{
 		    allResidues = TRUE;
 		    p++;
 		}
-	
+
 		t = DBTechNoisyNameType(p);
 		if (t >= 0) m2 = DBLayerTypeMaskTbl[t];
 		*p2 = save;
 
 		/* Include all types which have t as a residue */
 		if (allResidues)
-		{
-		    TileTypeBitMask rmask;
-		    DBResidueMask(t, &rmask);
-		    TTMaskSetMask(&m2, &rmask);
-		}
+		    for (rtype = TT_TECHDEPBASE; rtype < DBNumUserLayers; rtype++)
+			if (TTMaskHasType(DBResidueMask(rtype), t))
+			    TTMaskSetType(&m2, rtype);
 	    }
 	    p = p2;
 	}
 
-	/* If we do not have a plane specifier, but we are asking for a	*/
-	/* plane mask to be returned, then retrieve the plane mask from	*/
-	/* the specified layers (before inverting, if requested)	*/
-
-	if (*p != '/')
-	    plane_return |= DBTechTypesToPlanes(&m2);
-
 	/* Now negate the layers, if that is called for. */
 
 	if (allBut) TTMaskCom(&m2);
@@ -678,16 +660,24 @@ DBTechNoisyNameMask(layers, mask)
 	    if (plane > 0)
 	    {
 		TTMaskAndMask(&m2, &DBPlaneTypes[plane]);
-		plane_return = PlaneNumToMaskBit(plane);
+		planemask = PlaneNumToMaskBit(plane);
 	    }
 	}
+	else
+	{
+	    TileType t; 
+
+	    planemask = 0;
+	    for (t = TT_TECHDEPBASE; t < DBNumTypes; t++)
+		if (TTMaskHasType(&m2, t))
+		    planemask |= DBTypePlaneMaskTbl[t];
+	}
 
 	TTMaskSetMask(mask, &m2);
 	while (*p == ',') p++;
     }
-    return plane_return;
+    return planemask;
 }
-
 
 /*
  * ----------------------------------------------------------------------------
@@ -732,7 +722,7 @@ DBTechMinSetPlanes(typeMask, newTypes)
 	if (!TTMaskHasType(&typeMask, i) || DBConnPlanes[i] != 0)
 	    continue;
 	TTMaskSetType(newTypes, i);
-	planes |= PlaneNumToMaskBit(DBTypePlaneTbl[i]);
+	planes |= PlaneNumToMaskBit(DBPlane(i));
     }
 
     /*
@@ -759,7 +749,7 @@ DBTechMinSetPlanes(typeMask, newTypes)
 	else
 	{
 	    TTMaskSetType(newTypes, i);
-	    planes |= PlaneNumToMaskBit(DBTypePlaneTbl[i]);
+	    planes |= PlaneNumToMaskBit(DBPlane(i));
 	}
     }
 
@@ -795,12 +785,12 @@ DBTechSubsetLayers(src, mask, result)
     TileTypeBitMask *result;		/* Store subset here. */
 {
     TileTypeBitMask tmp,tmp2,clrmask;
-    register int i;
-    bool success = TRUE;
+    int i;
 
     TTMaskZero(result);
     TTMaskZero(&clrmask);
-    for (i = 0; i < DBNumUserLayers; i++)
+    /* for (i = 0; i < DBNumUserLayers; i++) */	/* ? */
+    for (i = 0; i < DBNumTypes; i++)
     {
 	TTMaskAndMask3(&tmp, &src, &DBLayerTypeMaskTbl[i]);
 	if (!TTMaskIsZero(&tmp))
