@@ -58,6 +58,11 @@ TileTypeBitMask dbNotDefaultPaintTbl[NT];
 
 int dbNumSavedRules = 0;
 Rule dbSavedRules[NT];
+
+/* Forward declarations */
+
+extern void dbTechBitTypeInit();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -82,8 +87,8 @@ Rule dbSavedRules[NT];
 void
 DBTechInitCompose()
 {
-    register TileType s, t, r;
-    int pNum, ps;
+    TileType s, t, r;
+    int ps;
     PaintResultType *stype, *dtype;
     TileTypeBitMask *ttype;
 
@@ -194,7 +199,7 @@ DBTechInitCompose()
     {
 	if ((ps = DBPlane(s)) > 0)
 	{
-	    for (t = 0; t < DBNumUserLayers; t++)
+	    for (t = 0; t < DBNumTypes; t++)
 	    {
 		if (DBPlane(t) > 0)
 		{
@@ -265,12 +270,13 @@ DBTechInitCompose()
  * ----------------------------------------------------------------------------
  */
 
+void
 dbTechBitTypeInit(bitToType, n, pNum, composeFlag)
-    register TileType *bitToType;
+    TileType *bitToType;
     int n, pNum;
     bool composeFlag;
 {
-    register int i, j;
+    int i, j;
     TileType have, type;
 
     for (i = 0; i < n; i++)
@@ -289,6 +295,8 @@ dbTechBitTypeInit(bitToType, n, pNum, composeFlag)
 }
 
 /* Returns nonzero if exactly one bit set */ 
+
+int
 dbIsPrimary(n)
     int n;
 {
@@ -338,7 +346,7 @@ DBTechAddCompose(sectionName, argc, argv)
     int argc;
     char *argv[];
 {
-    register TileType type, r, s;
+    TileType type, r, s;
     int pNum, ruleType, i;
     static char *ruleNames[] =
 	{ "compose", "decompose", "paint", "erase", 0 };
@@ -450,8 +458,8 @@ dbTechSaveCompose(ruleType, t, argc, argv)
     int argc;
     char *argv[];
 {
-    register TileType r, s;
-    register Rule *rp;
+    TileType r, s;
+    Rule *rp;
 
     rp = &dbSavedRules[dbNumSavedRules++];
     rp->r_ruleType = ruleType;
@@ -526,19 +534,18 @@ dbTechSaveCompose(ruleType, t, argc, argv)
 bool
 dbTechCheckImages(t, r, s)
     TileType t;			/* Type that is composed */
-    register TileType r;	/* First constituent */
+    TileType r;	/* First constituent */
     TileType s;			/* Second constituent */
 {
-    register int pNum, pMask;
+    int pNum, pMask;
 
     if (pMask = (PlaneMask(r) & ~PlaneMask(s)))
     {
 	for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
-	    if (PlaneMaskHasPlane(pMask, pNum)
-		    && dbImageOnPlane(t, pNum) != dbImageOnPlane(r, pNum))
+	    if (PlaneMaskHasPlane(pMask, pNum) && (t != r))
 	    {
-		TechError("Result image on plane %s must be the same as "
-			"image of %s on plane %s\n",
+		TechError("Result image on plane %s must be the same "
+			"as image of %s on plane %s\n",
 			DBPlaneLongName(pNum),
 			DBTypeLongName(r),
 			DBPlaneLongName(pNum));
@@ -567,7 +574,6 @@ dbTechCheckImages(t, r, s)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
 bool
 dbTechAddPaint(sectionName, argc, argv)
     char *sectionName;
@@ -591,7 +597,8 @@ dbTechAddPaint(sectionName, argc, argv)
 	if (t1 == TT_SPACE)
 	{
 	    TechError("<%s, %s, %s>:\n"
-			"Must specify plane in paint table for painting space\n",
+			"Must specify plane in paint table for "
+			"painting space\n",
 			argv[0], argv[1], argv[2]);
 	    return FALSE;
 	}
@@ -599,18 +606,28 @@ dbTechAddPaint(sectionName, argc, argv)
     }
     else if ((pNum = DBTechNoisyNamePlane(argv[3])) < 0) return FALSE;
 
-    if (tres != TT_SPACE && DBPlane(tres) != pNum)
+    if ((tres != TT_SPACE) && (DBPlane(tres) != pNum))
     {
-	if (argc == 3)
+	if (DBIsContact(tres))
+	{
+	    TileTypeBitMask *rmask = DBResidueMask(tres);
+	    TileType rtype;
+	    for (rtype = TT_TECHDEPBASE; rtype < DBNumUserLayers; rtype++)
+		if (TTMaskHasType(rmask, rtype))
+		    dbSetPaintEntry(t1, t2, DBPlane(rtype), tres);
+	}
+	else if (argc == 3)
 	    TechError("<%s, %s, %s>:\n"
-		"Warning: type %s (%d) belongs on plane %s (%d), not %s (%d)\n",
+		"Warning: type %s (%d) belongs on plane %s (%d), "
+		"not %s (%d)\n",
 		argv[0], argv[1], argv[2],
 		argv[2], tres,
 		DBPlaneLongName(DBPlane(tres)), DBPlane(tres),
 		argv[0], pNum);
 	else
 	    TechError("<%s, %s, %s, %s>:\n"
-		"Warning: type %s (%d) belongs on plane %s (%d), not %s (%d)\n",
+		"Warning: type %s (%d) belongs on plane %s (%d), "
+		"not %s (%d)\n",
 		argv[0], argv[1], argv[2], argv[3],
 		argv[2], tres,
 		DBPlaneLongName(DBPlane(tres)), DBPlane(tres),
@@ -706,7 +723,7 @@ dbTechAddErase(sectionName, argc, argv)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 dbTechCheckPaint(where)
     char *where;	/* If non-null, print this as header */
 {
@@ -759,16 +776,18 @@ dbTechCheckPaint(where)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 dbTechPrintPaint(where, doPaint, contactsOnly)
     char *where;	/* If non-null, print this as header */
     bool doPaint;	/* TRUE -> print paint tables, FALSE -> print erase */
     bool contactsOnly;
 {
     TileType have, paint, erase, result;
+    int plane;
+    LayerInfo *lp;
 
     if (where)
-	TxPrintf("\f\n%s:\n\n", where);
+	TxPrintf("\n%s:\n\n", where);
 
     if (doPaint)
     {
@@ -776,16 +795,27 @@ dbTechPrintPaint(where, doPaint, contactsOnly)
 	for (have = TT_TECHDEPBASE; have < DBNumTypes; have++)
 	{
 	    if (contactsOnly && !IsContact(have)) continue;
-	    for (paint = TT_TECHDEPBASE; paint < DBNumUserLayers; paint++)
+	    for (paint = TT_TECHDEPBASE; paint < DBNumTypes; paint++)
 	    {
 		if (contactsOnly && !IsContact(paint)) continue;
-		result = DBStdPaintEntry(have, paint, DBPlane(have));
-		if (result != have)
+		for (plane = PL_TECHDEPBASE; plane < DBNumPlanes; plane++)
 		{
-		    TxPrintf("%s + %s -> %s\n",
-			    DBTypeShortName(have),
-			    DBTypeShortName(paint),
-			    DBTypeShortName(result));
+		    lp = &dbLayerInfo[have];
+		    if (!PlaneMaskHasPlane(lp->l_pmask, plane))
+			continue;
+
+		    result = DBStdPaintEntry(have, paint, plane);
+		    if (result != have)
+		    {
+		        TxPrintf("%s ",
+				DBTypeShortName(have));
+			if (IsContact(have))
+		            TxPrintf("(on %s) ",
+					DBPlaneLongName(plane));
+		        TxPrintf(" + %s -> %s\n",
+				DBTypeShortName(paint),
+				DBTypeShortName(result));
+		    }
 		}
 	    }
 	}
@@ -796,16 +826,27 @@ dbTechPrintPaint(where, doPaint, contactsOnly)
 	for (have = TT_TECHDEPBASE; have < DBNumTypes; have++)
 	{
 	    if (contactsOnly && !IsContact(have)) continue;
-	    for (erase = TT_TECHDEPBASE; erase < DBNumUserLayers; erase++)
+	    for (erase = TT_TECHDEPBASE; erase < DBNumTypes; erase++)
 	    {
 		if (contactsOnly && !IsContact(erase)) continue;
-		result = DBStdEraseEntry(have, erase, DBPlane(have));
-		if (result != have)
+		for (plane = PL_TECHDEPBASE; plane < DBNumPlanes; plane++)
 		{
-		    TxPrintf("%s - %s -> %s\n",
-			    DBTypeShortName(have),
-			    DBTypeShortName(erase),
-			    DBTypeShortName(result));
+		    lp = &dbLayerInfo[have];
+		    if (!PlaneMaskHasPlane(lp->l_pmask, plane))
+			continue;
+
+		    result = DBStdEraseEntry(have, erase, plane);
+		    if (result != have)
+		    {
+		        TxPrintf("%s ",
+				DBTypeShortName(have));
+			if (IsContact(have))
+		            TxPrintf("(on %s) ",
+					DBPlaneLongName(plane));
+		        TxPrintf(" - %s -> %s\n",
+				DBTypeShortName(erase),
+				DBTypeShortName(result));
+		    }
 		}
 	    }
 	}
