@@ -37,75 +37,75 @@ static char rcsid[] = "$Header: /ufs/repository/magic/commands/CmdINTERP.c,v 1.8
  * Standard DBWind command set
  */
 
-extern Void CmdAddPath(), CmdArray();
-extern Void CmdBox(), CmdCellname();
-extern Void CmdClockwise(), CmdCopy(), CmdCorner();
-extern Void CmdDelete(), CmdDown(), CmdDrc(), CmdDump();
-extern Void CmdEdit(), CmdElement(), CmdErase(), CmdExpand(), CmdExtract();
-extern Void CmdFeedback(), CmdFill(), CmdFindBox(), CmdFindLabel(), CmdFlush();
-extern Void CmdGetcell(), CmdGrid(), CmdIdentify();
-extern Void CmdLabel(), CmdLoad();
-extern Void CmdMove(), CmdPaint(), CmdPath(), CmdPlow();
-extern Void CmdPort(), CmdProperty();
-extern Void CmdSave(), CmdScaleGrid(), CmdSee();
-extern Void CmdSelect(), CmdSideways();
-extern Void CmdShell(), CmdSnap();
-extern Void CmdStretch(), CmdStraighten();
-extern Void CmdTech(), CmdTool(), CmdUnexpand();
-extern Void CmdUpsidedown(), CmdWhat(), CmdWire(), CmdWriteall();
-extern Void CmdGoto(), CmdFlatten(), CmdXload();
+extern void CmdAddPath(), CmdArray();
+extern void CmdBox(), CmdCellname();
+extern void CmdClockwise(), CmdCopy(), CmdCorner();
+extern void CmdDelete(), CmdDown(), CmdDrc(), CmdDump();
+extern void CmdEdit(), CmdElement(), CmdErase(), CmdExpand(), CmdExtract();
+extern void CmdFeedback(), CmdFill(), CmdFindBox(), CmdFindLabel(), CmdFlush();
+extern void CmdGetcell(), CmdGrid(), CmdIdentify();
+extern void CmdLabel(), CmdLoad();
+extern void CmdMove(), CmdPaint(), CmdPath(), CmdPlow();
+extern void CmdPort(), CmdProperty();
+extern void CmdSave(), CmdScaleGrid(), CmdSee();
+extern void CmdSelect(), CmdSideways();
+extern void CmdShell(), CmdSnap();
+extern void CmdStretch(), CmdStraighten();
+extern void CmdTech(), CmdTool(), CmdUnexpand();
+extern void CmdUpsidedown(), CmdWhat(), CmdWire(), CmdWriteall();
+extern void CmdGoto(), CmdFlatten(), CmdXload();
 
 /*
  * Nonmanhattan geometry extensions
  */
 
 #ifdef NONMANHATTAN
-extern Void CmdSplit();
-extern Void CmdSplitErase();
+extern void CmdSplit();
+extern void CmdSplitErase();
 #endif
 
 /*
  * Wizard commands
  */
 
-extern Void CmdCoord();
-extern Void CmdExtractTest();
-extern Void CmdExtResis();
-extern Void CmdPsearch();
-extern Void CmdPlowTest();
-extern Void CmdShowtech();
-extern Void CmdTilestats();
-extern Void CmdTsearch();
-extern Void CmdWatch();
+extern void CmdCoord();
+extern void CmdExtractTest();
+extern void CmdExtResis();
+extern void CmdPsearch();
+extern void CmdPlowTest();
+extern void CmdShowtech();
+extern void CmdTilestats();
+extern void CmdTsearch();
+extern void CmdWatch();
 
 /*
  * CIF and GDS commands
  */
 
 #ifdef CIF_MODULE
-extern Void CmdCif();
+extern void CmdCif();
 #endif
 #ifdef CALMA_MODULE
-extern Void CmdCalma();
+extern void CmdCalma();
 #endif
 
 /*
  * Plot module commands
  */
 #ifdef PLOT_MODULE
-extern Void CmdPlot();
+extern void CmdPlot();
 #endif
 #ifdef PLOT_AUTO
-extern Void CmdAutoPlot();
+extern void CmdAutoPlot();
 #endif
 
 /*
  * SIM module commands
  */
 #ifndef NO_SIM_MODULE
-extern Void CmdGetnode();
+extern void CmdGetnode();
 #ifdef RSIM_MODULE
-extern Void CmdRsim(), CmdSimCmd(), CmdStartRsim();
+extern void CmdRsim(), CmdSimCmd(), CmdStartRsim();
 #endif
 #endif
 
@@ -114,22 +114,22 @@ extern Void CmdRsim(), CmdSimCmd(), CmdStartRsim();
  */
 
 #ifdef ROUTE_MODULE
-extern Void CmdGARouterTest(), CmdGRouterTest(), CmdIRouterTest();
-extern Void CmdMZRouterTest(), CmdSeeFlags();
-extern Void CmdChannel(), CmdGaRoute(), CmdIRoute(), CmdRoute();
+extern void CmdGARouterTest(), CmdGRouterTest(), CmdIRouterTest();
+extern void CmdMZRouterTest(), CmdSeeFlags();
+extern void CmdChannel(), CmdGaRoute(), CmdIRoute(), CmdRoute();
 #endif
 #ifdef ROUTE_AUTO
-extern Void CmdAutoRoute();
+extern void CmdAutoRoute();
 #endif
 
 /*
  * LEF module commands
  */
 #ifdef LEF_MODULE
-extern Void CmdLef();
+extern void CmdLef();
 #endif
 #ifdef LEF_AUTO
-extern Void CmdAutoLef();
+extern void CmdAutoLef();
 #endif
 
 /*
@@ -137,10 +137,8 @@ extern Void CmdAutoLef();
  */ 
 
 #ifdef MAGIC_WRAPPER
-extern Void CmdAutoExtToSim();
-extern Void CmdAutoExtToSpice();
-extern Void CmdSearch();
-extern Void CmdCellsearch();
+extern void CmdAutoExtToSim();
+extern void CmdAutoExtToSpice();
 #endif
 
 /*
@@ -148,7 +146,7 @@ extern Void CmdCellsearch();
  */
 
 #ifdef USE_READLINE
-extern Void CmdHistory();
+extern void CmdHistory();
 #endif
 
 /*
@@ -156,8 +154,8 @@ extern Void CmdHistory();
  */
 
 #ifdef	LLNL
-extern Void CmdMakeSW();
-extern Void CmdSgraph();
+extern void CmdMakeSW();
+extern void CmdSgraph();
 #endif	/* LLNL */
 
 /*
@@ -218,34 +216,34 @@ DBWInitCommands()
 	CmdAddPath, FALSE);
     WindAddCommand(DBWclientID,
 	"array xsize ysize	OR\n"
-	"array xlo xhi ylo yhi\n\
-			array everything in selection",
+	"array xlo xhi ylo yhi\n"
+	"			array everything in selection",
 	CmdArray, FALSE);
     WindAddCommand(DBWclientID,
-	"box [dir [amount]]	move box dist units in direction or (with\n\
-			no arguments) show box size",
+	"box [dir [amount]]	move box dist units in direction or (with\n"
+	"			no arguments) show box size",
 	CmdBox, FALSE);
     WindAddCommand(DBWclientID,
 	"cellname [list] children|parents|exists|self [name]	OR\n"
-	"cellname [list] allcells|topcells\n\
-			list cells by relationship to cell \"name\", or\n\
-			the current selection if no name given.  \"list\"\n\
-			returns result as a list. \"exists + name\" returns\n\
-			true or false (also see command instance)",
+	"cellname [list] allcells|topcells\n"
+	"			list cells by relationship to cell \"name\", or\n"
+	"			the current selection if no name given.  \"list\"\n"
+	"			returns result as a list. \"exists + name\" returns\n"
+	"			true or false (also see command instance)",
 	CmdCellname, FALSE);
     WindAddCommand(DBWclientID,
 	"clockwise [deg]		rotate selection and box clockwise",
 	CmdClockwise, FALSE);
     WindAddCommand(DBWclientID,
 	"copy [dir [amount]]	OR\n"
-	"copy to x y		copy selection:  what used to be at box\n\
-			lower-left will be copied at cursor location (or,\n\
-			copy will appear amount units in dir from original);\n\
-			second form will copy to location x y",
+	"copy to x y		copy selection:  what used to be at box\n"
+	"			lower-left will be copied at cursor location (or,\n"
+	"			copy will appear amount units in dir from original);\n"
+	"			second form will copy to location x y",
 	CmdCopy, FALSE);
     WindAddCommand(DBWclientID,
-	"corner d1 d2 [layers]	make L-shaped wires inside box, filling\n\
-			first in direction d1, then in d2",
+	"corner d1 d2 [layers]	make L-shaped wires inside box, filling\n"
+	"			first in direction d1, then in d2",
 	CmdCorner, FALSE);
     WindAddCommand(DBWclientID,
 	"delete			delete everything in selection",
@@ -254,8 +252,8 @@ DBWInitCommands()
 	"down			load selected cell into a window",
 	CmdDown, FALSE);
     WindAddCommand(DBWclientID,
-	"drc option		design rule checker; type \"drc help\"\n\
-			for information on options",
+	"drc option		design rule checker; type \"drc help\"\n"
+	"			for information on options",
 	CmdDrc, FALSE);
     WindAddCommand(DBWclientID,
 	"dump cell [child refPointC] [parent refPointP]\n\
@@ -471,14 +469,6 @@ DBWInitCommands()
 	"exttospice [args]	convert extracted file(s) to a SPICE format file;"
 	" type\n\t\t\t\"exttopice help\" for information on options",
 	CmdAutoExtToSpice, FALSE);
-
-    /* Add the low-level TCL tile search procedures */
-    WindAddCommand(DBWclientID,
-	"search [layers] proc	low-level tile search",
-	CmdSearch, FALSE);
-    WindAddCommand(DBWclientID,
-	"cellsearch [instances] proc	low-level cell search",
-	CmdCellsearch, FALSE);
 #endif
 
 
