@@ -23,6 +23,9 @@ static char rcsid[] = "$Header: /ufs/repository/magic/dbwind/DBWdisplay.c,v 1.5
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -145,8 +148,7 @@ extern int dbwWindowFunc(), dbwChangedFunc();
  * ----------------------------------------------------------------------------
  */
 
-	/* ARGSUSED */
-Void
+void
 DBWredisplay(w, rootArea, clipArea)
     MagWindow *w;			/* Window some of whose contents are to be
 				 * redisplayed.
@@ -172,11 +174,6 @@ DBWredisplay(w, rootArea, clipArea)
 	    rootArea->r_xtop, rootArea->r_ytop);
     */
 
-#ifdef MAGIC_WRAPPER
-    /* Honor the display suspend state */
-    if (GrDisplayStatus == DISPLAY_SUSPEND) return 0;
-#endif
-
     GrLock(w, TRUE);
 
     /* Round up the redisplay area by 1 pixel on all sides.  This
@@ -336,7 +333,7 @@ DBWredisplay(w, rootArea, clipArea)
 	    disStyle = i + TECHBEGINSTYLES;
 	    disWasPale = FALSE;		/* Using normal solid style */
 	    dbwNeedStyle = TRUE;	/* Haven't set style yet */
-	    (void) DBTreeSrTiles(&scontext, &layers, bitMask,
+	    (void) DBTreeSrUniqueTiles(&scontext, &layers, bitMask,
 		    dbwPaintFunc, (ClientData) NULL);
 	    if (dbwIsLocked)
 	    {
@@ -518,12 +515,13 @@ DBWredisplay(w, rootArea, clipArea)
  *
  * ----------------------------------------------------------------------------
  */
+
 int
 dbwPaintFunc(tile, cxp)
-    register Tile *tile;	/* Tile to be redisplayed. */
+    Tile *tile;	/* Tile to be redisplayed. */
     TreeContext *cxp;		/* From DBTreeSrTiles */
 {
-    register SearchContext *scx = cxp->tc_scx;
+    SearchContext *scx = cxp->tc_scx;
 			/* Contains pointer to use containing def
 			 * in which tile appears, and transform to
 			 * screen coordinates.
@@ -712,7 +710,7 @@ DBWDrawLabel(text, rect, pos, style, labelSize, sizeBox)
  *
  * ----------------------------------------------------------------------------
  */
-    /*ARGSUSED*/
+
 int
 dbwLabelFunc(scx, label, tpath)
     SearchContext *scx;		/* Contains pointer to use containing def in
@@ -775,6 +773,7 @@ dbwLabelFunc(scx, label, tpath)
  *
  * ----------------------------------------------------------------------------
  */
+
 int
 dbwBBoxFunc(scx)
     SearchContext *scx;		/* Describes context of cell. */
@@ -822,6 +821,7 @@ dbwBBoxFunc(scx)
  *
  * ----------------------------------------------------------------------------
  */
+
 int
 dbwTileFunc(tile)
     Tile *tile;				/* A tile to be redisplayed. */
@@ -1267,7 +1267,7 @@ DBWLabelChanged(cellDef, text, area, pos, mask)
     CellDef *cellDef;		/* Cell definition containing label. */
     char *text;			/* The text of the label. */
     Rect *area;			/* The area of the label. */
-    int pos;			/* Relative position of text to area.
+    int pos;			/* Relative position of text to area. */
     int mask;			/* Mask of windows where changes should be
 				 * reflected (DBW_ALLWINDOWS selects all
 				 * windows, and is usually the right value.)
@@ -1384,7 +1384,7 @@ global TileTypeBitMask	*DBWStyleToTypesTbl = NULL;
 void
 DBWTechInitStyles()
 {
-    register int i;
+    int i;
 
     if (DBWNumStyles == 0)
     {
@@ -1457,14 +1457,13 @@ DBWTechParseStyle(stylestr)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
 bool
 DBWTechAddStyle(sectionName, argc, argv)
     char *sectionName;
     int argc;
     char *argv[];
 {
-    TileType t;
+    TileType t, r;
     int i, sidx;
     static char styleType[50];
 
@@ -1495,7 +1494,7 @@ DBWTechAddStyle(sectionName, argc, argv)
 
 	GrSetCursor(0);
     }
-    else 
+    else
     {
 	if ((t = DBTechNoisyNameType(argv[0])) < 0) return (FALSE);
 
@@ -1507,7 +1506,20 @@ DBWTechAddStyle(sectionName, argc, argv)
 	    if (sidx < 0)
 		TechError("Invalid style \"%s\" for tile type %s\n", argv[i], argv[0]);
 	    else
+	    {
 		TTMaskSetType(&DBWStyleToTypesTbl[sidx], t);
+
+		/* If type t is a contact, then any stacked contact type which	*/
+		/* has t as a residue, and for which the home plane of the	*/
+		/* stacked contact is also the home plane of t, should be added	*/
+		/* to the list of types to be painted with this style.		*/
+
+		if (DBIsContact(t) && (t < DBNumUserLayers))
+		    for (r = DBNumUserLayers; r < DBNumTypes; r++)
+			if (TTMaskHasType(DBResidueMask(r), t)
+				&& (DBPlane(r) == DBPlane(t)))
+			    TTMaskSetType(&DBWStyleToTypesTbl[sidx], r);
+	    }
 	}
     }
     return TRUE;
