@@ -13,8 +13,11 @@
  */
 
 #include <stdio.h>
+#include <string.h>
 
-#include "tcltk/tclmagic.h"
+#ifdef MAGIC_WRAPPER
+#include "magic/tclmagic.h"
+#endif
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -252,7 +255,7 @@ DBWPrintElements(cellDef, flagmask)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 DBWElementRedraw(window, plane)
     MagWindow *window;		/* Window in which to redraw. */
     Plane *plane;		/* Non-space tiles on this plane mark what
@@ -354,7 +357,7 @@ DBWElementRedraw(window, plane)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 dbwElementUndraw(mw, elem)
     MagWindow *mw;
     DBWElement *elem;		/* The element to erase */
@@ -568,7 +571,8 @@ DBWElementInbox(area)
  * 	Adds a new element to the element hash table.
  *
  * Results:
- *	None.
+ *	None, except
+ *	DBWElementAdd(): returns Pointer to a DBWElement structure.
  *
  * Side effects:
  *	CellDef's ancestors are searched until its first root definition
