@@ -105,7 +105,7 @@ static CellDef *dbwfbRootDef;		/* To pass root cell definition from
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 DBWFeedbackRedraw(window, plane)
     MagWindow *window;		/* Window in which to redraw. */
     Plane *plane;		/* Non-space tiles on this plane mark what
@@ -519,7 +519,8 @@ DBWFeedbackShow()
  *	feedback area.
  *
  * Results:
- *	None.
+ *	Returns a pointer to the text associated with the Nth feedback
+ *	entry.
  *
  * Side effects:
  *	The parameter "area" is filled with the area of the nth
