@@ -47,7 +47,7 @@ static dbwBitMask = 0;
 #define MAX_BITMASK	0177777
 #define MAX_BITS_IN_MASK 16
 
-extern Void DBWredisplay();		/* Defined in DBWdisplay.c */
+extern void DBWredisplay();		/* Defined in DBWdisplay.c */
 
 /* The following variable is used to allow somebody besides ourselves
  * to take over button handling for database windows.  If it is NULL
@@ -55,7 +55,7 @@ extern Void DBWredisplay();		/* Defined in DBWdisplay.c */
  * the address of a procedure to handle buttons.
  */
 
-static Void (*dbwButtonHandler)() = NULL;
+static int (*dbwButtonHandler)() = NULL;
 
 /*
  * ----------------------------------------------------------------------------
@@ -76,6 +76,7 @@ static Void (*dbwButtonHandler)() = NULL;
  * ----------------------------------------------------------------------------
  */
 
+bool
 DBWcreate(window, argc, argv)
     MagWindow *window;
     int argc;
@@ -165,6 +166,7 @@ DBWcreate(window, argc, argv)
  * ----------------------------------------------------------------------------
  */
 
+bool
 DBWdelete(window)
     MagWindow *window;
 {
@@ -609,7 +611,7 @@ DBWexit()
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 DBWcommands(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -654,7 +656,7 @@ DBWcommands(w, cmd)
  *	From now on, all button pushes within database windows are
  *	passed to buttonProc, in the following form:
  *
- *	    Void
+ *	    int 
  *	    buttonProc(w, cmd)
  *		MagWindow *w;
  *		TxCommand *cmd;
@@ -664,10 +666,10 @@ DBWcommands(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void (*(DBWNewButtonHandler(buttonProc)))()
-    Void (*buttonProc)();		/* New button handler. */
+int (*(DBWNewButtonHandler(buttonProc)))()
+    int (*buttonProc)();		/* New button handler. */
 {
-    Void (*result)();
+    int (*result)();
 
     result = dbwButtonHandler;
     dbwButtonHandler = buttonProc;
@@ -690,7 +692,7 @@ Void (*(DBWNewButtonHandler(buttonProc)))()
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 DBWupdate()
 {
     DBWFeedbackShow();
@@ -715,25 +717,25 @@ DBWupdate()
 extern bool MakeMainWindow;
 #endif
 
-int
+void
 DBWinit()
 {
     MagWindow *initialWindow;
     int i;
     static char *doc =
-"You are currently using the \"box\" tool.  The button actions are:\n\
-   left    - move the box so its lower-left corner is at cursor position\n\
-   right   - resize box by moving upper-right corner to cursor position\n\
-   middle  - paint box area with material underneath cursor\n\
-You can move or resize the box by different corners by pressing left\n\
-    or right, holding it down, moving the cursor near a different corner\n\
-    and clicking the other (left or right) button down then up without\n\
-    releasing the initial button.\n";
+	"You are currently using the \"box\" tool.  The button actions are:\n"
+	"   left    - move the box so its lower-left corner is at cursor position\n"
+	"   right   - resize box by moving upper-right corner to cursor position\n"
+	"   middle  - paint box area with material underneath cursor\n"
+	"You can move or resize the box by different corners by pressing left\n"
+	"    or right, holding it down, moving the cursor near a different corner\n"
+	"    and clicking the other (left or right) button down then up without\n"
+	"    releasing the initial button.\n";
 
     /* Initialize */
     DBWclientID = WindAddClient("layout", DBWcreate, DBWdelete, 
 	    DBWredisplay, DBWcommands, DBWupdate, DBWexit,
-	    ( Void (*)() ) NULL,
+	    (void (*)()) NULL,
 	    (GrGlyph *) NULL);
 
     /* Add all of the commands for the DBWind interface.  These	*/
