@@ -67,6 +67,8 @@ bool DBWSnapToGrid = DBW_SNAP_LAMBDA;
 /* Forward reference: */
 
 extern int DBWToolDraw();
+extern void toolSnapToGrid();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -423,7 +425,7 @@ dbwRecordBoxArea(erase)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 DBWDrawBox(window, plane)
     MagWindow *window;		/* Window in which to redraw box. */
     Plane *plane;		/* Non-space tiles on this plane indicate
@@ -813,13 +815,14 @@ ToolMoveCorner(corner, point, screenCoords, rootDef)
  * ----------------------------------------------------------------------------
  */
 
+void
 toolSnapToGrid(w, p, rEnclose)
     MagWindow *w;
     Point *p;
     Rect *rEnclose;
 {
     DBWclientRec *crec = (DBWclientRec *) w->w_clientData;
-    register Rect *r;
+    Rect *r;
     Rect lr;
     int xd, yd, xlo, xhi, ylo, yhi, xtmp, ytmp;
 
