@@ -74,8 +74,8 @@ extern int drcTile();
 
 int
 areaCheck(tile, arg) 
-    register Tile *tile;
-    register struct drcClientData *arg;
+    Tile *tile;
+    struct drcClientData *arg;
 {
     Rect rect;		/* Area where error is to be recorded. */
 
@@ -210,11 +210,11 @@ DRCBasicCheck (celldef, checkRect, clipRect, function, cdata)
 
     for (planeNum = PL_TECHDEPBASE; planeNum < DBNumPlanes; planeNum++)
     {
-        arg.dCD_plane = celldef->cd_planes[planeNum];
+        arg.dCD_plane = planeNum;
 #ifdef	DRC_EXTENSIONS
-	DBResetTilePlane(arg.dCD_plane,DRC_UNPROCESSED);
+	DBResetTilePlane(celldef->cd_planes[planeNum], DRC_UNPROCESSED);
 #endif
-        (void) DBSrPaintArea ((Tile *) NULL, arg.dCD_plane,
+        (void) DBSrPaintArea ((Tile *) NULL, celldef->cd_planes[planeNum],
 		checkRect, &DBAllTypeBits, drcTile, (ClientData) &arg);
     }
 #ifdef	DRC_CIF_EXTENSIONS
@@ -246,14 +246,15 @@ DRCBasicCheck (celldef, checkRect, clipRect, function, cdata)
 
 int
 drcTile (tile, arg)
-    register Tile *tile;	/* Tile being examined */
+    Tile *tile;	/* Tile being examined */
     struct drcClientData *arg;
 {
-    register DRCCookie *cptr;	/* Current design rule on list */
-    register Tile *tp;		/* Used for corner checks */
+    DRCCookie *cptr;	/* Current design rule on list */
+    Tile *tp;		/* Used for corner checks */
     Rect *rect = arg->dCD_rect;	/* Area being checked */
     Rect errRect;		/* Area checked for an individual rule */
-    TileTypeBitMask tmpMask;
+    TileTypeBitMask tmpMask, *rMask;
+    unsigned char stackpending = (char)0;
 
     arg->dCD_constraint = &errRect;
 #ifdef DRC_EUCLIDEAN
@@ -322,7 +323,8 @@ drcTile (tile, arg)
 
     if (LEFT(tile) >= rect->r_xbot)		/* check tile against rect */
     {
-	register Tile *tpleft;
+	Tile *tpleft;
+	TileType tt, to;
 	int edgeTop, edgeBot;
         int top = MIN(TOP(tile), rect->r_ytop);
         int bottom = MAX(BOTTOM(tile), rect->r_ybot);
@@ -330,15 +332,43 @@ drcTile (tile, arg)
 
         for (tpleft = BL(tile); BOTTOM(tpleft) < top; tpleft = RT(tpleft))
         {
+	    /* Get the tile types to the left and right of the edge */
+
+	    tt = TiGetLeftType(tile);
+	    to = TiGetRightType(tpleft);
+
 	    /* Don't check synthetic edges, i.e. edges with same type on
              * both sides.  Such "edges" have no physical significance, and
 	     * depend on internal-details of how paint is spit into tiles.
 	     * Thus checking them just leads to confusion.  (When edge rules
-	     * involving such edges are encountered during technology readin
+	     * involving such edges are encountered during technology read-in
 	     * the user is warned that such edges are not checked).
 	     */
-	    if(TiGetRightType(tpleft) == TiGetLeftType(tile))
-	        continue;
+
+	    if (tt == to) continue;
+
+	    /*
+	     * Stacked contact types have no rules.  Any stacked contact
+	     * type must have DRC rules applied to each of its constituent
+	     * types.  Start with the first type encountered for each.
+	     */
+	    stackpending = (unsigned char)0x0;
+	    if (tt >= DBNumUserLayers)
+	    {
+		rMask = DBResidueMask(tt);
+		stackpending |= (unsigned char)0x01;
+		for (tt = TT_TECHDEPBASE; tt < DBNumUserLayers; tt++)
+		    if (TTMaskHasType(rMask, tt))
+			break;
+	    }
+	    if (to >= DBNumUserLayers)
+	    {
+		rMask = DBResidueMask(to);
+		stackpending |= (unsigned char)0x02;
+		for (to = TT_TECHDEPBASE; to < DBNumUserLayers; to++)
+		    if (TTMaskHasType(rMask, to))
+			break;
+	    }
 
 	    /*
 	     * Go through list of design rules triggered by the
@@ -349,174 +379,228 @@ drcTile (tile, arg)
 	    if (edgeTop <= edgeBot)
 		continue;
 
-	    for (cptr = DRCRulesTbl[TiGetRightType(tpleft)][TiGetLeftType(tile)];
-		    cptr != (DRCCookie *) NULL;
-		    cptr = cptr->drcc_next)
+	    while(1)
 	    {
-		DRCstatRules++;
-		errRect.r_ytop = edgeTop;
-		errRect.r_ybot = edgeBot;
+		if (stackpending && (to == tt)) goto hnextstacktype;
+		
+		for (cptr = DRCRulesTbl[to][tt]; cptr != (DRCCookie *) NULL;
+			cptr = cptr->drcc_next)
+		{
+
+		    /* Contact images exist in multple planes; only check	*/
+		    /* rules that are for the plane being checked.		*/
+		    if (arg->dCD_plane != cptr->drcc_plane) continue;
+
+		    DRCstatRules++;
+		    errRect.r_ytop = edgeTop;
+		    errRect.r_ybot = edgeBot;
 
 #ifdef DRC_EXTENSIONS
-		if (cptr->drcc_flags & DRC_AREA)
-		{
-		     drcCheckArea(tile,arg,cptr);
-		     continue;
-		}
-		if (cptr->drcc_flags & DRC_MAXWIDTH)
-		{
-		     drcCheckMaxwidth(tile,arg,cptr);
-		     continue;
-		}
-		if (cptr->drcc_flags & DRC_RECTSIZE)
-		{
-		     /* only checked for bottom-left tile in a rect area */
-		     if (!TTMaskHasType(&cptr->drcc_mask, TiGetRightType(BL(tile))) &&
-		       !TTMaskHasType(&cptr->drcc_mask, TiGetTopType(LB(tile))))
-			 drcCheckRectSize(tile,arg,cptr);
-		     continue;
-		}
-#endif
-		/* The widespacing rule needs to check if the triggering edge	*/
-		/* is narrow to avoid generating errors on long, narrow wires.	*/
-
-		if (cptr->drcc_flags & DRC_TRIGGER)
-		    if ((edgeTop - edgeBot) < cptr->drcc_dist)
+		    if (cptr->drcc_flags & DRC_AREA)
 		    {
-			cptr = cptr->drcc_next;
+			drcCheckArea(tile,arg,cptr);
 			continue;
 		    }
-
-		if (cptr->drcc_flags & DRC_REVERSE)
-		{
-		    /*
-		     * Determine corner extensions.
-		     * Find the point (3) to the bottom right of pointB
-		     */
-		    for (tp = tile; BOTTOM(tp) >= errRect.r_ybot; tp = LB(tp))
-			/* Nothing */;
-		    if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tp)))
+		    if (cptr->drcc_flags & DRC_MAXWIDTH)
 		    {
-			errRect.r_ybot -= cptr->drcc_cdist;
-#ifdef DRC_EUCLIDEAN
-			arg->dCD_radial |= 0x1000;
-#endif
+			drcCheckMaxwidth(tile,arg,cptr);
+			continue;
 		    }
+		    if (cptr->drcc_flags & DRC_RECTSIZE)
+		    {
+		        /* only checked for bottom-left tile in a rect area */
+		        if (!TTMaskHasType(&cptr->drcc_mask,
+					TiGetRightType(BL(tile))) &&
+					!TTMaskHasType(&cptr->drcc_mask,
+					TiGetTopType(LB(tile))))
+			    drcCheckRectSize(tile, arg, cptr);
+			continue;
+		    }
+#endif
+		    /* The widespacing rule needs to check if the	*/
+		    /* triggering edge is narrow to avoid generating	*/
+		    /* errors on long, narrow wires.			*/
 
-		    if (cptr->drcc_flags & DRC_BOTHCORNERS)
+		    if (cptr->drcc_flags & DRC_TRIGGER)
+			if ((edgeTop - edgeBot) < cptr->drcc_dist)
+			{
+			    cptr = cptr->drcc_next;
+			    continue;
+			}
+
+		    if (cptr->drcc_flags & DRC_REVERSE)
 		    {
 			/*
-			 * Check the other corner by finding the
-			 * point (4) to the top right of pointT.
+			 * Determine corner extensions.
+			 * Find the point (3) to the bottom right of pointB
 			 */
-			if (TOP(tp = tile) <= errRect.r_ytop)
-			    for (tp = RT(tp); LEFT(tp) > edgeX; tp = BL(tp))
-				/* Nothing */;
+			for (tp = tile; BOTTOM(tp) >= errRect.r_ybot; tp = LB(tp))
+			    /* Nothing */;
+			if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tp)))
+		 	{
+			    errRect.r_ybot -= cptr->drcc_cdist;
+#ifdef DRC_EUCLIDEAN
+			    arg->dCD_radial |= 0x1000;
+#endif
+			}
+
+			if (cptr->drcc_flags & DRC_BOTHCORNERS)
+			{
+			    /*
+			     * Check the other corner by finding the
+			     * point (4) to the top right of pointT.
+			     */
+			    if (TOP(tp = tile) <= errRect.r_ytop)
+				for (tp = RT(tp); LEFT(tp) > edgeX; tp = BL(tp))
+				    /* Nothing */;
+			    if (TTMaskHasType(&cptr->drcc_corner, TiGetBottomType(tp)))
+			    {
+				errRect.r_ytop += cptr->drcc_cdist;
+#ifdef DRC_EUCLIDEAN
+				arg->dCD_radial |= 0x2000;
+#endif
+			    }
+			}
+
+			/*
+			 * Just for grins, see if we could avoid a messy search
+			 * by looking only at tpleft.
+			 */
+			errRect.r_xbot = edgeX - cptr->drcc_dist;
+			if (LEFT(tpleft) <= errRect.r_xbot
+				&& BOTTOM(tpleft) <= errRect.r_ybot
+				&& TOP(tpleft) >= errRect.r_ytop
+				&& !(cptr->drcc_flags & DRC_XPLANE)
+				&& TTMaskHasType(&cptr->drcc_mask,
+				TiGetRightType(tpleft)))
+			    continue;
+			errRect.r_xtop = edgeX;
+			arg->dCD_initial = tile;
+#ifdef DRC_EXTENSIONS
+			arg->dCD_which = DRC_LEFT;
+#endif
+		    }
+		    else  /* FORWARD */
+		    {
+			/*
+			 * Determine corner extensions.
+			 * Find the point (1) to the top left of pointT
+			 */
+			for (tp = tpleft; TOP(tp) <= errRect.r_ytop; tp = RT(tp))
+			    /* Nothing */;
 			if (TTMaskHasType(&cptr->drcc_corner, TiGetBottomType(tp)))
 			{
 			    errRect.r_ytop += cptr->drcc_cdist;
 #ifdef DRC_EUCLIDEAN
-			    arg->dCD_radial |= 0x2000;
+			    arg->dCD_radial |= 0x8000;
 #endif
 			}
-		    }
 
-		    /*
-		     * Just for grins, see if we could avoid a messy search
-		     * by looking only at tpleft.
-		     */
-		    errRect.r_xbot = edgeX - cptr->drcc_dist;
-		    if (LEFT(tpleft) <= errRect.r_xbot
-			&& BOTTOM(tpleft) <= errRect.r_ybot
-			&& TOP(tpleft) >= errRect.r_ytop
-			&& !(cptr->drcc_flags & DRC_XPLANE)
-			&& TTMaskHasType(&cptr->drcc_mask, TiGetRightType(tpleft)))
-			    continue;
-		    errRect.r_xtop = edgeX;
-		    arg->dCD_initial = tile;
-#ifdef DRC_EXTENSIONS
-		    arg->dCD_which = DRC_LEFT;
-#endif
-		}
-		else  /* FORWARD */
-		{
-		    /*
-		     * Determine corner extensions.
-		     * Find the point (1) to the top left of pointT
-		     */
-		    for (tp = tpleft; TOP(tp) <= errRect.r_ytop; tp = RT(tp))
-			/* Nothing */;
-		    if (TTMaskHasType(&cptr->drcc_corner, TiGetBottomType(tp)))
-		    {
-			errRect.r_ytop += cptr->drcc_cdist;
-#ifdef DRC_EUCLIDEAN
-			arg->dCD_radial |= 0x8000;
-#endif
-		    }
-
-		    if (cptr->drcc_flags & DRC_BOTHCORNERS)
-		    {
-			/*
-			 * Check the other corner by finding the
-			 * point (2) to the bottom left of pointB.
-			 */
-			if (BOTTOM(tp = tpleft) >= errRect.r_ybot)
-			    for (tp = LB(tp); RIGHT(tp) < edgeX; tp = TR(tp))
-				/* Nothing */;
-			if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tp)))
+			if (cptr->drcc_flags & DRC_BOTHCORNERS)
 			{
-			    errRect.r_ybot -= cptr->drcc_cdist;
+			    /*
+			     * Check the other corner by finding the
+			     * point (2) to the bottom left of pointB.
+			     */
+			    if (BOTTOM(tp = tpleft) >= errRect.r_ybot)
+				for (tp = LB(tp); RIGHT(tp) < edgeX; tp = TR(tp))
+				    /* Nothing */;
+			    if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tp)))
+			    {
+				errRect.r_ybot -= cptr->drcc_cdist;
 #ifdef DRC_EUCLIDEAN
-			    arg->dCD_radial |= 0x4000;
+				arg->dCD_radial |= 0x4000;
 #endif
+			    }
 			}
+
+			/*
+			 * Just for grins, see if we could avoid a messy search
+			 * by looking only at tile.
+			 */
+			errRect.r_xtop = edgeX + cptr->drcc_dist;
+			if (RIGHT(tile) >= errRect.r_xtop
+				&& BOTTOM(tile) <= errRect.r_ybot
+				&& TOP(tile) >= errRect.r_ytop
+				&& !(cptr->drcc_flags & DRC_XPLANE)
+				&& TTMaskHasType(&cptr->drcc_mask,
+				TiGetLeftType(tile)))
+			    continue;
+			errRect.r_xbot = edgeX;
+			arg->dCD_initial= tpleft;
+#ifdef DRC_EXTENSIONS
+			arg->dCD_which = DRC_RIGHT;
+#endif
+		    }
+#ifdef DRC_EUCLIDEAN
+		    if (arg->dCD_radial)
+		    {
+			arg->dCD_radial &= 0xf000;
+			arg->dCD_radial |= (0xfff & cptr->drcc_cdist);
+		    }
+#endif
+
+		    /* Trigger rule:  If rule check passed without	*/
+		    /* errors, do the next rule.  Otherwise, skip	*/
+		    /* it.						*/
+
+		    if (cptr->drcc_flags & DRC_TRIGGER)
+		    {
+			if (!GEO_RECTNULL(&errRect))
+			    cptr = cptr->drcc_next;  /* skip triggered rule */
+			continue;	/* don't generate any errors on trigger rule */
 		    }
 
-		    /*
-		     * Just for grins, see if we could avoid a messy search
-		     * by looking only at tile.
-		     */
-		    errRect.r_xtop = edgeX + cptr->drcc_dist;
-		    if (RIGHT(tile) >= errRect.r_xtop
-			&& BOTTOM(tile) <= errRect.r_ybot
-			&& TOP(tile) >= errRect.r_ytop
-			&& !(cptr->drcc_flags & DRC_XPLANE)
-			&& TTMaskHasType(&cptr->drcc_mask, TiGetLeftType(tile)))
-			    continue;
-		    errRect.r_xbot = edgeX;
-		    arg->dCD_initial= tpleft;
-#ifdef DRC_EXTENSIONS
-		    arg->dCD_which = DRC_RIGHT;
-#endif
+		    DRCstatSlow++;
+		    arg->dCD_cptr = cptr;
+		    TTMaskCom2(&tmpMask, &cptr->drcc_mask);
+		    (void) DBSrPaintArea((Tile *) NULL,
+				arg->dCD_celldef->cd_planes[cptr->drcc_plane],
+				&errRect, &tmpMask, areaCheck, (ClientData) arg);
 		}
-#ifdef DRC_EUCLIDEAN
-		if (arg->dCD_radial)
+		DRCstatEdges++;
+
+hnextstacktype:
+
+		/* Check if more processing is required for stacked	*/
+		/* contact types 					*/
+
+		if (!stackpending) break;
+		else if (stackpending == (unsigned char)0x01)
 		{
-		    arg->dCD_radial &= 0xf000;
-		    arg->dCD_radial |= (0xfff & cptr->drcc_cdist);
+		    rMask = DBResidueMask(TiGetLeftType(tile));
+		    for (++tt; tt < DBNumUserLayers; tt++)
+			if (TTMaskHasType(rMask, tt))
+			    break;
 		}
-#endif
-
-		/* Trigger rule:  If rule check passed without	*/
-		/* errors, do the next rule.  Otherwise, skip	*/
-		/* it.						*/
-
-		if (cptr->drcc_flags & DRC_TRIGGER)
+		else if (stackpending == (unsigned char)0x02)
 		{
-		    if (!GEO_RECTNULL(&errRect))
-			cptr = cptr->drcc_next;  /* skip triggered rule */
-		    continue;	/* don't generate any errors on trigger rule */
+		    rMask = DBResidueMask(TiGetRightType(tpleft));
+		    for (++to; to < DBNumUserLayers; to++)
+			if (TTMaskHasType(rMask, to))
+			    break;
 		}
+		else /* stackpending for both types */
+		{
+		    rMask = DBResidueMask(TiGetLeftType(tile));
+		    for (++tt; tt < DBNumUserLayers; tt++)
+			if (TTMaskHasType(rMask, tt))
+			    break;
 
-		DRCstatSlow++;
-		arg->dCD_cptr = cptr;
-		TTMaskCom2(&tmpMask, &cptr->drcc_mask);
-		(void) DBSrPaintArea((Tile *) NULL,
-		    arg->dCD_celldef->cd_planes[cptr->drcc_plane],
-		    &errRect, &tmpMask, areaCheck, (ClientData) arg);
+		    if (tt >= DBNumUserLayers)	
+		    {
+			for (tt = TT_TECHDEPBASE; tt < DBNumUserLayers; tt++)
+			    if (TTMaskHasType(rMask, tt))
+				break;
+
+			rMask = DBResidueMask(TiGetRightType(tpleft));
+			for (++to; to < DBNumUserLayers; to++)
+			    if (TTMaskHasType(rMask, to))
+				break;
+		    }
+		}
+		if ((to >= DBNumUserLayers) || (tt >= DBNumUserLayers)) break;
 	    }
-
-	    DRCstatEdges++;
         }
     }
 
@@ -559,7 +643,8 @@ checkbottom:
 
     if (BOTTOM(tile) >= rect->r_ybot)
     {
-	register Tile *tpbot;
+	Tile *tpbot;
+	TileType tt, to;
 	int edgeLeft, edgeRight;
         int left = MAX(LEFT(tile), rect->r_xbot);
         int right = MIN(RIGHT(tile), rect->r_xtop);
@@ -569,6 +654,11 @@ checkbottom:
         for (tpbot = LB(tile); LEFT(tpbot) < right; tpbot = TR(tpbot))
         {
 
+	    /* Get the tile types to the top and bottom of the edge */
+
+	    tt = TiGetBottomType(tile);
+	    to = TiGetTopType(tpbot);
+
 	    /* Don't check synthetic edges, i.e. edges with same type on
              * both sides.  Such "edges" have no physical significance, and
 	     * depend on internal-details of how paint is spit into tiles.
@@ -576,8 +666,32 @@ checkbottom:
 	     * involving such edges are encountered during technology readin
 	     * the user is warned that such edges are not checked).
 	     */
-	    if(TiGetTopType(tpbot) == TiGetBottomType(tile))
-	        continue;
+
+	    if (tt == to) continue;
+
+	    /*
+	     * Stacked contact types have no rules.  Any stacked contact
+	     * type must have DRC rules applied to each of its constituent
+	     * types.  Start with the first type encountered for each.
+	     */
+
+	    stackpending = (unsigned char)0x0;
+	    if (tt >= DBNumUserLayers)
+	    {
+		rMask = DBResidueMask(tt);
+		stackpending |= (unsigned char)0x01;
+		for (tt = TT_TECHDEPBASE; tt < DBNumUserLayers; tt++)
+		    if (TTMaskHasType(rMask, tt))
+			break;
+	    }
+	    if (to >= DBNumUserLayers)
+	    {
+		rMask = DBResidueMask(to);
+		stackpending |= (unsigned char)0x02;
+		for (to = TT_TECHDEPBASE; to < DBNumUserLayers; to++)
+		    if (TTMaskHasType(rMask, to))
+			break;
+	    }
 
 	    /*
 	     * Check to insure that we are inside the clip area.
@@ -589,162 +703,215 @@ checkbottom:
 	    if (edgeLeft >= edgeRight)
 		continue;
 
-	    for (cptr = DRCRulesTbl[TiGetTopType(tpbot)][TiGetBottomType(tile)];
-		    cptr != (DRCCookie *) NULL;
-		    cptr = cptr->drcc_next)
+	    while(1)
 	    {
-		DRCstatRules++;
-		errRect.r_xbot = edgeLeft;
-		errRect.r_xtop = edgeRight;
+		if (stackpending && (to == tt)) goto vnextstacktype;
 
-		/* top to bottom */
+		for (cptr = DRCRulesTbl[to][tt]; cptr != (DRCCookie *) NULL;
+				cptr = cptr->drcc_next)
+		{
+		    /* Contact images exist in multple planes; only check	*/
+		    /* rules that are for the plane being checked.		*/
+		    if (arg->dCD_plane != cptr->drcc_plane) continue;
+
+		    DRCstatRules++;
+		    errRect.r_xbot = edgeLeft;
+		    errRect.r_xtop = edgeRight;
+
+		    /* top to bottom */
 
 #ifdef DRC_EXTENSIONS
-		if (cptr->drcc_flags & (DRC_AREA|DRC_MAXWIDTH|DRC_RECTSIZE))
-		{
-		    /* only have to do these checks in one direction */
-		    if (cptr->drcc_flags & DRC_TRIGGER) cptr = cptr->drcc_next;
-		    continue;
-		}
-#endif
-		/* The widespacing rule needs to check if the triggering edge	*/
-		/* is narrow to avoid generating errors on long, narrow wires.	*/
-
-		if (cptr->drcc_flags & DRC_TRIGGER)
-		    if ((edgeRight - edgeLeft) < cptr->drcc_dist)
+		    if (cptr->drcc_flags & (DRC_AREA|DRC_MAXWIDTH|DRC_RECTSIZE))
 		    {
-			cptr = cptr->drcc_next;
+			/* only have to do these checks in one direction */
+			if (cptr->drcc_flags & DRC_TRIGGER) cptr = cptr->drcc_next;
 			continue;
 		    }
-
-		if (cptr->drcc_flags & DRC_REVERSE)
-		{
-		    /*
-		     * Determine corner extensions.
-		     * Find the point (3) to the top right of pointR
-		     */
-		    if (RIGHT(tp = tile) <= errRect.r_xtop)
-			for (tp = TR(tp); BOTTOM(tp) > edgeY; tp = LB(tp))
-			    /* Nothing */;
-		    if (TTMaskHasType(&cptr->drcc_corner, TiGetLeftType(tp)))
-		    {
-			errRect.r_xtop += cptr->drcc_cdist; 	
-#ifdef DRC_EUCLIDEAN
-			arg->dCD_radial |= 0x4000;
 #endif
-		    }
+		    /* The widespacing rule needs to check if the	*/
+		    /* triggering edge is narrow to avoid generating	*/
+		    /* errors on long, narrow wires.			*/
 
-		    if (cptr->drcc_flags & DRC_BOTHCORNERS)
+		    if (cptr->drcc_flags & DRC_TRIGGER)
+			if ((edgeRight - edgeLeft) < cptr->drcc_dist)
+			{
+			    cptr = cptr->drcc_next;
+			    continue;
+			}
+
+		    if (cptr->drcc_flags & DRC_REVERSE)
 		    {
 			/*
-			 * Check the other corner by finding the
-			 * point (4) to the top left of pointL.
+			 * Determine corner extensions.
+			 * Find the point (3) to the top right of pointR
 			 */
-			for (tp = tile; LEFT(tp) >= errRect.r_xbot; tp = BL(tp))
-			    /* Nothing */;
-			if (TTMaskHasType(&cptr->drcc_corner, TiGetRightType(tp)))
+			if (RIGHT(tp = tile) <= errRect.r_xtop)
+			    for (tp = TR(tp); BOTTOM(tp) > edgeY; tp = LB(tp))
+				/* Nothing */;
+		 	if (TTMaskHasType(&cptr->drcc_corner, TiGetLeftType(tp)))
 			{
-			    errRect.r_xbot -= cptr->drcc_cdist; 	
+			    errRect.r_xtop += cptr->drcc_cdist; 	
 #ifdef DRC_EUCLIDEAN
-			    arg->dCD_radial |= 0x1000;
+			    arg->dCD_radial |= 0x4000;
 #endif
 			}
-		    }
 
-		    /*
-		     * Just for grins, see if we could avoid
-		     * a messy search by looking only at tpbot.
-		     */
-		    errRect.r_ybot = edgeY - cptr->drcc_dist;
-		    if (BOTTOM(tpbot) <= errRect.r_ybot
-			&& LEFT(tpbot) <= errRect.r_xbot
-			&& RIGHT(tpbot) >= errRect.r_xtop
-			&& !(cptr->drcc_flags & DRC_XPLANE)
-			&& TTMaskHasType(&cptr->drcc_mask, TiGetTopType(tpbot)))
-			    continue;
-		    errRect.r_ytop = edgeY;
-		    arg->dCD_initial = tile;
-#ifdef DRC_EXTENSIONS
-		    arg->dCD_which = DRC_BOTTOM;
-#endif
-		}
-		else  /* FORWARD */
-		{
-		    /*
-		     * Determine corner extensions.
-		     * Find the point (1) to the bottom left of pointL
-		     */
-		    if (LEFT(tp = tpbot) >= errRect.r_xbot)
-			for (tp = BL(tp); TOP(tp) < edgeY; tp = RT(tp))
-			    /* Nothing */;
-
-		    if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tp)))
-		    {
-			errRect.r_xbot -= cptr->drcc_cdist;
+			if (cptr->drcc_flags & DRC_BOTHCORNERS)
+			{
+			    /*
+			     * Check the other corner by finding the
+			     * point (4) to the top left of pointL.
+			     */
+			    for (tp = tile; LEFT(tp) >= errRect.r_xbot; tp = BL(tp))
+				/* Nothing */;
+			    if (TTMaskHasType(&cptr->drcc_corner, TiGetRightType(tp)))
+			    {
+				errRect.r_xbot -= cptr->drcc_cdist; 	
 #ifdef DRC_EUCLIDEAN
-			arg->dCD_radial |= 0x2000;
+				arg->dCD_radial |= 0x1000;
+#endif
+			    }
+			}
+
+			/*
+			 * Just for grins, see if we could avoid
+			 * a messy search by looking only at tpbot.
+			 */
+			errRect.r_ybot = edgeY - cptr->drcc_dist;
+			if (BOTTOM(tpbot) <= errRect.r_ybot
+				&& LEFT(tpbot) <= errRect.r_xbot
+				&& RIGHT(tpbot) >= errRect.r_xtop
+				&& !(cptr->drcc_flags & DRC_XPLANE)
+				&& TTMaskHasType(&cptr->drcc_mask,
+				TiGetTopType(tpbot)))
+			    continue;
+			errRect.r_ytop = edgeY;
+			arg->dCD_initial = tile;
+#ifdef DRC_EXTENSIONS
+			arg->dCD_which = DRC_BOTTOM;
 #endif
 		    }
-
-		    if (cptr->drcc_flags & DRC_BOTHCORNERS)
+		    else  /* FORWARD */
 		    {
 			/*
-			 * Check the other corner by finding the
-			 * point (2) to the bottom right of pointR.
+			 * Determine corner extensions.
+			 * Find the point (1) to the bottom left of pointL
 			 */
-			for (tp=tpbot; RIGHT(tp) <= errRect.r_xtop; tp=TR(tp))
-			    /* Nothing */;
+			if (LEFT(tp = tpbot) >= errRect.r_xbot)
+			    for (tp = BL(tp); TOP(tp) < edgeY; tp = RT(tp))
+				/* Nothing */;
+
 			if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tp)))
 			{
-			    errRect.r_xtop += cptr->drcc_cdist;
+			    errRect.r_xbot -= cptr->drcc_cdist;
 #ifdef DRC_EUCLIDEAN
-			    arg->dCD_radial |= 0x8000;
+			    arg->dCD_radial |= 0x2000;
 #endif
 			}
+
+			if (cptr->drcc_flags & DRC_BOTHCORNERS)
+			{
+			    /*
+			     * Check the other corner by finding the
+			     * point (2) to the bottom right of pointR.
+			     */
+			    for (tp=tpbot; RIGHT(tp) <= errRect.r_xtop; tp=TR(tp))
+				/* Nothing */;
+			    if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tp)))
+			    {
+				errRect.r_xtop += cptr->drcc_cdist;
+#ifdef DRC_EUCLIDEAN
+				arg->dCD_radial |= 0x8000;
+#endif
+			    }
+			}
+
+			/*
+			 * Just for grins, see if we could avoid
+			 * a messy search by looking only at tile.
+			 */
+			errRect.r_ytop = edgeY + cptr->drcc_dist;
+			if (TOP(tile) >= errRect.r_ytop
+				&& LEFT(tile) <= errRect.r_xbot
+				&& RIGHT(tile) >= errRect.r_xtop
+				&& !(cptr->drcc_flags & DRC_XPLANE)
+				&& TTMaskHasType(&cptr->drcc_mask,
+				TiGetBottomType(tile)))
+			    continue;
+			errRect.r_ybot = edgeY;
+			arg->dCD_initial = tpbot;
+#ifdef DRC_EXTENSIONS
+			arg->dCD_which = DRC_TOP;
+#endif
+		    }
+#ifdef DRC_EUCLIDEAN
+		    if (arg->dCD_radial)
+		    {
+			arg->dCD_radial &= 0xf000;
+			arg->dCD_radial |= (0xfff & cptr->drcc_cdist);
+		    }
+#endif
+		    /* Trigger rule:  If trigger check passed, do	*/
+		    /* the next rule.  Otherwise, skip it.		*/
+
+		    if (cptr->drcc_flags & DRC_TRIGGER)
+		    {
+			if (!GEO_RECTNULL(&errRect))
+			    cptr = cptr->drcc_next; /* skip triggered rule */
+			continue;	/* don't generate any errors on trigger rule */
 		    }
 
-		    /*
-		     * Just for grins, see if we could avoid
-		     * a messy search by looking only at tile.
-		     */
-		    errRect.r_ytop = edgeY + cptr->drcc_dist;
-		    if (TOP(tile) >= errRect.r_ytop
-			&& LEFT(tile) <= errRect.r_xbot
-			&& RIGHT(tile) >= errRect.r_xtop
-			&& !(cptr->drcc_flags & DRC_XPLANE)
-			&& TTMaskHasType(&cptr->drcc_mask, TiGetBottomType(tile)))
-			    continue;
-		    errRect.r_ybot = edgeY;
-		    arg->dCD_initial = tpbot;
-#ifdef DRC_EXTENSIONS
-		    arg->dCD_which = DRC_TOP;
-#endif
-		}
-#ifdef DRC_EUCLIDEAN
-		if (arg->dCD_radial)
-		{
-		    arg->dCD_radial &= 0xf000;
-		    arg->dCD_radial |= (0xfff & cptr->drcc_cdist);
-		}
-#endif
-		/* Trigger rule:  If trigger check passed, do	*/
-		/* the next rule.  Otherwise, skip it.		*/
+		    DRCstatSlow++;
+		    arg->dCD_cptr = cptr;
+		    TTMaskCom2(&tmpMask, &cptr->drcc_mask);
+		    (void) DBSrPaintArea((Tile *) NULL,
+				arg->dCD_celldef->cd_planes[cptr->drcc_plane],
+				&errRect, &tmpMask, areaCheck, (ClientData) arg);
 
-		if (cptr->drcc_flags & DRC_TRIGGER)
-		{
-		    if (!GEO_RECTNULL(&errRect))
-			cptr = cptr->drcc_next; /* skip triggered rule */
-		    continue;	/* don't generate any errors on trigger rule */
 		}
+		DRCstatEdges++;
 
-		DRCstatSlow++;
-		arg->dCD_cptr = cptr;
-		TTMaskCom2(&tmpMask, &cptr->drcc_mask);
-		(void) DBSrPaintArea((Tile *) NULL,
-		    arg->dCD_celldef->cd_planes[cptr->drcc_plane],
-		    &errRect, &tmpMask, areaCheck, (ClientData) arg);
+vnextstacktype:
+		/* Check if more processing is required for stacked	*/
+		/* contact types 					*/
+		
+		if (!stackpending) break;
+		else if (stackpending == (unsigned char)0x01)
+		{
+		    rMask = DBResidueMask(TiGetBottomType(tile));
+		    for (++tt; tt < DBNumUserLayers; tt++)
+			if (TTMaskHasType(rMask, tt))
+			    break;
+		}
+		else if (stackpending == (unsigned char)0x02)
+		{
+		    rMask = DBResidueMask(TiGetTopType(tpbot));
+		    for (++to; to < DBNumUserLayers; to++)
+			if (TTMaskHasType(rMask, to))
+			    break;
+		}
+		else /* stackpending for both types */
+		{
+		    rMask = DBResidueMask(TiGetBottomType(tile));
+		    for (++tt; tt < DBNumUserLayers; tt++)
+			if (TTMaskHasType(rMask, tt))
+			    break;
+
+		    if (tt >= DBNumUserLayers)	
+		    {
+			for (tt = TT_TECHDEPBASE; tt < DBNumUserLayers; tt++)
+			    if (TTMaskHasType(rMask, tt))
+				break;
+
+			rMask = DBResidueMask(TiGetTopType(tpbot));
+			for (++to; to < DBNumUserLayers; to++)
+			    if (TTMaskHasType(rMask, to))
+				break;
+
+		    }
+		}
+		if ((to >= DBNumUserLayers) || (tt >= DBNumUserLayers)) break;
 	    }
-	    DRCstatEdges++;
         }
     }
     return (0);
