@@ -21,6 +21,9 @@ static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCtech.c,v 1.4 2001/0
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
@@ -121,12 +124,12 @@ static struct drcwhylist * drcWhyList = NULL;
  * ----------------------------------------------------------------------------
  */
 
-static Void
+void 
 drcWhyClear()
 {
     while (drcWhyList != NULL)
     {
-	register char * old = (char *) drcWhyList;
+	char * old = (char *) drcWhyList;
 	(void) StrDup(&(drcWhyList->dwl_string), (char *) NULL);
 	drcWhyList = drcWhyList->dwl_next;
 	FREE(old);
@@ -148,11 +151,7 @@ drcWhyClear()
  * ----------------------------------------------------------------------------
  */
 
-#ifdef DRC_CIF_EXTENSIONS
 char *
-#else
-static char *
-#endif
 drcWhyDup(why)
     char * why;
 {
@@ -227,8 +226,9 @@ drcFindBucket(i, j, distance)
 void
 DRCTechInit()
 {
-    register int i, j, plane;
-    register DRCCookie *dp;
+    int i, j, plane;
+    DRCCookie *dp;
+    PaintResultType result;
 
     TechHalo = 0;
     drcRulesOptimized = 0;
@@ -251,7 +251,7 @@ DRCTechInit()
 	    dp = DRCRulesTbl[i][j];
 	    while (dp != NULL)
 	    {
-		register char * old = (char *) dp;
+		char * old = (char *) dp;
 		dp = dp->drcc_next;
 		FREE(old);
 	    }
@@ -273,32 +273,40 @@ DRCTechInit()
      */
     
     for (plane = 0; plane < DBNumPlanes; plane++)
-    {
-	/* printf("Plane is %s.\n", DBPlaneLongName(plane)); */
 	for (i = 0; i < DBNumTypes; i++)
 	    for (j = 0; j < DBNumTypes; j++)
 	    {
-		PaintResultType result = DBPaintResultTbl[plane][i][j];
+		result = DBPaintResultTbl[plane][i][j];
 		if ((i == TT_ERROR_S) || (j == TT_ERROR_S))
 		    DRCPaintTable[plane][i][j] = TT_ERROR_S;
 		else if ((i == TT_SPACE) || (j == TT_SPACE)
-			|| (DBPlane(j) != plane)
-			|| !DBPaintOnPlane(i, DBPlane(j)))
+			|| !DBTypeOnPlane(j, plane)
+			|| !DBPaintOnTypePlanes(i, j))
 		    DRCPaintTable[plane][i][j] = result;
+
+		/* Modified for stackable types (Tim, 10/3/03) */
+		else if ((i >= DBNumUserLayers) ||
+			((result >= DBNumUserLayers)
+			&& (DBTechFindStacking(i, j) == result)))
+		{
+		    DRCPaintTable[plane][i][j] = result;
+		}
+			
 		else if ((!TTMaskHasType(&DBLayerTypeMaskTbl[i], result)
 			&& !TTMaskHasType(&DBLayerTypeMaskTbl[j], result))
 			|| ((result != DBPaintResultTbl[plane][j][i])
-			&& (DBPlane(i) == plane)
-			&& DBPaintOnPlane(j, DBPlane(i))))
+			&& DBTypeOnPlane(i, plane)
+			&& DBPaintOnTypePlanes(j, i)))
 		{
 		    DRCPaintTable[plane][i][j] = TT_ERROR_S;
-		    /* printf("Error: %s on %s, was %s\n", DBTypeShortName(i),
-			    DBTypeShortName(j), DBTypeShortName(result)); */
+		    /* TxError("Error: %s on %s, was %s\n",
+				DBTypeLongNameTbl[i], DBTypeLongNameTbl[j],
+				DBTypeLongNameTbl[result]); */
 		}
 		else
 		    DRCPaintTable[plane][i][j] = result;
 	    }
-    }
+
 #ifdef DRC_CIF_EXTENSIONS
     drcCifInit();
 #endif
@@ -338,6 +346,13 @@ DRCTechInit()
  * ----------------------------------------------------------------------------
  */
 
+/* DRC rule assignment has been modified to limit the mask and corner	*/
+/* types to the "user layers" only.  Because stacked contacts are	*/
+/* amalgams of two or more other types, the DRCTile routine decomposes	*/
+/* each stacked tile encountered into its constituent residue (contact)	*/
+/* types and applies the rules separately to each.  Therefore,		*/
+/* drcc_mask and drcc_corner should never contain stacked types.	*/
+
 #define ASSIGN(cookie,dist,next,mask,corner,why,cdist,flags,plane) \
 	((cookie)->drcc_dist = dist, \
 	(cookie)->drcc_next = next, \
@@ -346,7 +361,9 @@ DRCTechInit()
 	(cookie)->drcc_why = why, \
 	(cookie)->drcc_cdist = cdist, \
 	(cookie)->drcc_flags = flags, \
-	(cookie)->drcc_plane = plane)
+	(cookie)->drcc_plane = plane, \
+	TTMaskAndMask(&(cookie)->drcc_mask, &DBUserLayerBits), \
+	TTMaskAndMask(&(cookie)->drcc_corner, &DBUserLayerBits))
 
 	/* ARGSUSED */
 bool
@@ -374,7 +391,7 @@ DRCTechAddRule(sectionName, argc, argv)
 	"no_overlap",	 3,	3,	drcNoOverlap,
     "layers1 layers2",
 	"overhang",	 5,	5,	drcOverhang,
-    "layers1 layers2 distance why", 
+    "layers1 layers2 distance why",
 	"rect_only",	 3,	3,	drcRectOnly,
     "layers why",
 	"spacing",	 6,	6,	drcSpacing,
@@ -464,7 +481,7 @@ DRCTechAddRule(sectionName, argc, argv)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
+int
 drcWidth(argc, argv)
     int argc;
     char *argv[];
@@ -481,7 +498,7 @@ drcWidth(argc, argv)
     for (plane = PL_TECHDEPBASE; plane < DBNumPlanes; plane++)
 	if (DBTechSubsetLayers(set, DBPlaneTypes[plane], &tmp1))
 	    break;
-
+    
     if (plane == DBNumPlanes)
     {
 	TechError("All layers for \"width\" must be on same plane\n");
@@ -491,16 +508,16 @@ drcWidth(argc, argv)
     set = tmp1;
     TTMaskCom2(&setC, &set);
 
-    for (i = 0; i < DBNumTypes; i++)
+    for (i = 0; i < DBNumUserLayers; i++)
     {
-	for (j = 0; j < DBNumTypes; j++)
+	for (j = 0; j < DBNumUserLayers; j++)
 	{
 	    /*
 	     * Must have types in 'set' for at least 'distance'
 	     * to the right of any edge between a type in '~set'
 	     * and a type in 'set'.
 	     */
-	    if (SamePlane(i, j)
+	    if (DBTypesOnSamePlane(i, j)
 		    && TTMaskHasType(&setC, i) && TTMaskHasType(&set, j))
 	    {
 		/* find bucket preceding the new one we wish to insert */
@@ -541,7 +558,7 @@ drcWidth(argc, argv)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
+int
 drcArea(argc, argv)
     int argc;
     char *argv[];
@@ -569,16 +586,16 @@ drcArea(argc, argv)
     set = tmp1;
     TTMaskCom2(&setC, &set);
 
-    for (i = 0; i < DBNumTypes; i++)
+    for (i = 0; i < DBNumUserLayers; i++)
     {
-	for (j = 0; j < DBNumTypes; j++)
+	for (j = 0; j < DBNumUserLayers; j++)
 	{
 	    /*
 	     * Must have types in 'set' for at least 'distance'
 	     * to the right of any edge between a type in '~set'
 	     * and a type in 'set'.
 	     */
-	    if (SamePlane(i, j)
+	    if (DBTypesOnSamePlane(i, j)
 		    && TTMaskHasType(&setC, i) && TTMaskHasType(&set, j))
 	    {
 		/* find bucket preceding the new one we wish to insert */
@@ -633,7 +650,7 @@ drcArea(argc, argv)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
+int
 drcMaxwidth(argc, argv)
     int argc;
     char *argv[];
@@ -669,16 +686,16 @@ drcMaxwidth(argc, argv)
     set = tmp1;
     TTMaskCom2(&setC, &set);
 
-    for (i = 0; i < DBNumTypes; i++)
+    for (i = 0; i < DBNumUserLayers; i++)
     {
-	for (j = 0; j < DBNumTypes; j++)
+	for (j = 0; j < DBNumUserLayers; j++)
 	{
 	    /*
 	     * Must have types in 'set' for at least 'distance'
 	     * to the right of any edge between a type in '~set'
 	     * and a type in 'set'.
 	     */
-	    if (SamePlane(i, j)
+	    if (DBTypesOnSamePlane(i, j)
 		    && TTMaskHasType(&setC, i) && TTMaskHasType(&set, j))
 	    {
 		/* find bucket preceding the new one we wish to insert */
@@ -695,6 +712,7 @@ drcMaxwidth(argc, argv)
     return (distance);
 }
 #endif
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -743,7 +761,7 @@ drcMaxwidth(argc, argv)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
+int
 drcSpacing(argc, argv)
     int argc;
     char *argv[];
@@ -843,8 +861,8 @@ drcSpacing(argc, argv)
 	 */
 	if (TTMaskIntersect(&set1, &set2))
 	{
-	    TechError(
-		"Spacing check with touching illegal must be between non intersecting type lists.\n");
+	    TechError("Spacing check with touching illegal must be between "
+			"non-intersecting type lists.\n");
 	    return (0);
 	}
 
@@ -866,11 +884,11 @@ drcSpacing(argc, argv)
 	return (0);
     }
 
-    for (i = 0; i < DBNumTypes; i++)
+    for (i = 0; i < DBNumUserLayers; i++)
     {
-	for (j = 0; j < DBNumTypes; j++)
+	for (j = 0; j < DBNumUserLayers; j++)
 	{
-	    if (i == j || !SamePlane(i, j)) continue;
+	    if ((i == j) || !DBTypesOnSamePlane(i, j)) continue;
 
 	    /* LHS is an element of set1, RHS is an element of setR */
 	    if (TTMaskHasType(&set1, i) && TTMaskHasType(&setR, j))
@@ -892,6 +910,7 @@ drcSpacing(argc, argv)
 		    MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
 		    TTMaskClearMask3(&tmp1, &DBPlaneTypes[curPlane], &set2);
 		    TTMaskAndMask3(&tmp2, &DBPlaneTypes[curPlane], &setR);
+
 		    if (widerule)
 		    {
 			DRCCookie *dptrig;
@@ -922,12 +941,12 @@ drcSpacing(argc, argv)
 
 		    if (i == TT_SPACE)
 		    {
-			if (curPlane != DBPlane(j))
+			if (!DBTypeOnPlane(j, curPlane))
 			    dpnew->drcc_flags |= DRC_XPLANE;
 		    }
 		    else
 		    {
-			if (curPlane != DBPlane(i))
+			if (!DBTypeOnPlane(i, curPlane))
 			    dpnew->drcc_flags |= DRC_XPLANE;
 		    }
 		    
@@ -993,17 +1012,18 @@ drcSpacing(argc, argv)
 		    MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
 		    TTMaskClearMask3(&tmp1, &DBPlaneTypes[curPlane], &set1);
 		    TTMaskAndMask3(&tmp2, &DBPlaneTypes[curPlane], &setRreverse);
+
 		    ASSIGN(dpnew, distance, dp->drcc_next,
 			tmp1, tmp2, why, distance, DRC_FORWARD, curPlane);
 
 		    if (i == TT_SPACE)
 		    {
-			if (curPlane != DBPlane(j))
+			if (!DBTypeOnPlane(j, curPlane))
 			    dpnew->drcc_flags |= DRC_XPLANE;
 		    }
 		    else
 		    {
-			if (curPlane != DBPlane(i))
+			if (!DBTypeOnPlane(i, curPlane))
 			    dpnew->drcc_flags |= DRC_XPLANE;
 		    }
 
@@ -1073,12 +1093,12 @@ drcSpacing(argc, argv)
 		    /* filter out checks that are not cross plane */
 		    if (i == TT_SPACE) 
 		    {
-			if (curPlane == DBPlane(j))
+			if (DBTypeOnPlane(j, curPlane))
 			    continue;
 		    }
 		    else
 		    {
-			if (curPlane == DBPlane(i))
+			if (DBTypeOnPlane(i, curPlane))
 			    continue;
 		    }
 
@@ -1086,6 +1106,7 @@ drcSpacing(argc, argv)
 		    MALLOC(DRCCookie *, dpnew, sizeof (DRCCookie));
 		    TTMaskClearMask3(&tmp1, &DBPlaneTypes[curPlane], &set2);
 		    TTMaskZero(&tmp2);
+
 		    ASSIGN(dpnew, 1, dp->drcc_next,
 			tmp1, tmp2, why, distance, 
 			DRC_FORWARD | DRC_XPLANE, curPlane);
@@ -1122,12 +1143,10 @@ drcSpacing(argc, argv)
  * Side effects:
  *	Updates the DRC technology variables.
  *
- * Notes:
- *	The "plane" argument is deprecated, and ignored except for sanity checking.
- *
  * ----------------------------------------------------------------------------
  */
 
+int
 drcEdge(argc, argv)
     int argc;
     char *argv[];
@@ -1180,36 +1199,64 @@ drcEdge(argc, argv)
 	return (0);
     }
 
-    checkPlane = plane;
     if (argc == 9)
-    {
-	checkPlane = DBTechNoisyNamePlane(argv[8]);
-	if (checkPlane < 0)
-	    return 0;
-    }
+	tmpPlane = DBTechNoisyNamePlane(argv[8]);
+
+    /*
+     * OKtypes determine the checkPlane.  If checkPlane exists, it should
+     * only be used to check against the plane of OKtypes.
+     */
 
     pMask = DBTechNoisyNameMask(okTypes, &setM);
-
-    /* 9th argument may be absent if okTypes is unambiguously	*/
-    /* on a specific plane.  Otherwise, standard rules apply.	*/
-
-    if (argc < 9)
-	for (tmpPlane = PL_TECHDEPBASE; tmpPlane < DBNumPlanes; tmpPlane++)
-	    if (PlaneMaskHasPlane(pMask, tmpPlane))
-		if ((pMask ^ PlaneNumToMaskBit(tmpPlane)) == 0)
-		    checkPlane = tmpPlane;
-
-    if (!DBTechSubsetLayers(setM, DBPlaneTypes[checkPlane], &tmp3))
+    for (checkPlane = PL_TECHDEPBASE; checkPlane < DBNumPlanes; checkPlane++)
+	if (PlaneMaskHasPlane(pMask, checkPlane))
+	    break;
+ 
+    if (pMask != PlaneNumToMaskBit(checkPlane))
     {
-	TechError("OK types \"%s\" in more than one plane.");
-	return 0;
+	/* Technically it should be illegal to specify simply "space"
+	 * in the types list for a DRC rule, as it is ambiguous.
+	 * However, we will assume that the plane of the edge is
+	 * intended.  The "plane" argument may be used to do the
+	 * qualification (for backwards compatibility); any other use
+	 * gets a warning.
+	 */
+
+	if (TTMaskEqual(&DBSpaceBits, &setM))
+	{
+	    if (argc == 9)
+		checkPlane = tmpPlane;
+	    else
+	    {
+		TechError("OK types \"%s\" in more than one plane.\n"
+	        	"	Assuming same plane (%s) as edge.\n",
+			okTypes, DBPlaneLongNameTbl[plane]);
+		checkPlane = plane;
+	    }
+	}
+
+	/* The case okTypes="0" is explicitly allowed according */
+	/* to the manual, so we parse it accordingly.		*/
+
+	else if (!strcmp(okTypes, "0"))
+	    checkPlane = plane;
+	else
+	{
+	    TechError("All OK types must lie in one plane.\n");
+	    return (0);
+	}
     }
 
     setM = tmp3;
 
-    for (i = 0; i < DBNumTypes; i++)
+    /* "plane" argument deprecated; kept for backward compatibility only */
+
+    if (argc == 9 && ((tmpPlane < 0) || (tmpPlane != checkPlane)))
+	    TechError("Ignoring bad plane argument.\n");
+
+    for (i = 0; i < DBNumUserLayers; i++)
     {
-	for (j = 0; j < DBNumTypes; j++)
+	for (j = 0; j < DBNumUserLayers; j++)
 	{
 	    if (TTMaskHasType(&set1, i) && TTMaskHasType(&set2, j))
 	    {
@@ -1241,7 +1288,6 @@ drcEdge(argc, argv)
 
     return (MAX(distance, cdist));
 }
-
 
 /*
  * ----------------------------------------------------------------------------
@@ -1263,6 +1309,7 @@ drcEdge(argc, argv)
  * ----------------------------------------------------------------------------
  */
 
+int
 drcOverhang(argc, argv)
     int argc;
     char *argv[];
@@ -1309,9 +1356,9 @@ drcOverhang(argc, argv)
     /* SetC is the empty set */
     TTMaskZero(&setC);
 
-    for (i = 0; i < DBNumTypes; i++)
+    for (i = 0; i < DBNumUserLayers; i++)
     {
-	for (j = 0; j < DBNumTypes; j++)
+	for (j = 0; j < DBNumUserLayers; j++)
 	{
 	    if (TTMaskHasType(&set1, i) && TTMaskHasType(&set2, j))
 	    {
@@ -1359,6 +1406,7 @@ drcOverhang(argc, argv)
  * ----------------------------------------------------------------------------
  */
 
+int
 drcRectOnly(argc, argv)
     int argc;
     char *argv[];
@@ -1396,9 +1444,9 @@ drcRectOnly(argc, argv)
     TTMaskZero(&setC);
     TTMaskSetMask(&setC, &DBPlaneTypes[plane]);
 
-    for (i = 0; i < DBNumTypes; i++)
+    for (i = 0; i < DBNumUserLayers; i++)
     {
-	for (j = 0; j < DBNumTypes; j++)
+	for (j = 0; j < DBNumUserLayers; j++)
 	{
 	    if (TTMaskHasType(&set1, i) && TTMaskHasType(&set2, j))
 	    {
@@ -1433,7 +1481,7 @@ drcRectOnly(argc, argv)
  *
  *	surround layers1 layers2 dist presence why
  *
- * indicating that layers2 must surround layers1 by a distance of at least
+ * indicating that layers2 must surround layers1 by at least distance
  * dist in all directions.
  *
  * This rule is equivalent to:
@@ -1446,9 +1494,12 @@ drcRectOnly(argc, argv)
  *	edge4way layers1 ~(layers2)/plane1 dist NULL ~(layers2)/plane1 \
  *		dist why
  *
+ * 
+ *
  * ----------------------------------------------------------------------------
  */
 
+int
 drcSurround(argc, argv)
     int argc;
     char *argv[];
@@ -1504,9 +1555,9 @@ drcSurround(argc, argv)
     TTMaskCom2(&invM, &setM);
     TTMaskAndMask(&invM, &DBPlaneTypes[plane1]);
 
-    for (i = 0; i < DBNumTypes; i++)
+    for (i = 0; i < DBNumUserLayers; i++)
     {
-	for (j = 0; j < DBNumTypes; j++)
+	for (j = 0; j < DBNumUserLayers; j++)
 	{
 	    if (TTMaskHasType(&set1, i) && TTMaskHasType(&set2, j))
 	    {
@@ -1535,7 +1586,7 @@ drcSurround(argc, argv)
 
     if (strcmp(presence, "absence_illegal")) return distance;
 
-    /* Add an extra rule when presence of the surrounding	*/
+    /* To do---add extra rule when presence of the surrounding	*/
     /* layer is required.  Rule is different if planes match.	*/
 
     if (plane1 == plane2)
@@ -1548,8 +1599,8 @@ drcSurround(argc, argv)
 
 	TTMaskZero(&set1);
 
-	for (i = 0; i < DBNumTypes; i++)
-	    for (j = 0; j < DBNumTypes; j++)
+	for (i = 0; i < DBNumUserLayers; i++)
+	    for (j = 0; j < DBNumUserLayers; j++)
 		if (TTMaskHasType(&setM, i) && TTMaskHasType(&invM, j))
 		{
 		    /* Find bucket preceding the new one we wish to insert */
@@ -1571,8 +1622,8 @@ drcSurround(argc, argv)
     }
     else
     {
-	for (i = 0; i < DBNumTypes; i++)
-	    for (j = 0; j < DBNumTypes; j++)
+	for (i = 0; i < DBNumUserLayers; i++)
+	    for (j = 0; j < DBNumUserLayers; j++)
 		if (TTMaskHasType(&setM, i) && TTMaskHasType(&invM, j))
 		{
 		    /* Find bucket preceding the new one we wish to insert */
@@ -1595,7 +1646,7 @@ drcSurround(argc, argv)
     return distance;
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1619,7 +1670,7 @@ drcSurround(argc, argv)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
+int
 drcNoOverlap(argc, argv)
     int argc;
     char *argv[];
@@ -1638,8 +1689,8 @@ drcNoOverlap(argc, argv)
     DBTechNoisyNameMask(layers1, &set1);
     DBTechNoisyNameMask(layers2, &set2);
 
-    for (i = 0; i < DBNumTypes; i++)
-	for (j = 0; j < DBNumTypes; j++)
+    for (i = 0; i < DBNumUserLayers; i++)
+	for (j = 0; j < DBNumUserLayers; j++)
 	    if (TTMaskHasType(&set1, i) && TTMaskHasType(&set2, j))
 		for (plane = 0; plane < DBNumPlanes; plane++)
 		{
@@ -1673,13 +1724,13 @@ drcNoOverlap(argc, argv)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
+int
 drcExactOverlap(argc, argv)
     int argc;
     char *argv[];
 {
     char *layers = argv[1];
-    TileTypeBitMask set;
+    TileTypeBitMask set, rmask;
     int i;
 
     /*
@@ -1689,17 +1740,18 @@ drcExactOverlap(argc, argv)
      */
 
     DBTechNoisyNameMask(layers, &set);
+    TTMaskSetMask(&DRCExactOverlapTypes, &set);
 
     /*
-     * Go through the types and eliminate all but the first image
-     * of each contact.
+     * Stacking types containing types in "set" must also be added
+     * to the list of exact overlap types.
      */
 
-    for (i = 0; i < DBNumTypes; i++)
+    for (i = DBNumUserLayers; i < DBNumTypes; i++)
     {
-	if (!TTMaskHasType(&set, i)) continue;
-	TTMaskSetType(&DRCExactOverlapTypes, i);
-	TTMaskClearMask(&set, &DBLayerTypeMaskTbl[i]);
+	TTMaskAndMask3(&rmask, &set, DBResidueMask(i));
+	if (!TTMaskIsZero(&rmask))
+	    TTMaskSetType(&DRCExactOverlapTypes, i);
     }
     return (0);
 }
@@ -1730,6 +1782,7 @@ drcExactOverlap(argc, argv)
  * ----------------------------------------------------------------------------
  */
 
+int
 drcRectangle(argc, argv)
     int argc;
     char *argv[];
@@ -1766,9 +1819,9 @@ drcRectangle(argc, argv)
     /* Install 2 edge rules: one that checks rectangle-ness, and one that
      * checks size
      */
-    for (i = 0; i < DBNumTypes; i++)
+    for (i = 0; i < DBNumUserLayers; i++)
     {
-	for (j = 0; j < DBNumTypes; j++)
+	for (j = 0; j < DBNumUserLayers; j++)
 	{
 	    if (TTMaskHasType(&types, i) && TTMaskHasType(&nottypes, j))
 	    {
@@ -1822,7 +1875,7 @@ drcRectangle(argc, argv)
     return maxwidth;
 }
 #endif
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1846,7 +1899,7 @@ drcRectangle(argc, argv)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
+int
 drcStepSize(argc, argv)
     int argc;
     char *argv[];
@@ -1890,7 +1943,7 @@ drcStepSize(argc, argv)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
+int
 drcSetCifStyle(argc, argv)
     int argc;
     char *argv[];
@@ -1962,9 +2015,9 @@ DRCTechFinal()
      * case, eliminate all of the edge's rules except one.
      */
     
-    for (i = 0; i < DBNumTypes; i++)
+    for (i = 0; i < DBNumUserLayers; i++)
     {
-	for (j = 0; j < DBNumTypes; j++)
+	for (j = 0; j < DBNumUserLayers; j++)
 	{
 	    DRCCookie *keep = NULL;
 	    
@@ -2015,9 +2068,9 @@ DRCTechFinal()
      *		if A is BOTHCORNERS then B must be, too
      */
 
-    for (i = 0; i < DBNumTypes; i++)
+    for (i = 0; i < DBNumUserLayers; i++)
     {
-	for (j = 0; j < DBNumTypes; j++)
+	for (j = 0; j < DBNumUserLayers; j++)
 	{
 	    for (dp = DRCRulesTbl[i][j]; dp != NULL; dp = dp->drcc_next)
 	    {
@@ -2103,6 +2156,32 @@ DRCTechFinal()
 	    }
 	}
     }
+
+    /*
+     * Add stacked types to all the rules which affect either of the
+     * stacked contact type's residue contacts.
+     */
+
+    for (i = 0; i < DBNumUserLayers; i++)
+    {
+	int k, l;
+	TileTypeBitMask *rMask;
+
+	for (j = 0; j < DBNumUserLayers; j++)
+	    for (dp = DRCRulesTbl[i][j]; dp != NULL; dp = dp->drcc_next)
+		for (k = DBNumUserLayers; k < DBNumTypes; k++)
+		{
+		    rMask = DBResidueMask(k);
+		    for (l = 0; l < DBNumUserLayers; l++)
+			if (TTMaskHasType(rMask, l))
+			{
+			    if (TTMaskHasType(&dp->drcc_mask, l))
+				TTMaskSetType(&dp->drcc_mask, k);
+			    if (TTMaskHasType(&dp->drcc_corner, l))
+				TTMaskSetType(&dp->drcc_corner, k);
+			}
+		}
+    }
 }
 
 
@@ -2146,8 +2225,7 @@ DRCTechRuleStats()
 	    for (dp = DRCRulesTbl[i][j]; dp != NULL; dp = dp->drcc_next)
 		thisCount++;
 	    edgeRules += thisCount;
-	    if ((i != TT_SPACE) && (j != TT_SPACE) &&
-		(DBPlane(i) != DBPlane(j))) continue;
+	    if (!DBTypesOnSamePlane(i, j)) continue;
 	    if (thisCount <= MAXBIN) counts[thisCount] += 1;
 	    else overflow += 1;
 	}
@@ -2178,7 +2256,7 @@ DRCTechRuleStats()
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 DRCTechScale(scalen, scaled)
     int scalen, scaled;
 {
