@@ -18,11 +18,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/ext2sim/ext2sim.c,v 1.5 20
 
 #include <stdio.h>
 #include <stdlib.h>	/* for atof() */
+#include <string.h>
 #include <ctype.h>
-#include <stdlib.h>
 #include <math.h>	/* for sqrt() in bipolar L,W calculation */
 
-#include "tcltk/tclmagic.h"
+#ifdef MAGIC_WRAPPER
+#include "magic/tclmagic.h"
+#endif
+
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
@@ -43,7 +46,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/ext2sim/ext2sim.c,v 1.5 20
 
 /* Forward declarations */
 #ifdef MAGIC_WRAPPER
-Void CmdExtToSim();
+void CmdExtToSim();
 #endif
 int simmainArgs();
 int simdevVisit(), simresistVisit(), simcapVisit(), simnodeVisit();
@@ -183,7 +186,7 @@ Exttosim_Init(interp)
 {
     /* Sanity checks! */
     if (interp == NULL) return TCL_ERROR;
-    if (Tcl_PkgRequire(interp, "Tclmagic", "7.2", 0) == NULL) return TCL_ERROR;
+    if (Tcl_PkgRequire(interp, "Tclmagic", "7.3", 0) == NULL) return TCL_ERROR;
     if (Tcl_InitStubs(interp, "8.1", 0) == NULL) return TCL_ERROR;
 
     TxPrintf("Auto-loading EXTTOSIM module\n");
@@ -195,7 +198,7 @@ Exttosim_Init(interp)
     if (WindReplaceCommand(DBWclientID, "exttosim", CmdExtToSim) < 0)
 	return TCL_ERROR;
 
-    Tcl_PkgProvide(interp, "Exttosim", "7.2");
+    Tcl_PkgProvide(interp, "Exttosim", "7.3");
     return TCL_OK;
 }
 
@@ -219,7 +222,7 @@ Exttosim_Init(interp)
 #define EXTTOSIM_EXTRESIST	8
 #define EXTTOSIM_HELP		9
 
-Void
+void
 CmdExtToSim(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -296,7 +299,7 @@ CmdExtToSim(w, cmd)
 	    if (cmd->tx_argc == 2)
 	    {
 		Tcl_SetResult(magicinterp, (esDoExtResis) ? "on" : "off", NULL);
-		return TCL_OK;
+		return;
 	    }
 	    else if (cmd->tx_argc != 3)
 		goto usage;
@@ -309,7 +312,7 @@ CmdExtToSim(w, cmd)
 	    if (cmd->tx_argc == 2)
 	    {
 		Tcl_SetResult(magicinterp, (esNoAlias) ? "off" : "on", NULL);
-		return TCL_OK;
+		return;
 	    }
 	    else if (cmd->tx_argc != 3)
 		goto usage;
@@ -322,7 +325,7 @@ CmdExtToSim(w, cmd)
 	    if (cmd->tx_argc == 2)
 	    {
 		Tcl_SetResult(magicinterp, (esNoLabel) ? "off" : "on", NULL);
-		return TCL_OK;
+		return;
 	    }
 	    else if (cmd->tx_argc != 3)
 		goto usage;
@@ -339,7 +342,7 @@ CmdExtToSim(w, cmd)
 		else
 		    Tcl_SetObjResult(magicinterp,
 			Tcl_NewDoubleObj((double)LocCapThreshold));
-		return TCL_OK;
+		return;
 	    }
 	    else if (cmd->tx_argc < 3) goto usage;
 	    if (!strncmp(cmd->tx_argv[2], "inf", 3))
@@ -357,7 +360,7 @@ CmdExtToSim(w, cmd)
 		else
 		    Tcl_SetObjResult(magicinterp,
 			Tcl_NewIntObj(LocResistThreshold));
-		return TCL_OK;
+		return;
 	    }
 	    else if (cmd->tx_argc < 3) goto usage;
 	    if (StrIsInt(cmd->tx_argv[2]))
@@ -371,7 +374,7 @@ CmdExtToSim(w, cmd)
 	    if (cmd->tx_argc == 2)
 	    {
 		Tcl_SetResult(magicinterp, sim_formats[esFormat], TCL_STATIC);
-		return TCL_OK;
+		return;
 	    }
 	    else if (cmd->tx_argc < 3) goto usage;
 	    value = Lookup(cmd->tx_argv[2], sim_formats);
@@ -389,7 +392,7 @@ CmdExtToSim(w, cmd)
 		    Tcl_SetResult(magicinterp, "conservative", NULL);
 		else
 		    Tcl_SetResult(magicinterp, "none", NULL);
-		return TCL_OK;
+		return;
 	    }
 	    else if (cmd->tx_argc < 3) goto usage;
 	    value = Lookup(cmd->tx_argv[2], cmdMergeTypes);
@@ -442,7 +445,7 @@ usage:
 	    }
 	    break;
     }
-    return TCL_OK;
+    return;
 
 runexttosim:
 
@@ -456,7 +459,7 @@ runexttosim:
     if (err_result == TRUE)
     {
 	EFDone();
-        return TCL_ERROR;
+        return /* TCL_ERROR */;
     }
 
     if (inName == NULL)
@@ -470,7 +473,7 @@ runexttosim:
 	{
 	    TxError("Point to a window or specify a cell name.\n");
 	    EFDone();
-	    return TCL_ERROR;
+	    return /* TCL_ERROR */;
 	}
 	inName = ((CellUse *) w->w_surfaceID)->cu_def->cd_name;
     }
@@ -503,7 +506,7 @@ runexttosim:
 		simesOutName);
 	Tcl_SetResult(magicinterp, tclres, TCL_DYNAMIC);
 	EFDone();
-	return TCL_ERROR;
+	return /* TCL_ERROR */;
     }
     if (!esNoAlias && (esAliasF = fopen(esAliasName, "w")) == NULL)
     {
@@ -512,7 +515,7 @@ runexttosim:
 		esAliasName);
 	Tcl_SetResult(magicinterp, tclres, TCL_DYNAMIC);
 	EFDone();
-	return TCL_ERROR;
+	return /* TCL_ERROR */;
     }
     if (!esNoLabel && (esLabF = fopen(esLabelName, "w")) == NULL)
     {
@@ -520,7 +523,7 @@ runexttosim:
 	sprintf(tclres, "exttosim: Unable to open file %s for writing\n",
 		esLabelName);
 	Tcl_SetResult(magicinterp, tclres, TCL_DYNAMIC);
-	return TCL_ERROR;
+	return /* TCL_ERROR */;
     }
 
     /* Set local values for capacitor and resistor thresholds */
@@ -531,7 +534,7 @@ runexttosim:
     if (EFReadFile(inName, FALSE, esDoExtResis) == FALSE)
     {
 	EFDone();
-	return TCL_ERROR;
+	return /* TCL_ERROR */;
     }
 
     if ((EFStyle == NULL) && (esFormat == SU))
@@ -621,7 +624,6 @@ runexttosim:
     if (esAliasF) fclose(esAliasF);
 
     TxPrintf("exttosim finished.\n");
-    return TCL_OK;
 }
 
 #else	/* !MAGIC_WRAPPER */
@@ -763,7 +765,8 @@ main(argc, argv)
  * argument.
  *
  * Results:
- *	None.
+ *	None.  TCL version returns False if an error is encountered
+ *	while parsing arguments, True otherwise.
  *
  * Side effects:
  *	After processing an argument, updates *pargc and *pargv
@@ -1150,7 +1153,7 @@ simdevVisit(dev, hierName, trans)
     return 0;
 }
 
-Void
+int
 simdevSubstrate( prefix, suffix, type, scale, doAP, outf)
 HierName *prefix;
 HierName *suffix;
@@ -1294,7 +1297,7 @@ int simnAPHier(dterm, hierName, resClass, scale, outf)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 simdevOutNode(prefix, suffix, name, outf)
     HierName *prefix;
     HierName *suffix;
@@ -1422,11 +1425,11 @@ simresistVisit(hierName1, hierName2, res)
  */
 
 int simnodeVisit(node, res, cap)
-    register EFNode *node;
+    EFNode *node;
     int res;
     double cap;
 {
-    register EFNodeName *nn;
+    EFNodeName *nn;
     HierName *hierName;
     bool isGlob;
     char *fmt;
@@ -1509,7 +1512,7 @@ EFNode *g, *s, *d, *b;
 HierName *hn;
 Dev    *dev;
 {
-	register    devMerge *fp;
+	   devMerge *fp;
 
 	MALLOC (devMerge *, fp, sizeof(devMerge));
 	fp->l = l; fp->w = w;
@@ -1611,7 +1614,7 @@ int l, w;
 	int      scale, pmode;
     	Rect	 r;
 	float	 m;
-	register devMerge *fp, *cfp;
+	devMerge *fp, *cfp;
 
 	if (dev->dev_nterm < 2) {
 		TxError("outPremature\n");
