@@ -23,7 +23,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/ext2spice/ext2spice.c,v 1.
 #include <string.h>
 #endif
 
-#include "tcltk/tclmagic.h"
+#ifdef MAGIC_WRAPPER
+#include "magic/tclmagic.h"
+#endif
+
 #include "misc/magic.h"
 #include "utils/malloc.h"
 #include "utils/geometry.h"
@@ -46,21 +49,17 @@ static char rcsid[] = "$Header: /ufs/repository/magic/ext2spice/ext2spice.c,v 1.
 
 /* Forward declarations */
 #ifdef MAGIC_WRAPPER
-Void CmdExtToSpice();
+void CmdExtToSpice();
 #endif
 int spcmainArgs();
 int spccapVisit(), spcdevVisit(), spcnodeVisit(), subcktVisit(), spcresistVisit(), 
     devMergeVisit(), devDistJunctVisit();
-int subcktUndef();
 EFNode *spcdevSubstrate();
 char *nodeSpiceName();
 
-#define AUTO  	2	/* TRUE | FALSE | AUTO for esDoSubckt */
-
 /* Options specific to ext2spice */
 bool esDoExtResis = FALSE;
 bool esDoPorts = TRUE;
-int esDoSubckt = AUTO;
 bool esDevNodesOnly = FALSE;
 bool esNoAttrs = FALSE;
 bool esHierAP = FALSE;
@@ -228,7 +227,6 @@ devMerge *devMergeList = NULL ;
 
 /* Forward declaration */
 int _ext2spice_start();
-void topVisit();
 
 /*
  * ----------------------------------------------------------------------------
@@ -244,7 +242,7 @@ Exttospice_Init(interp)
 {
     /* Sanity checks! */
     if (interp == NULL) return TCL_ERROR;
-    if (Tcl_PkgRequire(interp, "Tclmagic", "7.2", 0) == NULL) return TCL_ERROR;
+    if (Tcl_PkgRequire(interp, "Tclmagic", "7.3", 0) == NULL) return TCL_ERROR;
     if (Tcl_InitStubs(interp, "8.1", 0) == NULL) return TCL_ERROR;
 
     TxPrintf("Auto-loading EXTTOSPICE module\n");
@@ -256,7 +254,7 @@ Exttospice_Init(interp)
     if (WindReplaceCommand(DBWclientID, "exttospice", CmdExtToSpice) < 0)
 	return TCL_ERROR;
 
-    Tcl_PkgProvide(interp, "Exttospice", "7.2");
+    Tcl_PkgProvide(interp, "Exttospice", "7.3");
     return TCL_OK;
 }
 
@@ -278,7 +276,7 @@ Exttospice_Init(interp)
 #define EXTTOSPC_SUBCIRCUITS	7
 #define EXTTOSPC_HELP		8
 
-Void
+void
 CmdExtToSpice(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -292,14 +290,14 @@ CmdExtToSpice(w, cmd)
     int argc = cmd->tx_argc;
     char **argv = cmd->tx_argv;
     char **msg;
-    bool err_result, locDoSubckt;
+    bool err_result;
     char *resstr;
 
     short sd_rclass;
     short sub_rclass;
     char *devname;
     char *subname;
-    int idx, idx2;
+    int idx;
 
     static EFCapValue LocCapThreshold = 2;
     static int LocResistThreshold = INFINITE_THRESHOLD; 
@@ -313,10 +311,7 @@ CmdExtToSpice(w, cmd)
 	"cthresh [<value>]	set capacitance threshold value",
 	"merge [<type>]		merge parallel transistors",
 	"extresist [on|off]	incorporate information from extresist",
-	"subcircuits top [on|off]\n"
-	"			wrap top-level cell in .subckt ... .ends\n"
-	"subcircuits [descend] [on|off]\n"
-	"			standard cells become subcircuit calls",
+	"subcircuits [on|off]	standard cells become subcircuit calls",
 	"help			print help information",
 	NULL
     };
@@ -342,17 +337,9 @@ CmdExtToSpice(w, cmd)
 	"no",
 	"false",
 	"off",
-	"automatic",
-	"top",
-	"descend",
 	NULL
     };
 
-    typedef enum {
-	IDX_YES, IDX_TRUE, IDX_ON, IDX_NO, IDX_FALSE, IDX_OFF,
-	IDX_AUTO, IDX_TOP, IDX_DESCEND
-    } yesnoType;
-
     if (cmd->tx_argc > 1)
     {
 	option = Lookup(cmd->tx_argv[1], cmdExtToSpcOption);
@@ -366,83 +353,33 @@ CmdExtToSpice(w, cmd)
 	    if (cmd->tx_argc == 2)
 	    {
 		Tcl_SetResult(magicinterp, (esDoExtResis) ? "on" : "off", NULL);
-		return TCL_OK;
+		return;
 	    }
 	    else if (cmd->tx_argc != 3)
 		goto usage;
 	    idx = Lookup(cmd->tx_argv[2], yesno);
-	    if (idx < 0 || idx > 5) goto usage;
+	    if (idx < 0) goto usage;
 	    else if (idx < 3) esDoExtResis = TRUE;
 	    else esDoExtResis = FALSE;
 	    break;
-
 	case EXTTOSPC_SUBCIRCUITS:
 	    if (cmd->tx_argc == 2)
 	    {
 		Tcl_SetResult(magicinterp, (esDoPorts) ? "on" : "off", NULL);
-		return TCL_OK;
+		return;
 	    }
-
+	    else if (cmd->tx_argc != 3)
+		goto usage;
 	    idx = Lookup(cmd->tx_argv[2], yesno);
-	    switch (idx) {
-		case IDX_YES: case IDX_TRUE: case IDX_ON:
-		    esDoPorts = TRUE;
-		    return TCL_OK;
-		    break;
-		case IDX_NO: case IDX_FALSE: case IDX_OFF:
-		    esDoPorts = FALSE;
-		    return TCL_OK;
-		    break;
-		case IDX_DESCEND:
-		    if (cmd->tx_argc == 3)
-		    {
-			Tcl_SetResult(magicinterp, (esDoPorts) ? "on" : "off", NULL);
-			return TCL_OK;
-		    }
-		    break;
-		case IDX_TOP:
-		    if (cmd->tx_argc == 3)
-		    {
-			Tcl_SetResult(magicinterp, (esDoSubckt) ? "on" : "off", NULL);
-			return TCL_OK;
-		    }
-		    break;
-		case IDX_AUTO:
-		default:
-		    goto usage;
-		    break;
-	    }
-
-	    if (cmd->tx_argc != 4) goto usage;
-	    idx2 = Lookup(cmd->tx_argv[3], yesno);
-	    switch (idx2) {
-		case IDX_YES: case IDX_TRUE: case IDX_ON:
-		    if (idx == IDX_DESCEND)
-			esDoPorts = TRUE;
-		    else
-			esDoSubckt = TRUE;
-		    break;
-		case IDX_NO: case IDX_FALSE: case IDX_OFF:
-		    if (idx == IDX_DESCEND)
-			esDoPorts = FALSE;
-		    else
-			esDoSubckt = FALSE;
-		    break;
-		case IDX_AUTO:
-		    esDoSubckt = AUTO;
-		    break;
-		case IDX_DESCEND:
-		case IDX_TOP: 
-		default:
-		    goto usage;
-	    }
+	    if (idx < 0) goto usage;
+	    else if (idx < 3) esDoPorts = TRUE;
+	    else esDoPorts = FALSE;
 	    break;
-
 	case EXTTOSPC_FORMAT:
 	    if (cmd->tx_argc == 2)
 	    {
 		Tcl_SetResult(magicinterp, cmdExtToSpcFormat[esFormat], NULL);
-		return TCL_OK;
+		return;
 	    }
 	    else if (cmd->tx_argc < 3) goto usage;
 	    idx = Lookup(cmd->tx_argv[2], cmdExtToSpcFormat);
@@ -450,7 +387,7 @@ CmdExtToSpice(w, cmd)
 	    {
 		Tcl_SetResult(magicinterp, "Bad format type.  Formats are:"
 			"spice2, spice3, and hspice.", NULL);
-		return TCL_ERROR;
+		return;
 	    }
 	    else esFormat = idx;
 	    break;
@@ -463,7 +400,7 @@ CmdExtToSpice(w, cmd)
 		else
 		    Tcl_SetObjResult(magicinterp,
 			Tcl_NewDoubleObj((double)LocCapThreshold));
-		return TCL_OK;
+		return;
 	    }
 	    else if (cmd->tx_argc < 3) goto usage;
 	
@@ -488,7 +425,7 @@ CmdExtToSpice(w, cmd)
 		else
 		    Tcl_SetObjResult(magicinterp,
 			Tcl_NewIntObj(LocResistThreshold));
-		return TCL_OK;
+		return;
 	    }
 	    else if (cmd->tx_argc < 3) goto usage;
 	    if (StrIsInt(cmd->tx_argv[2]))
@@ -508,7 +445,7 @@ CmdExtToSpice(w, cmd)
 		    Tcl_SetResult(magicinterp, "conservative", NULL);
 		else
 		    Tcl_SetResult(magicinterp, "none", NULL);
-		return TCL_OK;
+		return;
 	    }
 	    else if (cmd->tx_argc < 3) goto usage;
 	    value = Lookup(cmd->tx_argv[2], cmdMergeTypes);
@@ -563,7 +500,7 @@ usage:
 	    }
 	    break;
     }
-    return TCL_OK;
+    return;
 
 runexttospice:
 
@@ -588,7 +525,7 @@ runexttospice:
     if (err_result == TRUE)
     {
 	EFDone();
-	return TCL_ERROR;
+	return;
     }
 
     if (inName == NULL)
@@ -603,12 +540,12 @@ runexttospice:
 	if (w == (MagWindow *) NULL)
 	{
 	    TxError("Point to a window or specify a cell name.\n");
-	    return TCL_ERROR;
+	    return;
 	}
 	if ((inName = ((CellUse *) w->w_surfaceID)->cu_def->cd_name) == NULL)
 	{
 	    TxError("No cell present\n");
-	    return TCL_ERROR;
+	    return;
 	}
     }
 
@@ -628,14 +565,14 @@ runexttospice:
 		spcesOutName);
 	Tcl_SetResult(magicinterp, tclres, TCL_DYNAMIC);
 	EFDone();
-        return TCL_ERROR;
+        return;
     }
 
     /* Read the hierarchical description of the input circuit */
-    if (EFReadFile(inName, TRUE, esDoExtResis) == FALSE)
+    if (EFReadFile(inName, esDoPorts, esDoExtResis) == FALSE)
     {
 	EFDone();
-        return TCL_ERROR;
+        return;
     }
 
     if (EFStyle == NULL)
@@ -705,22 +642,6 @@ runexttospice:
     }
     EFFlatBuild(inName, flatFlags);
 
-    /* Determine if this is a subcircuit */
-    locDoSubckt = FALSE;
-    if (esDoSubckt == AUTO) {
-	Def *rootDef = EFRootDef();
-	if (rootDef->def_flags & DEF_SUBCIRCUIT)
-	    locDoSubckt = TRUE;
-    }
-    if ((esDoSubckt == TRUE) || (locDoSubckt == TRUE))
-	topVisit(EFRootDef());
-
-    /* If we don't want to write subcircuit calls, remove the	*/
-    /* subcircuit flag from all cells at this time.		*/
-
-    if (!esDoPorts)
-	EFVisitSubcircuits(subcktUndef, (ClientData) NULL);
-
     initMask = ( esDistrJunct  ) ? (unsigned long)0 : DEV_CONNECT_MASK;
 
     if (esMergeDevsA || esMergeDevsC)
@@ -729,7 +650,7 @@ runexttospice:
 	TxPrintf("Devs merged: %d\n", esDevsMerged);
 	esFMIndex = 0;
 	{
-	    register devMerge *p;
+	    devMerge *p;
 
 	    for (p = devMergeList; p != NULL; p = p->next)
 		FREE(p);
@@ -750,9 +671,6 @@ runexttospice:
     (void) sprintf( esCapFormat, "C%%d %%s GND %%.%dlffF%%s", esCapAccuracy);
     EFVisitNodes(spcnodeVisit, (ClientData) NULL);
 
-    if ((esDoSubckt == TRUE) || (locDoSubckt == TRUE))
-	fprintf(esSpiceF, ".ends\n");
-
     if (esFormat == HSPICE) 
 	printSubcktDict();
 
@@ -762,7 +680,7 @@ runexttospice:
     if (esSpiceF) fclose(esSpiceF);
 
     TxPrintf("exttospice finished.\n");
-    return TCL_OK;
+    return;
 }
 
 #else	/* MAGIC_WRAPPER */
@@ -786,7 +704,6 @@ main(argc, argv)
     int i,flatFlags;
     char *inName;
     FILE *f;
-    bool locDoSubckt;
 
     esDevsMerged = 0;
 
@@ -837,7 +754,7 @@ main(argc, argv)
     }
 
     /* Read the hierarchical description of the input circuit */
-    if (EFReadFile(inName, TRUE, esDoExtResis) == FALSE)
+    if (EFReadFile(inName, esDoPorts, esDoExtResis) == FALSE)
     {
 	exit (1);
     }
@@ -863,22 +780,6 @@ main(argc, argv)
     }
     EFFlatBuild(inName, flatFlags);
 
-    /* Determine if this is a subcircuit */
-    locDoSubckt = FALSE;
-    if (esDoSubckt == AUTO) {
-	Def *rootDef = EFRootDef();
-	if (rootDef->def_flags & DEF_SUBCIRCUIT)
-	    locDoSubckt = TRUE;
-    }
-    if ((esDoSubckt == TRUE) || (locDoSubckt == TRUE))
-	topVisit(EFRootDef());
-
-    /* If we don't want to write subcircuit calls, remove the	*/
-    /* subcircuit flag from all cells at this time.		*/
-
-    if (!esDoPorts)
-	EFVisitSubcircuits(subcktUndef, (ClientData) NULL);
-
     initMask = ( esDistrJunct  ) ? (unsigned long)0 : DEV_CONNECT_MASK ;
 
     if ( esMergeDevsA || esMergeDevsC ) {
@@ -886,7 +787,7 @@ main(argc, argv)
 	TxPrintf("Devs merged: %d\n", esDevsMerged);
 	esFMIndex = 0 ;
 	{
-	  register devMerge *p;
+	  devMerge *p;
 
 	  for ( p = devMergeList ; p != NULL ; p=p->next ) FREE(p);
 	}
@@ -903,9 +804,6 @@ main(argc, argv)
     (void) sprintf( esCapFormat, "C%%d %%s GND %%.%dlffF%%s", esCapAccuracy);
     EFVisitNodes(spcnodeVisit, (ClientData) NULL);
 
-    if ((esDoSubckt == TRUE) || (locDoSubckt == TRUE))
-	fprintf(esSpiceF, ".ends\n");
-
     if ( esFormat == HSPICE ) 
 	printSubcktDict();
 
@@ -1090,7 +988,7 @@ HierName *prefix;
 HierName *suffix;
 {
     HashEntry *he;
-    register EFNodeName *nn;
+    EFNodeName *nn;
 
     he = EFHNConcatLook(prefix, suffix, "output");
     if (he == NULL) return NULL;
@@ -1129,7 +1027,6 @@ DevTerm *term;
     return r;
 }
 
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1158,18 +1055,16 @@ DevTerm *term;
  * ----------------------------------------------------------------------------
  */
 int
-subcktVisit(use, hierName, is_top)
+subcktVisit(use, hierName, cdata)
     Use *use;
     HierName *hierName;
-    bool is_top;	/* TRUE if this is the top-level cell */
+    ClientData cdata;	/* unused */
 {
     EFNode *snode;
     Def *def = use->use_def;
     HierName *nodeName;
     int portorder, portmax;
 
-    if (is_top == TRUE) return 0;	/* Ignore the top-level cell */
-
     fprintf(esSpiceF, "X%d", esSbckNum++);
 
     /* This is not a DEV, but "spcdevOutNode" is a general-purpose routine that */
@@ -1234,135 +1129,6 @@ subcktVisit(use, hierName, is_top)
     return 0;
 }
 
-/*
- * ----------------------------------------------------------------------------
- *
- * subcktUndef --
- *
- * Procedure to remove the DEF_SUBCIRCUIT flag from all subcells.
- * Called by EFVisitSubcircuits().
- *
- * Results:
- *	Returns 0 always.
- *
- * Side effects:
- *	Undefines the DEF_SUBCIRCUIT flag in each encountered Def.
- *
- * ----------------------------------------------------------------------------
- */
-int
-subcktUndef(use, hierName, is_top)
-    Use *use;
-    HierName *hierName;
-    bool is_top;	/* TRUE if this is the top-level cell */
-{
-    Def *def = use->use_def;
-
-    def->def_flags &= ~(DEF_SUBCIRCUIT);
-    return 0;
-}
-
-/*
- * ----------------------------------------------------------------------------
- *
- * topVisit --
- *
- * Procedure to output a subcircuit definition to the .spice file.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	Writes to the file esSpiceF.
- *
- * Format of a .spice subcircuit definition:
- *
- *	.subckt name node1 node2 ... noden
- *
- * where
- *	node1 node2 ... noden are the nodes connecting to the ports of
- *	the subcircuit.  "name" is the name of the cell def.
- *
- * ----------------------------------------------------------------------------
- */
-
-void
-topVisit(def)
-    Def *def;
-{
-    EFNode *snode;
-    EFNodeName *sname;
-    HierName *nodeName;
-    HashSearch hs;
-    HashEntry *he;
-    int portorder, portmax;
-
-    fprintf(esSpiceF, ".subckt %s", def->def_name);
-
-    /* Note that the ports of the subcircuit will not necessarily be	*/
-    /* ALL the entries in the hash table, so we have to check.		*/
-
-    HashStartSearch(&hs);
-    portmax = -1;
-
-    while (he = HashNext(&def->def_nodes, &hs))
-    {
-	sname = (EFNodeName *) HashGetValue(he);
-	snode = sname->efnn_node;
-
-	portorder = snode->efnode_name->efnn_node->efnode_flags;
-	if (!(portorder & EF_PORT)) continue;
-	else portorder >>= PORT_SHIFT;
-	if (portorder > portmax) portmax = portorder;
-    }
-
-    if (portmax < 0)
-    {
-	/* No port order declared; print them as we see them.	*/
-	/* This shouldn't happen for proper .ext files written	*/
-	/* by the magic extractor.				*/
-
-	HashStartSearch(&hs);
-        while (he = HashNext(&def->def_nodes, &hs))
-	{
-	    sname = (EFNodeName *) HashGetValue(he);
-	    snode = sname->efnn_node;
-
-	    if (snode->efnode_name->efnn_node->efnode_flags & EF_PORT)
-		fprintf(esSpiceF, " %s", he->h_key.h_name);
-	}
-    }
-    else
-    {
-	/* Port numbers need not start at zero or be contiguous. */
-	/* They will be printed in numerical order.		 */
-
-	portorder = 0;
-	while (portorder <= portmax)
-	{
-	    HashStartSearch(&hs);
-            while (he = HashNext(&def->def_nodes, &hs))
-	    {
-		int portidx;
-
-	        sname = (EFNodeName *) HashGetValue(he);
-	        snode = sname->efnn_node;
-
-		portidx = snode->efnode_name->efnn_node->efnode_flags;
-		if (!(portidx & EF_PORT)) continue;
-		else portidx >>= PORT_SHIFT;
-		if (portidx == portorder)
-		{
-		    fprintf(esSpiceF, " %s", he->h_key.h_name);
-		    break;
-		}
-	    }
-	    portorder++;
-	}
-    }
-    fprintf(esSpiceF, "\n");
-}
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1537,6 +1303,31 @@ spcdevVisit(dev, hierName, trans)
 			dev->dev_type, esSpiceF);
 	    }
 	    fprintf(esSpiceF, " %s", EFDevTypes[dev->dev_type]);
+
+	    /* If this thing looks like a FET (3 or 4 terminals), then	*/
+	    /* write its length and width.				*/
+
+	    if (dev->dev_nterm > 2)
+	    {
+		GeoTransRect(trans, &dev->dev_rect, &r);
+		scale = GeoScale(trans);
+
+		sdM = getCurDevMult();
+
+		if (esFormat == HSPICE)
+		{
+		    fprintf(esSpiceF, " w=%d l=%d", w*scale, l*scale);
+		    if (sdM != 1.0)
+			fprintf(esSpiceF, " M=%g", sdM);
+		}
+		else
+		{
+		    fprintf(esSpiceF, " w=%gu l=%gu",
+				(float)w * scale * esScale * sdM,
+				(float)l * scale * esScale);
+		    sdM = 1.0;
+		}
+	    }
 	    break;
 
 	case DEV_RES:
@@ -1551,7 +1342,7 @@ spcdevVisit(dev, hierName, trans)
 	    spcdevOutNode(hierName, source->dterm_node->efnode_name->efnn_hier,
 			name, esSpiceF);
 
-	    /* SPICE has two resistor types.  If the "name" (EFDevTypes)    */
+	    /* SPICE has two resistor types.  If the "name" (EFDevTypes) is */
 	    /* "None", the simple resistor type is used, and a value given. */
 	    /* If not, the "semiconductor resistor" is used, and L and W    */
 	    /* and the device name are output.				    */
@@ -1605,7 +1396,38 @@ spcdevVisit(dev, hierName, trans)
 			name, esSpiceF);
 	    spcdevOutNode(hierName, source->dterm_node->efnode_name->efnn_hier,
 			name, esSpiceF);
-	    fprintf(esSpiceF, " %ffF", (double)(dev->dev_values.dev_cap));
+
+	    /* SPICE has two capacitor types.  If the "name" (EFDevTypes) is */
+	    /* "None", the simple capacitor type is used, and a value given. */
+	    /* If not, the "semiconductor capacitor" is used, and L and W    */
+	    /* and the device name are output.				     */
+
+	    if (!strcmp(EFDevTypes[dev->dev_type], "None"))
+	    {
+		fprintf(esSpiceF, " %ffF", (double)(dev->dev_values.dev_cap));
+	    }
+	    else
+	    {
+		fprintf(esSpiceF, " %s", EFDevTypes[dev->dev_type]);
+
+		GeoTransRect(trans, &dev->dev_rect, &r);
+		scale = GeoScale(trans);
+		sdM = getCurDevMult();
+
+		if (esFormat == HSPICE)
+		{
+		    fprintf(esSpiceF, " w=%d l=%d", w*scale, l*scale);
+		    if (sdM != 1.0)
+			fprintf(esSpiceF, " M=%g", sdM);
+		}
+		else
+		{
+		    fprintf(esSpiceF, " w=%gu l=%gu",
+			(float)w * scale * esScale * sdM,
+			(float)l * scale * esScale);
+		    sdM = 1.0;
+		}
+	    }
 	    break;
 
 	case DEV_FET:
@@ -1788,7 +1610,7 @@ FILE *outf;
  *
  * ----------------------------------------------------------------------------
  */
-Void spcnAP(node, resClass, scale, sterm, m, outf, w)
+int spcnAP(node, resClass, scale, sterm, m, outf, w)
     EFNode *node;
     int  resClass, scale;
     char *sterm;
@@ -1838,7 +1660,7 @@ oldFmt:
 	    ((float)node->efnode_pa[resClass].pa_perim*scale)*esScale);
 }
 
-Void spcnAPHier(dterm, hierName, resClass, scale, sterm, m, outf)
+int spcnAPHier(dterm, hierName, resClass, scale, sterm, m, outf)
     DevTerm *dterm;
     HierName *hierName;
     int  resClass, scale;
@@ -1895,7 +1717,7 @@ Void spcnAPHier(dterm, hierName, resClass, scale, sterm, m, outf)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 spcdevOutNode(prefix, suffix, name, outf)
     HierName *prefix;
     HierName *suffix;
@@ -2014,11 +1836,11 @@ spcresistVisit(hierName1, hierName2, res)
 
 int
 spcnodeVisit(node, res, cap)
-    register EFNode *node;
+    EFNode *node;
     int res; 
     double cap;
 {
-    register EFNodeName *nn;
+    EFNodeName *nn;
     HierName *hierName;
     bool isConnected = FALSE;
     char *fmt, *nsn;
@@ -2064,11 +1886,11 @@ spcnodeVisit(node, res, cap)
 /* a debugging procedure */
 int
 nodeVisitDebug(node, res, cap)
-    register EFNode *node;
+    EFNode *node;
     int res; 
     double cap;
 {
-    register EFNodeName *nn;
+    EFNodeName *nn;
     HierName *hierName;
     bool isConnected;
     char *fmt, *nsn;
@@ -2158,13 +1980,13 @@ retName:
  * ----------------------------------------------------------------------------
  */
 
-Void 
+int 
 EFHNSprintf(str, hierName)
-    register char *str;
+    char *str;
     HierName *hierName;
 {
     bool trimGlob, trimLocal;
-    register char *s, *cp, c;
+    char *s, *cp, c;
     char *efHNSprintfPrefix();
 
     s = str;
@@ -2190,10 +2012,10 @@ EFHNSprintf(str, hierName)
 }
 
 char *efHNSprintfPrefix(hierName, str)
-    register HierName *hierName;
-    register char *str;
+    HierName *hierName;
+    char *str;
 {
-    register char *cp, c;
+    char *cp, c;
 
     if (hierName->hn_parent)
 	str = efHNSprintfPrefix(hierName->hn_parent, str);
@@ -2221,10 +2043,10 @@ char *efHNSprintfPrefix(hierName, str)
  *
  * ----------------------------------------------------------------------------
  */
-Void nodeHspiceName(s)
+int nodeHspiceName(s)
 char *s;
 {
-	register char *p, *sf;
+	char *p, *sf;
 	int l, snum=-1 ;
 	HashEntry *he;
 	static char map[MAX_STR_SIZE];
@@ -2295,7 +2117,7 @@ topLevel:
  *
  * ----------------------------------------------------------------------------
  */
-Void printSubcktDict()
+int printSubcktDict()
 {
 	HashSearch  hs;
 	HashEntry  *he;
@@ -2331,7 +2153,7 @@ EFNode *g, *s, *d, *b;
 HierName *hn;
 Dev    *dev;
 {
-	register    devMerge *fp;
+	   devMerge *fp;
 
 	MALLOC (devMerge *, fp, sizeof(devMerge));
 	fp->l = l; fp->w = w;
@@ -2435,7 +2257,7 @@ int l, w;
 	int      scale, pmode;
 	bool     hS, hD, chS, chD;
     	Rect r;
-	register devMerge *fp, *cfp;
+	devMerge *fp, *cfp;
 	float m;
 
 	if (esDistrJunct)
@@ -2540,7 +2362,7 @@ mergeThem:
  *
  * ----------------------------------------------------------------------------
  */
-Void 
+int 
 update_w(resClass, w,  n)
 short  resClass;
 int w;
