@@ -58,6 +58,9 @@ int   EFLayerNumNames;
 /* Forward declarations */
 Connection *efAllocConn();
 EFNode *efBuildDevNode();
+void efNodeAddName();
+void efNodeMerge();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -125,7 +128,7 @@ EFNode *efBuildDevNode();
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efBuildNode(def, nodeName, nodeCap, x, y, layerName, av, ac)
     Def *def;		/* Def to which this connection is to be added */
     char *nodeName;	/* One of the names for this node */
@@ -135,11 +138,11 @@ efBuildNode(def, nodeName, nodeCap, x, y, layerName, av, ac)
     char **av;		/* Pairs of area, perimeter strings */
     int ac;		/* Number of strings in av */
 {
-    register EFNodeName *newname;
-    register EFNode *newnode;
+    EFNodeName *newname;
+    EFNode *newnode;
     HashEntry *he;
     unsigned size;
-    register int n;
+    int n;
 
     he = HashFind(&def->def_nodes, nodeName);
     if (newname = (EFNodeName *) HashGetValue(he))
@@ -216,7 +219,7 @@ efBuildNode(def, nodeName, nodeCap, x, y, layerName, av, ac)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efBuildAttr(def, nodeName, r, layerName, text)
     Def *def;
     char *nodeName;
@@ -272,7 +275,7 @@ efBuildAttr(def, nodeName, r, layerName, text)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efBuildDist(def, driver, receiver, min, max)
     Def *def;		/* Def for which we're adding a new Distance */
     char *driver;	/* Source terminal */
@@ -347,7 +350,7 @@ efBuildDist(def, driver, receiver, min, max)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efBuildKill(def, name)
     Def *def;		/* Def for which we're adding a new Kill */
     char *name;		/* Name of node to die */
@@ -379,7 +382,7 @@ efBuildKill(def, name)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efBuildEquiv(def, nodeName1, nodeName2)
     Def *def;		/* Def for which we're adding a new node name */
     char *nodeName1;	/* One of node names to be made equivalent */
@@ -452,25 +455,27 @@ efBuildEquiv(def, nodeName1, nodeName2)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efBuildDevice(def, class, type, r, argc, argv)
     Def *def;		/* Def to which this connection is to be added */
     char class;		/* Class (dev, bjt, etc.) of this device */
     char *type;		/* Type (name) of this device */
     Rect *r;		/* Coordinates of 1x1 rectangle entirely inside device */
-    int argc;		/* Size of argv; should be a multiple of 3 */
-    char *argv[];	/* Tokens for the rest of the dev line.  These are
-			 * taken in groups of 3, one for each terminal.
+    int argc;		/* Size of argv */
+    char *argv[];	/* Tokens for the rest of the dev line.
+			 * The first depend on the type of device.  The rest
+			 * are taken in groups of 3, one for each terminal.
 			 * Each group of 3 consists of the node name to which
 			 * the terminal connects, the length of the terminal,
 			 * and an attribute list (or the token 0).
 			 */
 {
-    register int n, nterminals;
-    register DevTerm *term;
-    register Dev *newdev;
-    register char **av;
+    int n, nterminals;
+    DevTerm *term;
+    Dev *newdev;
+    char **av;
     int argstart = 1;	/* start of terminal list in argv[] */
+    bool hasModel = strcmp(type, "None") ? TRUE : FALSE;
 
     int area, perim;	/* Total area, perimeter of primary type (i.e., channel) */
     char *substrate;	/* Name of node to which substrate is connected */
@@ -486,6 +491,11 @@ efBuildDevice(def, class, type, r, argc, argv)
 	case DEV_DIODE:
 	    argstart = 0;
 	    break;
+	case DEV_RES:
+	case DEV_CAP:
+	    if (hasModel)
+		argstart = 2;
+	    break;
     }
     nterminals = (argc - argstart) / 3;
 
@@ -515,21 +525,53 @@ efBuildDevice(def, class, type, r, argc, argv)
 	case DEV_DIODE:		/* do nothing */
 	    break;
 	case DEV_RES:
-	    if (StrIsNumeric(argv[0]))
+	    if (hasModel && StrIsInt(argv[0]) && StrIsInt(argv[1]))
+	    {
+		newdev->dev_values.dev_lw.dev_length = atoi(argv[0]);
+		newdev->dev_values.dev_lw.dev_width = atoi(argv[1]);
+		newdev->dev_values.dev_res = 0.0;
+	    }
+	    else if (StrIsNumeric(argv[0]))
+	    {
 		newdev->dev_values.dev_res = (float)atof(argv[0]);
+		newdev->dev_values.dev_lw.dev_length = 0;
+		newdev->dev_values.dev_lw.dev_width = 0;
+	    }
 	    else
 	    {
-		efReadError("Error: expected resistance value, got %s\n", argv[0]);
+		if (hasModel)
+		    efReadError("Error: expected L and W, got %s %s\n", argv[0],
+				argv[1]);
+		else
+		    efReadError("Error: expected resistance value, got %s\n", argv[0]);
 		newdev->dev_values.dev_res = 0.0;
+		newdev->dev_values.dev_lw.dev_length = 0;
+		newdev->dev_values.dev_lw.dev_width = 0;
 	    }
 	    break;
 	case DEV_CAP:
-	    if (StrIsNumeric(argv[0]))
+	    if (hasModel && StrIsInt(argv[0]) && StrIsInt(argv[1]))
+	    {
+		newdev->dev_values.dev_lw.dev_length = atoi(argv[0]);
+		newdev->dev_values.dev_lw.dev_width = atoi(argv[1]);
+		newdev->dev_values.dev_cap = 0.0;
+	    }
+	    else if (StrIsNumeric(argv[0]))
+	    {
 		newdev->dev_values.dev_cap = (float)atof(argv[0]);
+		newdev->dev_values.dev_lw.dev_length = 0;
+		newdev->dev_values.dev_lw.dev_width = 0;
+	    }
 	    else
 	    {
-		efReadError("Error: expected capacitance value, got %s\n", argv[0]);
+		if (hasModel)
+		    efReadError("Error: expected L and W, got %s %s\n", argv[0],
+				argv[1]);
+		else
+		    efReadError("Error: expected capacitance value, got %s\n", argv[0]);
 		newdev->dev_values.dev_cap = 0.0;
+		newdev->dev_values.dev_lw.dev_length = 0;
+		newdev->dev_values.dev_lw.dev_width = 0;
 	    }
 	    break;
     }
@@ -582,8 +624,8 @@ efBuildPortNode(def, name, idx, x, y, layername)
     int x; int y;	/* Location of a point inside this node */
     char *layername;	/* Name of tile type */
 {
-    register HashEntry *he;
-    register EFNodeName *nn;
+    HashEntry *he;
+    EFNodeName *nn;
 
     he = HashFind(&def->def_nodes, name);
     nn = (EFNodeName *) HashGetValue(he);
@@ -625,8 +667,8 @@ efBuildDevNode(def, name, isSubsNode)
     char *name;
     bool isSubsNode;
 {
-    register HashEntry *he;
-    register EFNodeName *nn;
+    HashEntry *he;
+    EFNodeName *nn;
 
     he = HashFind(&def->def_nodes, name);
     nn = (EFNodeName *) HashGetValue(he);
@@ -670,12 +712,12 @@ efBuildDevNode(def, name, isSubsNode)
 
 int
 efBuildAddStr(table, pMax, size, str)
-    register char *table[];	/* Table to search */
+    char *table[];	/* Table to search */
     int *pMax;			/* Increment this if we add an entry */
     int size;			/* Maximum size of table */
-    register char *str;		/* String to add */
+    char *str;		/* String to add */
 {
-    register int n, max;
+    int n, max;
 
     max = *pMax;
     for (n = 0; n < max; n++)
@@ -718,7 +760,7 @@ efBuildAddStr(table, pMax, size, str)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efBuildUse(def, subDefName, subUseId, ta, tb, tc, td, te, tf)
     Def *def;		/* Def to which this connection is to be added */
     char *subDefName;	/* Def of which this a use */
@@ -730,7 +772,7 @@ efBuildUse(def, subDefName, subUseId, ta, tb, tc, td, te, tf)
 {
     Use *newuse;
     Def *newdef;
-    register char *cp;
+    char *cp;
 
     newdef = efDefLook(subDefName);
     if (newdef == NULL)
@@ -784,7 +826,7 @@ efBuildUse(def, subDefName, subUseId, ta, tb, tc, td, te, tf)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efBuildConnect(def, nodeName1, nodeName2, deltaC, av, ac)
     Def *def;		/* Def to which this connection is to be added */
     char *nodeName1;	/* Name of first node in connection */
@@ -833,7 +875,7 @@ efBuildConnect(def, nodeName1, nodeName2, deltaC, av, ac)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efBuildResistor(def, nodeName1, nodeName2, resistance)
     Def *def;		/* Def to which this connection is to be added */
     char *nodeName1;	/* Name of first node in resistor */
@@ -870,7 +912,7 @@ efBuildResistor(def, nodeName1, nodeName2, resistance)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efBuildCap(def, nodeName1, nodeName2, cap)
     Def *def;		/* Def to which this connection is to be added */
     char *nodeName1;	/* Name of first node in capacitor */
@@ -966,12 +1008,12 @@ bad:
 
 bool
 efConnBuildName(cnp, name)
-    register ConnName *cnp;
+    ConnName *cnp;
     char *name;
 {
-    register char *srcp, *dstp, *cp, *dp;
-    register int nsubs;
-    register Range *rp;
+    char *srcp, *dstp, *cp, *dp;
+    int nsubs;
+    Range *rp;
     char newname[1024];
     char c;
 
@@ -1071,7 +1113,7 @@ again:
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efNodeAddName(node, he, hn)
     EFNode *node;
     HashEntry *he;
@@ -1124,13 +1166,13 @@ efNodeAddName(node, he, hn)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efNodeMerge(node1, node2)
     EFNode *node1, *node2;	/* Hierarchical nodes */
 {
     EFNodeName *nn, *nnlast;
     EFAttr *ap;
-    register int n;
+    int n;
 
     /* Sanity check: ignore if same node */
     if (node1 == node2)
@@ -1259,14 +1301,14 @@ efNodeMerge(node1, node2)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efFreeNodeTable(table)
     HashTable *table;
 {
     HashSearch hs;
-    register HashEntry *he;
-    register HierName *hn;
-    register EFNodeName *nn;
+    HashEntry *he;
+    HierName *hn;
+    EFNodeName *nn;
 
     HashStartSearch(&hs);
     while (he = HashNext(table, &hs))
@@ -1295,12 +1337,12 @@ efFreeNodeTable(table)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efFreeNodeList(head)
     EFNode *head;
 {
-    register EFNode *node;
-    register EFAttr *ap;
+    EFNode *node;
+    EFAttr *ap;
 
     for (node = (EFNode *) head->efnode_next;
 	    node != head;
@@ -1328,9 +1370,9 @@ efFreeNodeList(head)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efFreeConn(conn)
-    register Connection *conn;
+    Connection *conn;
 {
     if (conn->conn_name1) FREE(conn->conn_name1);
     if (conn->conn_name2) FREE(conn->conn_name2);
