@@ -22,7 +22,9 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFflat.c,v 1.2 200
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <string.h>
 #include <math.h>
+
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
@@ -80,7 +82,7 @@ char *efFlatGlobCopy();
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 EFFlatBuild(name, flags)
     char *name;		/* Name of root def being flattened */
     int flags;		/* Say what to flatten; see above */
@@ -90,7 +92,7 @@ EFFlatBuild(name, flags)
 
     /* Keyed by a full HierName */
     HashInitClient(&efNodeHashTable, INITFLATSIZE, HT_CLIENTKEYS,
-	efHNCompare, (char *(*)()) NULL, efHNHash, (Void (*)()) NULL);
+	efHNCompare, (char *(*)()) NULL, efHNHash, (int (*)()) NULL);
 
     /* Keyed by a pair of HierNames */
     HashInitClient(&efDistHashTable, INITFLATSIZE, HT_CLIENTKEYS,
@@ -101,7 +103,7 @@ EFFlatBuild(name, flags)
 
     /* Keyed by a string and a HierName */
     HashInitClient(&efHNUseHashTable, INITFLATSIZE, HT_CLIENTKEYS,
-	efHNUseCompare, (char *(*)()) NULL, efHNUseHash, (Void (*)()) NULL);
+	efHNUseCompare, (char *(*)()) NULL, efHNUseHash, (int (*)()) NULL);
 
     /* Circular list of all nodes contains no elements initially */
     efNodeList.efnode_next = (EFNodeHdr *) &efNodeList;
@@ -148,7 +150,7 @@ EFFlatBuild(name, flags)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 EFFlatDone()
 {
 #ifdef	MALLOCTRACE
@@ -360,7 +362,7 @@ efAddNodes(hc)
 efAddConns(hc)
     HierContext *hc;
 {
-    register Connection *conn;
+    Connection *conn;
 
     if (efWatchNodes)
 	TxPrintf("Processing %s (%s)\n",
@@ -404,9 +406,9 @@ efAddOneConn(hc, name1, name2, conn)
     char *name1, *name2;	/* These are strings, not HierNames */
     Connection *conn;
 {
-    register HashEntry *he1, *he2;
-    register EFNode *node, *newnode;
-    register int n;
+    HashEntry *he1, *he2;
+    EFNode *node, *newnode;
+    int n;
 
     he1 = EFHNLook(hc->hc_hierName, name1, "connect(1)");
     if (he1 == NULL)
@@ -464,7 +466,7 @@ efAddOneConn(hc, name1, name2, conn)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 efFlatGlob()
 {
     EFNodeName *nameFlat, *nameGlob;
@@ -475,7 +477,7 @@ efFlatGlob()
     HashSearch hs;
 
     HashInitClient(&globalTable, INITFLATSIZE, HT_CLIENTKEYS,
-	efFlatGlobCmp, efFlatGlobCopy, efFlatGlobHash, (Void (*)()) NULL);
+	efFlatGlobCmp, efFlatGlobCopy, efFlatGlobHash, (int (*)()) NULL);
 
     /*
      * The following loop examines each global name (the last component of
@@ -576,12 +578,12 @@ efFlatGlob()
     HashKill(&globalTable);
 }
 
-Void
+int
 efFlatGlobError(nameGlob, nameFlat)
     EFNodeName *nameGlob, *nameFlat;
 {
     EFNode *nodeGlob = nameGlob->efnn_node, *nodeFlat = nameFlat->efnn_node;
-    register EFNodeName *nn;
+    EFNodeName *nn;
     int count;
 
     TxPrintf("*** Global name %s not fully connected:\n",
@@ -608,7 +610,7 @@ efFlatGlobError(nameGlob, nameFlat)
 
 int
 efFlatGlobCmp(hierName1, hierName2)
-    register HierName *hierName1, *hierName2;
+    HierName *hierName1, *hierName2;
 {
     if (hierName1 == hierName2)
 	return 0;
@@ -620,9 +622,9 @@ efFlatGlobCmp(hierName1, hierName2)
 
 char *
 efFlatGlobCopy(hierName)
-    register HierName *hierName;
+    HierName *hierName;
 {
-    register HierName *hNew;
+    HierName *hNew;
     int size;
 
     size = HIERNAMESIZE(strlen(hierName->hn_name));
@@ -638,7 +640,7 @@ efFlatGlobCopy(hierName)
 
 int
 efFlatGlobHash(hierName)
-    register HierName *hierName;
+    HierName *hierName;
 {
     return hierName->hn_hash;
 }
@@ -723,7 +725,7 @@ efFlatKills(hc)
 efFlatCaps(hc)
     HierContext *hc;
 {
-    register Connection *conn;
+    Connection *conn;
 
     /* Recursively flatten capacitors */
     (void) efHierSrUses(hc, efFlatCaps, (ClientData) 0);
@@ -894,7 +896,7 @@ HashEntry *he;
  * argument promotion in ANSI C
  *
  */
-Void
+int
 CapHashSetValue(he, c)
 HashEntry *he; 
 double c;
