@@ -21,9 +21,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFname.c,v 1.4 200
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <string.h>
 #include <math.h>
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
@@ -53,6 +54,11 @@ HashTable efNodeHashTable;
  * with the same fields.
  */
 HashTable efHNUseHashTable;
+
+extern void EFHNFree();
+extern void efHNInit();
+extern void efHNRecord();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -76,7 +82,7 @@ HashTable efHNUseHashTable;
 
 bool
 EFHNIsGlob(hierName)
-    register HierName *hierName;
+    HierName *hierName;
 {
 #ifdef MAGIC_WRAPPER
     char *retstr;
@@ -107,7 +113,7 @@ EFHNIsGlob(hierName)
 
 bool
 EFHNIsGND(hierName)
-    register HierName *hierName;
+    HierName *hierName;
 {
 #ifdef MAGIC_WRAPPER
     char *retstr;
@@ -144,9 +150,9 @@ EFHNIsGND(hierName)
 HierName *
 EFHNConcat(prefix, suffix)
     HierName *prefix;		/* Components of name on root side */
-    register HierName *suffix;	/* Components of name on leaf side */
+    HierName *suffix;	/* Components of name on leaf side */
 {
-    register HierName *new, *prev;
+    HierName *new, *prev;
     HierName *firstNew;
     unsigned size;
 
@@ -194,8 +200,8 @@ EFStrToHN(prefix, suffixStr)
     HierName *prefix;	/* Components of name on side of root */
     char *suffixStr;	/* Leaf part of name (may have /'s) */
 {
-    register char *cp;
-    register HashEntry *he;
+    char *cp;
+    HashEntry *he;
     char *slashPtr;
     HierName *hierName;
     unsigned size;
@@ -280,9 +286,9 @@ EFHNToStr(hierName)
 char *
 efHNToStrFunc(hierName, dstp)
     HierName *hierName;		/* Name to be converted */
-    register char *dstp;	/* Store name here */
+    char *dstp;	/* Store name here */
 {
-    register char *srcp;
+    char *srcp;
 
     if (hierName == NULL)
     {
@@ -433,7 +439,7 @@ EFHNConcatLook(prefix, suffix, errorStr)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 EFHNFree(hierName, prefix, type)
     HierName *hierName, *prefix;
     int type;	/* HN_ALLOC, HN_CONCAT, etc */
@@ -480,7 +486,7 @@ EFHNBest(hierName1, hierName2)
     HierName *hierName1, *hierName2;
 {
     int ncomponents1, ncomponents2, len1, len2;
-    register HierName *np1, *np2;
+    HierName *np1, *np2;
     char last1, last2;
 
     for (ncomponents1 = 0, np1 = hierName1; np1; np1 = np1->hn_parent)
@@ -545,9 +551,9 @@ EFHNBest(hierName1, hierName2)
 
 int
 efHNLexOrder(hierName1, hierName2)
-    register HierName *hierName1, *hierName2;
+    HierName *hierName1, *hierName2;
 {
-    register int i;
+    int i;
 
     if (hierName1 == hierName2)
 	return 0;
@@ -585,7 +591,7 @@ efHNFromUse(hc, prefix)
     HierContext *hc;	/* Contains use and array information */
     HierName *prefix;	/* Root part of name */
 {
-    register char *srcp, *dstp;
+    char *srcp, *dstp;
     char name[2048], *namePtr;
     Use *u = hc->hc_use;
     HierName *hierName;
@@ -678,7 +684,7 @@ efHNFromUse(hc, prefix)
 
 int
 efHNUseCompare(hierName1, hierName2)
-    register HierName *hierName1, *hierName2;
+    HierName *hierName1, *hierName2;
 {
     return (hierName1->hn_parent != hierName2->hn_parent
 	    || strcmp(hierName1->hn_name, hierName2->hn_name));
@@ -686,7 +692,7 @@ efHNUseCompare(hierName1, hierName2)
 
 int
 efHNUseHash(hierName)
-    register HierName *hierName;
+    HierName *hierName;
 {
     return hierName->hn_hash + (int) hierName->hn_parent;
 }
@@ -710,14 +716,14 @@ efHNUseHash(hierName)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efHNInit(hierName, cp, endp)
     HierName *hierName;		/* Fill in fields of this HierName */
-    register char *cp;		/* Start of name to be stored in hn_name */
-    register char *endp;	/* End of name if non-NULL; else, see above */
+    char *cp;		/* Start of name to be stored in hn_name */
+    char *endp;	/* End of name if non-NULL; else, see above */
 {
-    register unsigned hashsum;
-    register char *dstp;
+    unsigned hashsum;
+    char *dstp;
 
     hashsum = 0;
     dstp = hierName->hn_name;
@@ -769,7 +775,7 @@ efHNInit(hierName, cp, endp)
 
 int
 efHNCompare(hierName1, hierName2)
-    register HierName *hierName1, *hierName2;
+    HierName *hierName1, *hierName2;
 {
     while (hierName1)
     {
@@ -789,9 +795,9 @@ efHNCompare(hierName1, hierName2)
 
 int
 efHNHash(hierName)
-    register HierName *hierName;
+    HierName *hierName;
 {
-    register int n;
+    int n;
 
     for (n = 0; hierName; hierName = hierName->hn_parent)
 	n += hierName->hn_hash;
@@ -818,6 +824,7 @@ efHNHash(hierName)
  *	    argument.
  *	efHNDistHash returns a single 32-bit hash value based on a Distance's
  *	    two HierNames.
+ *	efHNDistKill has no return value.
  *
  * Side effects:
  *	efHNDistKill frees its Distance argument, and adds the HierNames
@@ -828,7 +835,7 @@ efHNHash(hierName)
 
 int
 efHNDistCompare(dist1, dist2)
-    register Distance *dist1, *dist2;
+    Distance *dist1, *dist2;
 {
     return efHNCompare(dist1->dist_1, dist2->dist_1)
 	|| efHNCompare(dist1->dist_2, dist2->dist_2);
@@ -836,9 +843,9 @@ efHNDistCompare(dist1, dist2)
 
 char *
 efHNDistCopy(dist)
-    register Distance *dist;
+    Distance *dist;
 {
-    register Distance *distNew;
+    Distance *distNew;
 
     MALLOC(Distance *, distNew, sizeof (Distance));
     *distNew = *dist;
@@ -847,17 +854,17 @@ efHNDistCopy(dist)
 
 int
 efHNDistHash(dist)
-    register Distance *dist;
+    Distance *dist;
 {
     return efHNHash(dist->dist_1) + efHNHash(dist->dist_2);
 }
 
 
-Void
+void
 efHNDistKill(dist)
-    register Distance *dist;
+    Distance *dist;
 {
-    register HierName *hn;
+    HierName *hn;
 
     for (hn = dist->dist_1; hn; hn = hn->hn_parent)
 	(void) HashFind(&efFreeHashTable, (char *) hn);
@@ -884,7 +891,7 @@ efHNDistKill(dist)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efHNBuildDistKey(prefix, dist, distKey)
     HierName *prefix;
     Distance *dist;
@@ -927,6 +934,7 @@ efHNBuildDistKey(prefix, dist, distKey)
  * ----------------------------------------------------------------------------
  */
 
+void
 efHNDump()
 {
     HashSearch hs;
@@ -949,6 +957,7 @@ efHNDump()
 
 int efHNSizes[4];
 
+void
 efHNRecord(size, type)
     int size;
     int type;
@@ -956,6 +965,7 @@ efHNRecord(size, type)
     efHNSizes[type] += size;
 }
 
+void
 efHNPrintSizes(when)
     char *when;
 {
