@@ -22,7 +22,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFvisit.c,v 1.2 20
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <math.h>
+
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
@@ -37,29 +40,11 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFvisit.c,v 1.2 20
 extern Def *efFlatRootDef;
 extern Use efFlatRootUse;
 extern HierContext efFlatContext;
+
+extern void efDevFixLW();
+extern void efHNOutPrefix();
+
 
-
-/*
- * ----------------------------------------------------------------------------
- *
- * EFRootDef --
- *
- * Helper function that returns a pointer to the root definition of
- * the extracted circuit.
- *
- * Results:
- *	Pointer to the root definition.
- *
- * Side Effects:
- *	None.
- * ----------------------------------------------------------------------------
- */
-
-Def *
-EFRootDef() {
-   return efFlatRootDef;
-}
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -77,16 +62,15 @@ EFRootDef() {
  * call the user-supplied procedure (*subProc)(), which should be of
  * the following form:
  *
- * 	(*subProc)(use, hierName, is_top)
+ * 	(*subProc)(use, hierName, cdata)
  *	    Use *use;
  *	    HierName *hierName;
- *	    Boolean is_top;
+ *	    ClientData cdata;
  *	{
  *	}
  *
- * is_top will be TRUE for the top-level cell, and FALSE for all
- * other cells.  The procedure should return 0 normally, or 1 to abort
- * the search.
+ * The procedure should return 0 normally, or 1 to abort the
+ * search.
  *
  * Results:
  *	Returns 0 if terminated normally, or 1 if the search
@@ -98,31 +82,16 @@ EFRootDef() {
  * ----------------------------------------------------------------------------
  */
 
+int
 EFVisitSubcircuits(subProc, cdata)
     int (*subProc)();
     ClientData cdata;
 {
     CallArg ca;
-    HierContext *hc;
-    int efVisitSubcircuits();	/* Forward declaration */
-
-    /* If the top-level def is defined as a subcircuit, call topProc */
-
-    hc = &efFlatContext;
-    if (hc->hc_use->use_def->def_flags & DEF_SUBCIRCUIT)
-	if ((*subProc)(hc->hc_use, hc->hc_hierName, TRUE))
-	    return 1;
-
-    /* For each subcell of the top-level def that is defined as	*/
-    /* a subcircuit, call subProc.				*/
 
     ca.ca_proc = subProc;
     ca.ca_cdata = cdata;
-
-    if (efHierSrUses(hc, efVisitSubcircuits, (ClientData) &ca))
-	return 1;
-
-    return 0;
+    return efVisitSubcircuits(&efFlatContext, (ClientData) &ca);
 }
 
 /*
@@ -138,15 +107,15 @@ EFVisitSubcircuits(subProc, cdata)
 
 int
 efVisitSubcircuits(hc, ca)
-    register HierContext *hc;
-    register CallArg *ca;
+    HierContext *hc;
+    CallArg *ca;
 {
     /* Look for children of this def which are defined	*/
     /* as subcircuits via the DEF_SUBCIRCUIT flag.	*/
 
     if (hc->hc_use->use_def->def_flags & DEF_SUBCIRCUIT)
     {
-	if ((*ca->ca_proc)(hc->hc_use, hc->hc_hierName, FALSE))
+	if ((*ca->ca_proc)(hc->hc_use, hc->hc_hierName, NULL))
 	    return 1;
 	else
 	    return 0;
@@ -167,9 +136,11 @@ efVisitSubcircuits(hc, ca)
  *
  *	Estimate length and width for a device from area and perimeter values.
  *
- * Results: None
+ * Results:
+ *	None
  *
- * Side Effects: values substituted for length and width
+ * Side Effects:
+ *	Values substituted for length and width.
  *
  * ----------------------------------------------------------------------------
  */
@@ -262,6 +233,7 @@ EFGetLengthAndWidth(dev, lptr, wptr)
  * ----------------------------------------------------------------------------
  */
 
+int
 EFVisitDevs(devProc, cdata)
     int (*devProc)();
     ClientData cdata;
@@ -286,11 +258,11 @@ EFVisitDevs(devProc, cdata)
 
 int
 efVisitDevs(hc, ca)
-    register HierContext *hc;
-    register CallArg *ca;
+    HierContext *hc;
+    CallArg *ca;
 {
     Def *def = hc->hc_use->use_def;
-    register Dev *dev;
+    Dev *dev;
     int scale;
     Transform t;
 
@@ -391,12 +363,12 @@ efDevKilled(dev, prefix)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 efDevFixLW(attrs, pL, pW)
     char *attrs;
     int *pL, *pW;
 {
-    register char *cp, *ep;
+    char *cp, *ep;
     char attrName, savec;
     int value;
 
@@ -476,6 +448,7 @@ skip:
  * ----------------------------------------------------------------------------
  */
 
+int
 EFVisitResists(resProc, cdata)
     int (*resProc)();
     ClientData cdata;
@@ -502,11 +475,11 @@ extern int efVisitSingleResist();
 
 int
 efVisitResists(hc, ca)
-    register HierContext *hc;
-    register CallArg *ca;
+    HierContext *hc;
+    CallArg *ca;
 {
     Def *def = hc->hc_use->use_def;
-    register Connection *res;
+    Connection *res;
     Transform t;
     int scale;
 
@@ -544,7 +517,8 @@ efVisitResists(hc, ca)
  * process the resistor if either terminal is a killed node.
  *
  * Results:
- *	Whatever the user-supplied procedure (*ca->ca_proc)() returns.
+ *	Whatever the user-supplied procedure (*ca->ca_proc)() returns
+ *	(type int).
  *
  * Side effects:
  *	Calls the user-supplied procedure.
@@ -552,11 +526,12 @@ efVisitResists(hc, ca)
  * ----------------------------------------------------------------------------
  */
 
+int
 efVisitSingleResist(hc, name1, name2, res, ca)
     HierContext *hc;		/* Contains hierarchical pathname to cell */
     char *name1, *name2;	/* Names of nodes connecting to resistor */
     Connection *res;		/* Contains resistance to add */
-    register CallArg *ca;
+    CallArg *ca;
 {
     EFNode *n1, *n2;
     HashEntry *he;
@@ -610,6 +585,7 @@ efVisitSingleResist(hc, name1, name2, res, ca)
  *
  * ----------------------------------------------------------------------------
  */
+
 int
 EFVisitCaps(capProc, cdata)
     int (*capProc)();
@@ -671,8 +647,8 @@ EFVisitNodes(nodeProc, cdata)
     int (*nodeProc)();
     ClientData cdata;
 {
-    register EFNode *node;
-    register EFNodeName *nn;
+    EFNode *node;
+    EFNodeName *nn;
     HierName *hierName;
     EFCapValue cap;
     int res;
@@ -758,9 +734,9 @@ EFVisitNodes(nodeProc, cdata)
 
 int
 EFNodeResist(node)
-    register EFNode *node;
+    EFNode *node;
 {
-    register int n, perim, area;
+    int n, perim, area;
     float s, fperim;
     double v, dresist;
     int resist;
@@ -851,13 +827,13 @@ EFLookDist(hn1, hn2, pMinDist, pMaxDist)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 EFHNOut(hierName, outf)
     HierName *hierName;
-    register FILE *outf;
+    FILE *outf;
 {
     bool trimGlob, trimLocal;
-    register char *cp, c;
+    char *cp, c;
 
     if (hierName->hn_parent) efHNOutPrefix(hierName->hn_parent, outf);
     if (EFTrimFlags)
@@ -879,12 +855,12 @@ EFHNOut(hierName, outf)
     else (void) fputs(hierName->hn_name, outf);
 }
 
-Void
+void
 efHNOutPrefix(hierName, outf)
-    register HierName *hierName;
-    register FILE *outf;
+    HierName *hierName;
+    FILE *outf;
 {
-    register char *cp, c;
+    char *cp, c;
 
     if (hierName->hn_parent)
 	efHNOutPrefix(hierName->hn_parent, outf);
