@@ -26,7 +26,9 @@ static char sccsid[] = "@(#)ExtBasic.c	4.13 MAGIC (Berkeley) 12/5/85";
 #include <string.h>
 #include <math.h>
 
-#include "tcltk/tclmagic.h"
+#ifdef MAGIC_WRAPPER
+#include "magic/tclmagic.h"
+#endif
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
@@ -52,7 +54,7 @@ static char sccsid[] = "@(#)ExtBasic.c	4.13 MAGIC (Berkeley) 12/5/85";
 /* ext2spice/ext2sim are compiled as separate programs (i.e., non-Tcl)	   */
 
 char *extDevTable[] = {"fet", "mosfet", "bjt", "devres", "devcap",
-			"diode", "subckt", NULL};
+	"diode", "subckt", NULL};
 
 /* --------------------- Data local to this file ---------------------- */
 
@@ -73,8 +75,6 @@ int extResistPerim[NT], extResistArea[NT];
      */
 #define	MAXSD	10	/* Maximum # of terminals per transistor */
 
-/* TEMPORARY */
-int TestNumTrans;
 
 typedef struct		/* Position of each terminal (below) tile position */
 {
@@ -82,7 +82,6 @@ typedef struct		/* Position of each terminal (below) tile position */
     Point	pt;
 } TermTilePos;
 
-
 struct transRec
 {
     int		 tr_nterm;		/* Number of terminals */
@@ -122,6 +121,11 @@ int extTransFindSubsFunc();
 int extAnnularTileFunc();
 int extAnnularPerimFunc();
 
+void extFindDuplicateLabels();
+void extOutputTrans();
+void extTransOutTerminal();
+void extTransBad();
+
 
 
 /*
@@ -278,10 +282,11 @@ extBasic(def, outFile)
  * ----------------------------------------------------------------------------
  */
 
+void
 extSetResist(reg)
-    register NodeRegion *reg;
+    NodeRegion *reg;
 {
-    register int n, perim, area;
+    int n, perim, area;
     float s, fperim, v;
 
     for (n = 0; n < ExtCurStyle->exts_numResistClasses; n++)
@@ -333,10 +338,10 @@ extOutputNodes(nodeList, outFile)
     ResValue rround = ExtCurStyle->exts_resistScale / 2;
     CapValue finC;
     int intR;
-    register NodeRegion *reg;
-    register LabelList *ll;
-    register char *cp;
-    register int n;
+    NodeRegion *reg;
+    LabelList *ll;
+    char *cp;
+    int n;
     Label *lab;
     char *text;
 
@@ -437,6 +442,7 @@ extOutputNodes(nodeList, outFile)
  * ----------------------------------------------------------------------------
  */
 
+void
 extFindDuplicateLabels(def, nreg)
     CellDef *def;
     NodeRegion *nreg;
@@ -445,9 +451,9 @@ extFindDuplicateLabels(def, nreg)
 	"Label \"%s\" attached to more than one unconnected node: %s";
     bool hashInitialized = FALSE;
     char message[512], name[512], *text;
-    register NodeRegion *np, *np2;
-    register LabelList *ll, *ll2;
-    register HashEntry *he;
+    NodeRegion *np, *np2;
+    LabelList *ll, *ll2;
+    HashEntry *he;
     NodeRegion *lastreg;
     NodeRegion badLabel;
     HashTable labelHash;
@@ -533,7 +539,7 @@ extNodeName(node)
     LabRegion *node;
 {
     static char namebuf[100];	/* Big enough to hold a generated nodename */
-    register LabelList *ll;
+    LabelList *ll;
 
     if (node == (LabRegion *) NULL || SigInterruptPending)
 	return ("(none)");
@@ -563,7 +569,9 @@ extNodeName(node)
  *
  * ---------------------------------------------------------------------
  */
-Void ExtSortTerminals(tran, ll)
+
+void
+ExtSortTerminals(tran, ll)
     struct transRec  *tran;
     LabelList *ll;
 {
@@ -852,14 +860,14 @@ extComputeEffectiveLW(rlengthptr, rwidthptr, numregions)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extOutputTrans(def, transList, outFile)
     CellDef *def;		/* Cell being extracted */
     TransRegion *transList;	/* Transistor regions built up in first pass */
     FILE *outFile;		/* Output file */
 {
     NodeRegion *node, *subsNode;
-    register TransRegion *reg;
+    TransRegion *reg;
     char *subsName;
     FindRegion arg;
     LabelList *ll;
@@ -867,7 +875,7 @@ extOutputTrans(def, transList, outFile)
     int nsd, length, width, n, i;
     double dres, dcap;
     char mesg[256];
-    bool isAnnular;
+    bool isAnnular, hasModel;
 
     for (reg = transList; reg && !SigInterruptPending; reg = reg->treg_next)
     {
@@ -889,20 +897,12 @@ extOutputTrans(def, transList, outFile)
 	arg.fra_connectsTo = ExtCurStyle->exts_transConn;
 	arg.fra_pNum = DBPlane(TiGetType(reg->treg_tile));
 
-	/* TEMPORARY */
-	TestNumTrans = 0;
-
 	    /* Mark with reg and process each perimeter segment */
 	arg.fra_uninit = (ClientData) extTransRec.tr_gatenode;
 	arg.fra_region = (Region *) reg;
 	arg.fra_each = extTransTileFunc;
 	(void) ExtFindNeighbors(reg->treg_tile, arg.fra_pNum, &arg);
 
-	/* TEMPORARY */
-	if (TestNumTrans > 1) {
-	    TxError("Transistor has %d tiles\n", TestNumTrans);
-	}
-
 	    /* Re-mark with extTransRec.tr_gatenode */
 	arg.fra_uninit = (ClientData) reg;
 	arg.fra_region = (Region *) extTransRec.tr_gatenode;
@@ -1012,13 +1012,7 @@ extOutputTrans(def, transList, outFile)
 		    width += extTransRec.tr_termlen[n];
 		    if (extTransRec.tr_termvector[n].p_x == 0 &&
 				extTransRec.tr_termvector[n].p_y == 0)
-		    {
 			isAnnular = TRUE;
-			/* TEMPORARY */
-			if (TestNumTrans > 1) {
-			    TxError("Tile test agrees w/annular test\n");
-			}
-		    }
 		}
 		if (n) width /= n;
 
@@ -1077,6 +1071,7 @@ extOutputTrans(def, transList, outFile)
 		break;
 
 	    case DEV_RES:
+		hasModel = strcmp(ExtCurStyle->exts_transName[t], "None");
 		length = extTransRec.tr_perim;
 		width = 0;
 		for (n = 0; extTransRec.tr_termlen[n] != 0; n++)
@@ -1086,29 +1081,57 @@ extOutputTrans(def, transList, outFile)
 		}
 		if (width)
 		{
-		    dres = ExtCurStyle->exts_sheetResist[t] * (double)length /
+		    if (!hasModel)
+			dres = ExtCurStyle->exts_sheetResist[t] * (double)length /
 				(double)width;
 		    if (ExtDoWarn && (n > 2))
 		    {
-			sprintf(mesg, "Resistor has %d terminals: "
-				"extracted L/W will be wrong", n);
+			if (hasModel)
+			    sprintf(mesg, "Resistor has %d terminals: "
+					"extracted L/W will be wrong", n);
+			else
+			    sprintf(mesg, "Resistor has %d terminals: "
+					"extracted value will be wrong", n);
 			extTransBad(def, reg->treg_tile, mesg);
 		    }
 		}
 		else {
 		    dres = 0.0;
 		    if (ExtDoWarn)
-			extTransBad(def, reg->treg_tile, "Resistor has zero width");
+			extTransBad(def, reg->treg_tile,
+					"Resistor has zero width");
 		}
 
-		(void) fprintf(outFile, " %g", dres / 1000.0); /* mOhms -> Ohms */
+		if (hasModel)	/* semiconductor resistor */
+		    (void) fprintf(outFile, " %d %d", length, width);
+		else		/* regular resistor */
+		    (void) fprintf(outFile, " %g", dres / 1000.0); /* mOhms -> Ohms */
+
 		break;
 
 	    case DEV_CAP:
-		dcap = (ExtCurStyle->exts_transGateCap[t] * reg->treg_area) +
+		hasModel = strcmp(ExtCurStyle->exts_transName[t], "None");
+		if (hasModel)
+		{
+		    width = 0;
+		    for (n = 0; extTransRec.tr_termlen[n] != 0; n++)
+			width += extTransRec.tr_termlen[n];
+
+		    if (!width && ExtDoWarn)
+			extTransBad(def, reg->treg_tile,
+					"Capacitor has zero width");
+		    else width <<= 2;	/* total perimeter / 4 */
+
+		    (void) fprintf(outFile, " %d %d", reg->treg_area / width,
+				width);
+		}
+		else
+		{
+		    dcap = (ExtCurStyle->exts_transGateCap[t] * reg->treg_area) +
 			(ExtCurStyle->exts_transSDCap[t] * extTransRec.tr_perim);
 
-		(void) fprintf(outFile, " %g", dcap / 1000.0);  /* aF -> fF */
+		    (void) fprintf(outFile, " %g", dcap / 1000.0);  /* aF -> fF */
+		}
 		break;
 	}
 
@@ -1137,7 +1160,7 @@ extOutputTrans(def, transList, outFile)
 NodeRegion *
 extTransFindSubsNode(def, treg)
     CellDef *def;
-    register TransRegion *treg;
+    TransRegion *treg;
 {
     TileType t = TiGetType(treg->treg_tile);
     TileTypeBitMask *mask;
@@ -1162,7 +1185,7 @@ extTransFindSubsNode(def, treg)
 
 int
 extTransFindSubsFunc(tile, pnreg)
-    register Tile *tile;
+    Tile *tile;
     NodeRegion **pnreg;
 {
     if (tile->ti_client != (ClientData) extUnInit)
@@ -1199,8 +1222,8 @@ extTransTileFunc(tile)
     TileTypeBitMask mask;
     TileType loctype;
 
-    register LabelList *ll;
-    register Label *lab;
+    LabelList *ll;
+    Label *lab;
     Rect r;
 
     for (ll = extTransRec.tr_gatenode->nreg_labels; ll; ll = ll->ll_next)
@@ -1215,10 +1238,6 @@ extTransTileFunc(tile)
 	     ll->ll_attr = LL_GATEATTR;
 	}
     }
-
-    /* TEMPORARY */
-    TestNumTrans++;
-
     /*
      * Visit each segment of the perimeter of this tile that
      * that borders on something of a different type.
@@ -1240,15 +1259,15 @@ extTransTileFunc(tile)
 
 int
 extTransPerimFunc(bp)
-    register Boundary *bp;
+    Boundary *bp;
 {
     TileType tinside = TiGetType(bp->b_inside);
     TileType toutside = TiGetType(bp->b_outside);
     NodeRegion *diffNode = (NodeRegion *) extGetRegion(bp->b_outside);
     int len = BoundaryLength(bp);
-    register int thisterm;
-    register LabelList *ll;
-    register Label *lab;
+    int thisterm;
+    LabelList *ll;
+    Label *lab;
     Rect r;
 
     if (TTMaskHasType(&ExtCurStyle->exts_transSDTypes[tinside], toutside))
@@ -1541,17 +1560,18 @@ extAnnularPerimFunc(bp)
  * ----------------------------------------------------------------------------
  */
 
+void
 extTransOutTerminal(lreg, ll, whichTerm, len, outFile)
     LabRegion *lreg;		/* Node connected to terminal */
-    register LabelList *ll;	/* Gate's label list */
+    LabelList *ll;	/* Gate's label list */
     int whichTerm;		/* Which terminal we are processing.  The gate
 				 * is indicated by LL_GATEATTR.
 				 */
     int len;			/* Length of perimeter along terminal */
     FILE *outFile;		/* Output file */
 {
-    register char *cp;
-    register int n;
+    char *cp;
+    int n;
     char fmt;
 
 
@@ -1590,6 +1610,7 @@ extTransOutTerminal(lreg, ll, whichTerm, len, outFile)
  * ----------------------------------------------------------------------------
  */
 
+void
 extTransBad(def, tp, mesg)
     CellDef *def;
     Tile *tp;
@@ -1625,7 +1646,7 @@ extTransBad(def, tp, mesg)
 
 bool
 extLabType(text, typeMask)
-    register char *text;
+    char *text;
     int typeMask;
 {
     if (*text == '\0')
@@ -1674,7 +1695,7 @@ extTransFirst(tile, arg)
     Tile *tile;
     FindRegion *arg;
 {
-    register TransRegion *reg;
+    TransRegion *reg;
 
     MALLOC(TransRegion *, reg, sizeof (TransRegion));
     reg->treg_next = (TransRegion *) NULL;
@@ -1696,7 +1717,7 @@ extTransEach(tile, pNum, arg)
     int pNum;
     FindRegion *arg;
 {
-    register TransRegion *reg;
+    TransRegion *reg;
 
     reg = (TransRegion *) arg->fra_region;
     reg->treg_area += TILEAREA(tile);
@@ -1752,9 +1773,12 @@ extFindNodes(def, clipArea)
 
     SigDisableInterrupts();
     for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
+    {
+	arg.fra_pNum = pNum;
 	(void) DBSrPaintClient((Tile *) NULL, def->cd_planes[pNum],
 		    &TiPlaneRect, &DBAllButSpaceBits, extUnInit,
 		    extNodeAreaFunc, (ClientData) &arg);
+    }
     SigEnableInterrupts();
 
     /* Compute resistance for last node */
@@ -1764,18 +1788,20 @@ extFindNodes(def, clipArea)
     return ((NodeRegion *) arg.fra_region);
 }
 
+int
 extNodeAreaFunc(tile, arg)
-    register Tile *tile;
+    Tile *tile;
     FindRegion *arg;
 {
     int tilePlaneNum, pNum, pMask, len, area, resistClass, n, nclasses;
     CapValue capval;
-    register TileTypeBitMask *mask, *resMask;
-    register NodeRegion *reg;
-    register Tile *tp;
-    TileType type, t;
+    TileTypeBitMask *mask, *resMask;
+    NodeRegion *reg;
+    Tile *tp;
+    TileType type, t, residue, tres;
     NodeRegion *old;
     Rect r;
+    PlaneAndArea pla;
 
     /* Compute the resistance for the previous region */
     if (old = (NodeRegion *) arg->fra_region)
@@ -1799,12 +1825,12 @@ extNodeAreaFunc(tile, arg)
     arg->fra_region = (Region *) reg;
 
     /* Mark this tile as pending and push it */
-    PUSHTILE(tile);
+    PUSHTILE(tile, arg->fra_pNum);
 
     /* Continue processing tiles until there are none left */
     while (!StackEmpty(extNodeStack))
     {
-	tile = (Tile *) STACKPOP(extNodeStack);
+	POPTILE(tile, tilePlaneNum);
 
 	/*
 	 * Since tile was pushed on the stack, we know that it
@@ -1828,10 +1854,15 @@ extNodeAreaFunc(tile, arg)
 #endif              
         type = TiGetTypeExact(tile);
 
+	/* Contacts are replaced by their residues when calculating */
+	/* perimeter capacitance.				    */
+
+	residue = (DBIsContact(type)) ?
+		DBPlaneToResidue(type, tilePlaneNum) : type;
+
 	mask = &ExtCurStyle->exts_nodeConn[type];
 	resMask = &ExtCurStyle->exts_typesResistChanged[type];
 	resistClass = ExtCurStyle->exts_typeToResistClass[type];
-	tilePlaneNum = DBPlane(type);
 
 	/*
 	 * Make sure the lower-leftmost point in the node is
@@ -1888,9 +1919,12 @@ topside:
             else
 #endif
 	    t = TiGetTypeExact(tp);
+	    tres = (DBIsContact(t)) ? DBPlaneToResidue(t, arg->fra_pNum) : t;
 	    if (TTMaskHasType(mask, t) && tp->ti_client == extUnInit)
-		PUSHTILE(tp);
-	    if ((capval = ExtCurStyle->exts_perimCap[type][t]) != (CapValue) 0)
+	    {
+		PUSHTILE(tp, tilePlaneNum);
+	    }
+	    if ((capval = ExtCurStyle->exts_perimCap[residue][tres]) != (CapValue) 0)
 		reg->nreg_cap += capval * len;
 	    if (TTMaskHasType(resMask, t) && resistClass != -1)
 		extResistPerim[resistClass] += len;
@@ -1920,9 +1954,12 @@ leftside:
             else
 #endif
 	    t = TiGetTypeExact(tp);
+	    tres = (DBIsContact(t)) ? DBPlaneToResidue(t, arg->fra_pNum) : t;
 	    if (TTMaskHasType(mask, t) && tp->ti_client == extUnInit)
-		PUSHTILE(tp);
-	    if ((capval = ExtCurStyle->exts_perimCap[type][t]) != (CapValue) 0)
+	    {
+		PUSHTILE(tp, tilePlaneNum);
+	    }
+	    if ((capval = ExtCurStyle->exts_perimCap[residue][tres]) != (CapValue) 0)
 		reg->nreg_cap += capval * len;
 	    if (TTMaskHasType(resMask, t) && resistClass != -1)
 		extResistPerim[resistClass] += len;
@@ -1953,9 +1990,12 @@ bottomside:
             else
 #endif
 	    t = TiGetTypeExact(tp);
+	    tres = (DBIsContact(t)) ? DBPlaneToResidue(t, arg->fra_pNum) : t;
 	    if (TTMaskHasType(mask, t) && tp->ti_client == extUnInit)
-		PUSHTILE(tp);
-	    if ((capval = ExtCurStyle->exts_perimCap[type][t]) != (CapValue) 0)
+	    {
+		PUSHTILE(tp, tilePlaneNum);
+	    }
+	    if ((capval = ExtCurStyle->exts_perimCap[residue][tres]) != (CapValue) 0)
 		reg->nreg_cap += capval * len;
 	    if (TTMaskHasType(resMask, t) && resistClass != -1)
 		extResistPerim[resistClass] += len;
@@ -1985,9 +2025,12 @@ rightside:
             else
 #endif
 	    t = TiGetTypeExact(tp);
+	    tres = (DBIsContact(t)) ? DBPlaneToResidue(t, arg->fra_pNum) : t;
 	    if (TTMaskHasType(mask, t) && tp->ti_client == extUnInit)
-		PUSHTILE(tp);
-	    if ((capval = ExtCurStyle->exts_perimCap[type][t]) != (CapValue) 0)
+	    {
+		PUSHTILE(tp, tilePlaneNum);
+	    }
+	    if ((capval = ExtCurStyle->exts_perimCap[residue][tres]) != (CapValue) 0)
 		reg->nreg_cap += capval * len;
 	    if (TTMaskHasType(resMask, t) && resistClass != -1)
 		extResistPerim[resistClass] += len;
@@ -1999,10 +2042,10 @@ donesides:
 	    reg->nreg_cap = (CapValue) 0;
 
 	/* If this is a contact, visit all the other planes */
-	if (TTMaskHasType(&DBImageBits, type))
+	if (DBIsContact(type))
 	{
 	    pMask = DBConnPlanes[type];
-	    for (pNum = tilePlaneNum - 1; pNum <= tilePlaneNum + 1; pNum += 2)
+	    for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
 		if (PlaneMaskHasPlane(pMask, pNum))
 		{
 		    Plane *plane = arg->fra_def->cd_planes[pNum];
@@ -2023,7 +2066,7 @@ donesides:
 		    t = TiGetTypeExact(tp);
 
 		    if (tp->ti_client == extUnInit && TTMaskHasType(mask, t))
-			PUSHTILE(tp);
+			PUSHTILE(tp, pNum);
 		}
 	}
 
@@ -2038,16 +2081,19 @@ donesides:
 	 */
 	if (pMask = DBAllConnPlanes[type])
 	{
-	    Rect tileArea, biggerArea;
+	    Rect biggerArea;
 
 	    extNbrUn = extUnInit;
-	    TITORECT(tile, &tileArea);
-	    GEO_EXPAND(&tileArea, 1, &biggerArea);
+	    TITORECT(tile, &pla.area);
+	    GEO_EXPAND(&pla.area, 1, &biggerArea);
 	    for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
 		if (pNum != tilePlaneNum && PlaneMaskHasPlane(pMask, pNum))
+		{
+		    pla.plane = pNum;
 		    (void) DBSrPaintArea((Tile *) NULL,
 			    arg->fra_def->cd_planes[pNum], &biggerArea,
-			    mask, extNbrPushFunc, (ClientData) &tileArea);
+			    mask, extNbrPushFunc, (ClientData) &pla);
+		}
 	}
     }
 
