@@ -51,6 +51,35 @@ int extBasicOverlap(), extBasicCouple();
 int extAddOverlap(), extAddCouple();
 int extSideLeft(), extSideRight(), extSideBottom(), extSideTop();
 int extSideOverlap();
+void extSideCommon();
+
+/* Structure to pass on to the coupling and sidewall capacitance	*/
+/* routines to include the current cell definition and the current	*/
+/* plane being searched.						*/
+
+typedef struct _ecs {
+    CellDef *def;
+    int	     plane;
+} extCapStruct;
+
+/* Structure to pass on two planes to check for coupling and the tile	*/
+/* which is doing the coupling.						*/
+
+typedef struct _ecpls {
+    Tile *tile;
+    int  plane_of_tile;
+    int  plane_checked;
+} extCoupleStruct;
+
+/* Structure to pass on two planes to check for coupling and the	*/
+/* boundary which initiated the check.					*/
+
+typedef struct _esws {
+    Boundary *bp;
+    int  plane_of_boundary;
+    int  plane_checked;
+} extSidewallStruct;
+
 
 /* --------------------- Debugging stuff ---------------------- */
 #define CAP_DEBUG	FALSE
@@ -131,6 +160,7 @@ void extAdjustCouple(he, c, str)
  * ----------------------------------------------------------------------------
  */
 
+void
 extFindCoupling(def, table, clipArea)
     CellDef *def;
     HashTable *table;
@@ -138,20 +168,25 @@ extFindCoupling(def, table, clipArea)
 {
     Rect *searchArea;
     int pNum;
+    extCapStruct ecs;
+
+    ecs.def = def;
 
     extCoupleHashPtr = table;
     extCoupleSearchArea = clipArea;
     searchArea = clipArea ? clipArea : &TiPlaneRect;
     for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
     {
+	ecs.plane = pNum;
+
 	if (PlaneMaskHasPlane(ExtCurStyle->exts_overlapPlanes, pNum))
 	    (void) DBSrPaintArea((Tile *) NULL, def->cd_planes[pNum],
 			searchArea, &ExtCurStyle->exts_overlapTypes[pNum],
-			extBasicOverlap, (ClientData) def);
+			extBasicOverlap, (ClientData) &ecs);
 	if (PlaneMaskHasPlane(ExtCurStyle->exts_sidePlanes, pNum))
 	    (void) DBSrPaintArea((Tile *) NULL, def->cd_planes[pNum],
 			searchArea, &ExtCurStyle->exts_sideTypes[pNum],
-			extBasicCouple, (ClientData) def);
+			extBasicCouple, (ClientData) &ecs);
     }
 
 }
@@ -177,12 +212,13 @@ extFindCoupling(def, table, clipArea)
  * ----------------------------------------------------------------------------
  */
 
+void
 extOutputCoupling(table, outFile)
     HashTable *table;	/* Coupling capacitance hash table */
     FILE *outFile;	/* Output file */
 {
-    register HashEntry *he;
-    register CoupleKey *ck;
+    HashEntry *he;
+    CoupleKey *ck;
     HashSearch hs;
     char *text;
     CapValue cap;  /* value of capacitance. */
@@ -223,19 +259,28 @@ extOutputCoupling(table, outFile)
  * ----------------------------------------------------------------------------
  */
 
-extBasicOverlap(tile, def)
+int
+extBasicOverlap(tile, ecs)
     Tile *tile;
-    CellDef *def;
+    extCapStruct *ecs;
 {
-    int thisType = TiGetType(tile), thisPlane = DBPlane(thisType);
+    int thisType = TiGetType(tile);
     int pNum, pMask = ExtCurStyle->exts_overlapOtherPlanes[thisType];
     TileTypeBitMask *tMask = &ExtCurStyle->exts_overlapOtherTypes[thisType];
     Rect r;
+    CellDef *def = ecs->def;
+    int thisPlane = ecs->plane;
+    extCoupleStruct ecpls;
 
     TITORECT(tile, &r);
     extOverlapDef = def;
     if (extCoupleSearchArea)
+    {
 	GEOCLIP(&r, extCoupleSearchArea);
+    }
+
+    ecpls.tile = tile;
+    ecpls.plane_of_tile = thisPlane;
 
     for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
     {
@@ -243,8 +288,9 @@ extBasicOverlap(tile, def)
 	if (pNum == thisPlane || !PlaneMaskHasPlane(pMask, pNum))
 	    continue;
 
+	ecpls.plane_checked = pNum;
 	(void) DBSrPaintArea((Tile *) NULL, def->cd_planes[pNum], &r, tMask,
-		extAddOverlap, (ClientData) tile);
+		extAddOverlap, (ClientData) &ecpls);
     }
 
     return (0);
@@ -287,26 +333,26 @@ struct overlap
     TileTypeBitMask	 o_tmask;
 };
 
-extAddOverlap(tbelow, tabove)
-    register Tile *tbelow, *tabove;
+int
+extAddOverlap(tbelow, ecpls)
+    Tile *tbelow;
+    extCoupleStruct *ecpls;
 {
     int extSubtractOverlap(), extSubtractOverlap2();
-    register NodeRegion *rabove, *rbelow;
-    register HashEntry *he;
+    NodeRegion *rabove, *rbelow;
+    HashEntry *he;
     struct overlap ov;
     TileType ta, tb;
     CoupleKey ck;
-    int pNum, oa, ob;
+    int pNum;
     CapValue c;
+    Tile *tabove = ecpls->tile;
 
-    /* Check if both tiles are connected.  If they are, we don't need   */
-    /* to check for shielding material, and we don't want to add any    */
-    /* coupling capacitance between them.  However, we *do* want to     */
-    /* subtract off any substrate (area) capacitance previously added   */
-    /* (Correction made 4/29/04 by Tim from a tip by Jeff Sondeen).     */
-
+    /* Do nothing if both tiles are connected */
     rabove = (NodeRegion *) extGetRegion(tabove);
     rbelow = (NodeRegion *) extGetRegion(tbelow);
+    if (rabove == rbelow)
+	return (0);
 
     /* Compute the area of overlap */
     ov.o_clip.r_xbot = MAX(LEFT(tbelow), LEFT(tabove));
@@ -314,18 +360,27 @@ extAddOverlap(tbelow, tabove)
     ov.o_clip.r_ybot = MAX(BOTTOM(tbelow), BOTTOM(tabove));
     ov.o_clip.r_ytop = MIN(TOP(tbelow), TOP(tabove));
     if (extCoupleSearchArea)
+    {
 	GEOCLIP(&ov.o_clip, extCoupleSearchArea);
+    }
     ov.o_area = (ov.o_clip.r_ytop - ov.o_clip.r_ybot)
 	      * (ov.o_clip.r_xtop - ov.o_clip.r_xbot);
     ta = TiGetType(tabove);
     tb = TiGetType(tbelow);
 
+    /* Revert any contacts to their residues */
+
+    if (DBIsContact(ta))
+	ta = DBPlaneToResidue(ta, ecpls->plane_of_tile);
+
+    if (DBIsContact(tb))
+	tb = DBPlaneToResidue(ta, ecpls->plane_checked);
+
     /*
      * Find whether rabove and rbelow are shielded by intervening material.
      * Deduct the area shielded from the area of the overlap, so we adjust
      * the overlap capacitance correspondingly.
      */
-
     if (ov.o_pmask = ExtCurStyle->exts_overlapShieldPlanes[ta][tb])
     {
 	ov.o_tmask = ExtCurStyle->exts_overlapShieldTypes[ta][tb];
@@ -352,8 +407,10 @@ extAddOverlap(tbelow, tabove)
     /* If any capacitance remains, add this record to the table */
     if (ov.o_area > 0)
     {
-	oa = ExtCurStyle->exts_planeOrder[DBTypePlaneTbl[ta]];
-	ob = ExtCurStyle->exts_planeOrder[DBTypePlaneTbl[tb]];
+	int oa = 
+	    ExtCurStyle->exts_planeOrder[DBPlane(TiGetType(tabove))];
+	int ob = 
+	    ExtCurStyle->exts_planeOrder[DBPlane(TiGetType(tbelow))];
 	if (oa > ob)
 	{
 	    /*
@@ -373,9 +430,6 @@ extAddOverlap(tbelow, tabove)
 	    extNregAdjustCap(rabove, 0.0, 
 		"obsolete_overlap (skipped, wrong direction)");
 	    
-	/* If the regions are the same, skip this part */
-	if (rabove == rbelow) return (0);
-	
 	/* Find the coupling hash record */
 	if (rabove < rbelow) ck.ck_1 = rabove, ck.ck_2 = rbelow;
 	else ck.ck_1 = rbelow, ck.ck_2 = rabove;
@@ -389,13 +443,14 @@ extAddOverlap(tbelow, tabove)
 		ov.o_area, "overlap");
 	extSetCapValue(he, c);
     }
+
     return (0);
 }
 
 int
 extSubtractOverlap(tile, ov)
-    register Tile *tile;
-    register struct overlap *ov;
+    Tile *tile;
+    struct overlap *ov;
 {
     Rect r;
     int area;
@@ -411,8 +466,8 @@ extSubtractOverlap(tile, ov)
 
 int
 extSubtractOverlap2(tile, ov)
-    register Tile *tile;
-    register struct overlap *ov;
+    Tile *tile;
+    struct overlap *ov;
 {
     struct overlap ovnew;
     int area, pNum;
@@ -481,12 +536,12 @@ extSubtractOverlap2(tile, ov)
  * ----------------------------------------------------------------------------
  */
 
-extBasicCouple(tile, def)
+extBasicCouple(tile, ecs)
     Tile *tile;
-    CellDef *def;
+    extCapStruct *ecs;
 {
     (void) extEnumTilePerim(tile, ExtCurStyle->exts_sideEdges[TiGetType(tile)],
-			extAddCouple, (ClientData) def);
+			extAddCouple, (ClientData) ecs);
     return (0);
 }
 
@@ -522,14 +577,23 @@ extBasicCouple(tile, def)
 
 Rect extSideOverlapSearchArea;
 
-extAddCouple(bp, def)
+int
+extAddCouple(bp, ecs)
     Boundary *bp;	/* Boundary being considered */
-    CellDef *def;	/* Def containing this boundary */
+    extCapStruct *ecs;
 {
     TileType tin = TiGetType(bp->b_inside), tout = TiGetType(bp->b_outside);
     int pNum, pMask, (*proc)();
     Boundary bpCopy;
     Rect r, ovr;
+    CellDef *def = ecs->def;
+    extSidewallStruct esws;
+
+    /* Revert any contacts to their residues */
+    if (DBIsContact(tin))
+	tin = DBPlaneToResidue(tin, ecs->plane);
+    if (DBIsContact(tout))
+	tin = DBPlaneToResidue(tout, ecs->plane);
 
     extCoupleList = ExtCurStyle->exts_sideCoupleCap[tin][tout];
     extOverlapList = ExtCurStyle->exts_sideOverlapCap[tin][tout];
@@ -584,13 +648,17 @@ extAddCouple(bp, def)
 	pMask = ExtCurStyle->exts_sideOverlapOtherPlanes[tin][tout];
 	extSideOverlapSearchArea = ovr;
 	extOverlapDef = def;
+
+	esws.bp = bp;
+	esws.plane_of_boundary = ecs->plane;
+
 	for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
 	    if (PlaneMaskHasPlane(pMask, pNum))
 	    {
-		bp->b_plane = pNum;
+		esws.plane_checked = pNum;
 		(void) DBSrPaintArea((Tile *) NULL, def->cd_planes[pNum],
 			&ovr, &ExtCurStyle->exts_sideOverlapOtherTypes[tin][tout],
-			extSideOverlap, (ClientData) bp);
+			extSideOverlap, (ClientData) &esws);
 	    }
     }
 
@@ -616,21 +684,26 @@ extAddCouple(bp, def)
  * ----------------------------------------------------------------------------
  */
 
-extSideOverlap(tp, bp)
-    register Tile *tp;		/* Overlapped tile */
-    register Boundary *bp;	/* Overlapping edge */
+int
+extSideOverlap(tp, esws)
+    Tile *tp;			/* Overlapped tile */
+    extSidewallStruct *esws;	/* Overlapping edge and plane information */
 {
+    Boundary *bp = esws->bp;	/* Overlapping edge */
     NodeRegion *rtp = (NodeRegion *) extGetRegion(tp);
     NodeRegion *rbp = (NodeRegion *) extGetRegion(bp->b_inside);
     TileType ta, tb;
     Rect tpr;
     struct overlap ov;
-    register HashEntry *he;
-    register EdgeCap *e;
+    HashEntry *he;
+    EdgeCap *e;
     int length, areaAccountedFor;
     CapValue cap;
     CoupleKey ck;
 
+    if (rtp == rbp)
+	return (0);
+
     if (bp->b_segment.r_xtop == bp->b_segment.r_xbot)
     {
 	length = MIN(bp->b_segment.r_ytop, TOP(tp))
@@ -651,9 +724,11 @@ extSideOverlap(tp, bp)
     ta = TiGetType(bp->b_inside);
     tb = TiGetType(tp);
 
-    /* Avoid doing the code below if we're just going to return without */
-    /* changing anything.                                               */
-    if ((tb == TT_SPACE) && (rtp == rbp)) return (0);
+    /* Revert any contacts to their residues */
+    if (DBIsContact(ta))
+	ta = DBPlaneToResidue(ta, esws->plane_of_boundary);
+    if (DBIsContact(tb))
+	tb = DBPlaneToResidue(tb, esws->plane_checked);
 
     /* Apply each rule, incorporating shielding into the edge length. */
     cap = (CapValue) 0;
@@ -698,14 +773,13 @@ extSideOverlap(tp, bp)
 		    break;
 		}
 	    }
-	    if (rtp != rbp)
-		cap += e->ec_cap * ov.o_area;
+	    cap += e->ec_cap * ov.o_area;
 	    areaAccountedFor += ov.o_area;
 	}
     }
     
     /* Add in the new capacitance. */
-    if (tb == TT_SPACE)
+    if (TiGetType(tp) == TT_SPACE)
     {
 	/* Is tp a space tile?  If so, extGetRegion points to garbage;  	
 	 * make terminal 2 point to ground.
@@ -715,8 +789,16 @@ extSideOverlap(tp, bp)
     }
     else
     {
-	int oa = ExtCurStyle->exts_planeOrder[DBTypePlaneTbl[ta]];
-	int ob = ExtCurStyle->exts_planeOrder[DBTypePlaneTbl[tb]];
+	int oa;
+	int ob;
+	if (rtp < rbp) ck.ck_1 = rtp, ck.ck_2 = rbp;
+	    else ck.ck_1 = rbp, ck.ck_2 = rtp;
+	he = HashFind(extCoupleHashPtr, (char *) &ck);
+	if (CAP_DEBUG) extAdjustCouple(he, cap, "sideoverlap");
+	extSetCapValue(he, cap + extGetCapValue(he));
+
+	oa = ExtCurStyle->exts_planeOrder[DBPlane(TiGetType(bp->b_inside))];
+	ob = ExtCurStyle->exts_planeOrder[DBPlane(TiGetType(tp))];
 	if (oa > ob)
 	{
 	    /* If the overlapped tile is between the substrate and the boundary
@@ -724,26 +806,26 @@ extSideOverlap(tp, bp)
 	     * from rbp's region due to the area of the sideoverlap, since 
 	     * we now know it is shielded from the substrate.
 	     */
+	    CapValue subcap;
+	    TileType intype = TiGetType(bp->b_inside);
 	    TileType outtype = TiGetType(bp->b_outside);
-	    CapValue subcap = (ExtCurStyle->exts_perimCap[ta][outtype] *
-		MIN(areaAccountedFor, length));
+
+	    /* Decompose contacts into their residues */
+	    if (DBIsContact(intype))
+		intype = DBPlaneToResidue(intype, esws->plane_of_boundary);
+	    if (DBIsContact(outtype))
+		outtype = DBPlaneToResidue(outtype, esws->plane_of_boundary);
+
+	    subcap = (ExtCurStyle->exts_perimCap[intype][outtype] *
+			MIN(areaAccountedFor, length));
 	    rbp->nreg_cap -= subcap;
 	    if (CAP_DEBUG)
 		extNregAdjustCap(rbp, -subcap, "obsolete_perimcap");
 	} else if (CAP_DEBUG)
 	    extNregAdjustCap(rbp, 0.0, 
 		"obsolete_perimcap (skipped, wrong direction)");
-
-	/* If the nodes are electrically connected, then we don't add	*/
-        /* any side overlap capacitance to the node.			*/
-	if (rtp == rbp) return (0);
-
-	if (rtp < rbp) ck.ck_1 = rtp, ck.ck_2 = rbp;
-	    else ck.ck_1 = rbp, ck.ck_2 = rtp;
-	he = HashFind(extCoupleHashPtr, (char *) &ck);
-	if (CAP_DEBUG) extAdjustCouple(he, cap, "sideoverlap");
-	extSetCapValue(he, cap + extGetCapValue(he));
     }
+
     return (0);
 }
 
@@ -774,13 +856,14 @@ extSideOverlap(tp, bp)
  * ----------------------------------------------------------------------------
  */
 
+int
 extSideLeft(tpfar, bp)
-    register Tile *tpfar;
-    register Boundary *bp;
+    Tile *tpfar;
+    Boundary *bp;
 {
     NodeRegion *rinside = (NodeRegion *) extGetRegion(bp->b_inside);
     NodeRegion *rfar = (NodeRegion *) extGetRegion(tpfar);
-    register Tile *tpnear;
+    Tile *tpnear;
 
     if (rfar != (NodeRegion *) extUnInit && rfar != rinside)
     {
@@ -822,13 +905,14 @@ extSideLeft(tpfar, bp)
  * ----------------------------------------------------------------------------
  */
 
+int
 extSideRight(tpfar, bp)
-    register Tile *tpfar;
-    register Boundary *bp;
+    Tile *tpfar;
+    Boundary *bp;
 {
     NodeRegion *rinside = (NodeRegion *) extGetRegion(bp->b_inside);
     NodeRegion *rfar = (NodeRegion *) extGetRegion(tpfar);
-    register Tile *tpnear;
+    Tile *tpnear;
 
     if (rfar != (NodeRegion *) extUnInit && rfar != rinside)
     {
@@ -870,13 +954,14 @@ extSideRight(tpfar, bp)
  * ----------------------------------------------------------------------------
  */
 
+int
 extSideTop(tpfar, bp)
-    register Tile *tpfar;
-    register Boundary *bp;
+    Tile *tpfar;
+    Boundary *bp;
 {
     NodeRegion *rinside = (NodeRegion *) extGetRegion(bp->b_inside);
     NodeRegion *rfar = (NodeRegion *) extGetRegion(tpfar);
-    register Tile *tpnear;
+    Tile *tpnear;
 
     if (rfar != (NodeRegion *) extUnInit && rfar != rinside)
     {
@@ -918,13 +1003,14 @@ extSideTop(tpfar, bp)
  * ----------------------------------------------------------------------------
  */
 
+int
 extSideBottom(tpfar, bp)
-    register Tile *tpfar;
-    register Boundary *bp;
+    Tile *tpfar;
+    Boundary *bp;
 {
     NodeRegion *rinside = (NodeRegion *) extGetRegion(bp->b_inside);
     NodeRegion *rfar = (NodeRegion *) extGetRegion(tpfar);
-    register Tile *tpnear;
+    Tile *tpnear;
 
     if (rfar != (NodeRegion *) extUnInit && rfar != rinside)
     {
@@ -967,6 +1053,7 @@ extSideBottom(tpfar, bp)
  * ----------------------------------------------------------------------------
  */
 
+void
 extSideCommon(rinside, rfar, tpnear, tpfar, overlap, sep)
     NodeRegion *rinside, *rfar;	/* Both must be valid */
     Tile *tpnear, *tpfar;	/* Tiles on near and far side of edge */
@@ -975,8 +1062,8 @@ extSideCommon(rinside, rfar, tpnear, tpfar, overlap, sep)
 				 */
 {
     TileType near = TiGetType(tpnear), far = TiGetType(tpfar);
-    register HashEntry *he;
-    register EdgeCap *e;
+    HashEntry *he;
+    EdgeCap *e;
     CoupleKey ck;
     CapValue cap;
 
