@@ -80,7 +80,7 @@ Node *extHierNewNode();
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extHierConnections(ha, cumFlat, oneFlat)
     HierExtractArg *ha;
     ExtTree *cumFlat, *oneFlat;
@@ -110,6 +110,7 @@ extHierConnections(ha, cumFlat, oneFlat)
  *	None here, but see extHierConnectFunc2().
  */
 
+int
 extHierConnectFunc1(oneTile, ha)
     Tile *oneTile;	/* Comes from 'oneFlat' in extHierConnections */
     HierExtractArg *ha;	/* Extraction context */
@@ -159,14 +160,15 @@ extHierConnectFunc1(oneTile, ha)
  *	to merely abut), mark it with feedback as an error.
  */
 
+int
 extHierConnectFunc2(cum, ha)
     Tile *cum;		/* Comes from extHierCumFlat->et_use->cu_def */
     HierExtractArg *ha;	/* Extraction context */
 {
     HashTable *table = &ha->ha_connHash;
-    register Node *node1, *node2;
-    register HashEntry *he;
-    register NodeName *nn;
+    Node *node1, *node2;
+    HashEntry *he;
+    NodeName *nn;
     char *name;
     Rect r;
 
@@ -264,13 +266,13 @@ extHierConnectFunc2(cum, ha)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extHierAdjustments(ha, cumFlat, oneFlat, lookFlat)
-    register HierExtractArg *ha;
+    HierExtractArg *ha;
     ExtTree *cumFlat, *oneFlat, *lookFlat;
 {
-    register HashEntry *he, *heCum;
-    register int n;
+    HashEntry *he, *heCum;
+    int n;
     CoupleKey *ckpOne, ckCum;
     NodeRegion *np;
     HashSearch hs;
@@ -349,14 +351,15 @@ extHierAdjustments(ha, cumFlat, oneFlat, lookFlat)
  * ----------------------------------------------------------------------------
  */
 
+void
 extOutputConns(table, outf)
     HashTable *table;
     FILE *outf;
 {
     CapValue c;  /* cap value */
-    register NodeName *nn, *nnext;
-    register Node *node;
-    register int n;
+    NodeName *nn, *nnext;
+    Node *node;
+    int n;
     NodeName *nfirst;
     HashSearch hs;
     HashEntry *he;
@@ -430,11 +433,11 @@ extOutputConns(table, outf)
 
 Node *
 extHierNewNode(he)
-    register HashEntry *he;
+    HashEntry *he;
 {
-    register int n, nclasses;
-    register NodeName *nn;
-    register Node *node;
+    int n, nclasses;
+    NodeName *nn;
+    Node *node;
 
     nclasses = ExtCurStyle->exts_numResistClasses;
     n = (nclasses - 1) * sizeof (PerimArea) + sizeof (Node);
@@ -481,7 +484,7 @@ extHierLabFirst(tile, arg)
     Tile *tile;
     FindRegion *arg;
 {
-    register LabRegion *new;
+    LabRegion *new;
 
     MALLOC(LabRegion *, new, sizeof (LabRegion));
     new->lreg_next = (LabRegion *) NULL;
@@ -498,11 +501,11 @@ extHierLabFirst(tile, arg)
     /*ARGSUSED*/
 int
 extHierLabEach(tile, pNum, arg)
-    register Tile *tile;
-    register int pNum;
+    Tile *tile;
+    int pNum;
     FindRegion *arg;
 {
-    register LabRegion *reg;
+    LabRegion *reg;
 
     reg = (LabRegion *) arg->fra_region;
     extSetNodeNum(reg, pNum, tile);
@@ -582,7 +585,7 @@ extHierNewOne()
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extHierFreeOne(et)
     ExtTree *et;
 {
