@@ -27,8 +27,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtLength.c,v 1.2
 #endif  /* not lint */
 
 #include <stdio.h>
-#include <math.h>
+#include <string.h>
 #include <ctype.h>
+#include <math.h>
+
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
@@ -114,6 +116,12 @@ int extLengthLabelsFunc();
 int extPathPairFunc();
 int extPathResetClient();
 int extPathFloodFunc();
+
+void extLengthInit();
+void extPathPairDistance();
+void extPathFlood();
+void extPathFloodTile();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -133,7 +141,7 @@ int extPathFloodFunc();
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 ExtSetDriver(name)
     char *name;
 {
@@ -143,7 +151,7 @@ ExtSetDriver(name)
     HashSetValue(he, 0);
 }
 
-Void
+void
 ExtSetReceiver(name)
     char *name;
 {
@@ -169,7 +177,7 @@ ExtSetReceiver(name)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 ExtLengthClear()
 {
     HashKill(&extDriverHash);
@@ -194,7 +202,7 @@ ExtLengthClear()
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extLengthInit()
 {
     HashInit(&extDriverHash, INITHASHSIZE, 0);
@@ -227,7 +235,7 @@ extLengthInit()
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extLength(rootUse, f)
     CellUse *rootUse;	/* The names stored in the driver and receiver tables
 			 * should all be relative to this root cell.  It is
@@ -417,7 +425,7 @@ extLengthYank(use, labList)
 
 int
 extLengthLabels(tile, rootUse)
-    register Tile *tile;	/* Some tile in extPathDef */
+    Tile *tile;	/* Some tile in extPathDef */
     CellUse *rootUse;		/* The original root cell */
 {
     char name[MAXNAMESIZE];
@@ -476,7 +484,7 @@ extLengthLabelsFunc(scx, label, tpath)
 				 * and the string label->lab_text.
 				 */
 {
-    register Label *newLab;
+    Label *newLab;
     HashEntry *he;
     int len;
 
@@ -567,7 +575,7 @@ extPathLabelFunc(rect, text, childLab, pLabList)
 			 * this list.
 			 */
 {
-    register Label *lab;
+    Label *lab;
     int len;
 
     len = strlen(text) + sizeof (Label) - sizeof lab->lab_text + 1;
@@ -610,7 +618,7 @@ extPathLabelFunc(rect, text, childLab, pLabList)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extPathPairDistance(lab1, lab2, pMin, pMax)
     Label *lab1, *lab2;
     int *pMin, *pMax;
@@ -656,6 +664,7 @@ extPathPairDistance(lab1, lab2, pMin, pMax)
 }
 
 /*
+ * ----------------------------------------------------------------------------
  * extPathResetClient --
  *
  * Called by DBSrPaintClient() on behalf of extPathPairDistance()
@@ -666,6 +675,7 @@ extPathPairDistance(lab1, lab2, pMin, pMax)
  *
  * Side effects:
  *	Sets tile->ti_client to MINFINITY.
+ * ----------------------------------------------------------------------------
  */
 
 int
@@ -704,7 +714,7 @@ extPathResetClient(tile)
 
 int
 extPathPairFunc(tile, epa)
-    register Tile *tile;
+    Tile *tile;
     struct extPathArg *epa;
 {
     Point startPoint;
@@ -745,9 +755,9 @@ extPathPairFunc(tile, epa)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extPathFlood(tile, p, distance, epa)
-    register Tile *tile;	/* Tile whose neighbors we are to visit */
+    Tile *tile;	/* Tile whose neighbors we are to visit */
     Point *p;			/* Usually at center of 'tile' */
     int distance;		/* Distance to 'p' */
     struct extPathArg *epa;	/* Update epa_min and epa_max when we reach
@@ -758,7 +768,7 @@ extPathFlood(tile, p, distance, epa)
     int tilePlaneNum = DBPlane(type);
     Label *lab2 = epa->epa_lab2;
     int pMask, pNum, newdistance;
-    register Tile *tp;
+    Tile *tp;
     char mesg[512];
     Point p2;
     Rect r;
@@ -823,7 +833,7 @@ extPathFlood(tile, p, distance, epa)
 	    extPathFloodTile(tile, p, distance, tp, epa);
 
     /* Try connections to other planes */
-    if (TTMaskHasType(&DBImageBits, type))
+    if (DBIsContact(type))
     {
 	for (pNum = tilePlaneNum - 1; pNum <= tilePlaneNum + 1; pNum += 2)
 	    if (PlaneMaskHasPlane(DBConnPlanes[type], pNum))
@@ -931,12 +941,12 @@ extPathFloodFunc(dstTile, epfa)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extPathFloodTile(srcTile, srcPoint, srcDist, dstTile, epa)
-    register Tile *srcTile;	/* Tile through which we're propagating */
+    Tile *srcTile;	/* Tile through which we're propagating */
     Point *srcPoint;		/* Point inside or on srcTile */
     int srcDist;		/* Distance to srcPoint so far */
-    register Tile *dstTile;	/* Tile on border of srcTile */
+    Tile *dstTile;	/* Tile on border of srcTile */
     struct extPathArg *epa;
 {
     Rect srcRect, dstRect;
@@ -980,8 +990,8 @@ extPathFloodTile(srcTile, srcPoint, srcDist, dstTile, epa)
 
 int
 extPathTileDist(p1, p2, tile, oldDist)
-    register Point *p1, *p2;
-    register Tile *tile;
+    Point *p1, *p2;
+    Tile *tile;
     int oldDist;
 {
     int newDist;
