@@ -82,6 +82,11 @@ int extSubtreeHardUseFunc();
 int extHardProc();
 int extSubtreeCopyPlane();
 int extSubtreeShrinkPlane();
+void extSubtreeInteraction();
+void extSubtreeAdjustInit();
+void extSubtreeOutputCoupling();
+void extSubtreeHardSearch();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -119,6 +124,7 @@ int extSubtreeShrinkPlane();
 
 #define	RECTAREA(r)	(((r)->r_xtop-(r)->r_xbot) * ((r)->r_ytop-(r)->r_ybot))
 
+void
 extSubtree(parentUse, f)
     CellUse *parentUse;
     FILE *f;
@@ -151,7 +157,8 @@ extSubtree(parentUse, f)
 
 #ifndef	exactinteractions
     /*
-     * Cookie-cutter up def into pieces ExtCurStyle->exts_stepSize by ExtCurStyle->exts_stepSize.
+     * Cookie-cutter up def into pieces ExtCurStyle->exts_stepSize by
+     * ExtCurStyle->exts_stepSize.
      * Find all interaction areas (within halo units distance, where
      * halo has been set above to reflect the maximum distance for
      * sidewall coupling capacitance).
@@ -305,7 +312,7 @@ extSubtreeInterFunc(tile, ha)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extSubtreeInteraction(ha)
     HierExtractArg *ha;	/* Context for hierarchical extraction */
 {
@@ -452,13 +459,13 @@ extSubtreeInteraction(ha)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extSubtreeAdjustInit(ha)
     HierExtractArg *ha;
 {
-    register NodeRegion *np;
-    register NodeName *nn;
-    register int n;
+    NodeRegion *np;
+    NodeName *nn;
+    int n;
     HashEntry *he;
     char *name;
 
@@ -504,14 +511,14 @@ extSubtreeAdjustInit(ha)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extSubtreeOutputCoupling(ha)
     HierExtractArg *ha;
 {
     CapValue cap;
-    register CoupleKey *ck;
-    register HashEntry *he;
-    register Tile *tp;
+    CoupleKey *ck;
+    HashEntry *he;
+    Tile *tp;
     HashSearch hs;
     char *name;
 
@@ -696,7 +703,7 @@ extSubtreeFunc(scx, ha)
 
 char *
 extSubtreeTileToNode(tp, et, ha, doHard)
-    register Tile *tp;	/* Tile whose node name is to be found */
+    Tile *tp;	/* Tile whose node name is to be found */
     ExtTree *et;	/* Yank buffer to search */
     HierExtractArg *ha;	/* Extraction context */
     bool doHard;	/* If TRUE, we look up this node's name the hard way
@@ -764,6 +771,7 @@ extSubtreeTileToNode(tp, et, ha, doHard)
 }
 
 /*
+ * ----------------------------------------------------------------------------
  * extConnFindFunc --
  *
  * Called when searching the area of a tile in the def et->et_lookNames
@@ -776,6 +784,7 @@ extSubtreeTileToNode(tp, et, ha, doHard)
  * Side effects:
  *	Sets *preg to the node found if we returned 1; otherwise,
  *	leaves *preg alone.
+ * ----------------------------------------------------------------------------
  */
 
 int
@@ -882,13 +891,16 @@ extSubtreeHardNode(tp, et, ha)
 }
 
 /*
+ * ----------------------------------------------------------------------------
  * extSubtreeHardSearch --
  *
  * Do the actual work of deciding which subtrees to search
  * for extSubtreeHardNode above.  We apply the procedure
  * extHardProc() at each subcell.
+ * ----------------------------------------------------------------------------
  */
 
+void
 extSubtreeHardSearch(et, arg)
     ExtTree *et;
     HardWay *arg;
@@ -925,19 +937,22 @@ extSubtreeHardSearch(et, arg)
 }
 
 /*
+ * ----------------------------------------------------------------------------
  * extSubtreeHardUseFunc --
  *
  * When searching a subtree, this is called once for each element
  * in the array that is the root of the subtree.
  *
  * Results:
- *	Returns 1 if we have successfully found a label, 0 if not.
+ *	Returns 1 if we have successfully found a label, 0 if not
+ *	(return value of arg->hw_proc).
  *
  * Side effects:
  *	Calls (*arg->hw_proc)().
+ * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
+int
 extSubtreeHardUseFunc(use, trans, x, y, arg)
     CellUse *use;	/* Use that is the root of the subtree being searched */
     Transform *trans;	/* Transform from coordinates of use->cu_def to those
