@@ -29,7 +29,7 @@ static char sccsid[] = "@(#)ExtTech.c	4.8 MAGIC (Berkeley) 10/26/85";
 #endif
 #include <stdlib.h>		/* for strtod() */
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/utils.h"
 #include "utils/geometry.h"
@@ -173,6 +173,8 @@ static keydesc devTable[] = {
 /*
  * ----------------------------------------------------------------------------
  *
+ * ExtCompareStyle --
+ *
  *	This routine is designed to work with embedded exttosim and
  *	exttospice.  It determines whether the current extract style
  *	matches the string (picked up from the .ext file).  If so, it
@@ -432,7 +434,7 @@ ExtPrintStyle(dolist, doforall, docurrent)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 ExtSetStyle(name)
     char *name;
 {
@@ -515,7 +517,7 @@ void
 extTechStyleInit(style)
     ExtStyle *style;
 {
-    register TileType r, s;
+    TileType r, s;
 
     style->exts_name = NULL;
     style->exts_status = TECH_NOT_LOADED;
@@ -875,7 +877,7 @@ ExtTechLine(sectionName, argc, argv)
     CapValue capVal, gscap, gccap;
     TileTypeBitMask types1, types2, near, far, ov, shield, subsTypes;
     char *subsName, *transName, *cp, *endptr;
-    register TileType s, t, r, o;
+    TileType s, t, r, o;
     keydesc *kp, *dv;
     bool isLinear;
     HashEntry *he;
@@ -1247,32 +1249,40 @@ ExtTechLine(sectionName, argc, argv)
 	    for (s = TT_TECHDEPBASE; s < DBNumTypes; s++)
 	    {
 		if (!TTMaskHasType(&types1, s)) continue;
+
+		/* Contact overlap caps are determined from residues */
+		if (DBIsContact(s)) continue;
+
 		for (t = TT_TECHDEPBASE; t < DBNumTypes; t++)
 		{
 		    if (!TTMaskHasType(&types2, t)) continue;
+
+		    /* Contact overlap caps are determined from residues */
+		    if (DBIsContact(t)) continue;
+
 		    if (s == t)
 		    {
-			TechError(
-"Can't have overlap capacitance between tiles of the same type (%s)\n",
-			    DBTypeLongName(s));
+			TechError("Can't have overlap capacitance between"
+				" tiles of the same type (%s)\n",
+				DBTypeLongName(s));
 			bad = TRUE;
 			continue;
 		    }
 		    p1 = DBPlane(s), p2 = DBPlane(t);
 		    if (p1 == p2)
 		    {
-			TechError(
-"Can't have overlap capacitance between tiles on the same plane (%s, %s)\n",
-			    DBTypeLongName(s), DBTypeLongName(t));
+			TechError("Can't have overlap capacitance between"
+				" tiles on the same plane (%s, %s)\n",
+				DBTypeLongName(s), DBTypeLongName(t));
 			bad = TRUE;
 			continue;
 		    }
-		    if ((ExtCurStyle->exts_overlapCap[s][t]) != (CapValue) 0)
+		    if (ExtCurStyle->exts_overlapCap[s][t] > (CapValue) 0)
 		    {
-			TechError(
-"Only one of \"overlap %s %s\" or \"overlap %s %s\" allowed\n",
-			    DBTypeLongName(s), DBTypeLongName(t),
-			    DBTypeLongName(t), DBTypeLongName(s));
+			TechError("Only one of \"overlap %s %s\" or"
+				" \"overlap %s %s\" allowed\n",
+				DBTypeLongName(s), DBTypeLongName(t),
+				DBTypeLongName(t), DBTypeLongName(s));
 			bad = TRUE;
 			continue;
 		    }
@@ -1290,11 +1300,14 @@ ExtTechLine(sectionName, argc, argv)
 		    {
 			if (TTMaskHasType(&shield, r))
 			{
+			    /* Shielding types are determined from residues */
+			    if (DBIsContact(r)) continue;
+
 			    p3 = DBPlane(r);
 			    if (p3 == p1 || p3 == p2)
 			    {
-				TechError(
-"Shielding type (%s) must be on a different plane from shielded types.\n",
+				TechError("Shielding type (%s) must be on a"
+					" different plane from shielded types.\n",
 					DBTypeLongName(r));
 				bad = TRUE;
 				continue;
@@ -1312,8 +1325,7 @@ ExtTechLine(sectionName, argc, argv)
 	case SIDEOVERLAP:
 	    bad = FALSE;
 	    DBTechNoisyNameMask(argv[2], &types2);
-	    DBTechNoisyNameMask(argv[3], &ov);
-	    pov = extTechTypesToPlanes(&ov);
+	    pov = DBTechNoisyNameMask(argv[3], &ov);
 	    capVal = aToCap(argv[4]);
 	    shield = DBZeroTypeBits;
 	    if (argc == 6) DBTechNoisyNameMask(argv[5], &shield);
@@ -1339,6 +1351,10 @@ ExtTechLine(sectionName, argc, argv)
 	    {
 		if (!TTMaskHasType(&types1, s))
 		    continue;
+
+		/* Side overlap computed from residues */
+		if (DBIsContact(s)) continue;
+
 		p1 = DBPlane(s);
 		if (PlaneMaskHasPlane(pov, p1))
 		    goto diffplane;
@@ -1349,6 +1365,10 @@ ExtTechLine(sectionName, argc, argv)
 		{
 		    if (!TTMaskHasType(&types2, t))
 			continue;
+
+		    /* Side overlap computed from residues */
+		    if (DBIsContact(t)) continue;
+
 		    p2 = DBPlane(t);
 		    if (t != TT_SPACE && PlaneMaskHasPlane(pov, p2))
 			goto diffplane;
@@ -1368,11 +1388,14 @@ ExtTechLine(sectionName, argc, argv)
 		    {
 			if (TTMaskHasType(&shield, r))
 			{
+			    /* Side overlap shielding computed from residues */
+			    if (DBIsContact(r)) continue;
+
 			    p3 = DBPlane(r);
 			    if (p3 == p1 || p3 == p2)
 			    {
-				TechError(
-"Shielding type (%s) must be on a different plane from shielded types.\n",
+				TechError("Shielding type (%s) must be on"
+					" a different plane from shielded types.\n",
 					DBTypeLongName(r));
 				bad = TRUE;
 				continue;
@@ -1494,39 +1517,12 @@ usage:
     return (TRUE);
 
 diffplane:
-    TechError("Overlapped types in \"sideoverlap\" rule must be on\n\
-\tdifferent plane from intypes and outtypes.\n");
+    TechError("Overlapped types in \"sideoverlap\" rule must be on a\n"
+		"\tdifferent plane from intypes and outtypes.\n");
     return (TRUE);
 }
 
-/*
- * ----------------------------------------------------------------------------
- *
- * extTechTypesToPlanes --
- *
- * Like DBTechTypesToPlanes, but makes sure that TT_SPACE is turned off in
- * its argument mask.
- *
- * Results:
- *	Returns a mask of the planes occupied by the types in the
- *	mask pointed to by 'm'.
- *
- * Side effects:
- *	None.
- *
- * ----------------------------------------------------------------------------
- */
 
-extTechTypesToPlanes(m)
-    TileTypeBitMask *m;
-{
-    TileTypeBitMask mnew;
-
-    mnew = *m;
-    TTMaskClearType(&mnew, TT_SPACE);
-    return (DBTechTypesToPlanes(&mnew));
-}
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1572,7 +1568,7 @@ extTechFinalStyle(style)
     ExtStyle *style;
 {
     TileTypeBitMask maskBits;
-    register TileType r, s, t;
+    TileType r, s, t;
     int p1, missing, conflict;
     int indicis[NP];
 
@@ -1695,7 +1691,7 @@ zinit:
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 ExtTechScale(scalen, scaled)
     int scalen;			/* Scale numerator */
     int scaled;			/* Scale denominator */
@@ -1735,7 +1731,7 @@ ExtTechScale(scalen, scaled)
 	    style->exts_perimCap[i][j] *= scalen;
 	    style->exts_perimCap[i][j] /= scaled;
 	    style->exts_overlapCap[i][j] *= sqn;
-	    style->exts_overlapCap[i][j] /= sqd;   /* Typo fixed in 7.2.57 */
+	    style->exts_overlapCap[i][j] /= sqd;    /* Typo fixed in 7.2.57 */
 	    for (ec = style->exts_sideCoupleCap[i][j]; ec != NULL;
 				ec = ec->ec_next)
 	    {
