@@ -94,9 +94,20 @@ struct cumStats cumPercentInteraction;
 struct cumStats cumTotalArea, cumInteractArea, cumClippedArea;
 
 FILE *extDevNull = NULL;
-struct cellStats *extGetStats();
 
+/* Forward declarations */
+
+struct cellStats *extGetStats();
+void extTimesCellFunc();
+void extTimesIncrFunc();
+void extTimesSummaryFunc();
+void extTimesParentFunc();
+void extTimeProc();
+void extCumInit();
+void extCumOutput();
+void extCumAdd();
 extern int extDefInitFunc();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -142,7 +153,7 @@ extern int extDefInitFunc();
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 ExtTimes(rootUse, f)
     CellUse *rootUse;
     FILE *f;
@@ -316,7 +327,7 @@ extTimesInitFunc(use)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extTimesCellFunc(cs)
     struct cellStats *cs;
 {
@@ -370,7 +381,7 @@ extTimesCellFunc(cs)
  *	Increments cs->cs_rects.
  */
 
-    /*ARGSUSED*/
+int
 extCountTiles(tile, cs)
     Tile *tile;			/* UNUSED */
     struct cellStats *cs;
@@ -403,7 +414,7 @@ extCountTiles(tile, cs)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extTimesIncrFunc(cs)
     struct cellStats *cs;
 {
@@ -452,7 +463,7 @@ extTimesIncrFunc(cs)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extTimesSummaryFunc(cs, f)
     struct cellStats *cs;
     FILE *f;
@@ -561,7 +572,7 @@ extTimesSummaryFunc(cs, f)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extTimesParentFunc(def, cs)
     CellDef *def;
     struct cellStats *cs;
@@ -751,6 +762,7 @@ extTimesFlatUse(use, cs)
  * ----------------------------------------------------------------------------
  */
 
+void
 extTimeProc(proc, def, tv)
     int (*proc)();
     CellDef *def;
@@ -808,7 +820,7 @@ extTimeProc(proc, def, tv)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extPaintOnly(def)
     CellDef *def;
 {
@@ -836,7 +848,7 @@ extPaintOnly(def)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extHierCell(def)
     CellDef *def;
 {
@@ -859,7 +871,7 @@ extHierCell(def)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extCumInit(cum)
     struct cumStats *cum;
 {
@@ -886,7 +898,7 @@ extCumInit(cum)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extCumOutput(str, cum, f)
     char *str;			/* Prefix string */
     struct cumStats *cum;
@@ -931,7 +943,7 @@ extCumOutput(str, cum, f)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 extCumAdd(cum, v)
     struct cumStats *cum;
     double v;
@@ -994,7 +1006,7 @@ extGetStats(def)
 int extInterCountHalo;
 CellDef *extInterCountDef;
 
-int
+void
 ExtInterCount(rootUse, halo, f)
     CellUse *rootUse;
     int halo;
@@ -1036,6 +1048,7 @@ ExtInterCount(rootUse, halo, f)
     (void) fprintf(f, "Mean %% interaction area = %.2f\n", inter);
 }
 
+int
 extInterAreaFunc(use, f)
     CellUse *use;
     FILE *f;
