@@ -83,16 +83,16 @@ bool
 gaStemSimpleInit(routeUse, term, pinPoint, pinSide, simple)
     CellUse *routeUse;			/* Search this cell for obstacles */
     NLTermLoc *term;			/* Route from term->nloc_rect */
-    register Point *pinPoint;		/* Crossing point to reach */
+    Point *pinPoint;		/* Crossing point to reach */
     int pinSide;			/* Direction of pin from term. */
-    register SimpleStem *simple;	/* Fill this in */
+    SimpleStem *simple;	/* Fill this in */
 {
 
-    register SimpleWire *sMetal = &simple->ss_metalWire;
-    register SimpleWire *sPoly = &simple->ss_polyWire;
-    register Rect *cTerm = &simple->ss_cTerm;
-    register Rect *cPin = &simple->ss_cPin;
-    register Rect *termLoc = &term->nloc_rect;
+    SimpleWire *sMetal = &simple->ss_metalWire;
+    SimpleWire *sPoly = &simple->ss_polyWire;
+    Rect *cTerm = &simple->ss_cTerm;
+    Rect *cPin = &simple->ss_cPin;
+    Rect *termLoc = &term->nloc_rect;
 
     /*
      * Check that the start terminal is big enough for the route to be
@@ -528,7 +528,7 @@ gaStemSimpleInit(routeUse, term, pinPoint, pinSide, simple)
 bool
 gaIsClear(use, r, mask)
     CellUse *use;
-    register Rect *r;
+    Rect *r;
     TileTypeBitMask *mask;
 {
     int gaIsClearFunc();
@@ -569,7 +569,7 @@ gaIsClear(use, r, mask)
 
 int
 gaIsClearFunc(tile, cxp)
-    register Tile *tile;
+    Tile *tile;
     TreeContext *cxp;
 {
     return 1;
@@ -596,11 +596,11 @@ gaIsClearFunc(tile, cxp)
 
 bool
 gaStemSimpleRoute(simple, pinLayer, def)
-    register SimpleStem *simple;	/* Describes the route */
+    SimpleStem *simple;	/* Describes the route */
     TileType pinLayer;			/* Connect to pin on this layer */
     CellDef *def;			/* If non-NULL, paint to this def */
 {
-    register SimpleWire *wPin, *wOther;
+    SimpleWire *wPin, *wOther;
 
     /*
      * Determine which wire corresponds to pin
