@@ -22,7 +22,7 @@
 #include <GL/gl.h>
 #include <GL/glx.h>
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
@@ -74,10 +74,10 @@ global WindClient W3DclientID;
 
 /* forward declarations */
 
-int W3DCIFredisplay();
-int W3Dredisplay();
+void W3DCIFredisplay();
+void W3Dredisplay();
 void Set3DDefaults();
-
+void w3drefreshFunc();
 
 /* ------------------------Low-Level Routines--------------------------------- */
 
@@ -576,9 +576,6 @@ w3dPaintFunc(tile, cxp)
     /* 3D window can only be interrupted by events in	*/
     /* the layout window.				*/
 
-    /* Honor display suspend status */
-    if (GrDisplayStatus == DISPLAY_SUSPEND) return 0;
-
     if (GrDisplayStatus == DISPLAY_BREAK_PENDING)
     {
 	GrDisplayStatus = DISPLAY_IN_PROGRESS;
@@ -615,9 +612,6 @@ w3dCIFPaintFunc(tile, arg)
 {
     CIFLayer *layer = (CIFLayer *)arg;
 
-    /* Honor display suspend status */
-    if (GrDisplayStatus == DISPLAY_SUSPEND) return 0;
-
     /* Allow display interrupt a la dbwPaintFunc() */
     if (GrDisplayStatus == DISPLAY_BREAK_PENDING)
     {
@@ -649,6 +643,7 @@ w3dCIFPaintFunc(tile, arg)
     w3dRenderCIF(tile, layer, &GeoIdentityTransform);
     return 0;			/* keep the search going! */
 }
+
 /* -----------------------Command Procedures------------------------------ */
 
 /*
@@ -661,7 +656,7 @@ w3dCIFPaintFunc(tile, arg)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 w3dHelp(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -692,7 +687,7 @@ w3dHelp(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 w3dCutBox(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -774,7 +769,7 @@ w3dCutBox(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 w3dSeeLayers(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -825,7 +820,7 @@ w3dSeeLayers(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 w3dClose(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -833,7 +828,7 @@ w3dClose(w, cmd)
     W3DclientRec *crec = (W3DclientRec *) w->w_clientData;
 
     if (cmd->tx_argc == 1)
-	W3Ddelete(w);
+	(void) W3Ddelete(w);
     else
 	TxError("Usage: close\n");
 }
@@ -871,7 +866,7 @@ w3dRescale(crec, scalefactor)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 w3dToggleCIF(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -910,7 +905,7 @@ w3dToggleCIF(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 w3dLevel(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -940,6 +935,7 @@ w3dLevel(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
+void
 w3drefreshFunc(mw)
     MagWindow *mw;
 {
@@ -965,7 +961,7 @@ w3drefreshFunc(mw)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 w3dDefaults(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -991,7 +987,7 @@ w3dDefaults(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 w3dRefresh(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1014,7 +1010,7 @@ w3dRefresh(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 w3dView(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1063,7 +1059,7 @@ w3dView(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 w3dScroll(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1112,7 +1108,7 @@ w3dScroll(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 w3dZoom(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1159,7 +1155,7 @@ w3dZoom(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 w3dRenderValues(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1297,7 +1293,7 @@ Set3DDefaults(mw, crec)
 
 /* -----------------------Event Procedures------------------------------ */
 
-Void
+int
 W3DEventProc(clientData, xevent)
     ClientData clientData;
     XEvent *xevent;
@@ -1719,6 +1715,7 @@ W3Dcreate(window, argc, argv)
  * ----------------------------------------------------------------------------
  */
 
+bool
 W3Ddelete(window)
     MagWindow *window;
 {
@@ -1750,7 +1747,7 @@ W3Ddelete(window)
  * ----------------------------------------------------------------------------
  */
 
-int
+void
 W3Dredisplay(w, rootArea, clipArea)
     MagWindow *w;	/* The window containing the area. */
     Rect *rootArea;	/* Ignore this---area defined by window with box */
@@ -1827,7 +1824,7 @@ W3Dredisplay(w, rootArea, clipArea)
  * ----------------------------------------------------------------------------
  */
 
-int
+void
 W3DCIFredisplay(w, rootArea, clipArea)
     MagWindow *w;	/* The window containing the area. */
     Rect *rootArea;	/* Ignore this---area defined by window with box */
@@ -1903,6 +1900,7 @@ W3DCIFredisplay(w, rootArea, clipArea)
  * ----------------------------------------------------------------------------
  */
 
+void
 W3Dcommand(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1930,9 +1928,7 @@ W3Dcommand(w, cmd)
 	default:
 	    ASSERT(False, "W3Dcommand");
     }
-
     UndoNext();
-    return (0);
 }
 
 
@@ -1952,12 +1948,13 @@ W3Dcommand(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
+void
 W3Dinit()
 {
     W3DclientID = WindAddClient("wind3d", W3Dcreate, W3Ddelete,
 			W3DCIFredisplay, W3Dcommand,
-			( Void (*)()) NULL, NULL, NULL,
-			(GrGlyph *) NULL);
+			(void(*)())NULL, (bool(*)())NULL,
+			(void(*)())NULL, (GrGlyph *)NULL);
 
     /* Register commands with the client */
 
