@@ -37,6 +37,7 @@ static char rcsid[]="$Header: /ufs/repository/magic/graphics/grClip.c,v 1.8 2001
 /* Forward declaration: */
 
 extern bool GrDisjoint();
+extern void GrClipTriangle();
 
 /* The following rectangle defines the size of the cross drawn for
  * zero-size rectangles.  This must be all on one line to keep
@@ -52,7 +53,6 @@ global int grCurDStyle;
 /* A rectangle that is one square of the grid */
 static Rect *grGridRect;
 
-
 
 /*
  * ----------------------------------------------------------------------------
@@ -135,6 +135,7 @@ grInformDriver()
  * ----------------------------------------------------------------------------
  */
 
+void
 grClipAgainst(startllr, clip)
     LinkedRect **startllr;	/* A pointer to the pointer that heads 
 				 * the list .
@@ -991,7 +992,7 @@ GrFastBox(prect)
 			 * screen coordinates.
 			 */
 {
-    register Rect *r;
+    Rect *r;
     bool needClip, needObscure;
     LinkedRect *ob;
 
@@ -1134,7 +1135,11 @@ GrFastBox(prect)
  *	triangle.  These are always arranged in counter-
  *	clockwise order.
  *
- * Results:  Returns array of points and modifies int * np
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Returns array of points and modifies int * np
  *	to hold the number of points in the array.
  *---------------------------------------------------------
  */
@@ -1142,9 +1147,9 @@ GrFastBox(prect)
 #define xround(d) (int)(((((d % height) << 1) >= height) ? 1 : 0) + (d / height))
 #define yround(d) (int)(((((d % width) << 1) >= width) ? 1 : 0) + (d / width))
 
-Void
+void
 GrClipTriangle(r, c, clipped, dir, side, points, np)
-    register Rect *r;   /* Bounding box of triangle, in screen coords	*/
+    Rect *r;   /* Bounding box of triangle, in screen coords	*/
     Rect *c;		/* Clipping rectangle 				*/
     bool clipped;	/* Boolean, if bounding box is clipped		*/
     int dir;		/* Direction of split				*/
@@ -1391,17 +1396,22 @@ GrClipTriangle(r, c, clipped, dir, side, points, np)
 }
 
 /*---------------------------------------------------------
- * GrDrawTriangleEdge:
- *	Returns a Rect structure representing the diagonal
- *	line in a triangle clipped by grCurClip.
+ * GrDrawTriangleEdge --
+ *	Draws the diagonal line in a triangle clipped by
+ *	grCurClip.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Draws nonmanhattan layout geometry.
  *
- * Results:  Returns Rect structure.
  *---------------------------------------------------------
  */
 
-Void
+void
 GrDrawTriangleEdge(r, dir, side)
-    register Rect *r;   /* Bounding box of triangle, in screen coords	*/
+    Rect *r;   /* Bounding box of triangle, in screen coords	*/
     int dir, side;
 {
     Point tpoints[5];
@@ -1431,7 +1441,8 @@ GrDrawTriangleEdge(r, dir, side)
  *	If GrDiagonal is called between GrFastBox calls then GrSetStuff
  *	must be called to set the parameters back.
  *
- * Results:	None.
+ * Results:
+ *	None.
  *
  * Side Effects:
  *	The rectangle is drawn in the style specified.
@@ -1447,7 +1458,7 @@ GrDiagonal(prect, dir, side)
     int dir;	/* direction of split: 0 = (/), 1 = (\)  */
     int side;	/* side of triangle to draw: 0 = left, 1 = right */
 {
-    register Rect *r;
+    Rect *r;
     bool needClip, needObscure;
     LinkedRect *ob;
     int cp, np;
