@@ -26,7 +26,7 @@
 #include <GL/gl.h>
 #include <GL/glx.h>
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "misc/magsgtty.h"
 #include "utils/geometry.h"
@@ -64,9 +64,10 @@ extern bool TxTkConsole;
  * of those names, which don't get modified.  Check out the Makefile
  * for details on this.
  */
-extern Void GrTOGLClose(), GrTOGLFlush(), GrTOGLInit();
-extern Void GrTOGLDelete(),GrTOGLConfigure(),GrTOGLRaise(),GrTOGLLower();
-extern Void GrTOGLLock(),GrTOGLUnlock(),GrTOGLIconUpdate();
+extern void GrTOGLClose(), GrTOGLFlush();
+extern void GrTOGLDelete(), GrTOGLConfigure(), GrTOGLRaise(), GrTOGLLower();
+extern void GrTOGLLock(), GrTOGLUnlock(), GrTOGLIconUpdate();
+extern bool GrTOGLInit();
 extern bool GrTOGLEventPending(), GrTOGLCreate(), grtoglGetCursorPos();
 extern int  GrTOGLWindowId();
 extern char *GrTkWindowName();
@@ -84,7 +85,7 @@ extern char *GrTkWindowName();
  *---------------------------------------------------------
  */
 
-Void
+void
 grtoglSetWMandC (mask, c)
     int mask;			/* New value for write mask */
     int c;			/* New value for current color */
@@ -147,7 +148,7 @@ grtoglSetWMandC (mask, c)
  *---------------------------------------------------------
  */
 
-Void
+void
 grtoglSetLineStyle (style)
     int style;			/* New stipple pattern for lines. */
 {
@@ -185,7 +186,7 @@ grtoglSetLineStyle (style)
  *---------------------------------------------------------
  */
 
-Void
+void
 grtoglSetSPattern (stipple, pattern)
     int stipple;			/* The stipple number, 1-15. */
     int pattern[8];			/* 8 8-bit patterns integers */
@@ -219,7 +220,7 @@ grtoglSetSPattern (stipple, pattern)
  *---------------------------------------------------------
  */
 
-Void
+void
 grtoglSetStipple (stipple)
     int stipple;			/* The stipple number to be used. */
 {
@@ -331,7 +332,7 @@ GrTOGLInit ()
  *---------------------------------------------------------
  */
 
-Void
+void
 GrTOGLClose ()
 {
     if (grXdpy == NULL) return;
@@ -357,7 +358,7 @@ GrTOGLClose ()
  *---------------------------------------------------------
  */
 
-Void
+void
 GrTOGLFlush ()
 {
     GR_TOGL_FLUSH_BATCH();
@@ -379,7 +380,7 @@ static GLXPixmap glpmap;
  *---------------------------------------------------------
  */
 
-Void
+int
 toglSetProjection(llx, lly, width, height)
     int llx, lly, width, height;
 {
@@ -433,7 +434,7 @@ toglSetProjection(llx, lly, width, height)
  * ---------------------------------------------------------------------------
  */
 
-Void
+void
 TOGLEventProc(clientData, xevent)
     ClientData clientData;
     XEvent *xevent;
@@ -912,13 +913,14 @@ extern void MakeWindowCommand();
  *	Bind X window to Magic Window w.
  *
  * Results:
- *      Window created, window ID send to Xhelper.
+ *	Success/Fail
  *
  * Side Effects:
- *	None.
+ *      Window created, window ID send to Xhelper.
  *
  * ----------------------------------------------------------------------------
  */
+
 bool
 GrTOGLCreate(w, name)
     MagWindow *w;
@@ -1060,12 +1062,15 @@ GrTOGLCreate(w, name)
  *      Destroy a Tk/OpenGL window.
  *
  * Results:
- *      Window destroyed.
+ *	None.
  *
+ * Side Effects:
+ *      Window destroyed.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrTOGLDelete(w)
     MagWindow *w;
 {
@@ -1087,15 +1092,15 @@ GrTOGLDelete(w)
  *      Resize/ Move an existing X window.
  *
  * Results:
- *      Window reconfigured to w->w_frameArea.
+ *      None.
  *
  * Side Effects:
- *      None.
+ *      Window reconfigured to w->w_frameArea.
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 GrTOGLConfigure(w)
     MagWindow *w;
 {
@@ -1115,14 +1120,15 @@ GrTOGLConfigure(w)
  *	obscures it.
  *
  * Results:
- *      Window raised.
+ *      None.
  *
  * Side Effects:
- *      None.
+ *      Window raised.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrTOGLRaise(w)
     MagWindow *w;
 {
@@ -1142,14 +1148,15 @@ GrTOGLRaise(w)
  *	obscures it.
  *
  * Results:
- *      Window lowered.
+ *      None.
  *
  * Side Effects:
- *      None.
+ *      Window lowered.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrTOGLLower(w)
     MagWindow *w;
 {
@@ -1170,14 +1177,15 @@ GrTOGLLower(w)
  *	and "toglCurrent.mw" to reference the locked window.
  *
  * Results:
- *      Window locked.
+ *	None.
  *
  * Side Effects:
- *	None.
+ *      Window locked.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrTOGLLock(w, flag)
     MagWindow *w;
     bool flag;
@@ -1213,14 +1221,16 @@ GrTOGLLock(w, flag)
  *      Unlock a window, flushing stuff out to the display.
  *
  * Results:
- *      Window unlocked.
+ *	None.
  *
  * Side Effects:
+ *      Window unlocked.
  *	Display update.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrTOGLUnlock(w)
     MagWindow *w;
 {
@@ -1237,14 +1247,23 @@ GrTOGLUnlock(w)
 
 /*           
  *-------------------------------------------------------------------------
- * GrTOGLEventPending -- check for pending graphics events.
+ * GrTOGLEventPending --
+ *	check for pending graphics events.
  *      Here we use the X11 check for window events, because Tcl/Tk doesn't
  *      allows peeking into its event queue without executing whatever is
  *      in the queue.
+ *
+ * Results:
+ *	TRUE if an event is waiting in the event queue.
+ *
+ * Side effects:
+ *	None, hopefully (put back the event!)
+ *
  *-------------------------------------------------------------------------
  */     
      
-bool GrTOGLEventPending()
+bool
+GrTOGLEventPending()
 { 
    Window       wind = toglCurrent.windowid;
    XEvent       genEvent;
@@ -1269,10 +1288,11 @@ bool GrTOGLEventPending()
  *
  *-------------------------------------------------------------------------
  */
-Void GrTOGLIconUpdate(w,text)		/* See Blt code */
-	MagWindow	*w;
-	char		*text;
 
+void
+GrTOGLIconUpdate(w,text)		/* See Blt code */
+    MagWindow	*w;
+    char	*text;
 {
     Tk_Window	tkwind;
     Window	wind;
@@ -1309,7 +1329,15 @@ Void GrTOGLIconUpdate(w,text)		/* See Blt code */
 
 /*
  *-------------------------------------------------------------------------
- * Get magic's ID number from the indicated MagWindow structure
+ * GrTOGLWindowId --
+ *	Get magic's ID number from the indicated MagWindow structure
+ *
+ * Results:
+ *	The window ID number.
+ *
+ * Side effects:
+ *	None.
+ *
  *-------------------------------------------------------------------------
  */
 
