@@ -23,7 +23,7 @@
 #include <X11/Xutil.h>
 #include <X11/keysym.h>
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "misc/magsgtty.h"
 #include "utils/geometry.h"
@@ -99,9 +99,10 @@ extern bool TxTkConsole;
  * of those names, which don't get modified.  Check out the Makefile
  * for details on this.
  */
-extern Void GrTkClose(), GrTkFlush(), GrTkInit();
-extern Void GrTkDelete(),GrTkConfigure(),GrTkRaise(),GrTkLower();
-extern Void GrTkLock(),GrTkUnlock(),GrTkIconUpdate();
+extern void GrTkClose(), GrTkFlush();
+extern void GrTkDelete(),GrTkConfigure(),GrTkRaise(),GrTkLower();
+extern void GrTkLock(),GrTkUnlock(),GrTkIconUpdate();
+extern bool GrTkInit();
 extern bool GrTkEventPending(), GrTkCreate(), grtkGetCursorPos();
 extern int  GrTkWindowId();
 extern char *GrTkWindowName();
@@ -120,7 +121,7 @@ extern char *GrTkWindowName();
  *---------------------------------------------------------
  */
 
-Void
+void
 grtkSetWMandC (mask, c)
     int mask;			/* New value for write mask */
     int c;			/* New value for current color */
@@ -162,7 +163,7 @@ grtkSetWMandC (mask, c)
  *---------------------------------------------------------
  */
 
-Void
+void
 grtkSetLineStyle (style)
     int style;			/* New stipple pattern for lines. */
 {
@@ -257,7 +258,7 @@ grtkSetLineStyle (style)
  *---------------------------------------------------------
  */
 
-Void
+void
 grtkSetSPattern (stipple, pattern)
     int stipple;			/* The stipple number, 1-15. */
     int pattern[8];			/* 8 8-bit patterns integers */
@@ -267,16 +268,14 @@ grtkSetSPattern (stipple, pattern)
     int x,y,pat;
 
     tkwind = Tk_MainWindow(magicinterp);
+
+    /* This routine may be executed before Tk tells X11 to create the	*/
+    /* main window.  So if no X11 window ID is registered, force the	*/
+    /* window creation and update.					*/
+
     if (tkwind == 0 || Tk_WindowId(tkwind) == 0)
-    {
 	Tk_MakeWindowExist(tkwind);
-    }
-    if (tkwind == 0 || Tk_WindowId(tkwind) == 0)
-    {
-	fprintf(stderr, "ERROR:  Bad window!\n");
-	fflush(stderr);
-	return;
-    }
+
     p = Tk_GetPixmap(grXdpy, Tk_WindowId(tkwind), 8, 8, 1);
     if (grGCStipple == 0) {
 	/* grGCStipple = Tk_GetGC(tkwind, 0, 0); */
@@ -306,7 +305,7 @@ grtkSetSPattern (stipple, pattern)
  *---------------------------------------------------------
  */
 
-Void
+void
 grtkSetStipple (stipple)
     int stipple;			/* The stipple number to be used. */
 {
@@ -478,9 +477,6 @@ GrTkInit(dispType)
 	    visual_table[3] = defpsindex;
 	log_color = getenv("MAGIC_COLOR");
 
-	/* environment variable MAGIC_COLOR overrides all, but we can do  */
-	/* the same thing by passing "-d 7bit", etc., on the command-line */
-
 	if ((log_color == NULL) && (dispType != NULL) && (dispType[0] != 'X'))
 	    log_color = dispType;
 
@@ -636,7 +632,7 @@ GrTkInit(dispType)
             /* This must be called here;  because in B/W the colormap   */
             /* is useless, it will not be called by the style file      */
             /* load procedure.                                          */
-            GrTkSetCMap((char *)NULL);
+            GrTkSetCMap();
             break;
         case 7: case 8:
             grDStyleType = "7bit";
@@ -660,13 +656,15 @@ GrTkInit(dispType)
 /*---------------------------------------------------------
  * GrTkClose:
  *
- * Results:	None.
+ * Results:
+ *	None.
  *
  * Side Effects:
+ *	Frees fonts from the Tk font cache.
  *---------------------------------------------------------
  */
 
-Void
+void
 GrTkClose ()
 {
     int i;
@@ -696,7 +694,7 @@ GrTkClose ()
  *---------------------------------------------------------
  */
 
-Void
+void
 GrTkFlush ()
 {
     GR_TK_FLUSH_BATCH();
@@ -719,7 +717,7 @@ GrTkFlush ()
  * ---------------------------------------------------------------------------
  */
 
-Void
+void
 MagicEventProc(clientData, xevent)
     ClientData clientData;
     XEvent *xevent;
@@ -1090,7 +1088,7 @@ MagicEventProc(clientData, xevent)
 
 
 /*---------------------------------------------------------
- * x11suSetDisplay:
+ * x11SetDisplay:
  *	This routine sets the appropriate parameters so that
  *	Magic will work with the X display under Tcl/Tk.
  *
@@ -1105,7 +1103,7 @@ MagicEventProc(clientData, xevent)
  *
  * Results:  success / fail
  *
- * Side Effects:	Sets up the pipe.
+ * Side Effects:
  *---------------------------------------------------------
  */
 
@@ -1175,7 +1173,7 @@ x11SetDisplay (dispType, outFileName, mouseFileName)
 	return false;
     }
 
-    if(!GrTkInit(dispType)) {
+    if (!GrTkInit(dispType)) {
 	return false;
     };
 
@@ -1199,13 +1197,14 @@ extern void MakeWindowCommand();
  *	Bind Tk window to Magic Window w.
  *
  * Results:
- *      Window created and mapped.
+ *	Success/Failure
  *
  * Side Effects:
- *	None.
+ *      Window created and mapped.
  *
  * ----------------------------------------------------------------------------
  */
+
 bool
 GrTkCreate(w, name)
     MagWindow *w;
@@ -1420,12 +1419,15 @@ GrTkCreate(w, name)
  *      Destroy an X window.
  *
  * Results:
- *      Window destroyed.
+ *	None.
  *
+ * Side effects:
+ *      Window destroyed.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrTkDelete(w)
     MagWindow *w;
 {
@@ -1448,15 +1450,15 @@ GrTkDelete(w)
  *      Resize/ Move an existing X window.
  *
  * Results:
- *      Window reconfigured to w->w_frameArea.
+ *      None.
  *
  * Side Effects:
- *      None.
+ *      Window reconfigured to w->w_frameArea.
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 GrTkConfigure(w)
     MagWindow *w;
 {
@@ -1476,14 +1478,15 @@ GrTkConfigure(w)
  *	obscures it.
  *
  * Results:
- *      Window raised.
+ *      None.
  *
  * Side Effects:
- *      None.
+ *      Window raised.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrTkRaise(w)
     MagWindow *w;
 {
@@ -1503,14 +1506,15 @@ GrTkRaise(w)
  *	obscures it.
  *
  * Results:
- *      Window lowered.
+ *      None.
  *
  * Side Effects:
- *      None.
+ *      Window lowered.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrTkLower(w)
     MagWindow *w;
 {
@@ -1530,14 +1534,15 @@ GrTkLower(w)
  *	and "grCurrent.mw" to reference the locked window.
  *
  * Results:
- *      Window locked.
+ *	None.
  *
  * Side Effects:
- *	None.
+ *      Window locked.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrTkLock(w, flag)
     MagWindow *w;
     bool flag;
@@ -1567,14 +1572,16 @@ GrTkLock(w, flag)
  *      Unlock a window, flushing stuff out to the display.
  *
  * Results:
- *      Window unlocked.
+ *	None.
  *
  * Side Effects:
+ *      Window unlocked.
  *	Display update.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrTkUnlock(w)
     MagWindow *w;
 {
@@ -1589,10 +1596,18 @@ GrTkUnlock(w)
  *	Here we use the X11 check for window events, because Tcl/Tk doesn't
  *	allows peeking into its event queue without executing whatever is
  *	in the queue.
+ *
+ * Results:
+ *	True if an event is in the event queue.
+ *
+ * Side effects:
+ *	Hopefully none (put back the event!)
+ *
  *-------------------------------------------------------------------------
  */
 
-bool GrTkEventPending()
+bool
+GrTkEventPending()
 {
    Tk_Window	tkwind = grCurrent.window;
    Window	wind = grCurrent.windowid;
@@ -1617,10 +1632,11 @@ bool GrTkEventPending()
  *
  *-------------------------------------------------------------------------
  */
-Void GrTkIconUpdate(w, text)		/* See Blt code */
-	MagWindow	*w;
-	char		*text;
 
+void
+GrTkIconUpdate(w, text)		/* See Blt code */
+    MagWindow	*w;
+    char	*text;
 {
     Tk_Window	tkwind;
     Window	wind;
@@ -1657,11 +1673,19 @@ Void GrTkIconUpdate(w, text)		/* See Blt code */
 
 /*
  *-------------------------------------------------------------------------
- * Get magic's ID number from the indicated MagWindow structure
+ * GrTkWindowId --
+ *	Get magic's ID number from the indicated MagWindow structure
+ *
+ * Results:
+ *	The window ID number
+ *
+ * Side effects:
+ *	None.
  *-------------------------------------------------------------------------
  */
 
-int GrTkWindowId(tkname)
+int
+GrTkWindowId(tkname)
     char *tkname;
 {
     Tk_Window tkwind;
