@@ -18,7 +18,7 @@
 #include <X11/Xutil.h>
 #include <X11/keysym.h>
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "misc/styles.h"
 #include "utils/geometry.h"
@@ -57,13 +57,15 @@ bool GrTkInstalledCMap = FALSE;
  * grTkLoadFont
  *	This local routine loads the Tk fonts used by Magic.
  *
- * Results:	None.
+ * Results:
+ *	Success/Failure.
  *
- * Side Effects:    None.
+ * Side Effects:
+ *	Font information saved in grTkFonts array.
  *---------------------------------------------------------
  */
 
-Void
+bool
 grTkLoadFont()
 {
     Tk_Window tkwind;
@@ -105,6 +107,12 @@ grTkLoadFont()
 /*---------------------------------------------------------
  * grTkFreeFonts
  *      This local routine frees the Tk font cache.
+ *
+ * Results:
+ *	None.
+ *
+ * Side Effects:
+ *	Memory deallocation.
  *---------------------------------------------------------
  */
 
@@ -132,7 +140,7 @@ grTkFreeFonts()
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 grTkDefineCursor(glyphs)
     GrGlyphs *glyphs;
 {
@@ -219,7 +227,14 @@ grTkDefineCursor(glyphs)
 
 /*
  *-------------------------------------------------------------------------
- * Get the window name from the indicated MagWindow structure
+ * GrTkWindowName --
+ *	Get the window name from the indicated MagWindow structure
+ *
+ * Results:
+ *	The Tk path name of the window "mw" (char * string).
+ *
+ * Side Effects:
+ *	None.
  *-------------------------------------------------------------------------
  */ 
   
@@ -312,11 +327,19 @@ GrTkGetColorByName(name)
 
 /*
  *---------------------------------------------------------
- * Tcl command callback for GrTkGetColorByName
+ * _magic_magiccolor --
+ *	Tcl command callback for GrTkGetColorByName
+ *
+ * Results:
+ *	TCL result type
+ *
+ * Side effects:
+ *	None.
  *---------------------------------------------------------
  */
 
-static int _magic_magiccolor(ClientData clientData,
+static int
+_magic_magiccolor(ClientData clientData,
 	Tcl_Interp *interp, int argc, char *argv[])
 {
     char *result;
@@ -557,9 +580,15 @@ ImgLayerConfigureMaster(masterPtr, objc, objv, flags)
 
 /*
  *----------------------------------------------------------------------
+ * grDrawOffScreenBox --
+ *	Draw a box on an off-screen drawable (convenience function for
+ *	the following procedure ImgLayerConfigureInstance()
+ * 
+ * Results:
+ *	None.
  *
- * Draw a box on an off-screen drawable (convenience function for the
- * following procedure ImgLayerConfigureInstance()
+ * Side effects:
+ *	Draws into an off-screen drawable destination.
  *
  *----------------------------------------------------------------------
  */
@@ -1114,8 +1143,15 @@ ImgLayerCmdDeletedProc(clientData)
 
 /*
  *---------------------------------------------------------
- * Register the "magiccolor" command with Tcl.
- * Register the layer type with the Tk "image" command
+ * RegisterTkCommands --
+ *	Register the "magiccolor" command with Tcl.
+ *	Register the layer type with the Tk "image" command
+ *
+ * Results:
+ *	None.
+ *
+ * Side Effects:
+ *	Command registration with the TCL interpreter.
  *---------------------------------------------------------
  */
 
