@@ -62,7 +62,6 @@ GR_CURRENT    grCurrent= {0,0,0,0,0,0};
 GR_DISPLAY    grDisplay;
 GC 	      grGCFill, grGCText,grGCDraw;
 GC	      grGCCopy, grGCGlyph, grGCStipple;
-int	      grXWStdin();
 
 unsigned long grPixels[256];
 unsigned long grPlanes[256];
@@ -115,10 +114,12 @@ int Xhelper;
  * of those names, which don't get modified.  Check out the Makefile
  * for details on this.
  */
-extern Void GrX11Close(), GrX11Flush(), GrX11Init();
-extern bool GrX11Create();
-extern Void GrX11Delete(),GrX11Configure(),GrX11Raise(),GrX11Lower();
-extern Void GrX11Lock(),GrX11Unlock(),GrX11IconUpdate();
+
+extern void GrX11Close(), GrX11Flush();
+extern bool GrX11Init(), GrX11Create();
+extern void GrX11Delete(), GrX11Configure(), GrX11Raise(), GrX11Lower();
+extern void GrX11Lock(), GrX11Unlock(), GrX11IconUpdate();
+extern void grXWStdin();
 
 
 /*---------------------------------------------------------
@@ -129,12 +130,10 @@ extern Void GrX11Lock(),GrX11Unlock(),GrX11IconUpdate();
  * Results:	None.
  *
  * Side Effects:    None.
- *
- * Errors:		None.
  *---------------------------------------------------------
  */
 
-Void
+void
 grx11SetWMandC (mask, c)
     int mask;			/* New value for write mask */
     int c;			/* New value for current color */
@@ -176,7 +175,7 @@ grx11SetWMandC (mask, c)
  *---------------------------------------------------------
  */
 
-Void
+void
 grx11SetLineStyle (style)
     int style;			/* New stipple pattern for lines. */
 {
@@ -271,7 +270,7 @@ grx11SetLineStyle (style)
  *---------------------------------------------------------
  */
 
-Void
+void
 grx11SetSPattern (stipple, pattern)
     int stipple;			/* The stipple number, 1-15. */
     int pattern[8];			/* 8 8-bit patterns integers */
@@ -307,7 +306,7 @@ grx11SetSPattern (stipple, pattern)
  *---------------------------------------------------------
  */
 
-Void
+void
 grx11SetStipple (stipple)
     int stipple;			/* The stipple number to be used. */
 {
@@ -534,10 +533,10 @@ GrX11Init(dispType)
         gritems = -1;
         if (log_color != NULL)
 	{
-	    if (strncmp(log_color, "8bit", 4) == 0)  gritems = visual_table[3];
-	    if (strncmp(log_color, "15bit", 5) == 0) gritems = visual_table[4];
-	    if (strncmp(log_color, "16bit", 5) == 0) gritems = visual_table[5];
-	    if (strncmp(log_color, "24bit", 5) == 0) gritems = visual_table[6];
+	    if (strncmp(log_color, "8", 1) == 0)  gritems = visual_table[3];
+	    if (strncmp(log_color, "15", 2) == 0) gritems = visual_table[4];
+	    if (strncmp(log_color, "16", 2) == 0) gritems = visual_table[5];
+	    if (strncmp(log_color, "24", 2) == 0) gritems = visual_table[6];
 	    if (gritems == -1) {
 		printf("The visual mode %s is not available. Sorry.\n", log_color);
 		XFree(grvisual_get);
@@ -661,7 +660,7 @@ GrX11Init(dispType)
 	    /* This must be called here;  because in B/W the colormap	*/
 	    /* is useless, it will not be called by the style file	*/
 	    /* load procedure.						*/
-	    GrX11SetCMap((char *)NULL);
+	    GrX11SetCMap();
 	    break;
 	case 7: case 8:
 	    grDStyleType = "7bit";
@@ -683,15 +682,19 @@ GrX11Init(dispType)
 
 
 /*---------------------------------------------------------
- * GrXClose:
+ * GrXClose --
  *
- * Results:	None.
+ * Results:
+ *	None.
  *
  * Side Effects:
+ *	In the non-pthreads version, kills the helper
+ *	process.  In the pthreads version, detaches the
+ *	X11 helper thread.
  *---------------------------------------------------------
  */
 
-Void
+void
 GrX11Close ()
 {
     if (grXdpy == NULL) return;
@@ -722,7 +725,7 @@ GrX11Close ()
  *---------------------------------------------------------
  */
 
-Void
+void
 GrX11Flush ()
 {
    XFlush(grXdpy);
@@ -745,8 +748,8 @@ GrX11Flush ()
  * ---------------------------------------------------------------------------
  */
 
-Void
-grX11Stdin ()
+void
+grX11Stdin()
 {
     TxInputEvent *event;
     XEvent	xevent;
@@ -1007,7 +1010,8 @@ x11SetDisplay (dispType, outFileName, mouseFileName)
     grFillPolygonPtr = grx11FillPolygon;
 #endif
     
-    if (execFailed) {
+    if (execFailed)
+    {
 	TxError("Execution failed!\n");
 	return false;
     }
@@ -1038,9 +1042,8 @@ x11SetDisplay (dispType, outFileName, mouseFileName)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
-Void
+void
 grXWStdin(fd, cdata)
     int fd;
     ClientData cdata;
@@ -1070,13 +1073,14 @@ grXWStdin(fd, cdata)
  *	Bind X window to Magic Window w.
  *
  * Results:
- *      Window created, window ID send to Xhelper.
+ *	Success/Failure
  *
  * Side Effects:
- *	None.
+ *      Window created, window ID send to Xhelper.
  *
  * ----------------------------------------------------------------------------
  */
+
 bool
 GrX11Create(w, name)
     MagWindow *w;
@@ -1182,7 +1186,7 @@ GrX11Create(w, name)
         write( pipeWrite, (char *) &wind, sizeof(Window));
 	kill( Xhelper, SIGTERM);
 #endif
-	sleep(1); /* wait for Xhelper to register for Expose Events; */
+	sleep(1); /* wait for Xhelper to for Expose Events; */
 		  /* the window new doesn't get painted initially    */
 		  /* otherwise.					     */
 /*        printf("Create call completed.\n");  */
@@ -1201,12 +1205,15 @@ GrX11Create(w, name)
  *      Destroy an X window.
  *
  * Results:
- *      Window destroyed.
+ *	None.
  *
+ * Side Effects:
+ *      Window destroyed.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrX11Delete(w)
     MagWindow *w;
 {
@@ -1227,15 +1234,15 @@ GrX11Delete(w)
  *      Resize/ Move an existing X window.
  *
  * Results:
- *      Window reconfigured to w->w_frameArea.
+ *      None.
  *
  * Side Effects:
- *      None.
+ *      Window reconfigured to w->w_frameArea.
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 GrX11Configure(w)
     MagWindow *w;
 {
@@ -1253,14 +1260,15 @@ GrX11Configure(w)
  *	obscures it.
  *
  * Results:
- *      Window raised.
+ *      None.
  *
  * Side Effects:
- *      None.
+ *      Window raised.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrX11Raise(w)
     MagWindow *w;
 {
@@ -1275,19 +1283,21 @@ GrX11Raise(w)
  *	obscures it.
  *
  * Results:
- *      Window lowered.
+ *      None.
  *
  * Side Effects:
- *      None.
+ *      Window lowered.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrX11Lower(w)
     MagWindow *w;
 {
     XLowerWindow(grXdpy, (Window) w->w_grdata );
 }
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -1297,14 +1307,15 @@ GrX11Lower(w)
  *	and "grCurrent.mw" to reference the locked window.
  *
  * Results:
- *      Window locked.
+ *	None.
  *
  * Side Effects:
- *	None.
+ *      Window locked.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrX11Lock(w, flag)
     MagWindow *w;
     bool flag;
@@ -1316,6 +1327,7 @@ GrX11Lock(w, flag)
 	grCurrent.window = (Window) w->w_grdata;
     }
 }
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -1324,20 +1336,23 @@ GrX11Lock(w, flag)
  *      Unlock a window, flushing stuff out to the display.
  *
  * Results:
- *      Window unlocked.
+ *	None.
  *
  * Side Effects:
+ *      Window unlocked.
  *	Display update.
  *
  * ----------------------------------------------------------------------------
  */
 
+void
 GrX11Unlock(w)
     MagWindow *w;
 {
     GR_X_FLUSH_BATCH();
     grSimpleUnlock(w);
 }
+
 
 /*
  *-------------------------------------------------------------------------
@@ -1350,7 +1365,9 @@ GrX11Unlock(w)
  *
  *-------------------------------------------------------------------------
  */
-Void GrX11IconUpdate(w,text)
+
+void
+GrX11IconUpdate(w,text)
 	MagWindow	*w;
 	char		*text;
 
