@@ -20,7 +20,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/lef/defRead.c,v 1.0 2003/0
 #include <errno.h>
 #include <stdarg.h>
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -43,7 +43,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/lef/defRead.c,v 1.0 2003/0
  *	and add it to the linked list representing the route.
  *
  * Results:
- *	None.
+ *	Returns the last token encountered.
  *
  * Side Effects:
  *	Reads from input stream;
@@ -52,8 +52,6 @@ static char rcsid[] = "$Header: /ufs/repository/magic/lef/defRead.c,v 1.0 2003/0
  *------------------------------------------------------------
  */
 
-#define DEFAULT_WIDTH 3
-
 char *
 DefAddRoutes(rootDef, f, oscale, special)
     CellDef *rootDef;		/* Cell to paint */
@@ -70,6 +68,8 @@ DefAddRoutes(rootDef, f, oscale, special)
     float x, y, w;
     int curWidth, w1, w2;
     TileType newLayer;
+    HashEntry *he;
+    lefLayer *lefl;
 
     while (initial || (token = LefNextToken(f, TRUE)) != NULL)
     {
@@ -84,9 +84,23 @@ DefAddRoutes(rootDef, f, oscale, special)
 
 	    token = LefNextToken(f, TRUE);
 
-	    /* Note that, like in lefRead.c, this measure is ad-hoc */
+	    he = HashLookOnly(&LefInfo, token);
+	    if (he != NULL)
+	    {
+		lefl = (lefLayer *)HashGetValue(he);
+		newLayer = lefl->type;
+	    }
+	    else
+	    {
+		/* The fallback position is to match the DEF name to the  */
+		/* magic layer name.  This is ad-hoc, and the declaration */
+		/* of type mappings in the lef section of the techfile is */
+		/* preferred.						  */
+
+		newLayer = DBTechNameType(LefLower(token));
+		lefl = NULL;
+	    }
 
-	    newLayer = DBTechNameType(LefLower(token));
 	    if (newLayer < 0)
 	    {
 		LefError("Unknown layer type \"%s\" for NEW route\n", token); 
@@ -102,10 +116,13 @@ DefAddRoutes(rootDef, f, oscale, special)
 		    LefError("Bad width in special net\n");
 		    continue;
 		}
-		curWidth = (w == 0) ? DEFAULT_WIDTH : (int)(w / oscale);
+		if (w != 0)
+		    curWidth = (int)(w / oscale);
+		else
+		    curWidth = (lefl) ? lefl->info.route.width : DEFAULT_WIDTH;
 	    }
 	    else
-		curWidth = DEFAULT_WIDTH;
+		curWidth = (lefl) ? lefl->info.route.width : DEFAULT_WIDTH;
 	}
 	else if (*token != '(')	/* via name */
 	{
@@ -118,20 +135,35 @@ DefAddRoutes(rootDef, f, oscale, special)
 		LefError("Route has via name \"%s\" but no points!\n", token);
 		continue;
 	    }
-	    newLayer = DBTechNameType(LefLower(token));
-	    if (newLayer >= 0)
+	    he = HashLookOnly(&LefInfo, token);
+	    if (he != NULL)
 	    {
+		lefl = (lefLayer *)HashGetValue(he);
 		newRoute = (linkedRect *)mallocMagic(sizeof(linkedRect));
 
-		/* The area to paint is supposed to be derived from the	*/
-		/* via definitions, not the width (to be implemented)!	*/
+		/* The area to paint is derived from the via definitions. */
 
-		w1 = curWidth >> 1;
-		w2 = curWidth - w1;
-		newRoute->area.r_xbot = refp.p_x - w1;
-		newRoute->area.r_ybot = refp.p_y - w1;
-		newRoute->area.r_xtop = refp.p_x + w2;
-		newRoute->area.r_ytop = refp.p_y + w2;
+		if (lefl != NULL)
+		{
+		    newLayer = lefl->type;
+
+		    newRoute->area.r_xbot = refp.p_x + lefl->info.via.area.r_xbot;
+		    newRoute->area.r_ybot = refp.p_y + lefl->info.via.area.r_ybot;
+		    newRoute->area.r_xtop = refp.p_x + lefl->info.via.area.r_xtop;
+		    newRoute->area.r_ytop = refp.p_y + lefl->info.via.area.r_ytop;
+		}
+		else if ((newLayer = DBTechNameType(LefLower(token))) >= 0)
+		{
+		    LefError("Error: Via \"%s\" named but undefined.\n", token);
+		    w1 = curWidth >> 1;
+		    w2 = curWidth - w1;
+		    newRoute->area.r_xbot = refp.p_x - w1;
+		    newRoute->area.r_ybot = refp.p_y - w1;
+		    newRoute->area.r_xtop = refp.p_x + w2;
+		    newRoute->area.r_ytop = refp.p_y + w2;
+		}
+		else
+		   LefError("Via name \"%s\" unknown in route.\n", token);
 	    }
 	    else
 		LefError("Via name \"%s\" unknown in route.\n", token);
@@ -507,6 +539,148 @@ parse_error:
     return;
 }
 
+/*
+ *------------------------------------------------------------
+ *
+ * DefReadVias --
+ *
+ *	Read a VIAS section from a DEF file.
+ *
+ * Results:
+ *	None.
+ *
+ * Side Effects:
+ *	Technically, this routine should be creating a cell for
+ *	each defined via.  For now, it just computes the bounding
+ *	rectangle and layer.
+ *
+ *------------------------------------------------------------
+ */
+
+enum def_vias_keys {DEF_VIAS_START = 0, DEF_VIAS_END};
+enum def_vias_prop_keys {
+	DEF_VIAS_PROP_RECT = 0};
+
+void
+DefReadVias(f, sname, oscale, total)
+    FILE *f;
+    char *sname;
+    float oscale;
+    int total;
+{
+    char *token;
+    char vianame[LEF_LINE_MAX];
+    int keyword, subkey, values;
+    int processed = 0;
+    TileType curlayer;
+    Rect viaArea, *currect;
+    lefLayer *lefl;
+    HashEntry *he;
+
+    static char *via_keys[] = {
+	"-",
+	"END",
+	NULL
+    };
+
+    static char *via_property_keys[] = {
+	"RECT",
+	NULL
+    };
+
+    while ((token = LefNextToken(f, TRUE)) != NULL)
+    {
+	keyword = Lookup(token, via_keys);
+
+	if (keyword < 0)
+	{
+	    LefError("Unknown keyword \"%s\" in VIAS "
+			"definition; ignoring.\n", token);
+	    LefEndStatement(f);
+	    continue;
+	}
+	switch (keyword)
+	{
+	    case DEF_VIAS_START:		/* "-" keyword */
+
+		/* Update the record of the number of vias		*/
+		/* processed and spit out a message for every 5% done.	*/
+ 
+		LefEstimate(processed++, total, "vias");
+		viaArea = GeoNullRect;
+
+		/* Get via name */
+		token = LefNextToken(f, TRUE);
+		if (sscanf(token, "%2047s", vianame) != 1)
+		{
+		    LefError("Bad via statement:  Need via name\n");
+		    LefEndStatement(f);
+		    break;
+		}
+		he = HashFind(&LefInfo, vianame);
+		lefl = (lefLayer *)HashGetValue(he);
+		if (lefl == NULL)
+		{
+		    lefl = (lefLayer *)mallocMagic(sizeof(lefLayer));
+		    lefl->type = -1;
+		    lefl->obsType = -1;
+		    lefl->is_via = TRUE;
+		    lefl->info.via.area = GeoNullRect;
+		    lefl->info.via.cell = (CellDef *)NULL;
+		    HashSetValue(he, lefl);
+		}
+
+		/* Now do a search through the line for "+" entries	*/
+		/* And process each.					*/
+
+		while ((token = LefNextToken(f, TRUE)) != NULL)
+		{
+		    if (*token == ';') break;
+		    if (*token != '+') continue;
+
+		    token = LefNextToken(f, TRUE);
+		    subkey = Lookup(token, via_property_keys);
+		    if (subkey < 0)
+		    {
+			LefError("Unknown via property \"%s\" in "
+				"VIAS definition; ignoring.\n", token);
+			continue;
+		    }
+		    switch (subkey)
+		    {
+			case DEF_VIAS_PROP_RECT:
+			    curlayer = LefReadLayer(f, FALSE);
+			    currect = LefReadRect(f, curlayer, oscale);
+			    if (currect)
+			    {
+				GeoInclude(currect, &viaArea);
+				if ((lefl->type < 0) || DBIsContact(curlayer))
+				    lefl->type = curlayer;
+				lefl->info.via.area = viaArea;
+			    }
+			    break;
+		    }
+		}
+		break;
+
+	    case DEF_VIAS_END:
+		if (!LefParseEndStatement(f, sname))
+		{
+		    LefError("Vias END statement missing.\n");
+		    keyword = -1;
+		}
+		break;
+	}
+	if (keyword == DEF_VIAS_END) break;
+    }
+
+    if (processed == total)
+	TxPrintf("  Processed %d vias total.\n", processed);
+    else
+	LefError("Warning:  Number of vias read (%d) does not match "
+		"the number declared (%d).\n", processed, total);
+}
+ 
 /*
  *------------------------------------------------------------
  *
@@ -856,7 +1030,7 @@ DefRead(inName)
 		token = LefNextToken(f, TRUE);
 		if (sscanf(token, "%d", &total) != 1) total = 0;
 		LefEndStatement(f);
-		LefSkipSection(f, sections[DEF_VIAS]);
+		DefReadVias(f, sections[DEF_VIAS], oscale, total);
 		break;
 	    case DEF_PINS:
 		token = LefNextToken(f, TRUE);
@@ -915,6 +1089,6 @@ DefRead(inName)
 		&DBAllButSpaceBits);
     DBCellSetModified(rootDef, TRUE);
 
-    UndoDisable();
     if (f != NULL) fclose(f);
+    UndoEnable();
 }
