@@ -26,7 +26,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/lef/lefRead.c,v 1.0 2003/0
 #include <stdarg.h>
 #include <sys/time.h>
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -460,20 +460,184 @@ LefLower(token)
     return token;
 }
 
+/*
+ *------------------------------------------------------------
+ * LefReadLayer --
+ *
+ *	Read a LEF "LAYER" record from the file, and
+ *	match the LEF layer to a magic tile type.
+ *	If "obstruct" is TRUE, returns the layer mapping
+ *	for obstruction geometry as defined in the
+ *	technology file (if it exists).
+ *
+ * Results:
+ *	Returns a magic TileType or -1 if no matching
+ *	tile type is found.
+ *
+ * Side Effects:
+ *	Reads input from file f;
+ *
+ *------------------------------------------------------------
+ */
+
+TileType
+LefReadLayer(f, obstruct)
+    FILE *f;
+    bool obstruct;
+{
+    char *token;
+    TileType curlayer = -1;
+
+    token = LefNextToken(f, TRUE);
+    if (*token == ';')
+    {
+	LefError("Bad Layer statement\n");
+	return -1;
+    }
+    else
+    {
+	HashEntry *he = HashLookOnly(&LefInfo, token);
+	if (he)
+	{
+	    lefLayer *lefl = (lefLayer *)HashGetValue(he);
+	    if (obstruct)
+	    {
+		/* Use the obstruction type, if it is defined */
+		curlayer = lefl->obsType;
+		if (curlayer < 0)
+		    curlayer = lefl->type;
+	    }
+	    else
+		curlayer = lefl->type;
+	}
+	else
+	{
+	    /* fallback: compare name to magic types */
+
+	    curlayer = DBTechNameType(token);
+	    if (curlayer < 0)
+	    {
+		(void) LefLower(token);
+		curlayer = DBTechNameType(token);
+	    }
+	}
+	if (curlayer < 0)
+	{
+	    LefError("Don't know how to parse layer \"%s\"\n", token);
+	    LefError("Try adding this name to the LEF techfile section\n");
+	}
+    }
+    return curlayer;
+}
+
+/*
+ *------------------------------------------------------------
+ * LefReadRect --
+ *
+ *	Read a LEF "RECT" record from the file, and
+ *	return a Rect in magic coordinates.
+ *
+ * Results:
+ *	Returns a pointer to a Rect containing the magic
+ *	coordinates, or NULL if an error occurred.
+ *
+ * Side Effects:
+ *	Reads input from file f;
+ *
+ * Note:
+ *	LEF/DEF does NOT define a RECT record as having (...)
+ *	pairs, only routes.  However, at least one DEF file
+ *	contains this syntax, so it is checked.
+ *
+ *------------------------------------------------------------
+ */
+
+Rect *
+LefReadRect(f, curlayer, oscale)
+    FILE *f;
+    TileType curlayer;
+    float oscale;
+{
+    char *token;
+    float llx, lly, urx, ury; 
+    static Rect paintrect;
+    bool needMatch = FALSE;
+
+    token = LefNextToken(f, TRUE);
+    if (*token == '(')
+    {
+	token = LefNextToken(f, TRUE);
+	needMatch = TRUE;
+    }
+    if (!token || sscanf(token, "%f", &llx) != 1) goto parse_error;
+    token = LefNextToken(f, TRUE);
+    if (!token || sscanf(token, "%f", &lly) != 1) goto parse_error;
+    token = LefNextToken(f, TRUE);
+    if (needMatch)
+    {
+	if (*token != ')') goto parse_error;
+	else token = LefNextToken(f, TRUE);
+	needMatch = FALSE;
+    }
+    if (*token == '(')
+    {
+	token = LefNextToken(f, TRUE);
+	needMatch = TRUE;
+    }
+    if (!token || sscanf(token, "%f", &urx) != 1) goto parse_error;
+    token = LefNextToken(f, TRUE);
+    if (!token || sscanf(token, "%f", &ury) != 1) goto parse_error;
+    if (needMatch)
+    {
+	token = LefNextToken(f, TRUE);
+	if (*token != ')') goto parse_error;
+    }
+    if (curlayer < 0)
+	LefError("No layer defined for RECT.\n");
+    else
+    {
+	/* Scale coordinates (microns to magic internal units)	*/
+	/* Need to scale grid if necessary!			*/
+		
+	paintrect.r_xbot = (int)(llx / oscale);
+	paintrect.r_ybot = (int)(lly / oscale);
+	paintrect.r_xtop = (int)(urx / oscale);
+	paintrect.r_ytop = (int)(ury / oscale);
+
+	/* Diagnostic */
+	/*
+	TxPrintf("   Painting %s at (%d, %d), (%d, %d) in cell %s.\n",
+		DBTypeLongNameTbl[curlayer],
+		paintrect.r_xbot, paintrect.r_ybot,
+		paintrect.r_xtop, paintrect.r_ytop,
+		lefMacro->cd_name);
+	*/
+    }
+    return (&paintrect);
+
+parse_error:
+    LefError("Bad port geometry: RECT requires 4 values.\n");
+    return (Rect *)NULL;
+}
+
 /*
  *------------------------------------------------------------
  * LefReadGeometry --
  *
  *	Read Geometry information from a LEF file.
  *	Used for PORT records and OBS statements.
- *	pinNum should be -1 for reading obstruction
- *	geometry.
  *
  * Results:
  *	Returns a linked list of all areas and types
  *	painted.  However, if "do_list" is FALSE, then
  *	LefReadGeometry always returns NULL.
  *
+ *	Note that do_list is always TRUE for PORT
+ *	records and FALSE for OBS statements, and so in
+ *	addition to determining what the return value is,
+ *	it also determines what layer is returned by
+ *	function LefReadLayer().
+ *
  * Side Effects:
  *	Reads input from file f;
  *	Paints into the CellDef lefMacro.
@@ -495,9 +659,8 @@ LefReadGeometry(lefMacro, f, oscale, do_list)
 
     char *token;
     int keyword;
-    float llx, lly, urx, ury;
-    Rect paintrect;
     linkedRect *newRect, *rectList;
+    Rect *paintrect;
 
     static char *geometry_keys[] = {
 	"LAYER",
@@ -524,31 +687,8 @@ LefReadGeometry(lefMacro, f, oscale, do_list)
 	switch (keyword)
 	{
 	    case LEF_LAYER:
-		token = LefNextToken(f, TRUE);
-		if (*token == ';')
-		    LefError("Bad Layer statement\n");
-		else
-		{
-		    /* NOTE:  magic-to-LEF layer mappings should be	*/
-		    /* declared in the technology file as aliases for	*/
-		    /* magic layer names.  The primary type is case-	*/
-		    /* sensitive, but this routine will also check the	*/
-		    /* lowercase equivalent (prevents having to add	*/
-		    /* entries for things like METAL1, etc.).		*/
-
-		    curlayer = DBTechNameType(token);
-		    if (curlayer < 0)
-		    {
-			(void) LefLower(token);
-			curlayer = DBTechNameType(token);
-		    }
-		    if (curlayer < 0)
-		    {
-			LefError("Don't know how to parse layer \"%s\"\n", token);
-			LefError("Try adding this name to the technology styles\n");
-		    }
-		    LefEndStatement(f);
-		}
+		curlayer = LefReadLayer(f, (do_list) ? FALSE : TRUE);
+		LefEndStatement(f);
 		break;
 	    case LEF_WIDTH:
 		LefEndStatement(f);
@@ -557,54 +697,25 @@ LefReadGeometry(lefMacro, f, oscale, do_list)
 		LefEndStatement(f);
 		break;
 	    case LEF_RECT:
-		token = LefNextToken(f, TRUE);
-		if (!token || sscanf(token, "%f", &llx) != 1) goto parse_error;
-		token = LefNextToken(f, TRUE);
-		if (!token || sscanf(token, "%f", &lly) != 1) goto parse_error;
-		token = LefNextToken(f, TRUE);
-		if (!token || sscanf(token, "%f", &urx) != 1) goto parse_error;
-		token = LefNextToken(f, TRUE);
-		if (!token || sscanf(token, "%f", &ury) != 1) goto parse_error;
-		if (curlayer < 0)
-		    LefError("No layer defined for RECT.\n");
-		else
+		paintrect = LefReadRect(f, curlayer, oscale);
+		if (paintrect)
 		{
-		    /* Scale coordinates (microns to magic internal units) */
-		    /* Need to scale grid if necessary!			   */
-		
-		    paintrect.r_xbot = (int)(llx / oscale);
-		    paintrect.r_ybot = (int)(lly / oscale);
-		    paintrect.r_xtop = (int)(urx / oscale);
-		    paintrect.r_ytop = (int)(ury / oscale);
+		    /* Paint the area, if a CellDef is defined */
+		    if (lefMacro)
+			DBPaint(lefMacro, paintrect, curlayer);
 
-		    /* Paint the area */
-		    DBPaint(lefMacro, &paintrect, curlayer);
-
-		    /* Remember the area */
+		    /* Remember the area and layer */
 		    if (do_list)
 		    {
 			newRect = (linkedRect *)mallocMagic(sizeof(linkedRect));
 			newRect->type = curlayer;
-			newRect->area = paintrect;
+			newRect->area = *paintrect;
 			newRect->rect_next = rectList;
 			rectList = newRect;
 		    }
-
-		    /* Diagnostic */
-		    /*
-		    TxPrintf("   Painting %s at (%d, %d), (%d, %d) in cell %s.\n",
-			DBTypeLongNameTbl[curlayer],
-			paintrect.r_xbot, paintrect.r_ybot,
-			paintrect.r_xtop, paintrect.r_ytop,
-			lefMacro->cd_name);
-		    */
 		}
 		LefEndStatement(f);
 		break;
-parse_error:
-		LefError("Bad port geometry: RECT requires 4 values.\n");
-		LefEndStatement(f);
-		break;
 	    case LEF_POLYGON:
 		LefEndStatement(f);
 		break;
@@ -1032,6 +1143,145 @@ origin_error:
     /* DBCellSetModified(lefMacro, TRUE); */
 }
 
+/*
+ *------------------------------------------------------------
+ *
+ * LefReadLayerSection --
+ *
+ *	Read in a LAYER, VIA, or VIARULE section from a LEF file.
+ *
+ * Results:
+ *	None.
+ *
+ * Side Effects:
+ *	Adds to the LEF layer info hash table.
+ *
+ *------------------------------------------------------------
+ */
+
+enum lef_layer_keys {LEF_LAYER_TYPE=0, LEF_LAYER_WIDTH, LEF_LAYER_SPACING,
+	LEF_LAYER_PITCH, LEF_LAYER_DIRECTION, LEF_LAYER_OFFSET,
+	LEF_VIA_DEFAULT, LEF_VIA_LAYER, LEF_VIA_RECT,
+	LEF_VIARULE_VIA, LEF_LAYER_END};
+
+void
+LefReadLayerSection(f, lname, mode, lefl)
+    FILE *f;			/* LEF file being read	  */
+    char *lname;		/* name of the layer 	  */
+    int mode;			/* layer, via, or viarule */
+    lefLayer *lefl;		/* pointer to layer info  */
+{
+    char *token;
+    int keyword, typekey;
+    Rect viaArea, *currect;
+    TileType curlayer = -1;
+    float fvalue, oscale;
+
+    static char *layer_type_keys[] = {
+	"MASTERSLICE",
+	"OVERLAP",
+	"ROUTING",
+	"CUT",
+	NULL
+    };
+
+    static char *layer_keys[] = {
+	"TYPE",
+	"WIDTH",
+	"SPACING",
+	"PITCH",
+	"DIRECTION",
+	"OFFSET",
+	"DEFAULT",
+	"LAYER",
+	"RECT",
+	"VIA",
+	"END",
+	NULL
+    };
+
+    oscale = CIFGetOutputScale(1000);
+    viaArea = GeoNullRect;
+
+    while ((token = LefNextToken(f, TRUE)) != NULL)
+    {
+	keyword = Lookup(token, layer_keys);
+	if (keyword < 0)
+	{
+	    LefError("Unknown keyword \"%s\" in LEF file; ignoring.\n", token);
+	    LefEndStatement(f);
+	    continue;
+	}
+	switch (keyword)
+	{
+	    case LEF_LAYER_TYPE:
+		token = LefNextToken(f, TRUE);
+		if (*token != '\n')
+		{
+		    typekey = Lookup(token, layer_type_keys);
+		    if (typekey < 0)
+			LefError("Unknown layer type \"%s\" in LEF file; "
+				"ignoring.\n", token);
+		}
+		LefEndStatement(f);
+		break;
+	    case LEF_LAYER_WIDTH:
+		token = LefNextToken(f, TRUE);
+		sscanf(token, "%f", &fvalue);
+		lefl->info.route.width = (int)(fvalue / oscale);
+		LefEndStatement(f);
+		break;
+	    case LEF_LAYER_SPACING:
+		token = LefNextToken(f, TRUE);
+		sscanf(token, "%f", &fvalue);
+		lefl->info.route.spacing = (int)(fvalue / oscale);
+		LefEndStatement(f);
+		break;
+	    case LEF_LAYER_PITCH:
+		token = LefNextToken(f, TRUE);
+		sscanf(token, "%f", &fvalue);
+		lefl->info.route.pitch = (int)(fvalue / oscale);
+		LefEndStatement(f);
+		break;
+	    case LEF_LAYER_DIRECTION:
+		token = LefNextToken(f, TRUE);
+		LefLower(token);
+		lefl->info.route.hdirection = (token[0] == 'h') ? TRUE : FALSE;
+		LefEndStatement(f);
+		break;
+	    case LEF_LAYER_OFFSET:
+		LefEndStatement(f);
+		break;
+	    case LEF_VIA_DEFAULT:
+		/* Do nothing; especially, don't look for end-of-statement! */
+		break;
+	    case LEF_VIA_LAYER:
+		curlayer = LefReadLayer(f, FALSE);
+		LefEndStatement(f);
+		break;
+	    case LEF_VIA_RECT:
+		currect = LefReadRect(f, curlayer, oscale);
+		GeoInclude(currect, &viaArea);
+		if ((lefl->type < 0) || DBIsContact(curlayer))
+		    lefl->type = curlayer;
+		lefl->info.via.area = viaArea;
+		LefEndStatement(f);
+		break;
+	    case LEF_VIARULE_VIA:
+		LefEndStatement(f);
+		break;
+	    case LEF_LAYER_END:
+		if (!LefParseEndStatement(f, lname))
+		{
+		    LefError("Layer END statement missing.\n");
+		    keyword = -1;
+		}
+		break;
+	}
+	if (keyword == LEF_LAYER_END) break;
+    }
+}
+
 /*
  *------------------------------------------------------------
  *
@@ -1067,6 +1317,8 @@ LefRead(inName)
     char tsave[128];
     int keyword;
     float oscale;
+    HashEntry *he;
+    lefLayer *lefl;
 
     static char *sections[] = {
 	"VERSION",
@@ -1136,24 +1388,83 @@ LefRead(inName)
 	    case LEF_UNITS:
 		LefSkipSection(f, sections[LEF_UNITS]);
 		break;
-	    case LEF_SECTION_LAYER:
-		token = LefNextToken(f, TRUE);
-		TxPrintf("LEF file:  Defines layer %s (ignored)\n", token);
-		sprintf(tsave, "%.127s", token);
-		LefSkipSection(f, tsave);
-		break;
+
 	    case LEF_SECTION_VIA:
-		token = LefNextToken(f, TRUE);
-		TxPrintf("LEF file:  Defines via %s (ignored)\n", token);
-		sprintf(tsave, "%.127s", token);
-		LefSkipSection(f, tsave);
-		break;
 	    case LEF_SECTION_VIARULE:
 		token = LefNextToken(f, TRUE);
-		TxPrintf("LEF file:  Defines via rule %s (ignored)\n", token);
 		sprintf(tsave, "%.127s", token);
-		LefSkipSection(f, tsave);
+		he = HashFind(&LefInfo, token);
+		lefl = (lefLayer *)HashGetValue(he);
+		if (lefl == NULL)
+		{
+		    lefl = (lefLayer *)mallocMagic(sizeof(lefLayer));
+		    lefl->type = -1;
+		    lefl->obsType = -1;
+		    lefl->refCnt = 1;
+		    lefl->is_via = TRUE;
+		    lefl->info.via.area = GeoNullRect;
+		    lefl->info.via.cell = (CellDef *)NULL;
+		    HashSetValue(he, lefl);
+		}
+		LefReadLayerSection(f, tsave, keyword, lefl);
 		break;
+
+	    case LEF_SECTION_LAYER:
+		token = LefNextToken(f, TRUE);
+		sprintf(tsave, "%.127s", token);
+		he = HashLookOnly(&LefInfo, token);
+		if (he == NULL)
+		{
+		    TileType mtype = DBTechNameType(token);
+		    if (mtype < 0)
+			mtype = DBTechNameType(LefLower(token));
+		    if (mtype < 0)
+		    {
+			LefError("Layer %s cannot be mapped to any magic layer!\n",
+				token);
+			LefSkipSection(f, tsave);
+			break;
+		    }
+		    else if (DBIsContact(mtype) && (keyword == LEF_SECTION_LAYER))
+		    {
+			LefError("Layer %s maps to a magic contact layer; "
+				"must be defined in lef section of techfile\n",
+				token);
+			LefSkipSection(f, tsave);
+			break;
+		    }
+		    else if (!DBIsContact(mtype) && (keyword != LEF_SECTION_LAYER))
+		    {
+			LefError("Via %s maps to a non-contact magic layer; "
+				"must be defined in lef section of techfile\n",
+				token);
+			LefSkipSection(f, tsave);
+			break;
+		    }
+		    else
+		    {
+			he = HashFind(&LefInfo, token);
+			lefl = (lefLayer *)mallocMagic(sizeof(lefLayer));
+			lefl->type = mtype;
+			lefl->obsType = -1;
+			lefl->refCnt = 1;
+			lefl->is_via = DBIsContact(mtype);
+			HashSetValue(he, lefl);
+		    }
+		}
+		else
+		{
+		    lefl = (lefLayer *)HashGetValue(he);
+		    if (lefl->type < 0)
+		    {
+			LefError("Layer %s is only defined for obstructions!\n", token);
+			LefSkipSection(f, tsave);
+			break;
+		    }
+		}
+		LefReadLayerSection(f, tsave, keyword, lefl);
+		break;
+
 	    case LEF_SECTION_SPACING:
 		LefSkipSection(f, sections[LEF_SECTION_SPACING]);
 		break;
@@ -1209,6 +1520,6 @@ LefRead(inName)
     /* Cleanup */
     HashKill(&LefCellTable);
     HashKill(&lefDefInitHash);
-    UndoDisable();
     if (f != NULL) fclose(f);
+    UndoEnable();
 }
