@@ -23,7 +23,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/lef/lefWrite.c,v 1.0 2003/
 #endif
 #include <errno.h>
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
