@@ -54,6 +54,9 @@ static char rcsid[]="$Header: /ufs/repository/magic/main/main.c,v 1.6 2001/08/14
 #ifdef ROUTE_MODULE
 #include "router/router.h"
 #endif
+#ifdef LEF_MODULE
+#include "lef/lef.h"
+#endif
 #include "extract/extract.h"
 #include "undo/undo.h"
 #include "netmenu/netmenu.h"
@@ -70,6 +73,9 @@ static char rcsid[]="$Header: /ufs/repository/magic/main/main.c,v 1.6 2001/08/14
 #include "mzrouter/mzrouter.h"
 #endif
 #include "lisp/lisp.h"
+#ifdef THREE_D
+#include "graphics/wind3d.h"
+#endif
 
 
 /*
@@ -88,7 +94,6 @@ global char	*SysLibPath = NULL;	/* Used to find color maps, styles, */
 
 global bool mainDebug = FALSE;
 
-
 /*
  * See the file main.h for a description of the information kept
  * pertaining to the edit cell.
@@ -160,9 +165,9 @@ char *mainArg();
  * ----------------------------------------------------------------------------
  */
 
-global
+void
 MainExit(errNum)
-int errNum;
+    int errNum;
 {
 #ifdef	MOCHA
     MochaExit(errNum);
@@ -190,7 +195,7 @@ int errNum;
  *	Process command line arguments
  *
  * Results:
- *	None.
+ *	Return 0 on success, 1 on failure
  *
  * Side effects:
  *	Global variables are modified
@@ -205,8 +210,8 @@ int errNum;
 
 int
 mainDoArgs(argc, argv)
-int argc;
-char **argv;
+    int argc;
+    char **argv;
 {
     bool haveDashI = FALSE;
     char *cp;
@@ -354,7 +359,7 @@ exitnow:
  * a '-').
  *
  * Results:
- *	None.
+ *	Return pointer to the argument string.
  *
  * Side effects:
  *	See the comments in ArgStr() in the utils module -- they
@@ -381,7 +386,6 @@ mainArg(pargc, pargv, mesg)
 	TxError("Bad name after '-%c' option: '%s'\n", option, cp);
 	return (char *) NULL;
     }
-
     return cp;
 }
 
@@ -393,7 +397,7 @@ mainArg(pargc, pargv, mesg)
  *	Initializes things before argument processing.
  *
  * Results:
- *	None.
+ *	0 on success.  As written, there are no failure modes.
  *
  * Side effects:
  *	All sorts of initialization.  Most initialization, however, is done
@@ -445,7 +449,8 @@ mainInitBeforeArgs(argc, argv)
  *	Initializes things after argument processing.
  *
  * Results:
- *	None.
+ *	Status: 0 = success, 1 = failure to set graphics display,
+ *	2 = failure to load technology file.
  *
  * Side effects:
  *	All sorts of initialization.
@@ -455,7 +460,7 @@ mainInitBeforeArgs(argc, argv)
 int
 mainInitAfterArgs()
 {
-    Void (*nullProc)() = 0;
+    int (*nullProc)() = 0;
     SectionID sec_tech, sec_planes, sec_types, sec_styles;
     SectionID sec_connect, sec_contact, sec_compose;
     SectionID sec_cifinput, sec_cifoutput;
@@ -480,6 +485,11 @@ mainInitAfterArgs()
     LispSetTech (TechDefault);
 #endif
 
+#ifdef LEF_MODULE
+    /* Pre-techfile-loading intialization of the LEF module */
+    LefInit();
+#endif
+
     /* TxPrintf("Using technology \"%s\".\n", TechDefault); */
 
     /*
@@ -521,6 +531,8 @@ mainInitAfterArgs()
 			DBTechAddContact, DBTechFinalContact,
 			sec_types|sec_planes, &sec_contact, FALSE);
 
+    TechAddAlias("contact", "images");
+
     TechAddClient("compose", DBTechInitCompose,
 			DBTechAddCompose, DBTechFinalCompose,
 			sec_types|sec_planes|sec_contact, &sec_compose, FALSE);
@@ -544,10 +556,10 @@ mainInitAfterArgs()
 #endif
 #ifdef ROUTE_MODULE
     TechAddClient("mzrouter", MZTechInit, MZTechLine, MZTechFinal,
-			sec_types|sec_planes, &sec_mzrouter, FALSE);
+			sec_types|sec_planes, &sec_mzrouter, TRUE);
 #else
     TechAddClient("mzrouter", nullProc,nullProc,nullProc,
-			sec_types|sec_planes, &sec_mzrouter, FALSE);
+			sec_types|sec_planes, &sec_mzrouter, TRUE);
 #endif
     TechAddClient("drc", DRCTechInit, DRCTechAddRule, DRCTechFinal,
 			sec_types|sec_planes, &sec_drc, FALSE);
@@ -555,11 +567,14 @@ mainInitAfterArgs()
 			(SectionID) 0, (SectionID *) 0, FALSE);
 #ifdef ROUTE_MODULE
     TechAddClient("drc", MZDRCInit, MZDRCLine, nullProc,
-			sec_mzrouter, (SectionID *) 0, FALSE);
-#else
-    TechAddClient("drc", nullProc,nullProc,nullProc,
-			sec_mzrouter, (SectionID *) 0, FALSE);
+			sec_types|sec_planes, (SectionID *) 0, TRUE);
 #endif
+
+#ifdef LEF_MODULE
+    TechAddClient("lef", LefTechInit, LefTechLine, nullProc,
+			sec_types|sec_planes, (SectionID *) 0, TRUE);
+#endif
+
 #ifdef NO_EXT
     TechAddClient("extract", nullProc, nullProc,nullProc,
 			sec_types|sec_connect, &sec_extract, FALSE);
@@ -569,23 +584,23 @@ mainInitAfterArgs()
 #endif
 	
     TechAddClient("wiring", WireTechInit, WireTechLine, WireTechFinal,
-			sec_types, &sec_wiring, FALSE);
+			sec_types, &sec_wiring, TRUE);
 
 #ifdef ROUTE_MODULE
     TechAddClient("router", RtrTechInit, RtrTechLine, RtrTechFinal,
-			sec_types, &sec_router, FALSE);
+			sec_types, &sec_router, TRUE);
 #else
     TechAddClient("router", nullProc,nullProc,nullProc,
-			sec_types, &sec_router, FALSE);
+			sec_types, &sec_router, TRUE);
 #endif
     TechAddClient("plowing", PlowTechInit, PlowTechLine, PlowTechFinal,
-			sec_types|sec_connect|sec_contact, &sec_plow, FALSE);
+			sec_types|sec_connect|sec_contact, &sec_plow, TRUE);
 #ifdef PLOT_MODULE
     TechAddClient("plot", PlotTechInit, PlotTechLine, PlotTechFinal,
-			sec_types, &sec_plot, FALSE);
+			sec_types, &sec_plot, TRUE);
 #else
     TechAddClient("plot", nullProc,nullProc,nullProc,
-			sec_types, &sec_plot, FALSE);
+			sec_types, &sec_plot, TRUE);
 #endif
 
     /* Load the technology file */
@@ -674,7 +689,7 @@ mainInitAfterArgs()
  *	specified.
  *
  * Results:
- *	None.
+ *	Return 0 on success.  As written, there is no failure mode.
  *
  * Side effects:
  *	All sorts of initialization.
@@ -755,6 +770,7 @@ mainInitFinal()
 
     return 0;
 }
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -771,6 +787,7 @@ mainInitFinal()
  * ----------------------------------------------------------------------------
  */
 
+void
 mainFinished()
 {
     /* Close up things */
