@@ -76,6 +76,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzBlock.c,v 1.2 2
 #include "mzrouter/mzrouter.h"
 #include "mzrouter/mzInternal.h"
 
+/* Forward declarations */
+extern void mzPaintBlock();
+extern void mzPaintSameNodeBlock();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -110,6 +114,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzBlock.c,v 1.2 2
  * ----------------------------------------------------------------------------
  */
 
+void
 mzBuildMaskDataBlocks(buildArea)
     Rect *buildArea;	/* Area over which blockage planes will be built */
 {
@@ -188,11 +193,11 @@ mzBuildMaskDataBlocks(buildArea)
 int
 mzBuildBlockFunc(tile, cxp)
 
-    register Tile *tile;
-    register TreeContext *cxp;
+    Tile *tile;
+    TreeContext *cxp;
 {
-    register SearchContext *scx = cxp->tc_scx;
-    register Rect *buildArea = (Rect *) (cxp->tc_filter->tf_arg);
+    SearchContext *scx = cxp->tc_scx;
+    Rect *buildArea = (Rect *) (cxp->tc_filter->tf_arg);
     Rect r, rDest;
 
     /* Transform to result coordinates */
@@ -240,11 +245,11 @@ mzBuildBlockFunc(tile, cxp)
 
 int
 mzBlockSubcellsFunc(scx, cdarg)
-    register SearchContext *scx;
-    register ClientData cdarg;
+    SearchContext *scx;
+    ClientData cdarg;
 {
     Rect r, rDest;
-    register Rect *buildArea = (Rect *) cdarg;
+    Rect *buildArea = (Rect *) cdarg;
 
     /* Transform bounding box to result coords */
     r = scx->scx_use->cu_def->cd_bbox;
@@ -287,13 +292,13 @@ mzBlockSubcellsFunc(scx, cdarg)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 mzPaintBlock(r, type, buildArea)
-    register Rect *r;
-    register TileType type;
-    register Rect *buildArea;
+    Rect *r;
+    TileType type;
+    Rect *buildArea;
 {
-    register RouteType *rT;
+    RouteType *rT;
 
     /* process routeTypes  */
     for (rT=mzActiveRTs; rT!=NULL; rT=rT->rt_nextActive)
@@ -354,13 +359,13 @@ mzPaintBlock(r, type, buildArea)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 mzPaintSameNodeBlock(r, type, buildArea)
-    register Rect *r;
-    register TileType type;
-    register Rect *buildArea;
+    Rect *r;
+    TileType type;
+    Rect *buildArea;
 {
-    register RouteType *rT;
+    RouteType *rT;
 
     /* process routeTypes  */
     for (rT=mzActiveRTs; rT!=NULL; rT=rT->rt_nextActive)
@@ -419,8 +424,9 @@ mzPaintSameNodeBlock(r, type, buildArea)
  * ----------------------------------------------------------------------------
  */
 
+void
 mzBuildFenceBlocks(buildArea)
-    register Rect *buildArea;		/* Area over which planes modified */
+    Rect *buildArea;		/* Area over which planes modified */
 {
     int mzBuildFenceBlocksFunc();
     Rect searchArea;
@@ -478,11 +484,11 @@ mzBuildFenceBlocks(buildArea)
 
 int
 mzBuildFenceBlocksFunc(tile, buildArea)
-    register Tile *tile;
-    register Rect *buildArea; /* clip to this area before painting */
+    Tile *tile;
+    Rect *buildArea; /* clip to this area before painting */
 {
-    register RouteType *rT;
-    register int d;
+    RouteType *rT;
+    int d;
     Rect r, rAdjusted; 
 
     /* Get boundary of tile */
@@ -536,7 +542,7 @@ mzBuildFenceBlocksFunc(tile, buildArea)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 mzExtendBlockBoundsR(rect)
     Rect *rect;
 {
@@ -604,17 +610,17 @@ mzExtendBlockBoundsR(rect)
  * generated.
  *
  * Results:
- *	None.
+ *	Return 0 always (to continue the search)
  *
  * Side effects:
  *	Paints into Blockage planes in RouteTypes
  *
  * ----------------------------------------------------------------------------
  */
-    /*ARGSUSED*/
+
 int
 mzExtendBlockFunc(tile, cdarg)
-    register Tile *tile;
+    Tile *tile;
     ClientData cdarg;
 {
     Rect area;
@@ -672,7 +678,7 @@ mzExtendBlockFunc(tile, cdarg)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 mzExtendBlockBounds(point)
     Point *point;
 {
@@ -726,7 +732,7 @@ List *mzWalkList;
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 mzBuildDestAreaBlocks()
 {
 
@@ -845,18 +851,15 @@ mzBuildDestAreaBlocks()
  * Side effects:
  *	Generates blockage info.
  *
- * Results:
- *	Returns 0 always.
- *
  * ----------------------------------------------------------------------------
  */
 
 int
 mzDestAreaFunc(tile, cxp)
-    register Tile *tile;
-    register TreeContext *cxp;
+    Tile *tile;
+    TreeContext *cxp;
 {
-    register SearchContext *scx = cxp->tc_scx;
+    SearchContext *scx = cxp->tc_scx;
     TileType type = TiGetType(tile);
     Rect r, rect;
     RouteType *rT;
@@ -946,7 +949,7 @@ mzDestAreaFunc(tile, cxp)
 
 int
 mzHWalksFunc(tile, cdarg)
-    register Tile *tile;
+    Tile *tile;
     ClientData cdarg;
 {
     RouteType *rT = (RouteType *) cdarg;
@@ -1035,7 +1038,7 @@ mzHWalksFunc(tile, cdarg)
 
 int
 mzVWalksFunc(tile, cdarg)
-    register Tile *tile;
+    Tile *tile;
     ClientData cdarg;
 {
     RouteType  *rT = (RouteType *) cdarg;
@@ -1117,18 +1120,15 @@ mzVWalksFunc(tile, cdarg)
  * Side effects:
  *	Generates blockage info.
  *
- * Results:
- *	Returns 0 always.
- *
  * ----------------------------------------------------------------------------
  */
 
 int
 mzCWalksFunc(tile, cxp)
-    register Tile *tile;
-    register TreeContext *cxp;
+    Tile *tile;
+    TreeContext *cxp;
 {
-    register SearchContext *scx = cxp->tc_scx;
+    SearchContext *scx = cxp->tc_scx;
     TileType type = TiGetType(tile);
     Rect r, rect;
     RouteType *rT;
@@ -1199,7 +1199,7 @@ typedef struct walkContactFuncData
 
 int
 mzCWalksFunc2(tile, cdarg)
-    register Tile *tile;
+    Tile *tile;
     ClientData cdarg;
 {
     RouteType *rT = (RouteType *) cdarg; /* RouteType of this dest area */
@@ -1280,7 +1280,7 @@ mzCWalksFunc2(tile, cdarg)
 
 int
 mzCWalksFunc3(tile, cdarg)
-    register Tile *tile;
+    Tile *tile;
     ClientData cdarg;
 {
     WalkContactFuncData *wD = (WalkContactFuncData *) cdarg;
