@@ -28,6 +28,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzMain.c,v 1.2 20
 
 /*--- includes --- */
 #include <stdio.h>
+#include <string.h>
+
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -265,6 +267,7 @@ if (TRUE) \
  *
  * ----------------------------------------------------------------------------
  */
+
 MazeParameters *
 MZCopyParms(oldParms)
     MazeParameters *oldParms;	/* Maze routing parameters */
@@ -411,6 +414,7 @@ MZCopyParms(oldParms)
  *
  * ----------------------------------------------------------------------------
  */
+
 MazeParameters *
 MZFindStyle(name)
 char *name;	/* name of style we are looking for */
@@ -452,7 +456,8 @@ char *name;	/* name of style we are looking for */
  *
  * ----------------------------------------------------------------------------
  */
-Void
+
+void
 MZInitRoute(parms, routeUse, expansionMask)
     MazeParameters *parms;	/* Maze routing parameters */
     CellUse *routeUse;		/* toplevel cell router sees */
@@ -564,7 +569,7 @@ MZInitRoute(parms, routeUse, expansionMask)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 MZAddStart(point, type)
     Point *point;
     TileType type;
@@ -670,7 +675,7 @@ MZAddStart(point, type)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 MZAddDest(rect, type)
     Rect *rect;
     TileType type;
@@ -711,6 +716,7 @@ MZAddDest(rect, type)
  *
  * ----------------------------------------------------------------------------
  */
+
 RoutePath *
 MZRoute()
 {
@@ -834,11 +840,12 @@ MZRoute()
  *
  * ----------------------------------------------------------------------------
  */
+
 CellUse *
 MZPaintPath(pathList)
     RoutePath *pathList;
 {
-    register RoutePath *path, *prev;
+    RoutePath *path, *prev;
 
     /*
      * Each segment of the path contains no bends, so is
@@ -913,7 +920,8 @@ MZPaintPath(pathList)
  *
  * ----------------------------------------------------------------------------
  */
-Void
+
+void
 MZClean()
 {
     if(mzDirty)
