@@ -146,6 +146,20 @@ static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzSearch.c,v 1.2
 #include "mzrouter/mzrouter.h"
 #include "mzrouter/mzInternal.h"
 
+/* Forward declarations */
+
+extern void mzExtendPath();
+extern void mzExtendViaContacts();
+extern void mzAddPoint();
+extern void mzBloomInit();
+extern void mzMakeStatReport();
+extern void mzExtendInitPath();
+extern void mzAddInitialContacts();
+extern void mzStartRight();
+extern void mzStartLeft();
+extern void mzStartUp();
+extern void mzStartDown();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -713,11 +727,11 @@ mzSearch()
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 mzExtendPath(path)
-    register RoutePath *path;
+    RoutePath *path;
 {
-    register int extendCode = path->rp_extendCode;
+    int extendCode = path->rp_extendCode;
 
     if (extendCode & EC_RIGHT)
     {
@@ -789,13 +803,14 @@ mzExtendPath(path)
  *
  * ----------------------------------------------------------------------------
  */
-Void
+
+void
 mzExtendViaContacts(path)
     RoutePath *path;
 {
-    register Point *p = &path->rp_entry;
-    register RouteLayer *rLayer = path->rp_rLayer; 
-    register List *cL;
+    Point *p = &path->rp_entry;
+    RouteLayer *rLayer = path->rp_rLayer; 
+    List *cL;
     RouteLayer *newRLayer;
 
     /* DEBUG - trace calls to this routine */
@@ -942,7 +957,7 @@ mzExtendViaContacts(path)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 mzAddPoint(path, p, rLayer, orient, extendCode, cost)
     RoutePath *path;	/* path that new point extends */
     Point *p;		/* new point */
@@ -954,9 +969,9 @@ mzAddPoint(path, p, rLayer, orient, extendCode, cost)
     DoubleInt cost;	/* Incremental cost of new path segment */
 
 {
-    register RoutePath *newPath;
+    RoutePath *newPath;
     RoutePath *hashedPath;
-    register HashEntry *he;
+    HashEntry *he;
     PointKey pk;
     DoubleInt togo;
 
@@ -1197,7 +1212,7 @@ mzAddPoint(path, p, rLayer, orient, extendCode, cost)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 mzBloomInit(path)
     RoutePath *path;	/* path that new point extends */
 {
@@ -1227,7 +1242,7 @@ mzBloomInit(path)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 mzMakeStatReport()
 {
     
