@@ -21,4 +21,4 @@
 
 #define _PARSER
 
-extern ParsSplit();
+extern bool ParsSplit();
