@@ -27,7 +27,7 @@ int err0 = Need_to_include_misc/magic_header;
 
 /* Technology-file reading procedures: */
 
-extern Void PlotTechInit();
+extern int PlotTechInit();
 extern bool PlotTechLine();
 extern bool PlotTechFinal();
 
