@@ -22,9 +22,11 @@
 static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowMain.c,v 1.3 2001/06/15 15:33:39 tim Exp $";
 #endif  /* not lint */
 
+#include <stdio.h>
+#include <string.h>
 #include <sys/time.h>
 #include <sys/resource.h>
-#include <stdio.h>
+
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -78,18 +80,18 @@ RuleTableEntry plowCellRulesTbl[MAXRULES];
 RuleTableEntry *plowCellRulesPtr = plowCellRulesTbl;
 
     /* Imported rules */
-extern Void prClearUmbra();
-extern Void prUmbra();
-extern Void prPenumbraTop(), prPenumbraBot();
-extern Void prFixedPenumbraTop(), prFixedPenumbraBot();
-extern Void prSliverTop(), prSliverBot();
-extern Void prInSliver();
-extern Void prIllegalTop(), prIllegalBot();
-extern Void prCoverTop(), prCoverBot();
-extern Void prFixedLHS(), prFixedRHS(), prFixedDragStubs();
-extern Void prContactLHS(), prContactRHS();
-extern Void prFindCells();
-extern Void prCell();
+extern int prClearUmbra();
+extern int prUmbra();
+extern int prPenumbraTop(), prPenumbraBot();
+extern int prFixedPenumbraTop(), prFixedPenumbraBot();
+extern int prSliverTop(), prSliverBot();
+extern int prInSliver();
+extern int prIllegalTop(), prIllegalBot();
+extern int prCoverTop(), prCoverBot();
+extern int prFixedLHS(), prFixedRHS(), prFixedDragStubs();
+extern int prContactLHS(), prContactRHS();
+extern int prFindCells();
+extern int prCell();
 
     /* Defined elsewhere in this module */
 extern CellDef *plowYankDef;
@@ -145,7 +147,16 @@ int plowMovedEdges;	/* Number of edges actually moved */
 int plowInitialPaint(), plowInitialCell();
 int plowUpdatePaintTile(), plowUpdateCell();
 PlowRule *plowBuildWidthRules();
-int PlowRedrawBound();
+
+extern void PlowRedrawBound();
+extern void PlowClearBound();
+extern void plowUpdate();
+extern void plowSetTrans();
+extern void plowProcessEdge();
+extern void plowMoveEdge();
+extern void plowMergeTop();
+extern void plowYankCreate();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -163,7 +174,7 @@ int PlowRedrawBound();
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 PlowSetBound(def, area, rootDef, rootArea)
     CellDef *def;	/* Def in which bounding area applies */
     Rect *area;		/* Area in 'def' coordinates */
@@ -209,7 +220,7 @@ PlowSetBound(def, area, rootDef, rootArea)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 PlowClearBound()
 {
     PlowBoundary *pb;
@@ -242,7 +253,7 @@ PlowClearBound()
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 PlowRedrawBound(window, plane)
     MagWindow *window;		/* Window in which to redraw. */
     Plane *plane;		/* Non-space tiles on this plane indicate
@@ -304,6 +315,7 @@ plowBoundAlways1()
  * ----------------------------------------------------------------------------
  */
 
+void
 PlowStraighten(def, area, direction)
     CellDef *def;	/* Def whose jogs we should straighten */
     Rect *area;		/* Area in which jogs are to be straightened */
@@ -528,7 +540,7 @@ Plow(def, userRect, layers, direction)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 plowUpdate(def, direction, pChangedArea)
     CellDef *def;
     int direction;
@@ -960,7 +972,7 @@ plowPropagateSel(def, pdistance, changedArea)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
+int
 plowSelPaintBox(rect, type, pSelBox)
     Rect *rect;
     TileType type;
@@ -973,7 +985,7 @@ plowSelPaintBox(rect, type, pSelBox)
     return (0);
 }
 
-    /*ARGSUSED*/
+int
 plowSelCellBox(selUse, realUse, transform, pSelBox)
     CellUse *selUse;
     CellUse *realUse;
@@ -1002,6 +1014,7 @@ plowSelCellBox(selUse, realUse, transform, pSelBox)
  * ----------------------------------------------------------------------------
  */
 
+int
 plowSelPaintPlow(rect, type, distance)
     Rect *rect;
     TileType type;
@@ -1068,7 +1081,7 @@ plowSelPaintAdd(edge)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
+int
 plowSelCellPlow(selUse, realUse, transform, distance)
     CellUse *selUse;		/* Cell in selection */
     CellUse *realUse;		/* Corresponding cell in def being plowed */
@@ -1149,12 +1162,12 @@ plowFindSelCell(yankUse, editUse)
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 PlowExtendJogHorizon(edge)
     Edge *edge;			/* Edge being moved */
 {
     int horizonTop, horizonBot, eTop, eBot;
-    register Tile *tpR, *tpL;
+    Tile *tpR, *tpL;
     Point startPoint;
     bool rhsChanged;
     Rect r, newEdgeR;
@@ -1184,7 +1197,7 @@ restarttop:
      */
     rhsChanged = FALSE;
     while (RIGHT(tpL) == edge->e_x
-	    && TiGetRightType(tpL) == edge->e_ltype
+	    && TiGetTypeExact(tpL) == edge->e_ltype
 	    && BOTTOM(tpL) < horizonTop)
     {
 	r.r_ytop = TOP(tpL);
@@ -1198,7 +1211,7 @@ restarttop:
 	 */
 	if (!rhsChanged)
 	    for (tpR = TR(tpL); TOP(tpR) > r.r_ybot; tpR = LB(tpR))
-		if (TiGetLeftType(tpR) != edge->e_rtype)
+		if (TiGetTypeExact(tpR) != edge->e_rtype)
 		    rhsChanged = TRUE, eTop = BOTTOM(tpR);
 	tpL = RT(tpL);
 	r.r_ybot = r.r_ytop;
@@ -1234,12 +1247,12 @@ restartbot:
 	    goto restartbot;
 
 	/* Record where the RHS type changed if it did */
-	if (!rhsChanged && TiGetLeftType(tpR) != edge->e_rtype)
+	if (!rhsChanged && TiGetTypeExact(tpR) != edge->e_rtype)
 	    rhsChanged = TRUE, eBot = TOP(tpR);
 
 	/* Walk up the LHS */
 	for (tpL = BL(tpR); BOTTOM(tpL) < r.r_ytop; tpL = RT(tpL))
-	    if (TiGetRightType(tpL) != edge->e_ltype)
+	    if (TiGetTypeExact(tpL) != edge->e_ltype)
 		r.r_ybot = TOP(tpL);
 
 	if (r.r_ybot > BOTTOM(tpR))
@@ -1284,8 +1297,11 @@ restartbot:
  *
  * Side effects:
  *	Sets plowYankTrans and plowInverseTrans.
+ *
+ * ----------------------------------------------------------------------------
  */
 
+void
 plowSetTrans(direction)
     int direction;
 {
@@ -1330,12 +1346,12 @@ plowSetTrans(direction)
 bool
 plowPastBoundary(def, edge, pmove)
     CellDef *def;		/* Def being plowed */
-    register Edge *edge;	/* Edge being moved */
-    register int *pmove;	/* Updated to be the maximum distance by
+    Edge *edge;	/* Edge being moved */
+    int *pmove;	/* Updated to be the maximum distance by
 				 * which something moves in an illegal area.
 				 */
 {
-    register PlowBoundary *pb;
+    PlowBoundary *pb;
     int delta;
     bool ret;
     Rect r;
@@ -1388,6 +1404,7 @@ plowPastBoundary(def, edge, pmove)
  * ----------------------------------------------------------------------------
  */
 
+int
 plowInitialPaint(edge, xnew)
     Edge *edge;
     int xnew;
@@ -1415,12 +1432,13 @@ plowInitialPaint(edge, xnew)
  * ----------------------------------------------------------------------------
  */
 
+int
 plowInitialCell(cellTile, plowRect)
     Tile *cellTile;
-    register Rect *plowRect;
+    Rect *plowRect;
 {
-    register CellTileBody *ctb;
-    register CellUse *use;
+    CellTileBody *ctb;
+    CellUse *use;
     int xmove;
     Edge edge;
 
@@ -1488,13 +1506,14 @@ plowInitialCell(cellTile, plowRect)
  * ----------------------------------------------------------------------------
  */
 
+void
 plowProcessEdge(edge, changedArea)
     Edge *edge;		/* Edge to be processed (in plowYankDef) */
     Rect *changedArea;	/* Include any additional area changed in this area */
 {
     int amountToMove = edge->e_newx - edge->e_x;
-    register RuleTableEntry *rte;
-    register Tile *tp;
+    RuleTableEntry *rte;
+    Tile *tp;
     Point p;
     Rect r;
 
@@ -1618,12 +1637,12 @@ worktodo:
  * ----------------------------------------------------------------------------
  */
 
-Void
+int
 plowApplySearchRules(edge)
     Edge *edge;
 {
     PlowRule *widthRules, *rules;
-    register RuleTableEntry *rte;
+    RuleTableEntry *rte;
     int halo;
 
     /*
@@ -1797,11 +1816,12 @@ retry:
  * ----------------------------------------------------------------------------
  */
 
+void
 plowMoveEdge(edge)
-    register Edge *edge;	/* Edge to be moved */
+    Edge *edge;	/* Edge to be moved */
 {
-    register Plane *plane = plowYankDef->cd_planes[edge->e_pNum];
-    register Tile *tp, *tpL;
+    Plane *plane = plowYankDef->cd_planes[edge->e_pNum];
+    Tile *tp, *tpL;
     Point p;
 
     /*
@@ -1914,9 +1934,9 @@ plowMoveEdge(edge)
 
 Tile *
 plowSplitY(tp, y)
-    register Tile *tp;
+    Tile *tp;
 {
-    register Tile *newTile;
+    Tile *newTile;
 
     newTile = TiSplitY(tp, y);
     newTile->ti_client = tp->ti_client;
@@ -1949,11 +1969,12 @@ plowSplitY(tp, y)
  * ----------------------------------------------------------------------------
  */
 
+void
 plowMergeTop(tp, plane)
-    register Tile *tp;
+    Tile *tp;
     Plane *plane;
 {
-    register Tile *tpRT = RT(tp);
+    Tile *tpRT = RT(tp);
 
     if (TiGetTypeExact(tp) == TiGetTypeExact(tpRT)
 	    && LEFT(tp) == LEFT(tpRT) && RIGHT(tp) == RIGHT(tpRT)
@@ -1964,10 +1985,10 @@ plowMergeTop(tp, plane)
 }
 
 plowMergeBottom(tp, plane)
-    register Tile *tp;
+    Tile *tp;
     Plane *plane;
 {
-    register Tile *tpLB = LB(tp);
+    Tile *tpLB = LB(tp);
 
     if (TiGetTypeExact(tp) == TiGetTypeExact(tpLB)
 	    && LEFT(tp) == LEFT(tpLB) && RIGHT(tp) == RIGHT(tpLB)
@@ -2006,6 +2027,7 @@ plowMergeBottom(tp, plane)
  * ----------------------------------------------------------------------------
  */
 
+void
 PlowInit()
 {
     RuleTableEntry *rp, *re;
@@ -2014,7 +2036,7 @@ PlowInit()
     TileTypeBitMask widthL, widthR;
     TileTypeBitMask spaceL, spaceR;
     TileTypeBitMask mask;
-    register TileType i, j;
+    TileType i, j;
 
     /* Set the masks we will use for all the rules below */
     allButSpace = DBAllButSpaceAndDRCBits;
@@ -2043,7 +2065,7 @@ PlowInit()
 
     /* Dummy rule for debugging */
     plowInitRule(&plowRuleInitial, (&plowRuleInitial) + 1, RTE_NULL,
-				(Void (*)()) NULL,
+				(int (*)()) NULL,
 				"initial edge",
 				DBZeroTypeBits, DBZeroTypeBits);
 
@@ -2168,7 +2190,7 @@ plowInitRule(rtePtr, rteEnd, whichRules, proc, name, ltypes, rtypes)
     RuleTableEntry *rtePtr;	/* Pointer to entry to be added */
     RuleTableEntry *rteEnd;	/* Pointer to one past last entry in table */
     int whichRules;		/* Which rules to use (RTE_* from earlier) */
-    Void (*proc)();		/* Procedure implementing the rule */
+    int (*proc)();		/* Procedure implementing the rule */
     char *name;			/* Name of this rule */
     TileTypeBitMask ltypes, rtypes;
 {
@@ -2202,6 +2224,7 @@ plowInitRule(rtePtr, rteEnd, whichRules, proc, name, ltypes, rtypes)
  * ----------------------------------------------------------------------------
  */
 
+void
 plowYankCreate()
 {
     if (plowYankDef == NULL)
