@@ -74,9 +74,9 @@ int plowPenumbraRule();
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 prClearUmbra(edge)
-    register Edge *edge;	/* Edge being moved */
+    Edge *edge;	/* Edge being moved */
 {
     TileTypeBitMask rhsTypes;
     struct applyRule ar;
@@ -120,12 +120,12 @@ prClearUmbra(edge)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 prUmbra(edge, rules)
     Edge *edge;		/* Edge being moved */
     PlowRule *rules;	/* List of rules */
 {
-    register PlowRule *pr;
+    PlowRule *pr;
     struct applyRule ar;
     Rect searchArea;
 
@@ -212,12 +212,12 @@ prUmbra(edge, rules)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 prPenumbraTop(edge, rules)
     Edge *edge;		/* Edge being moved */
     PlowRule *rules;	/* Rules to apply (must be non-NULL) */
 {
-    register PlowRule *pr;
+    PlowRule *pr;
     struct applyRule ar;
     Point startPoint;
 
@@ -235,13 +235,13 @@ prPenumbraTop(edge, rules)
     }
 }
 
-Void
+int
 prPenumbraBot(edge, rules)
     Edge *edge;		/* Edge being moved */
     PlowRule *rules;	/* Rules to apply (must be non-NULL) */
 {
     TileTypeBitMask insideTypes;
-    register PlowRule *pr;
+    PlowRule *pr;
     struct applyRule ar;
     Point startPoint;
 
@@ -299,11 +299,11 @@ prPenumbraBot(edge, rules)
 
 int
 plowPenumbraTopProc(outline, ar)
-    register Outline *outline;		/* Segment along penumbra border */
-    register struct applyRule *ar;	/* Info needed for shadow search */
+    Outline *outline;		/* Segment along penumbra border */
+    struct applyRule *ar;	/* Info needed for shadow search */
 {
-    register Edge *movingEdge = ar->ar_moving;
-    register PlowRule *pr = ar->ar_rule;
+    Edge *movingEdge = ar->ar_moving;
+    PlowRule *pr = ar->ar_rule;
     Rect searchArea;
     int ret = 0;
 
@@ -353,11 +353,11 @@ plowPenumbraTopProc(outline, ar)
 
 int
 plowPenumbraBotProc(outline, ar)
-    register Outline *outline;		/* Segment along penumbra border */
-    register struct applyRule *ar;	/* Info needed for shadow search */
+    Outline *outline;		/* Segment along penumbra border */
+    struct applyRule *ar;	/* Info needed for shadow search */
 {
-    register Edge *movingEdge = ar->ar_moving;
-    register PlowRule *pr = ar->ar_rule;
+    Edge *movingEdge = ar->ar_moving;
+    PlowRule *pr = ar->ar_rule;
     Rect searchArea;
     int ret = 0;
 
@@ -421,14 +421,15 @@ plowPenumbraBotProc(outline, ar)
  *	May queue the edge.
  */
 
+int
 plowPenumbraRule(impactedEdge, ar)
-    register Edge *impactedEdge;	/* Edge found by shadow search */
-    register struct applyRule *ar;	/* Edge causing the shadow search, and
+    Edge *impactedEdge;	/* Edge found by shadow search */
+    struct applyRule *ar;	/* Edge causing the shadow search, and
 					 * the design rule to apply.
 					 */
 {
-    register PlowRule *pr;
-    register Edge *movingEdge = ar->ar_moving;
+    PlowRule *pr;
+    Edge *movingEdge = ar->ar_moving;
     int newsep, oldsep, newx;
 
     oldsep = impactedEdge->e_x - movingEdge->e_x;
@@ -473,12 +474,12 @@ plowPenumbraRule(impactedEdge, ar)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 prSliverTop(edge, rules)
-    register Edge *edge;
+    Edge *edge;
     PlowRule *rules;
 {
-    register PlowRule *pr;
+    PlowRule *pr;
     struct applyRule ar;
     Point startPoint;
 
@@ -526,13 +527,13 @@ prSliverTop(edge, rules)
     }
 }
 
-Void
+int
 prSliverBot(edge, rules)
-    register Edge *edge;
+    Edge *edge;
     PlowRule *rules;
 {
     TileTypeBitMask insideTypes;
-    register PlowRule *pr;
+    PlowRule *pr;
     struct applyRule ar;
     Point startPoint;
 
@@ -614,8 +615,8 @@ prSliverBot(edge, rules)
 
 int
 plowSliverTopMove(outline, ar)
-    register Outline *outline;		/* Segment of outline being followed */
-    register struct applyRule *ar;
+    Outline *outline;		/* Segment of outline being followed */
+    struct applyRule *ar;
 {
     int howfar = ar->ar_moving->e_newx - ar->ar_moving->e_x;
     Edge edge;
@@ -628,8 +629,8 @@ plowSliverTopMove(outline, ar)
     /* Queue the edge to be moved */
     edge.e_rect = outline->o_rect;
     edge.e_newx = ar->ar_mustmove;
-    edge.e_ltype = TiGetRightType(outline->o_inside);
-    edge.e_rtype = TiGetLeftType(outline->o_outside);
+    edge.e_ltype = TiGetTypeExact(outline->o_inside);
+    edge.e_rtype = TiGetTypeExact(outline->o_outside);
     if (TTMaskHasType(&PlowFixedTypes, edge.e_rtype)
 	    && edge.e_newx > edge.e_x + howfar)
 	edge.e_newx = edge.e_x + howfar;
@@ -644,12 +645,12 @@ plowSliverTopMove(outline, ar)
 
 int
 plowSliverBotMove(outline, ar)
-    register Outline *outline;		/* Segment of outline being followed.
+    Outline *outline;		/* Segment of outline being followed.
 					 * The sense of "inside" and "outside"
 					 * is reversed from that when handling
 					 * the top half of the penumbra.
 					 */
-    register struct applyRule *ar;
+    struct applyRule *ar;
 {
     int howfar = ar->ar_moving->e_newx - ar->ar_moving->e_x;
     Edge edge;
@@ -662,8 +663,8 @@ plowSliverBotMove(outline, ar)
     /* Queue the edge to be moved */
     edge.e_rect = outline->o_rect;
     edge.e_newx = ar->ar_mustmove;
-    edge.e_ltype = TiGetRightType(outline->o_outside);
-    edge.e_rtype = TiGetLeftType(outline->o_inside);
+    edge.e_ltype = TiGetTypeExact(outline->o_outside);
+    edge.e_rtype = TiGetTypeExact(outline->o_inside);
     if (TTMaskHasType(&PlowFixedTypes, edge.e_rtype)
 	    && edge.e_newx > edge.e_x + howfar)
 	edge.e_newx = edge.e_x + howfar;
@@ -707,10 +708,10 @@ plowSliverBotMove(outline, ar)
 
 int
 plowSliverTopExtent(outline, ar)
-    register Outline *outline;		/* Segment of outline being followed */
-    register struct applyRule *ar;
+    Outline *outline;		/* Segment of outline being followed */
+    struct applyRule *ar;
 {
-    register Edge *movingEdge = ar->ar_moving;
+    Edge *movingEdge = ar->ar_moving;
     int newx, xmove, ret = 0;
 
     /*
@@ -748,7 +749,7 @@ plowSliverTopExtent(outline, ar)
 
 	    /* Set the type to be used in applying the design rules */
 	    if (outline->o_rect.r_ybot == movingEdge->e_ytop)
-		ar->ar_slivtype = TiGetType(outline->o_outside);
+		ar->ar_slivtype = TiGetTypeExact(outline->o_outside);
 
 	    /*
 	     * If this is not a special case where we have to check for
@@ -805,7 +806,7 @@ plowSliverTopExtent(outline, ar)
     }
 
     /* Apply the plowing rules to see if this is a sliver */
-    if (plowSliverApplyRules(ar, TiGetType(outline->o_inside),
+    if (plowSliverApplyRules(ar, TiGetTypeExact(outline->o_inside),
 		outline->o_rect.r_ybot - movingEdge->e_ytop))
 	ar->ar_mustmove = xmove;
     return (ret);
@@ -813,10 +814,10 @@ plowSliverTopExtent(outline, ar)
 
 int
 plowSliverBotExtent(outline, ar)
-    register Outline *outline;		/* Segment of outline being followed */
-    register struct applyRule *ar;
+    Outline *outline;		/* Segment of outline being followed */
+    struct applyRule *ar;
 {
-    register Edge *movingEdge = ar->ar_moving;
+    Edge *movingEdge = ar->ar_moving;
     int newx, xmove, ret = 0;
 
     /*
@@ -854,7 +855,7 @@ plowSliverBotExtent(outline, ar)
 
 	    /* Set the type to be used in applying the design rules */
 	    if (outline->o_rect.r_ytop == movingEdge->e_ybot)
-		ar->ar_slivtype = TiGetType(outline->o_inside);
+		ar->ar_slivtype = TiGetTypeExact(outline->o_inside);
 
 	    /*
 	     * If this is not a special case where we have to check for
@@ -911,7 +912,7 @@ plowSliverBotExtent(outline, ar)
     }
 
     /* Apply the plowing rules to see if this is a sliver */
-    if (plowSliverApplyRules(ar, TiGetType(outline->o_outside),
+    if (plowSliverApplyRules(ar, TiGetTypeExact(outline->o_outside),
 		movingEdge->e_ybot - outline->o_rect.r_ytop))
 	ar->ar_mustmove = xmove;
     return (ret);
@@ -951,12 +952,12 @@ plowSliverBotExtent(outline, ar)
 
 bool
 plowSliverApplyRules(ar, far, farDist)
-    register struct applyRule *ar;
+    struct applyRule *ar;
     TileType far;
     int farDist;
 {
     TileType near = ar->ar_moving->e_ltype;
-    register PlowRule *pr;
+    PlowRule *pr;
 
     for (pr = plowWidthRulesTbl[near][ar->ar_slivtype]; pr; pr = pr->pr_next)
 	if (pr->pr_dist > farDist && !TTMaskHasType(&pr->pr_oktypes, far))
@@ -997,12 +998,12 @@ plowSliverApplyRules(ar, far, farDist)
 
 int
 plowApplyRule(impactedEdge, ar)
-    register Edge *impactedEdge;	/* Edge found by shadow search */
-    register struct applyRule *ar;	/* Edge causing the shadow search, and
+    Edge *impactedEdge;	/* Edge found by shadow search */
+    struct applyRule *ar;	/* Edge causing the shadow search, and
 					 * the design rule to apply.
 					 */
 {
-    register Edge *movingEdge = ar->ar_moving;
+    Edge *movingEdge = ar->ar_moving;
     int newsep, oldsep, newx;
 
     oldsep = impactedEdge->e_x - movingEdge->e_x;
