@@ -23,6 +23,9 @@ static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowTech.c,v 1.2 2001/0
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -65,8 +68,9 @@ TileTypeBitMask PlowFixedTypes;		/* Fixed-width types (e.g, fets).
 int plowMaxDist[TT_MAXTYPES];
 
 /* Forward declarations */
-Void plowEdgeRule(), plowWidthRule(), plowSpacingRule();
+extern void plowEdgeRule(), plowWidthRule(), plowSpacingRule();
 PlowRule *plowTechOptimizeRule();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -84,11 +88,11 @@ PlowRule *plowTechOptimizeRule();
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 PlowDRCInit()
 {
-    register int i, j;
-    register PlowRule *pr;
+    int i, j;
+    PlowRule *pr;
 
     /* Remove all old rules from the plowing rules table */
     for (i = 0; i < TT_MAXTYPES; i++)
@@ -125,7 +129,7 @@ PlowDRCInit()
  *	and call it to do the work of implementing the rule.  Each
  *	such procedure is of the following form:
  *
- *	Void
+ *	int	
  *	proc(argc, argv)
  *	    int argc;
  *	    char *argv[];
@@ -135,7 +139,6 @@ PlowDRCInit()
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
 bool
 PlowDRCLine(sectionName, argc, argv)
     char *sectionName;		/* Unused */
@@ -148,7 +151,7 @@ PlowDRCLine(sectionName, argc, argv)
 	char	*rk_keyword;	/* Initial keyword */
 	int	 rk_minargs;	/* Min # arguments */
 	int	 rk_maxargs;	/* Max # arguments */
-	int    (*rk_proc)();	/* Procedure implementing this keyword */
+	void    (*rk_proc)();	/* Procedure implementing this keyword */
     } ruleKeys[] = {
 	"edge",		 8,	9,	plowEdgeRule,
 	"edge4way",	 8,	9,	plowEdgeRule,
@@ -192,7 +195,7 @@ PlowDRCLine(sectionName, argc, argv)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
+void
 plowWidthRule(argc, argv)
     int argc;
     char *argv[];
@@ -200,8 +203,8 @@ plowWidthRule(argc, argv)
     char *layers = argv[1];
     int distance = atoi(argv[2]);
     TileTypeBitMask set, setC, tmp1;
-    register PlowRule *pr;
-    register TileType i, j;
+    PlowRule *pr;
+    TileType i, j;
     int pNum;
 
     /*
@@ -228,7 +231,7 @@ plowWidthRule(argc, argv)
 	{
 	    for (j = 0; j < DBNumTypes; j++)
 	    {
-		if (SamePlane(i, j) && TTMaskHasType(&set, j))
+		if (DBTypesOnSamePlane(i, j) && TTMaskHasType(&set, j))
 		{
 		    MALLOC(PlowRule *, pr, sizeof (PlowRule));
 		    pr->pr_dist = distance;
@@ -270,7 +273,7 @@ plowWidthRule(argc, argv)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
+void
 plowSpacingRule(argc, argv)
     int argc;
     char *argv[];
@@ -280,8 +283,8 @@ plowSpacingRule(argc, argv)
     char *adjacency = argv[4];
     TileTypeBitMask set1, set2, tmp1, tmp2, setR, setRreverse;
     int pNum, planes1, planes2;
-    register PlowRule *pr;
-    register TileType i, j;
+    PlowRule *pr;
+    TileType i, j;
 
     DBTechNoisyNameMask(layers1, &set1);
     planes1 = DBTechMinSetPlanes(set1, &set1);
@@ -327,7 +330,7 @@ plowSpacingRule(argc, argv)
     {
 	for (j = 0; j < DBNumTypes; j++)
 	{
-	    if (i == j || !SamePlane(i, j)) continue;
+	    if (i == j || !DBTypesOnSamePlane(i, j)) continue;
 
 	    /* LHS is an element of set1 and RHS is an element of setR */
 	    if (TTMaskHasType(&set1, i) && TTMaskHasType(&setR, j))
@@ -411,6 +414,7 @@ plowSpacingRule(argc, argv)
  * ----------------------------------------------------------------------------
  */
 
+void
 plowEdgeRule(argc, argv)
     int argc;
     char *argv[];
@@ -424,8 +428,8 @@ plowEdgeRule(argc, argv)
     int pNum, checkPlane, flags;
     bool needPenumbraOnly;
     bool isFourWay = (strcmp(argv[0], "edge4way") == 0);
-    register PlowRule *pr;
-    register TileType i, j;
+    PlowRule *pr;
+    TileType i, j;
 
     DBTechNoisyNameMask(layers1, &set1);
     DBTechNoisyNameMask(layers2, &set2);
@@ -585,11 +589,11 @@ plowEdgeRule(argc, argv)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 PlowDRCFinal()
 {
-    register PlowRule *pr;
-    register TileType i, j;
+    PlowRule *pr;
+    TileType i, j;
 
     for (i = 0; i < DBNumTypes; i++)
     {
@@ -643,7 +647,7 @@ PlowRule *
 plowTechOptimizeRule(ruleList)
     PlowRule *ruleList;
 {
-    register PlowRule *pCand, *pCandLast, *pr;
+    PlowRule *pCand, *pCandLast, *pr;
     TileTypeBitMask tmpMask;
 
     /*
@@ -759,7 +763,6 @@ PlowTechInit()
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
 bool
 PlowTechLine(sectionName, argc, argv)
     char *sectionName;	/* Unused */
@@ -818,7 +821,13 @@ PlowTechLine(sectionName, argc, argv)
 void
 PlowTechFinal()
 {
-    PlowContactTypes = DBImageBits;
+    TileType t;
+
+    TTMaskZero(&PlowContactTypes);
+    for (t = TT_TECHDEPBASE; t < DBNumTypes; t++)
+	if (DBIsContact(t))
+	    TTMaskSetType(&PlowContactTypes, t);
+
     TTMaskSetMask(&PlowFixedTypes, &PlowContactTypes);
 }
 
@@ -839,6 +848,7 @@ PlowTechFinal()
  * ----------------------------------------------------------------------------
  */
 
+void
 plowTechShow(f)
     FILE *f;
 {
