@@ -12,6 +12,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResReadSim.c,v 1.2 2
  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <ctype.h>
 #include <math.h>
 #ifdef	SYSV
@@ -103,6 +104,10 @@ ResFixPoint		*ResFixList;
      (n)->rn_status = TRUE;\
 }
 
+/* Forward declarations */
+
+extern void ResSimProcessDrivePoints();
+
 
 /*
  *-------------------------------------------------------------------------
@@ -115,6 +120,8 @@ ResFixPoint		*ResFixList;
  *
  *-------------------------------------------------------------------------
  */
+
+int
 ResReadSim(simfile,fetproc,capproc,resproc,attrproc,mergeproc)
      char	*simfile;
      int	(*fetproc)(),(*capproc)(),(*resproc)();
@@ -209,6 +216,8 @@ ResReadSim(simfile,fetproc,capproc,resproc,attrproc,mergeproc)
  *
  *-------------------------------------------------------------------------
  */
+
+int
 ResReadNode(nodefile)
 	char	*nodefile;
  
@@ -265,6 +274,7 @@ ResReadNode(nodefile)
  *
  *-------------------------------------------------------------------------
  */
+
 int
 gettokens(line,fp)
 	char line[][MAXTOKEN];
@@ -310,6 +320,8 @@ gettokens(line,fp)
  *
  *-------------------------------------------------------------------------
  */
+
+int
 ResSimTransistor(line,rpersquare,ttype)
 	char line[][MAXTOKEN];
 	float	rpersquare;
@@ -403,6 +415,7 @@ ResSimTransistor(line,rpersquare,ttype)
  *
  *-------------------------------------------------------------------------
  */
+
 int
 ResSimNewNode(line,type,transistor)
 	char 		line[];
@@ -448,12 +461,15 @@ ResSimNewNode(line,type,transistor)
  *	node. Coupling capacitors are added twice, moving the capacitance 
  *	to the substrate.
  *
- *  Results: none
+ *  Results:
+ *	Always return 0
  *
  *  Side Effects: modifies capacitance field  of ResSimNode.
  *
  *-------------------------------------------------------------------------
  */
+
+int
 ResSimCapacitor(line)
 	char line[][MAXTOKEN];
 
@@ -516,12 +532,15 @@ ResSimCapacitor(line)
  *  ResSimResistor-- Adds the capacitance  from a R line to the appropriate
  *	node. 
  *
- *  Results: none
+ *  Results
+ *	Return 0 to keep search going, 1 to abort
  *
  *  Side Effects: modifies resistance field of ResSimNode
  *
  *-------------------------------------------------------------------------
  */
+
+int
 ResSimResistor(line)
 	char line[][MAXTOKEN];
 
@@ -554,12 +573,15 @@ ResSimResistor(line)
  *	attribute. If it is, add it to the correct node's status flag.
  *	Only works with 5.0 1/line attributes
  *
- *  Results: none
+ *  Results:
+ *	Return 0 to keep search going, 1 to abort
  *
  *  Side Effects: modifies resistance field of ResSimNode
  *
  *-------------------------------------------------------------------------
  */
+
+int
 ResSimAttribute(aname,avalue,rootname,readextfile)
 	char *aname,*avalue,*rootname;
 	int	*readextfile;
@@ -660,12 +682,14 @@ ResSimAttribute(aname,avalue,rootname,readextfile)
  *	they are in the root cell.
  *
  * Results:
+ *	None.
  *
  * Side Effects:
  *
  *-------------------------------------------------------------------------
  */
-int
+
+void
 ResSimProcessDrivePoints(filename)
 	char	*filename;
 
@@ -704,13 +728,16 @@ ResSimProcessDrivePoints(filename)
  *	is only done after the first res:fix label is encountered.
  *
  *
- * Results: For each new name, allocate
+ * Results:
+ *	None.
  *
  * Side Effects:
+ *	For each new name, allocate memory
  *
  *-------------------------------------------------------------------------
  */
-int
+
+void
 ResSimProcessFixPoints(filename)
 	char	*filename;
 {
@@ -756,7 +783,7 @@ ResSimProcessFixPoints(filename)
  *
  * ResSimMerge-- Processes = line in sim file
  *
- * Results: none
+ * Results: Success/Failure
  *
  * Side Effects: The forward field of one node is set to point to the
  *	other node. All of the junkt from the first node is moved to
@@ -764,6 +791,8 @@ ResSimProcessFixPoints(filename)
  *
  *-------------------------------------------------------------------------
  */
+
+int
 ResSimMerge(line)
 	char line[][MAXTOKEN];
 
@@ -803,6 +832,7 @@ ResSimMerge(line)
  *
  *-------------------------------------------------------------------------
  */
+
 ResSimNode *
 ResInitializeNode(entry)
 	HashEntry	*entry;
