@@ -44,6 +44,12 @@ static char rcsid[] = "$Header: /ufs/repository/magic/resis/ResSimple.c,v 1.2 20
 Heap	ResistorHeap;
 int	resRemoveLoops = FALSE;
 
+/* Forward declarations */
+
+extern void ResMoveTransistors();
+extern void ResAddResistorToList();
+
+
 
 /*
  *-------------------------------------------------------------------------
@@ -58,6 +64,8 @@ int	resRemoveLoops = FALSE;
  *
  *-------------------------------------------------------------------------
  */
+
+void
 ResSimplifyNet(nodelist,biglist,reslist,tolerance)
 	resNode		**nodelist,**biglist;
 	resResistor	**reslist;
@@ -381,6 +389,8 @@ ResSimplifyNet(nodelist,biglist,reslist,tolerance)
  *
  *-------------------------------------------------------------------------
  */
+
+void
 ResMoveTransistors(node1,node2)
 	resNode		*node1,*node2;
 
@@ -446,6 +456,8 @@ ResMoveTransistors(node1,node2)
  *
  *-------------------------------------------------------------------------
  */
+
+void
 ResScrunchNet(reslist,pendingList,biglist,tolerance)
 	resResistor 	**reslist;
 	resNode		**pendingList,**biglist;
@@ -598,6 +610,8 @@ ResScrunchNet(reslist,pendingList,biglist,tolerance)
  *
  *-------------------------------------------------------------------------
  */
+
+void
 ResAddResistorToList(resistor,locallist)
      resResistor	*resistor,**locallist;
 
@@ -649,13 +663,17 @@ ResAddResistorToList(resistor,locallist)
  *
  * ResdistributeSubstrateCapacitance--
  *
- * Results: takes total capacitance to VDD or GND in a node and distributes
- * 	it onto the new nodes.
+ * Results:
+ *	None.
  *
  * Side Effects:
+ *	takes total capacitance to VDD or GND in a node and distributes
+ * 	it onto the new nodes.
  *
  *-------------------------------------------------------------------------
  */
+
+void
 ResDistributeCapacitance(nodelist,totalcap)
 	resNode		*nodelist;
 	float		totalcap;
@@ -703,6 +721,7 @@ ResDistributeCapacitance(nodelist,totalcap)
  *
  *-------------------------------------------------------------------------
  */
+
 float
 ResCalculateChildCapacitance(me)
 	resNode	*me;
@@ -774,6 +793,8 @@ ResCalculateChildCapacitance(me)
  *
  *-------------------------------------------------------------------------
  */
+
+void
 ResCalculateTDi(node,resistor,resistorvalue)
 	resNode	*node;
 	resResistor *resistor;
@@ -823,6 +844,8 @@ ResCalculateTDi(node,resistor,resistorvalue)
  *
  *-------------------------------------------------------------------------
  */
+
+void
 ResPruneTree(node,minTdi,nodelist1,nodelist2,resistorlist)
 	resNode		*node,**nodelist1,**nodelist2;
 	float		minTdi;
@@ -853,7 +876,7 @@ ResPruneTree(node,minTdi,nodelist1,nodelist2,resistorlist)
 	 node->rn_re->re_nextEl == NULL &&
 	 node->rn_re->re_thisEl->rr_connection2 == node)
      {
-     	  if (node->rn_client == (ClientData) NULL)
+     	  if (node->rn_client == (ClientData)NULL)
 	  {
 	       TxError("Internal Error in Tree Pruning: Missing TDi value.\n");
 	  }
