@@ -26,7 +26,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/router/routeCmd.c,v 1.0 20
 #include <string.h>
 #endif
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "misc/styles.h"
 #include "utils/geometry.h"
@@ -67,6 +67,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/router/routeCmd.c,v 1.0 20
  * ----------------------------------------------------------------------------
  */
 
+void
 CmdGARouterTest(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -93,6 +94,7 @@ CmdGARouterTest(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
+void
 CmdGRouterTest(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -119,6 +121,7 @@ CmdGRouterTest(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
+void
 CmdIRouterTest(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -145,6 +148,7 @@ CmdIRouterTest(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
+void
 CmdMZRouterTest(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -174,8 +178,8 @@ CmdMZRouterTest(w, cmd)
  *
  * ----------------------------------------------------------------------------
  */
-    /* ARGSUSED */
 
+void
 CmdChannel(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -243,8 +247,7 @@ cmdChannelFunc(tile)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
-Void
+void
 CmdGaRoute(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -360,10 +363,10 @@ badWarn:
 	    }
 	    else if (cmd->tx_argc == 6 || cmd->tx_argc == 7)
 	    {
-		editArea.r_xbot = cmdParseCoord(w, cmd->tx_argv[2], FALSE, TRUE);
-		editArea.r_ybot = cmdParseCoord(w, cmd->tx_argv[3], FALSE, FALSE);
-		editArea.r_xtop = cmdParseCoord(w, cmd->tx_argv[4], FALSE, TRUE);
-		editArea.r_ytop = cmdParseCoord(w, cmd->tx_argv[5], FALSE, FALSE);
+		editArea.r_xbot = cmdParseCoord(cmd->tx_argv[2]);
+		editArea.r_ybot = cmdParseCoord(cmd->tx_argv[3]);
+		editArea.r_xtop = cmdParseCoord(cmd->tx_argv[4]);
+		editArea.r_ytop = cmdParseCoord(cmd->tx_argv[5]);
 		chanType = CHAN_NORMAL;
 		if (cmd->tx_argc == 7)
 		    channame = cmd->tx_argv[6];
@@ -433,9 +436,8 @@ badChanCmd:
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
-Void
+void
 CmdIRoute(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -481,9 +483,7 @@ CmdIRoute(w, cmd)
 #define ROUTERVIAS	17
 #define	ROUTERVIAMIN	18
 
-
-    /* ARGSUSED */
-
+void
 CmdRoute(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -686,8 +686,8 @@ CmdRoute(w, cmd)
 	    {
 		if (cmd->tx_argc != 4)
 		    goto wrongNumArgs;
-		RtrOrigin.p_x = cmdParseCoord(w, cmd->tx_argv[2], FALSE, TRUE);
-		RtrOrigin.p_y = cmdParseCoord(w, cmd->tx_argv[3], FALSE, FALSE);
+		RtrOrigin.p_x = cmdParseCoord(cmd->tx_argv[2]);
+		RtrOrigin.p_y = cmdParseCoord(cmd->tx_argv[3]);
 		break;
 	    }
 	    TxPrintf("Routing grid origin = (%d,%d)\n",
@@ -749,8 +749,7 @@ usage2:
  * ----------------------------------------------------------------------------
  */
 
-    /* ARGSUSED */
-
+void
 CmdSeeFlags(w, cmd)
     MagWindow * w;
     TxCommand *cmd;
