@@ -42,6 +42,13 @@ int rtrMetalLength	= 0;
 int rtrPolyLength	= 0;
 int rtrViaCount		= 0;
 bool RtrDoMMax		= TRUE;
+
+/* Forward declarations */
+
+extern void rtrPaintRows();
+extern void rtrPaintColumns();
+extern void rtrMaxMetal();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -58,6 +65,8 @@ bool RtrDoMMax		= TRUE;
  *	paint is added to the edit cell.
  * ----------------------------------------------------------------------------
  */
+
+void
 RtrPaintBack(ch, def)
     GCRChannel * ch;
     CellDef *def;
@@ -87,13 +96,14 @@ RtrPaintBack(ch, def)
  * ----------------------------------------------------------------------------
  */
 
+void
 rtrPaintRows(def, ch)
     CellDef *def;	/* Def into which paint will go */
     GCRChannel *ch;	/* Channel being painted */
 {
     TileType curType, nextType;
-    register short **result, code;
-    register int row, col;
+    short **result, code;
+    int row, col;
     Rect paint, contact;
     PaintUndoInfo ui;
 
@@ -214,6 +224,7 @@ rtrPaintRows(def, ch)
  * ----------------------------------------------------------------------------
  */
 
+void
 rtrPaintColumns(def, ch)
     CellDef * def;
     GCRChannel * ch;
@@ -321,13 +332,15 @@ rtrPaintColumns(def, ch)
  *
  * ----------------------------------------------------------------------------
  */
+
+bool
 rtrDoVia(ch, col, row)
     GCRChannel *ch;	/* The channel undergoing display */
-    register int col;	/* The x coordinate of the location considered */
-    register int row;	/* The y coordinate of the location considered */
+    int col;	/* The x coordinate of the location considered */
+    int row;	/* The y coordinate of the location considered */
 {
     short up, down, left, right, mask;
-    register short **result, code;
+    short **result, code;
 
     result = ch->gcr_result;
     code = result[col][row];
@@ -411,7 +424,7 @@ rtrDoVia(ch, col, row)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 rtrMaxMetal(ch)
     GCRChannel * ch;
 {
@@ -556,9 +569,9 @@ rtrMetalOkay(ch, col, dir)
     int col;		/* The crossing column in the originating channel */
     int dir;		/* Direction of the crossing NORTH or SOUTH */
 {
-    register GCRChannel *newCh;
-    register GCRPin *pin;
-    register short flags;
+    GCRChannel *newCh;
+    GCRPin *pin;
+    short flags;
     int newCol;
 
     switch (dir)
