@@ -72,9 +72,11 @@ static struct dirs			/* List of directions for stems */
 
 
 /* Forward declarations */
-GCRChannel *rtrStemSearch();
-GCRPin *rtrStemTip();
-GCRPin *rtrStemTryPin();
+extern GCRChannel *rtrStemSearch();
+extern GCRPin *rtrStemTip();
+extern GCRPin *rtrStemTryPin();
+extern void rtrStemRange();
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -119,7 +121,7 @@ GCRPin *rtrStemTryPin();
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 RtrStemProcessAll(use, netList, doWarn, func)
     CellUse *use;
     NLNetList *netList;
@@ -373,7 +375,7 @@ fail:
 
 GCRPin *
 rtrStemTip(loc, si, use)
-    register NLTermLoc *loc;	/* Location whose stem tip is being found */
+    NLTermLoc *loc;	/* Location whose stem tip is being found */
     StemInfo *si;		/* Stem information */
     CellUse *use;
 {
@@ -556,6 +558,7 @@ rtrStemTryPin(loc, dir, p, use)
  * ----------------------------------------------------------------------------
  */
 
+bool
 rtrTreeSrArea(loc, dir, p, use)
     NLTermLoc *loc;	/* Terminal location under consideration */
     int dir;		/* Direction away from loc that p lies */
@@ -697,13 +700,13 @@ rtrSrArea(dir,use,tmp,delta)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 rtrStemRange(loc, dir, si)
     NLTermLoc *loc;	/* Terminal we're trying to find a stem for */
     int dir;		/* Direction away from loc that we're searching */
     StemInfo *si;	/* Fill this in if this direction looks best so far */
 {
-    register Rect *area = &loc->nloc_rect;
+    Rect *area = &loc->nloc_rect;
     Point start, near, center;
     int dist, halfGrid;
     GCRChannel *ch;
@@ -780,7 +783,7 @@ rtrStemContactLine(lo, hi, origin)
     int lo, hi;		/* Bottom and top, or left and right of terminal */
     int origin;		/* Coordinate of routing grid origin */
 {
-    register int center;
+    int center;
 
     /*
      * The following code is tricky because we want to round DOWN always
@@ -818,7 +821,7 @@ rtrStemSearch(center, dir, point)
     int dir;
     Point *point;
 {
-    register Tile *tile;
+    Tile *tile;
     GCRChannel *ch;
 
     *point = *center;
@@ -891,7 +894,7 @@ rtrStemSearch(center, dir, point)
 bool
 RtrStemPaintExt(use, loc)
     CellUse *use;
-    register NLTermLoc *loc;	/* Terminal whose stem is to be painted */
+    NLTermLoc *loc;	/* Terminal whose stem is to be painted */
 {
     TileTypeBitMask startMask;	/* Possible layers for first part of stem */
     TileTypeBitMask finalMask;	/* Possible layers for last part of stem */
@@ -1069,7 +1072,7 @@ rtrStemMask(routeUse, loc, flags, startMask, finalMask)
     return (TRUE);
 }
 
-Void
+int
 rtrStemTypes(startMask, finalMask, startType, finalType)
     TileTypeBitMask *startMask, *finalMask;
     TileType *startType, *finalType;
@@ -1107,16 +1110,17 @@ rtrStemTypes(startMask, finalMask, startType, finalType)
  *	or to actually paint the stem.
  *
  * Results:
- *	Returns *contact*, *jog*, and *start*.
+ *	True on success, False on failure.
  *
  * Side effects:
+ *	Returns contact, jog, and start points, passed via pointer.
  *
  * ----------------------------------------------------------------------------
  */
 
 bool
 RtrComputeJogs(loc, stem, dir, contact, jog, start, width)
-    register NLTermLoc *loc;	/* Terminal whose stem is to be painted */
+    NLTermLoc *loc;	/* Terminal whose stem is to be painted */
     Point *stem;		/* Point intersecting channel*/
     Point *start;		/* Somewhere along terminal area */
     Point *jog;			/* Where the stem crosses the first usable
@@ -1128,7 +1132,7 @@ RtrComputeJogs(loc, stem, dir, contact, jog, start, width)
 				 * the channel.
 				 */
 {
-    register Rect *area;
+    Rect *area;
     area = &loc->nloc_rect;
 
     /* In the following code, we compute two jog points in the stem.
