@@ -439,11 +439,11 @@ selFindChunk(plane, wrongTypes, searchArea, containedArea, bestMin,
 
 int
 selSplitFunc(tile, cxp)
-   register Tile *tile;
+   Tile *tile;
    TreeContext *cxp;
 {
-    register SearchContext *scx = cxp->tc_scx;
-    register Rect *area = (Rect *) cxp->tc_filter->tf_arg;
+    SearchContext *scx = cxp->tc_scx;
+    Rect *area = (Rect *) cxp->tc_filter->tf_arg;
     Rect locarea;
 
     if (IsSplit(tile))
@@ -1088,8 +1088,8 @@ selACPaintFunc2(tile, editClip)
     type = TiGetType(tile);
     if (type >= DBNumUserLayers)
     {
-        register TileType primary,first;
-        register typecount=0;
+        TileType primary,first;
+        int typecount = 0;
 
         for (primary = TT_SELECTBASE; primary < DBNumUserLayers; primary++)
         {
