@@ -722,7 +722,7 @@ SelectStretch(x, y)
     
     selStretchX = x;
     selStretchY = y;
-    for (plane = PL_SELECTBASE; plane < DBNumPlanes; plane += 1)
+    for (plane = PL_SELECTBASE; plane < DBNumPlanes; plane++)
     {
 	(void) DBSrPaintArea((Tile *) NULL, Select2Def->cd_planes[plane],
 		&TiPlaneRect, &DBAllButSpaceAndDRCBits, selStretchEraseFunc,
@@ -737,7 +737,7 @@ SelectStretch(x, y)
      */
 
     selStretchList = NULL;
-    for (plane = PL_SELECTBASE; plane < DBNumPlanes; plane += 1)
+    for (plane = PL_SELECTBASE; plane < DBNumPlanes; plane++)
     {
 	(void) DBSrPaintArea((Tile *) NULL, Select2Def->cd_planes[plane],
 		&TiPlaneRect, &DBAllButSpaceAndDRCBits, selStretchFillFunc,
@@ -807,9 +807,20 @@ selStretchEraseFunc(tile)
     /* Translate into edit coords and erase all material on the
      * tile's plane.
      */
-    
+
+    /*
+     * Stacking contact types do not get erased
+     */
+
     GeoTransRect(&RootToEditTransform, &area, &editArea);
-    DBEraseMask(EditCellUse->cu_def, &editArea, &DBPlaneTypes[DBPlane(type)]);
+
+    DBErase(EditCellUse->cu_def, &editArea, type);
+
+    /* Was previously DBEraseMask().  Don't know why.  If you trust the */
+    /* paint/erase tables, it should not be necessary to erase anything	*/
+    /* other than the type itself.					*/
+
+    /* DBEraseMask(EditCellUse->cu_def, &editArea, &DBPlaneTypes[DBPlane(type)]); */
 
     return 0;
 }
@@ -913,6 +924,8 @@ selStretchFillFunc2(tile, area)
 					 */
 {
     Rect spaceArea, editArea;
+    int pNum;
+
     extern int selStretchFillFunc3();
 
     TiToRect(tile, &spaceArea);
@@ -930,10 +943,12 @@ selStretchFillFunc2(tile, area)
     spaceArea.r_ytop -= selStretchY;
     GeoTransRect(&RootToEditTransform, &spaceArea, &editArea);
 
-    (void) DBSrPaintArea((Tile *) NULL,
-	    EditCellUse->cu_def->cd_planes[DBPlane(selStretchType)],
-	    &editArea, &DBAllButSpaceAndDRCBits, selStretchFillFunc3,
-	    (ClientData) &spaceArea);
+    for (pNum = PL_PAINTBASE; pNum < DBNumPlanes; pNum++)
+	if (DBPaintOnPlane(selStretchType, pNum))
+	    (void) DBSrPaintArea((Tile *) NULL,
+			EditCellUse->cu_def->cd_planes[pNum],
+			&editArea, &DBAllButSpaceAndDRCBits, selStretchFillFunc3,
+			(ClientData) &spaceArea);
 
     return 0;
 }
@@ -955,8 +970,8 @@ selStretchFillFunc3(tile, area)
 				 */
 {
     Rect editArea, rootArea;
-    TileType type;
-    register TileTypeBitMask *mask;
+    TileType type, stype;
+    TileTypeBitMask *mask;
     StretchArea *sa;
 
     /* Compute the area to be painted. */
@@ -1009,15 +1024,45 @@ selStretchFillFunc3(tile, area)
 #endif
     type = TiGetType(tile);
 
-    if (TTMaskHasType(&PlowFixedTypes, type)
-	    || !TTMaskHasType(&PlowFixedTypes, selStretchType))
-	type = selStretchType;
+    /* If have type and stretch type are both contacts (fixed types)	*/
+    /* and there exists a stacking contact type between them, then	*/
+    /* we should be filling in the original type.			*/
 
-    if (type >= DBNumUserLayers)
+    if (!DBIsContact(type) || !DBIsContact(selStretchType) ||
+		(((stype = DBTechFindStacking(type, selStretchType))
+		< DBNumUserLayers) && (stype >= TT_TECHDEPBASE)))
     {
-	mask = &DBLayerTypeMaskTbl[type];
-	for (type = TT_SELECTBASE; !TTMaskHasType(mask, type); type += 1)
-	    /* Null loop body. */;
+	/* If type is a residue of selStretchType then we always fill	*/
+	/* with type.  Otherwise, we check the list of plow types to	*/
+	/* see what is and isn't fixed.					*/
+
+	if (!TTMaskHasType(DBResidueMask(selStretchType), type))
+	    if (TTMaskHasType(&PlowFixedTypes, type)
+			|| !TTMaskHasType(&PlowFixedTypes, selStretchType))
+		type = selStretchType;
+    }
+
+    /* Otherwise, if we have two fixed types, and they both border the	*/
+    /* selection area (as opposed to overlapping), and they share a	*/
+    /* residue, then the type to paint is the shared residue type.	*/
+
+    else if (DBIsContact(type) && DBIsContact(selStretchType))
+    {
+	if (((selStretchX < 0) && (editArea.r_xtop == area->r_xbot)) ||
+	    ((selStretchX > 0) && (editArea.r_xbot == area->r_xtop)) ||
+	    ((selStretchY < 0) && (editArea.r_ytop == area->r_ybot)) ||
+	    ((selStretchY > 0) && (editArea.r_ybot == area->r_ytop)))
+	{
+	    TileTypeBitMask rmask;
+	    TTMaskAndMask3(&rmask, DBResidueMask(type),
+			DBResidueMask(selStretchType));
+	    for (type = TT_TECHDEPBASE; type < DBNumUserLayers; type++)
+		if (TTMaskHasType(&rmask, type))
+		    break;
+
+	    if (type == DBNumUserLayers)
+		return 0;	/* Types do not share any residues */
+	}
     }
 
     /* Save around the area we just found. */
