@@ -1,3 +1,4 @@
+
 /* SimDBstuff.c -
  *
  *	This file contains routines that extract electrically connected
@@ -22,8 +23,9 @@
  * University of California
  */
 
-
 #include <stdio.h>
+#include <string.h>
+
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
@@ -90,9 +92,30 @@ struct conSrArg2
 
 #define CSA2_LIST_START_SIZE 256
 
+/* We need to maintain where in the cell hierarchy we are as we search
+ * the tile database when extracting a node name.  To do this, a stack is
+ * maintained of the hierarchy of cell definitions (a search context)
+ * as the search progresses.  This stack is doubly linked to allow fast
+ * pathname construction.
+ */
+
+typedef struct scx_stack_elt
+{
+    SearchContext  se_scx;		/* current cell def we're looking at */
+    struct scx_stack_elt *se_next;
+    struct scx_stack_elt *se_prev;
+} ScxStackElt;
+
+/* Forward declarations */
+
 extern char *DBPrintUseId();
 extern int  dbcUnconnectFunc();
+extern void SimInitScxStk();
+extern void SimPopScx();
+extern void SimMakePathname();
 
+static ScxStackElt	*stackBase = (ScxStackElt *) NULL;
+					/* stack of search contexts */
 static char 		bestName[256];
 
 
@@ -136,9 +159,9 @@ SimConnectFunc(tile, cx)
     TileTypeBitMask	notConnectMask, *connectMask;
     TileType		newtype, loctype;
     int 		i, pNum;
+    char		pathName[256];
     static char		nodeName[256];
     CellDef 		*def;
-    TerminalPath	*tpath = cx->tc_filter->tf_tpath;
 
     TiToRect(tile, &tileArea);
     srArea = &scx->scx_area;
@@ -166,26 +189,6 @@ SimConnectFunc(tile, cx)
     GeoClip(&newarea, csa2->csa2_bounds);
     if (GEO_RECTNULL(&newarea)) return 0;
 
-    /* Stuff unique to the nodename search follows. */
-
-    if (tpath != (TerminalPath *)NULL)
-    {
-	/* Extract the node name */
-	char *n = tpath->tp_next;
-	char c = *n;
-
-	SigDisableInterrupts();
-	strcpy(nodeName, SimGetNodeName(cx->tc_scx, tile, tpath->tp_first)); 
-	SigEnableInterrupts();
-
-	*n = c;
-
-	/* save the "best" name for this node */
-
-	if (bestName[0] == '\0' || efPreferredName(nodeName, bestName))
-	    strcpy(bestName, nodeName);
-    }
-
 #ifdef NONMANHATTAN
     /* Resolve geometric transformations on diagonally-split tiles */
    
@@ -228,7 +231,7 @@ SimConnectFunc(tile, cx)
     pNum = DBPlane(loctype);
     connectMask = &csa2->csa2_connect[loctype];
 
-    if (TTMaskHasType(&DBContactBits,loctype))
+    if (DBIsContact(loctype))
     {
 	TTMaskSetOnlyType(&notConnectMask, loctype);
 	TTMaskCom(&notConnectMask);
@@ -254,6 +257,21 @@ SimConnectFunc(tile, cx)
 		DBStdPaintTbl(loctype, pNum), (PaintUndoInfo *) NULL);
 #endif
 
+    /* Stuff unique to the nodename search follows. */
+
+    SimMakePathname(pathName);
+
+    /* Extract the node name */
+
+    SigDisableInterrupts();
+    strcpy(nodeName, SimGetNodeName(cx->tc_scx, tile, pathName)); 
+    SigEnableInterrupts();
+
+    /* save the "best" name for this node */
+
+    if (bestName[0] == '\0' || efPreferredName(nodeName, bestName))
+	strcpy(bestName, nodeName);
+
     /* Since the whole area of this tile hasn't been recorded,
      * we must process its area to find any other tiles that
      * connect to it.  Add each of them to the list of things
@@ -289,18 +307,13 @@ SimConnectFunc(tile, cx)
     }
 #endif
 
-    /* Abort the name search if the name is in the abort name search table 
-     * or if the name is global and the SimIgnoreGlobals flag is not set.
+    /* Abort the name search if the name is global or name is in the
+     * abort name search table 
      */
 
-    if (SimSawAbortString  || SigInterruptPending)
+    i = strlen(nodeName);
+    if (SimSawAbortString  || SigInterruptPending || (nodeName[i - 1] == '!'))
 	return 1;
-    else if (SimIsGetnode && !SimIgnoreGlobals)
-    {
-	i = strlen(nodeName);
-	if (nodeName[i - 1] == '!')
-	    return 1;
-    }
 
     /* Register the area and connection mask as needing to be processed */
 
@@ -359,8 +372,6 @@ SimConnectFunc(tile, cx)
  * ----------------------------------------------------------------------------
  */
 
-#define MAXPATHNAME 256
-
 void
 SimTreeCopyConnect(scx, mask, xMask, connect, area, destUse, Node_Name)
     SearchContext *scx;			/* Describes starting area.  The
@@ -396,8 +407,6 @@ SimTreeCopyConnect(scx, mask, xMask, connect, area, destUse, Node_Name)
 					 * words in some compilers.
 					 */
 {
-    TerminalPath tpath;
-    char pathName[MAXPATHNAME];
     TileTypeBitMask *newmask;
     struct conSrArg2 csa2;
 
@@ -410,19 +419,16 @@ SimTreeCopyConnect(scx, mask, xMask, connect, area, destUse, Node_Name)
 			* sizeof(conSrArea));
     csa2.csa2_top = -1;
 
-    tpath.tp_first = tpath.tp_next = pathName;
-    tpath.tp_last = pathName + MAXPATHNAME;
-
+    SimInitScxStk();
     bestName[0] = '\0';
 
-    (void) SimTreeSrTiles(scx, mask, xMask, &tpath, SimConnectFunc,
-		(ClientData) &csa2);
+    (void) SimTreeSrTiles(scx, mask, xMask, SimConnectFunc, (ClientData) &csa2);
     while (csa2.csa2_top >= 0)
     {
 	newmask = csa2.csa2_list[csa2.csa2_top].connectMask;
 	scx->scx_area = csa2.csa2_list[csa2.csa2_top].area;
 	csa2.csa2_top--;
-	SimTreeSrTiles(scx, newmask, xMask, &tpath, SimConnectFunc, (ClientData) &csa2);
+	SimTreeSrTiles(scx, newmask, xMask, SimConnectFunc, (ClientData) &csa2);
     }
     freeMagic((char *)csa2.csa2_list);
 
@@ -460,8 +466,8 @@ bool
 efPreferredName(name1, name2)
     char *name1, *name2;
 {
-    register int nslashes1, nslashes2;
-    register char *np1, *np2;
+    int nslashes1, nslashes2;
+    char *np1, *np2;
 
     if( name1[0] == '@' && name1[1] == '=' )
 	return( TRUE );
@@ -481,27 +487,24 @@ efPreferredName(name1, name2)
     --np1;
     --np2;
 
-    if (!SimIgnoreGlobals)
-    {
-	/* both are global names */
-	if ((*np1 == '!') && (*np2 == '!')) {
-	    /* check # of pathname components */
-	    if (nslashes1 < nslashes2) return (TRUE);
-	    if (nslashes1 > nslashes2) return (FALSE);
+    /* both are global names */
+    if ((*np1 == '!') && (*np2 == '!')) {
+	/* check # of pathname components */
+	if (nslashes1 < nslashes2) return (TRUE);
+	if (nslashes1 > nslashes2) return (FALSE);
 
-	    /* same # of pathname components; check length */
-            if (np1 - name1 < np2 - name2) return (TRUE);
-    	    if (np1 - name1 > np2 - name2) return (FALSE);
+	/* same # of pathname components; check length */
+        if (np1 - name1 < np2 - name2) return (TRUE);
+    	if (np1 - name1 > np2 - name2) return (FALSE);
 
-	    /* same # of pathname components; same length; use lex order */
-	    if (strcmp(name1, name2) > 0) 
-		return(TRUE);
-	    else
-		return(FALSE);
-	}
-	if (*np1 == '!') return(TRUE);
-	if (*np2 == '!') return(FALSE);
+	/* same # of pathname components; same length; use lex order */
+	if (strcmp(name1, name2) > 0) 
+	    return(TRUE);
+	else
+	    return(FALSE);
     }
+    if (*np1 == '!') return(TRUE);
+    if (*np2 == '!') return(FALSE);
 
     /* neither name is global */
     /* chose label over generated name */
@@ -632,13 +635,153 @@ SimSrConnect(def, startArea, mask, connect, bounds, func, clientData)
     return result;
 }
 
+
+/*
+ * ----------------------------------------------------------------------------
+ * SimInitScxStk
+ *
+ *	This procedure initializes the doubly-linked stack of search
+ *	contexts which describes the current hierarchy of the search.
+ *	
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	The stack is set to NULL.
+ *	Space in the stack is freed if the stack is not empty.
+ *	
+ * ----------------------------------------------------------------------------
+ */
+
+void
+SimInitScxStk()
+{
+    if (stackBase == (ScxStackElt *) NULL) {
+	MALLOC(ScxStackElt *, stackBase, sizeof(ScxStackElt));
+	stackBase->se_scx.scx_use = (CellUse *) NULL;
+	stackBase->se_next = stackBase->se_prev = stackBase;
+    }
+    else {
+	while (stackBase != stackBase->se_next) {
+	    SimPopScx();
+	}
+    }
+}
+
+/*
+ * ----------------------------------------------------------------------------
+ * SimPushScx
+ *
+ *	This procedure pushes a new search context onto the search
+ *	context stack.  A search context is pushed only if it is
+ *	different from the one on top of the stack.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Search context is pushed.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+SimPushScx(newscx) 
+    SearchContext *newscx;
+{
+
+    ScxStackElt *dummy;
+
+    /* check to see if the search context is different from the
+     * one on top of the stack
+     */
+
+    if (stackBase->se_prev->se_scx.scx_use != newscx->scx_use) {
+	MALLOC(ScxStackElt *, dummy, sizeof(ScxStackElt));
+	dummy->se_scx = *newscx;
+	dummy->se_next = stackBase->se_next;
+	stackBase->se_next = dummy;
+	dummy->se_prev = stackBase;
+	dummy->se_next->se_prev = dummy;
+    }
+}
+
+/*
+ * ----------------------------------------------------------------------------
+ * SimPopScx
+ *
+ *	This procedure pops the search context on top of the stack.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	The stack is popped.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+SimPopScx()
+{
+    ScxStackElt *dummy;
+    if (stackBase == stackBase->se_next) {
+	TxPrintf("SimPopScx -- stack empty\n");
+	return;
+    }
+    else {
+	dummy = stackBase->se_next;
+	stackBase->se_next = dummy->se_next;
+	stackBase->se_next->se_prev = stackBase;
+	FREE(dummy);
+    }
+}
+
+/*
+ * ----------------------------------------------------------------------------
+ * SimMakePathname
+ *
+ * 	This procedure creates a pathname for the current hierarchy
+ *	by walking the search context stack in reverse order.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	The pathname is returned in the parameter pathname.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+SimMakePathname(pathname)
+    char *pathname;
+{
+    ScxStackElt *dummy;
+    char buff[100];
+
+    *pathname = '\0';
+    if (stackBase == stackBase->se_next) {
+        return;
+    } 
+    else {
+	for (dummy = stackBase->se_prev; dummy != stackBase; 
+	     dummy = dummy->se_prev) {
+	    DBPrintUseId(&(dummy->se_scx), buff, 100);
+	    strcat(pathname, buff);
+	    strcat(pathname, "/");
+	}
+    }
+}
+
+
 /*
  *-----------------------------------------------------------------------------
  *
  * SimTreeSrTiles
  *
- * Similar to the procedure DBTreeSrTiles, although having a terminal
- * path similar to procedure DBTreeSrLabels.
+ * Similar to the procedure DBTreeSrTiles.
  *
  * Recursively search downward from the supplied CellUse for
  * all visible paint tiles matching the supplied type mask.
@@ -648,7 +791,6 @@ SimSrConnect(def, startArea, mask, connect, bounds, func, clientData)
  *	func(tile, cxp)
  *	    Tile *tile;
  *	    TreeContext *cxp;
- *	    char *pathName;
  *	{
  *	}
  *
@@ -679,7 +821,7 @@ SimSrConnect(def, startArea, mask, connect, bounds, func, clientData)
  */
 
 int
-SimTreeSrTiles(scx, mask, xMask, tpath, func, cdarg)
+SimTreeSrTiles(scx, mask, xMask, func, cdarg)
     SearchContext *scx;		/* Pointer to search context specifying
 				 * a cell use to search, an area in the
 				 * coordinates of the cell's def, and a
@@ -693,10 +835,6 @@ SimTreeSrTiles(scx, mask, xMask, tpath, func, cdarg)
 				 * when anded with xMask, are not
 				 * equal to xMask.
 				 */
-    TerminalPath *tpath;	/* Pointer to a structure describing a
-				 * partially filled-in terminal pathname.
-				 * Add new components as encountered.
-				 */
     int (*func)();		/* Function to apply at each qualifying tile */
     ClientData cdarg;		/* Client data for above function */
 {
@@ -719,7 +857,6 @@ SimTreeSrTiles(scx, mask, xMask, tpath, func, cdarg)
     filter.tf_mask = mask;
     filter.tf_xmask = xMask;
     filter.tf_planes = DBTechTypesToPlanes(mask);
-    filter.tf_tpath = tpath;
 
     context.tc_scx = scx;
     context.tc_filter = &filter;
@@ -754,13 +891,12 @@ SimTreeSrTiles(scx, mask, xMask, tpath, func, cdarg)
 
 int
 SimCellTileSrFunc(scx, fp)
-    register SearchContext *scx;
-    register TreeFilter *fp;
+    SearchContext *scx;
+    TreeFilter *fp;
 {
     TreeContext context;
     CellDef *def = scx->scx_use->cu_def;
-    int pNum, result;
-    char *tnext;
+    int pNum;
 
     ASSERT(def != (CellDef *) NULL, "SimCellTileSrFunc");
     if (!DBIsExpand(scx->scx_use, fp->tf_xmask))
@@ -770,36 +906,21 @@ SimCellTileSrFunc(scx, fp)
 
     context.tc_scx = scx;
     context.tc_filter = fp;
-
-    /* Create the path prefix */
-
-    if (fp->tf_tpath != (TerminalPath *)NULL)
-    {
-	TerminalPath *tp = fp->tf_tpath;
-        tnext = tp->tp_next;
-        tp->tp_next = DBPrintUseId(scx, tp->tp_next, tp->tp_last-tp->tp_next);
-        if (tp->tp_next < tp->tp_last)
-        {
-            *(tp->tp_next++) = '/';
-            *(tp->tp_next) = '\0';
-        }
-    }
+    SimPushScx(scx);
 
     /*
      * Apply the function first to any of the tiles in the planes
      * for this CellUse's CellDef that match the mask.
      */
 
-    result = 0;
     for (pNum = PL_PAINTBASE; pNum < DBNumPlanes; pNum++)
 	if (PlaneMaskHasPlane(fp->tf_planes, pNum))
 	{
 	    if (DBSrPaintArea((Tile *) NULL, def->cd_planes[pNum],
 		    &scx->scx_area, fp->tf_mask,
-		    fp->tf_func, (ClientData) &context))
-	    {
-		result = 1;
-		goto cleanup;
+		    fp->tf_func, (ClientData) &context)) {
+		SimPopScx();
+		return 1;
 	    }
 	}
 
@@ -808,19 +929,19 @@ SimCellTileSrFunc(scx, fp)
      * in our tile plane.
      */
 
-    if (DBCellSrArea(scx, SimCellTileSrFunc, (ClientData) fp))
-	result = 1;
-
-cleanup:
-    /* Remove the trailing pathname component from the TerminalPath */
-    if (fp->tf_tpath != (TerminalPath *) NULL)
-    {
-	fp->tf_tpath->tp_next = tnext;
-	*tnext = '\0';
+    if (DBCellSrArea(scx, SimCellTileSrFunc, (ClientData) fp)) {
+	SimPopScx();
+	return 1;
+    }
+    else {
+	SimPopScx();
+	return 0;
     }
-    return (result);
 }
 
+
+
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -859,7 +980,7 @@ SimPutLabel(cellDef, rect, align, text, type)
     char *text;		/* Pointer to actual text of label */
     TileType type;	/* Type of tile to be labeled */
 {
-    register Label *lab;
+    Label *lab;
     int len, x1, x2, y1, y2, tmp, labx, laby;
 
     len = strlen(text) + sizeof (Label) - sizeof lab->lab_text + 1;
@@ -951,7 +1072,6 @@ SimPutLabel(cellDef, rect, align, text, type)
  * ----------------------------------------------------------------------------
  */
 
-	/* ARGSUSED */
 void
 SimRsimHandler(w, cmd)
     MagWindow *w;			/* Window containing cursor. */
