@@ -20,9 +20,9 @@
  */
 
 #include <stdio.h>
+#include <string.h>
 #include <math.h>
 
-#include "tcltk/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
@@ -94,7 +94,8 @@ int		SimFetPlanes;
 
 
 /*
- * SimAddDefList
+ *----------------------------------------------------------------
+ * SimAddDefList --
  *
  * 	This procedure adds a cell definition to the DefList.  A cell
  * 	definition is added only if is not already in the list.
@@ -105,11 +106,12 @@ int		SimFetPlanes;
  * Side effects:
  *	The cell may be added to the list.
  *
+ *----------------------------------------------------------------
  */
  
+void
 SimAddDefList(newdef)
-
-CellDef *newdef;
+    CellDef *newdef;
 {
     DefListElt *d;
 
@@ -138,6 +140,7 @@ CellDef *newdef;
 }
 
 /*
+ *----------------------------------------------------------------
  * SimInitDefList
  *
  * 	This procedure initializes the cell definition list.  Any cell
@@ -146,14 +149,16 @@ CellDef *newdef;
  *	is freed.
  *
  * Results:
+ *	None.
+ *
+ * Side effects:
  *	The cell definitions' tiles' marks we left are erased and the
  *	list is set to NULL.
  *
- * Side effects:
- *	None.
- *
+ *----------------------------------------------------------------
  */
 
+void
 SimInitDefList()
 {
     DefListElt *p, *q;
@@ -170,6 +175,7 @@ SimInitDefList()
 
 
 /*
+ *----------------------------------------------------------------
  * SimAddNodeList
  *
  *      This procedure prepends a node region to the node region list.
@@ -180,8 +186,10 @@ SimInitDefList()
  * Side effects:
  *      The region next pointer is updated.
  *
+ *----------------------------------------------------------------
  */
 
+void
 SimAddNodeList(newnode)
     NodeRegion *newnode;
 {
@@ -193,18 +201,21 @@ SimAddNodeList(newnode)
 
 
 /*
+ *----------------------------------------------------------------
  * SimFreeNodeRegs
  *
  * 	This procedure frees the label regions stored in the list.
  *
  * Results:
- *	The list is set to NULL.
- *
- * Side effects:
  *	None.
  *
+ * Side effects:
+ *	The list is set to NULL.
+ *
+ *----------------------------------------------------------------
  */
 
+void
 SimFreeNodeRegs()
 {
     NodeRegion *p, *q;
@@ -217,12 +228,14 @@ SimFreeNodeRegs()
 
 
 /*
+ *----------------------------------------------------------------
  * SimInitConnTables --
  *
  * Initialize the connectivity tables for finding transistors connected
  * to the region being searched.
+ *----------------------------------------------------------------
  */
-Void SimInitConnTables()
+int SimInitConnTables()
 {
     int  t, sd, p;
 
@@ -300,11 +313,13 @@ typedef struct			/* return value from SimFindOneNode */
 
 
 /*
+ *----------------------------------------------------------------
  * SimTxtorLabel --
  *
  * Return a string that identifies a node as a function of a transistor
  * position.
  *
+ *----------------------------------------------------------------
  */
 char *SimTxtorLabel( nterm, tm, trans )
     int		nterm;
@@ -470,6 +485,7 @@ int SimFindTxtor( tile, pNum, arg )
 
 
 /*
+ *----------------------------------------------------------------
  * SimFindOneNode
  *
  *	This procedure returns the node region for a tile which lies
@@ -481,9 +497,11 @@ int SimFindTxtor( tile, pNum, arg )
  * Side effects:
  *	None.
  *
+ *----------------------------------------------------------------
  */
 
-NodeSpec *SimFindOneNode( sx, tile )
+NodeSpec *
+SimFindOneNode( sx, tile )
     SearchContext	*sx;
     Tile		*tile;
 {
@@ -587,6 +605,7 @@ NodeSpec *SimFindOneNode( sx, tile )
 
 
 /*
+ *----------------------------------------------------------------
  * SimGetNodeName
  *
  * 	This procedure uses the Magic circuit extraction code to generate
@@ -604,9 +623,11 @@ NodeSpec *SimFindOneNode( sx, tile )
  *
  * Side effects:
  *	Any node region created is added to the node region list.
+ *----------------------------------------------------------------
  */
 
-char *SimGetNodeName(sx, tp, path)
+char *
+SimGetNodeName(sx, tp, path)
     SearchContext	*sx;		/* current search context */
     Tile		*tp;		/* tile in this cell which is part
 					 * of the node
@@ -672,11 +693,7 @@ char *SimGetNodeName(sx, tp, path)
     if (SimGetnodeAlias && SimIsGetnode) {
 	if (HashLookOnly(&SimGNAliasTbl, nodename) == (HashEntry *) NULL) {
 	    HashFind(&SimGNAliasTbl, nodename);
-#ifdef MAGIC_WRAPPER
-	    Tcl_AppendElement(magicinterp, nodename);
-#else
 	    TxPrintf("alias: %s\n", nodename);
-#endif
 	}
     }
 
@@ -697,11 +714,7 @@ char *SimGetNodeName(sx, tp, path)
 			if (HashLookOnly(&SimGNAliasTbl, nodename) 
 			    == (HashEntry *) NULL) {
 			    HashFind(&SimGNAliasTbl, nodename);
-#ifdef MAGIC_WRAPPER
-			    Tcl_AppendElement(magicinterp, nodename);
-#else
 			    TxPrintf("alias: %s\n", nodename);
-#endif
 			}
 		    }
 		}
@@ -715,20 +728,22 @@ char *SimGetNodeName(sx, tp, path)
 }
 
 /*
+ *----------------------------------------------------------------
  * SimGetNodeCleanup
  *
  *	This procedure is called to clean up the data structures and the
  *	tile database after a node name is extracted.
  * 
  * Results:
- *	The node region list and cell def lists are re-initialized.
+ *	None.
  *
  * Side effects:
- *	None.
+ *	The node region list and cell def lists are re-initialized.
+ *----------------------------------------------------------------
  */
 
+void
 SimGetNodeCleanUp()
-
 {
     SimFreeNodeRegs();
     SimInitDefList();
