@@ -23,12 +23,14 @@
 #ifdef RSIM_MODULE
 
 #include <stdio.h>
+#include <string.h>
 #include <ctype.h>
 #include <signal.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
 #include <sys/file.h>
+
 #include "misc/magic.h"
 #include "utils/stack.h"
 #include "utils/geometry.h"
@@ -75,6 +77,7 @@ bool	SimGetReplyLine();
 
 
 /*
+ *-----------------------------------------------------------------------
  * SimGetNodeCommand
  *
  *	This function returns the "full" name of the rsim command if 'cmd'
@@ -86,9 +89,11 @@ bool	SimGetReplyLine();
  *
  * Side effects:
  *	None.
+ *-----------------------------------------------------------------------
  */
 
-char *SimGetNodeCommand( cmd )
+char *
+SimGetNodeCommand(cmd)
     char *cmd;
 {
     /* This table is used to define which Rsim commands are applied to
@@ -123,6 +128,7 @@ char *SimGetNodeCommand( cmd )
 
 
 /*
+ *-----------------------------------------------------------------------
  * SimStartRsim
  *
  *	This procedure is used to fork the rsim process.  It takes a list of
@@ -136,12 +142,12 @@ char *SimGetNodeCommand( cmd )
  *
  * Side effects:
  *	None.
+ *-----------------------------------------------------------------------
  */
 
-bool SimStartRsim(argv)
-
-char *argv[];		/* list of rsim args for the fork */
-
+bool
+SimStartRsim(argv)
+    char *argv[];		/* list of rsim args for the fork */
 {
 
     int child;
@@ -254,6 +260,7 @@ char *argv[];		/* list of rsim args for the fork */
 
 
 /*
+ *-----------------------------------------------------------------------
  * SimConnectRsim
  *
  *	This procedure is called when Magic is sending commands to Rsim and
@@ -264,18 +271,19 @@ char *argv[];		/* list of rsim args for the fork */
  *	Rsim's reply comes back from the other pipe.
  *
  * Results:
- *	The reply generated by Rsim is printed.
+ *	None.
  *
  * Side effects:
+ *	The reply generated by Rsim is printed.
  *	The reply buffer from SimGetReplyLine is statically allocated.  
  *	Subsequent calls will change the contents of this buffer.
  *
+ *-----------------------------------------------------------------------
  */
 
+void
 SimConnectRsim(escRsim)
-
-bool escRsim;			/* TRUE if we should escape back to Magic */
-
+    bool escRsim;			/* TRUE if we should escape back to Magic */
 {
     static char HELLO_MSG[] = 
 	"Type \"q\" to quit simulator or \".\" to escape back to Magic.\n";
@@ -353,6 +361,7 @@ bool escRsim;			/* TRUE if we should escape back to Magic */
 
 
 /*
+ *-----------------------------------------------------------------------
  * InitRsim
  *	Read the initial header from rsim and determine the prompt.
  *	The prompt is found by searching for the string enclosed
@@ -363,9 +372,11 @@ bool escRsim;			/* TRUE if we should escape back to Magic */
  *
  * Side effects:
  *	Sets the rsim prompt and length.
+ *-----------------------------------------------------------------------
  */
 
-static bool InitRsim( hello_msg )
+bool
+InitRsim(hello_msg)
     char  *hello_msg;
 {
     char	buff[READBUF_SIZE];
@@ -429,19 +440,22 @@ static bool InitRsim( hello_msg )
 
 
 /*
+ *-----------------------------------------------------------------------
  * SimStopRsim
  *
  *	This procedure is called to kill off the Rsim process.  The
  *	exit condition is checked and a message is printed if necessary.
  *
  * Results:
- *	The child Rsim process is killed.
- *
- * Side effects:
  *	None.
  *
+ * Side effects:
+ *	The child Rsim process is killed.
+ *
+ *-----------------------------------------------------------------------
  */
 
+void
 SimStopRsim()
 {
     int  pid;
@@ -479,6 +493,7 @@ SimStopRsim()
 
 
 /*
+ *-----------------------------------------------------------------------
  * RsimErrorMsg
  *
  *	This procedure prints out an error message.
@@ -489,21 +504,24 @@ SimStopRsim()
  * Side effects:
  *	None.
  *
+ *-----------------------------------------------------------------------
  */
 
+void
 RsimErrorMsg()
-
 {
-static char msg[] = 
-"The simulator must be running before this command can be executed.  To do\n\
-this enter the command \"rsim <options> <filename>\".  To escape back to\n\
-Magic enter \".\" in response to the simulator prompt.\n";
+    static char msg[] = "The simulator must be running before this command "
+		"can be executed.  To do\n"
+		"this enter the command \"rsim <options> <filename>\".  "
+		"To escape back to\n"
+		"Magic enter \".\" in response to the simulator prompt.\n";
 
     TxPrintf("%s", msg);
 }
 
 
 /*
+ *-----------------------------------------------------------------------
  * SimRsimIt
  *
  *	This procedure takes an Rsim command and a node name to apply
@@ -511,20 +529,21 @@ Magic enter \".\" in response to the simulator prompt.\n";
  *	to Rsim to process.  
  *
  * Results:
- *	Everything is set up so that GetReplyLine() should be called
- *	after this routine to read the Rsim output for each node.
+ *	None.
  *
  * Side effects:
+ *	Everything is set up so that GetReplyLine() should be called
+ *	after this routine to read the Rsim output for each node.
  *	The reply buffer is statically allocated.  Subsequent calls will
  *	change the contents of this buffer.
  *	
+ *-----------------------------------------------------------------------
  */
 
+void
 SimRsimIt(cmd, nodeName)
-
-char *cmd;
-char *nodeName;
-
+    char *cmd;
+    char *nodeName;
 {
 
     static char cmdStr[256];
@@ -567,6 +586,7 @@ char *nodeName;
 
 
 /*
+ *-----------------------------------------------------------------------
  * SimFillBuffer
  *
  *	This procedure reads characters from Rsim via a pipe and
@@ -580,25 +600,24 @@ char *nodeName;
  *	command parser (or kill it depending on the simulator).
  *
  * Results:
+ *	Number of characters read into the buffer.
+ *
+ * Side effects:
  *	pLastChar is updated to point to the last valid character
  *	in the buffer.  charCount is also updated to contain the
  *	total number of unprocessed characters in the buffer.
- *
- * Side effects:
  *	Some i/o may take place.
  *
+ *-----------------------------------------------------------------------
  */
 
 int
 SimFillBuffer(buffHead, pLastChar, charCount)
-
     char *buffHead;			/* ptr to start of buffer */
-
     char **pLastChar;			/* used to return ptr to last char 
 					 * in the buffer.
 					 */
     int *charCount;			/* number of chars in the buffer */
-
 {
     int 	charsRead = 0;
     char 	*temp;
@@ -622,7 +641,7 @@ SimFillBuffer(buffHead, pLastChar, charCount)
 #if defined(SYSV) || defined(CYGWIN)
     FD_ZERO(&readfds);
     FD_ZERO(&exceptfds);
-#endif
+#endif  /* SYSV */
 
     nfd = pipeIn + 1;
 
@@ -672,6 +691,7 @@ try_again:
 }
 
 /*
+ *-----------------------------------------------------------------------
  * SimShiftChars
  *
  *	This procedure shifts unprocessed charcters in a buffer
@@ -679,20 +699,20 @@ try_again:
  *	tail pointers to the valid buffer characters.
  *
  * Results:
+ *	None.
+ *
+ * Side effects:
  *	Valid data in the buffer is shifted to the beginning of
  *	the buffer.
  *
- * Side effects:
- *	None.
- *
+ *-----------------------------------------------------------------------
  */
 
+void
 SimShiftChars(buffStart, lineStart, lastChar)
-
-char *buffStart;		/* beginning of buffer */
-char **lineStart;		/* ptr to first valid char in buffer */
-char **lastChar;		/* ptr to last valid char in buffer */
-
+    char *buffStart;		/* beginning of buffer */
+    char **lineStart;		/* ptr to first valid char in buffer */
+    char **lastChar;		/* ptr to last valid char in buffer */
 {
     char *temp;
     char *temp1;
@@ -710,6 +730,7 @@ char **lastChar;		/* ptr to last valid char in buffer */
 }
 
 /*
+ *-----------------------------------------------------------------------
  * SimFindNewLine
  *
  *	This procedure searches for a '\n' in the char buffer delimited by
@@ -722,15 +743,15 @@ char **lastChar;		/* ptr to last valid char in buffer */
  * Side effects:
  *	None.
  *
+ *-----------------------------------------------------------------------
  */
+
 char *
 SimFindNewLine(buffStart, buffEnd)
-
     char 	*buffStart;		/* first char in buffer */
     char	*buffEnd;		/* last char in buffer */
-
 {
-    register char *sp;
+    char *sp;
 
     for (sp = buffStart; sp <= buffEnd; sp++) {
 	if (*sp == '\n') {
@@ -741,6 +762,7 @@ SimFindNewLine(buffStart, buffEnd)
 }
 
 /*
+ *-----------------------------------------------------------------------
  * SimGetReplyLine
  *
  *	This procedure returns the next line of an Rsim reply.  It does this
@@ -757,24 +779,23 @@ SimFindNewLine(buffStart, buffEnd)
  *	from a pipe in one read call.
  *
  * Results:
- *	replyLine contains a pointer to the next Rsim reply line
  *	SimGetReplyLine returns TRUE if replyLine is a valid value, 
- *	otherwise it is FALSE.  If we find a line containing only
- * 	the rsim prompt, replyLine points to a NULL pointer and
- *	true is returned.
+ *	otherwise it is FALSE.
+ *	If we find a line containing only the rsim prompt, replyLine
+ *	points to a NULL pointer and TRUE is returned.
  *
  * Side effects:
+ *	replyLine contains a pointer to the next Rsim reply line.
  *	The buffer returned by replyLine is statically allcoated, so
  *	subsequent calls to this routine will change this buffer.
  *
+ *-----------------------------------------------------------------------
  */
 
 bool
 SimGetReplyLine(replyLine)
-
-char **replyLine;
+    char **replyLine;
 {
-
     static char	simReadBuff[READBUF_SIZE];	/* buffer in which to read the 
 						 * rsim reply before processing
 						 * it.  This is big enough for
@@ -793,7 +814,6 @@ char **replyLine;
     static int	charsInBuff = 0;		/* number of characters left
 						 * in input buffer to process.
 						 */
-
     char *strptr;
     char *strptr1;
 
