@@ -29,7 +29,7 @@ static char sccsid[] = "@(#)SimSelect.c	4.14 MAGIC (Berkeley) 10/3/85";
 #include <strings.h>
 #endif
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -92,14 +92,12 @@ HashTable SimGetnodeTbl;	/* node names to abort name search on */
 HashTable SimGNAliasTbl;	/* node name aliases found during search */
 HashTable SimAbortSeenTbl;	/* aborted node names found during search */
 
-bool 	SimRecomputeSel = TRUE;	 /* selection has changed */
-bool	SimInitGetnode  = TRUE;	 /* Getnode called for the 1st time */
-bool	SimGetnodeAlias = FALSE; /* if node aliases are to be printed */
-bool	SimSawAbortString;	 /* if saw string to abort name search */
-bool	SimIsGetnode;		 /* true if command was issued from Getnode */
-bool	SimUseCoords;		 /* true if we should use trans. position */
-bool	SimIgnoreGlobals = TRUE; /* If FALSE, node names ending in "!"	*/
-				 /* are treated as global node names.	*/
+bool 	  SimRecomputeSel = TRUE;	/* selection has changed */
+bool	  SimInitGetnode = TRUE;	/* Getnode called for the 1st time */
+bool	  SimGetnodeAlias = FALSE;	/* if node aliases are to be printed */
+bool	  SimSawAbortString;	/* if saw string to abort name search */
+bool	  SimIsGetnode;		/* true if command was issued from Getnode */
+bool	  SimUseCoords;		/* true if we should use trans. position */
 
 #ifndef RSIM_MODULE
 bool	  SimRsimRunning = FALSE;	/* Always false if there's no rsim module */
@@ -108,12 +106,12 @@ bool	  SimRsimRunning = FALSE;	/* Always false if there's no rsim module */
 /*
  * ----------------------------------------------------------------------------
  *
- *	SimSelectNode
+ *   SimSelectNode --
  *
  * 	This procedure selects an entire node.  It is similar to SelectNet.
  *
  * Results:
- *	None.
+ *	Returns the node name.
  *
  * Side effects:
  *	Starting from material of type "type" under scx, this procedure
@@ -153,28 +151,22 @@ SimSelectNode(scx, type, xMask, buffer)
 	    &TiPlaneRect, Select2Use, buffer);
     UndoEnable();
 
-    /* Strip out path if name is global (ends with a "!")	*/
-    /* and flag SimIgnoreGlobals is not set.			*/
+    /* Strip out path if name is global (ends with a "!") */
 
-    if (!SimIgnoreGlobals)
-    {
-	strptr = buffer + strlen(buffer) - 1; 
-	if (*strptr == '!') {		
-	    *strptr = '\0';
-	    while (strptr != buffer) {
-		if (*strptr == '/') {
-		    strptr++;
-		    break;
-		}
-		strptr--;
+    strptr = buffer + strlen(buffer) - 1; 
+    if (*strptr == '!') {		
+	*strptr = '\0';
+	while (strptr != buffer) {
+	    if (*strptr == '/') {
+		strptr++;
+		break;
 	    }
-	}
-	else {
-	    strptr = buffer;
+	    strptr--;
 	}
     }
-    else
+    else {
 	strptr = buffer;
+    }
 
     return(strptr);
 }
@@ -185,6 +177,7 @@ NullFunc()
 }
 
 /*
+ * ----------------------------------------------------------------------------
  * SimFreeNodeList
  *
  *	This procedure frees all space allocated for the node list
@@ -196,11 +189,12 @@ NullFunc()
  * Side effects:
  *	After the list has been deallocated, the head pointer is set to
  *	a NULL value.
+ * ----------------------------------------------------------------------------
  */
 
+void
 SimFreeNodeList(List)
-TileListElt **List;
-
+    TileListElt **List;
 {
     TileListElt *current;
     TileListElt *temp;
@@ -215,9 +209,9 @@ TileListElt **List;
     *List = (TileListElt *) NULL;
 }
 
-static TileListElt*
-simFreeNodeEntry( list, entry )
-  TileListElt *list, *entry;
+TileListElt *
+simFreeNodeEntry(list, entry)
+    TileListElt *list, *entry;
 {
     TileListElt *prev, *curr;
 
@@ -230,11 +224,13 @@ simFreeNodeEntry( list, entry )
 	    FREE( entry );
 	    return( prev );		/* next element in list */
 	}
+
     /* should never get here */
-    return( entry );
+    return(entry);
 }
 
 /*
+ * ----------------------------------------------------------------------------
  * SimSelectArea
  *
  * 	This procedure checks the current selected paint in the circuit and
@@ -248,7 +244,9 @@ simFreeNodeEntry( list, entry )
  *	search algorithm.  After finishing the search, these marks are 
  *	erased.
  *
+ * ----------------------------------------------------------------------------
  */
+
 TileListElt *
 SimSelectArea()
 {
@@ -290,6 +288,7 @@ SimSelectArea()
 
 
 /*
+ * ----------------------------------------------------------------------------
  * SimSelectFunc
  *
  * 	This procedure is called for each tile in the current selection.
@@ -299,12 +298,13 @@ SimSelectArea()
  *	this node are marked.
  *
  * Results:
- *	None.
+ *	Return 0 to keep the search going.
  *
  * Side effects:
  *	The tiles in the selection cell definition are left marked.  
  *	It is the responsibility of the calling function to erase these
  *	tile marks when finished.
+ * ----------------------------------------------------------------------------
  */
 
 int
@@ -410,6 +410,7 @@ SimSelectFunc(tile, pHead)
 #ifdef RSIM_MODULE
 
 /*
+ * ----------------------------------------------------------------------------
  * SimSelection
  *
  *	This procedure applies the specified rsim command to the list of
@@ -422,13 +423,12 @@ SimSelectFunc(tile, pHead)
  * Side effects:
  *	None.
  *
+ * ----------------------------------------------------------------------------
  */
 
 bool
 SimSelection(cmd)
-
-char *cmd;			/* rsim command to apply to the selection */
-
+    char *cmd;			/* rsim command to apply to the selection */
 {
     static char Hstring[] = "RSIM=1";
     static char Lstring[] = "RSIM=0";
@@ -585,6 +585,7 @@ the selection.\n");
 #endif
 
 /*
+ * ----------------------------------------------------------------------------
  * SimAddLabels
  *
  *	This procedure adds the node value labels to the Magic database
@@ -597,12 +598,13 @@ the selection.\n");
  *	The cell modified flags are deliberately not set when these labels 
  *	are added to the database.
  *
+ * ----------------------------------------------------------------------------
  */
+
+void
 SimAddLabels(SelectNodeList, rootuse)
-
-TileListElt *SelectNodeList;
-CellDef *rootuse;		/* the root cell def for the window */
-
+    TileListElt *SelectNodeList;
+    CellDef *rootuse;		/* the root cell def for the window */
 {
 
     TileListElt *current;
@@ -630,6 +632,7 @@ CellDef *rootuse;		/* the root cell def for the window */
 #ifdef RSIM_MODULE
 
 /*
+ * ----------------------------------------------------------------------------
  * SimRsimMouse
  *
  *	This procedure erases the old rsim node labels and display the
@@ -641,8 +644,10 @@ CellDef *rootuse;		/* the root cell def for the window */
  * Side effects:
  *	None.
  *
+ * ----------------------------------------------------------------------------
  */
 
+void
 SimRsimMouse(w)
     MagWindow *w;
 {
@@ -696,6 +701,7 @@ SimRsimMouse(w)
 #endif
 
 /*
+ * ----------------------------------------------------------------------------
  * SimGetnode
  *
  *	This procedure prints the node names of all selected nodes.
@@ -706,16 +712,17 @@ SimRsimMouse(w)
  * Side effects:
  *	None.
  *
+ * ----------------------------------------------------------------------------
  */
 
+void
 SimGetnode()
 {
-
     TileListElt *current;
 
     /* get the list of node names */
 
-    SimIsGetnode = TRUE;
+    SimIsGetnode = FALSE;
     SimUseCoords = FALSE;
 
     HashInit(&SimNodeNameTbl, 60, HT_STRINGKEYS);
@@ -731,7 +738,7 @@ SimGetnode()
     {
 #ifdef MAGIC_WRAPPER
 	/* Return the node name as the result of the command */
-	Tcl_AppendElement(magicinterp, current->tl_nodeName);
+	Tcl_SetResult(magicinterp, current->tl_nodeName, NULL);
 #else
 	TxPrintf("node name : %s\n", current->tl_nodeName);
 #endif
@@ -741,6 +748,7 @@ SimGetnode()
 
 
 /*
+ * ----------------------------------------------------------------------------
  * SimGetsnode
  *
  *	This procedure prints the short node names of all selected nodes.
@@ -751,17 +759,17 @@ SimGetnode()
  * Side effects:
  *	None.
  *
+ * ----------------------------------------------------------------------------
  */
 
+void
 SimGetsnode()
-
 {
-
     TileListElt *current;
 
     /* get the list of node names */
 
-    SimIsGetnode = TRUE;
+    SimIsGetnode = FALSE;
     SimUseCoords = TRUE;
 
     HashInit(&SimNodeNameTbl, 60, HT_STRINGKEYS);
@@ -777,7 +785,7 @@ SimGetsnode()
     {
 #ifdef MAGIC_WRAPPER
 	/* Return the node short name as the result of the command */
-	Tcl_AppendElement(magicinterp, current->tl_nodeName);
+	Tcl_SetResult(magicinterp, current->tl_nodeName, NULL);
 #else
 	TxPrintf("short node name : %s\n", current->tl_nodeName);
 #endif
@@ -787,6 +795,7 @@ SimGetsnode()
 
 
 /*
+ * ----------------------------------------------------------------------------
  * SimEraseLabels
  *
  *	This procedure erases the RSIM labels from any cell defs they
@@ -798,9 +807,11 @@ SimGetsnode()
  * Side effects:
  *	Removes the RSIM labels from "marked" cell defs.
  *
+ * ----------------------------------------------------------------------------
  */
-SimEraseLabels()
 
+void
+SimEraseLabels()
 {
     SimDefListElt *p;
 
