@@ -2,7 +2,7 @@ extern	char	*SimGetNodeCommand();
 extern	char	*SimGetNodeName();
 extern	char	*SimSelectNode();
 extern	bool	SimGetReplyLine();
-extern		SimRsimIt();
+extern	void	SimRsimIt();
 extern	bool	efPreferredName();
 extern  void	SimRsimHandler();
 extern  void	SimInit();
@@ -15,7 +15,6 @@ extern 	bool	SimRsimRunning;
 extern	bool	SimIsGetnode;
 extern	bool	SimHasCoords;
 extern	bool	SimUseCoords;
-extern  bool	SimIgnoreGlobals;
 
 extern HashTable SimNodeNameTbl;
 extern HashTable SimGNAliasTbl;
