@@ -21,8 +21,10 @@ static char rcsid[] = "$Header: /ufs/repository/magic/tech/tech.c,v 1.3 2001/01/
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <string.h>
 #include <stdarg.h>
 #include <ctype.h>
+
 #include "misc/magic.h"
 #include "utils/geometry.h"
 #include "utils/utils.h"
@@ -67,6 +69,7 @@ char *TechFileName = NULL;
     typedef struct
     {
 	char		*ts_name;	/* Name of section */
+	char		*ts_alias;	/* Alternative name of section */
 	techClient	*ts_clients;	/* Pointer to list of clients */
 	bool		 ts_read;	/* Flag: TRUE if section was read */
 	bool		 ts_optional;	/* Flag: TRUE if section is optional */
@@ -163,12 +166,60 @@ TechSectionGetMask(sectionName, depend)
  * ----------------------------------------------------------------------------
  */
 
+void
 TechInit()
 {
     techCurrentSection = (techSection *) NULL;
     techSectionFree = techSectionTable;
     techSectionNum = 0;
 }
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * TechAddAlias --
+ *
+ *	Add an alternative name (alias) for a technology file section which
+ *	may be used in place of the primary name.
+ *
+ *	This has been added mainly to handle sections which have been
+ *	expanded beyond their original definition such that the section
+ *	name is no longer appropriate.  Case in point:  the "images"
+ *	section is broader in scope than the "contact" section, but
+ *	because contacts are a subset of images in version 7.3, it is
+ *	preferable to have an "images" section instead of a "contacts"
+ *	section, with allowances for backwards compatibility.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Allocates string memory.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+TechAddAlias(primaryName, alias)
+    char *primaryName;
+    char *alias;
+{
+    techSection *tsp;
+
+    tsp = techFindSection(primaryName);
+    if (tsp == (techSection *) NULL)
+    {
+	TxError("Unknown technology file section \"%s\" requested.\n",
+		primaryName);
+    }
+    else
+    {
+	if (tsp->ts_alias != NULL)
+	    freeMagic(tsp->ts_alias);
+	tsp->ts_alias = StrDup(NULL, alias);
+    }
+}
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -215,7 +266,7 @@ TechInit()
  * ----------------------------------------------------------------------------
  */
 
-bool
+void
 TechAddClient(sectionName, init, proc, final, prevSections, pSectionID, opt)
     char *sectionName;
     void (*init)();
@@ -234,6 +285,7 @@ TechAddClient(sectionName, init, proc, final, prevSections, pSectionID, opt)
 	tsp = techSectionFree++;
 	ASSERT(tsp < &techSectionTable[MAXSECTIONS], "TechAddClient");
 	tsp->ts_name = StrDup((char **) NULL, sectionName);
+	tsp->ts_alias = NULL;
 	tsp->ts_clients = (techClient *) NULL;
 	tsp->ts_thisSect = SectionToMaskBit(techSectionNum);
 	tsp->ts_prevSects = (SectionID) 0;
@@ -286,9 +338,9 @@ TechLoad(filename, initmask)
     char *filename;
     SectionID initmask;
 {
-    register FILE *tf;
-    register techSection *tsp;
-    register techClient *tcp;
+    FILE *tf;
+    techSection *tsp;
+    techClient *tcp;
     char suffix[20], line[MAXLINESIZE], *realname;
     char *argv[MAXARGS];
     SectionID mask, badMask;
@@ -387,7 +439,7 @@ TechLoad(filename, initmask)
 	    }
 	    if (mask = (tsp->ts_prevSects & ~techSectionMask))
 	    {
-		register techSection *sp;
+		techSection *sp;
 
 		TechError("Section %s appears too early.\n", argv[0]);
 		TxError("\tMissing prerequisite sections:\n");
@@ -545,12 +597,18 @@ techSection *
 techFindSection(sectionName)
     char *sectionName;
 {
-    register techSection *tsp;
+    techSection *tsp;
 
     for (tsp = techSectionTable; tsp < techSectionFree; tsp++)
-	if (strcmp(tsp->ts_name, sectionName) == 0)
+    {
+	if (!strcmp(tsp->ts_name, sectionName))
 	    return (tsp);
-
+	else if (tsp->ts_alias != NULL)
+	{
+	    if (!strcmp(tsp->ts_alias, sectionName))
+		return (tsp);
+	}
+    }
     return ((techSection *) NULL);
 }
 
@@ -577,13 +635,14 @@ techFindSection(sectionName)
  * ----------------------------------------------------------------------------
  */
 
+int
 techGetTokens(line, size, file, argv)
     char *line;			/* Character array into which line is read */
     int size;			/* Size of character array */
-    register FILE *file;	/* Open technology file */
+    FILE *file;	/* Open technology file */
     char *argv[];		/* Vector of tokens built by techGetTokens() */
 {
-    register char *get, *put, *getp;
+    char *get, *put, *getp;
     bool inquote;
     int argc = 0;
     int currspace;		/* chars remaining before end of line[size] */
@@ -609,16 +668,10 @@ start:
 	while(isspace(*getp)) getp++;
 	if (*getp == '#') continue;
 	for (put = get; *put != '\n'; put++) currspace -= 1;
-	if (put != get)
+	if ((put != get) && (*(put-1) == '\\'))
 	{
-	    put--;
-	    if (*put == 0xd) put--;	/* Handle DOS-style CR/LF */
-	    if (*put == '\\')
-	    {
-		get = put-1;
-		continue;
-	    }
-	    put++;
+	    get = put-1;
+	    continue;
 	}
 	*put= '\0';
 	break;
