@@ -456,7 +456,7 @@ TxAddInputDevice(fdmask, inputProc, cdata)
     fd_set fdmask;		/* A mask of file descriptors that this
 				 * device will handle.
 				 */
-    Void (*inputProc)();	/* A routine to call.  This routine will
+    void (*inputProc)();	/* A routine to call.  This routine will
 				 * be passed a single file descriptor that
 				 * is ready, and should read that file and
 				 * add events(s) by calling TxNewEvent() 
@@ -483,7 +483,7 @@ TxAddInputDevice(fdmask, inputProc, cdata)
 void
 TxAdd1InputDevice(fd, inputProc, cdata)
     int fd;		
-    Void (*inputProc)();	
+    void (*inputProc)();	
     ClientData cdata;		
 {
     fd_set fs;
@@ -663,6 +663,7 @@ TxLogCommands(fileName, update)
  * ----------------------------------------------------------------------------
  */
 
+void
 txLogCommand(cmd)
     TxCommand *cmd;
 {
@@ -748,7 +749,7 @@ txLogCommand(cmd)
  * ----------------------------------------------------------------------------
  */
 
-int
+bool
 TxGetInputEvent(block, returnOnSigWinch)
     bool block;		/* If TRUE, we will wait for an event.  Otherwise, we
 			 * just poll.
@@ -1392,6 +1393,7 @@ done:
  * ----------------------------------------------------------------------------
  */
 
+void
 txCommandsInit()
 {
     txZeroTime.tv_sec = 0;
@@ -1412,7 +1414,7 @@ txCommandsInit()
  *	Send command to magic window.
  *
  * Results:
- *	Returns a 1 on success, 0 on failure.
+ *	Returns TRUE on success, FALSE on failure.
  *
  * Side Effects:
  *	whatever the command does.
