@@ -971,6 +971,7 @@ make_techtype_list(void)
  *
  * ----------------------------------------------------------------------------
  */
+
 char *
 TxGetLineWPrompt(dest, maxChars, prompt, prefix)
     char *dest;
@@ -1198,6 +1199,7 @@ TxGetLine(dest, maxChars)
  */
 
 #if defined(SYSV) || defined(CYGWIN)
+
 void
 txGetTermState(buf)
     struct termio *buf;
@@ -1261,9 +1263,10 @@ txSetTermState(buf)
  *	cbreak on, and no EOFs the way we like it.
  *
  * Results:
- *	The passed terminal record is modified.
+ *	None.
  *
  * Side effects:
+ *	The passed terminal record is modified.
  *	No terminal modes are actually changed.
  * ----------------------------------------------------------------------------
  */
@@ -1286,9 +1289,6 @@ txInitTermRec(buf)
     buf->tx_i_sgtty.sg_flags &= ~ECHO;
     buf->tx_i_tchars.t_eofc = -1;
 
-    /* Give the graphics module a chance to override this. */
-    if (GrTermStatePtr) 
-	(*GrTermStatePtr)(&buf->tx_i_sgtty, &buf->tx_i_tchars);
 #endif /* SYSV */
 }
 
