@@ -22,11 +22,12 @@ static char rcsid[] = "$Header: /ufs/repository/magic/utils/path.c,v 1.5 2001/01
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <pwd.h>
 #include <ctype.h>
 #include <sys/param.h>
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/hash.h"
 #include "utils/malloc.h"
@@ -115,7 +116,7 @@ PaExpand(psource, pdest, size)
     int size;			/* Number of bytes available at pdest */
 
 {
-    register char *ps, *pd;
+    char *ps, *pd;
     struct passwd *passwd, *getpwnam();
     char expandName[100], *string, *newEntry;
     HashEntry *h;
@@ -605,6 +606,7 @@ char *newWD;			/* New working directory to be used.  Must
  * ----------------------------------------------------------------------------
  */
 
+int
 PaEnum(path, file, proc, cdata)
     char *path;		/* Search path */
     char *file;		/* Each element of the search path is prepended to
