@@ -98,10 +98,10 @@ static int windCorner = WIND_ILG;	/* Nearest corner when button went
  * ----------------------------------------------------------------------------
  */
 
+void
 windButtonSetCursor(button, corner)
-int button;			/* Button that is down. */
-int corner;			/* Corner to be displayed in cursor. */
-
+    int button;			/* Button that is down. */
+    int corner;			/* Corner to be displayed in cursor. */
 {
     switch (corner)
     {
@@ -306,6 +306,7 @@ windMoveRect(wholeRect, corner, p, rect)
  * ----------------------------------------------------------------------------
  */
 
+void
 windFrameDown(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -512,12 +513,6 @@ windClientButtons(w, cmd)
 	case WIND_X_WINDOWS:
 	    break;
 	
-	case WIND_SUN_WINDOWS:
-#ifdef	SUNVIEW
-	    windSunHandleCaptionInput(w, cmd);
-#endif	/* SUNVIEW */
-	    break;
-	
 	default:
 	    /* Magic Windows */
 	    if (cmd->tx_button == TX_MIDDLE_BUTTON) 
@@ -562,7 +557,7 @@ windClientButtons(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 windCmdInterp(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -604,9 +599,9 @@ windCmdInterp(w, cmd)
 void
 windClientInit()
 {
-    windClientID = WindAddClient(WINDOW_CLIENT, ( Void (*)() ) NULL,
-	( Void (*)() ) NULL, ( Void (*)() ) NULL, windCmdInterp, 
-	( Void (*)() ) NULL, ( Void (*)() ) NULL, ( Void (*)() ) NULL,
+    windClientID = WindAddClient(WINDOW_CLIENT, ( bool (*)() ) NULL,
+	( bool (*)() ) NULL, ( void (*)() ) NULL, windCmdInterp, 
+	( void (*)() ) NULL, ( bool (*)() ) NULL, ( void (*)() ) NULL,
 	(GrGlyph *) NULL);
 
     /* Set up all of the window commands */
@@ -699,12 +694,7 @@ windClientInit()
 	"undo [count]		undo commands",
 	windUndoCmd, FALSE);
     WindAddCommand(windClientID,
-#ifdef MAGIC_WRAPPER
-	"updatedisplay [suspend|resume]\n\
-			force display update, or suspend/resume updates",
-#else
 	"updatedisplay		force the display to be updated",
-#endif
 	windUpdateCmd, FALSE);
     WindAddCommand(windClientID,
 	"version			print out version info",
