@@ -22,13 +22,14 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windCmdAM.c,v 1.7 20
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/times.h>
 #include <sys/stat.h>
 #include <errno.h>
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
@@ -59,17 +60,17 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windCmdAM.c,v 1.7 20
  *	windborder [on|off]
  *
  * Results:
- *	None.  In Tcl, if no options are presented, the border status
- *	is returned.
+ *	None.
  *
  * Side effects:
  *	A flag is changed.
+ *	In Tcl, if no options are presented, the border status is returned
+ *	in the command exit status.
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
-Void
+void
 windBorderCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -129,17 +130,17 @@ windBorderCmd(w, cmd)
  *	windcaption [on|off]
  *
  * Results:
- *	None.  In Tcl, if no options are presented, the window title caption
- *	is returned.
+ *	None.
  *
  * Side effects:
  *	A flag is changed.
+ *	In Tcl, if no options are presented, the window title caption is
+ *	returned in the command status.
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
-Void
+void
 windCaptionCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -210,6 +211,7 @@ windCaptionCmd(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
+void
 windCenterCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -308,8 +310,8 @@ windCenterCmd(w, cmd)
  *	refuse to have the window closed, in which case nothing happens.
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windCloseCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -345,7 +347,7 @@ windCloseCmd(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
-    /*ARGSUSED*/
+void
 windCrashCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -369,13 +371,15 @@ windCrashCmd(w, cmd)
  *	Report the cursor position in Magic (internal) coordinates
  *
  * Results:
- *	Returns the cursor position as a list (Tcl version)
+ *	None.
  *
  * Side effects:
  *	Prints coordinates (non-Tcl version)
+ *	Return value set to the cursor position as a list (Tcl version)
  * ----------------------------------------------------------------------------
  */
 
+void
 windCursorCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -415,8 +419,8 @@ windCursorCmd(w, cmd)
  *	None.
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windDebugCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -444,8 +448,8 @@ usage:
  *	None.
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windDumpCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -470,8 +474,8 @@ windDumpCmd(w, cmd)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windEchoCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -573,8 +577,8 @@ windFilesCmd(w, cmd)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windGrowCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -602,8 +606,8 @@ windGrowCmd(w, cmd)
  *	None.
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windGrstatsCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -708,8 +712,8 @@ windGrstatsCmd(w, cmd)
  *	None.
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windHelpCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -733,7 +737,8 @@ windHelpCmd(w, cmd)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
+
+void
 windDoMacro(cmd, interactive)
     TxCommand *cmd;
     bool interactive;
@@ -831,8 +836,8 @@ windDoMacro(cmd, interactive)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windIntMacroCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -860,8 +865,8 @@ static char *logKeywords[] =
  *	None.
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windLogCommandsCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -908,8 +913,8 @@ usage:
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windMacroCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
