@@ -21,9 +21,11 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windCmdSZ.c,v 1.3 20
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <math.h>
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
@@ -66,7 +68,7 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windCmdSZ.c,v 1.3 20
  * ----------------------------------------------------------------------------
  */
 
-Void
+void
 windScrollCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -81,23 +83,23 @@ windScrollCmd(w, cmd)
     if ( (cmd->tx_argc < 2) || (cmd->tx_argc > 4) )
     {
 	TxError("Usage: %s direction [amount [units]]\n", cmd->tx_argv[0]);
-	return 0;
+	return;
     }
 
     if (w == NULL)
     {
 	TxError("Point to a window first.\n");
-	return 0;
+	return;
     }
 
     if ((w->w_flags & WIND_SCROLLABLE) == 0) {
 	TxError("Sorry, can't scroll this window.\n");
-	return 0;
+	return;
     };
 
     pos = GeoNameToPos(cmd->tx_argv[1], FALSE, TRUE);
     if (pos < 0 || pos == GEO_CENTER)
-	return 0;
+	return;
 
     if (cmd->tx_argc == 2)	/* default = half-screen pan */
     {
@@ -117,14 +119,14 @@ windScrollCmd(w, cmd)
 	{
 	    TxError("Usage: %s direction [amount [units]]\n", cmd->tx_argv[0]);
 	    TxError("  'units' must be one of 'w' (window) or 'l' (layout);\n");
-	    return 0;
+	    return;
 	}
 
 	if (sscanf(cmd->tx_argv[2], "%f", &amount) != 1)
 	{
 	    TxError("Usage: %s direction [amount [units]]\n", cmd->tx_argv[0]);
 	    TxError("  'amount' is a fractional value.\n");
-	    return 0;
+	    return;
 	}
 	doFractional = TRUE;
     }
@@ -137,8 +139,7 @@ windScrollCmd(w, cmd)
     else
     {
 	/* Alternate syntax: parse for integer coordinate amount to scroll */
-	xsize = cmdParseCoord(w, cmd->tx_argv[2], TRUE, TRUE);
-	ysize = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
+	xsize = ysize = cmdParseCoord(cmd->tx_argv[2]);
     }
 
     p.p_x = 0;
@@ -186,7 +187,7 @@ windScrollCmd(w, cmd)
 	WindScroll(w, &p, (Point *) NULL);
     }
 
-    return 0;
+    return;
 }
 
 /*
@@ -205,6 +206,7 @@ windScrollCmd(w, cmd)
  * ----------------------------------------------------------------------------
  */
 
+void
 windSetpointCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -282,8 +284,8 @@ windSetPrintProc(name, val)
  *	None.
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windSleepCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -326,8 +328,8 @@ windSleepCmd(w, cmd)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windSourceCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -367,8 +369,8 @@ windSourceCmd(w, cmd)
  *	None.
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windSpecialOpenCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -444,6 +446,7 @@ usage:
  * ----------------------------------------------------------------------------
  */
 
+void
 windNamesCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -511,8 +514,8 @@ windNamesCmd(w, cmd)
  *	Screen updates.
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windUnderCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -551,8 +554,8 @@ windUnderCmd(w, cmd)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windUndoCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -608,32 +611,19 @@ windUndoCmd(w, cmd)
  *	Display updates.
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windUpdateCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
-    if (cmd->tx_argc == 1)
-	WindUpdate();  
-#ifdef MAGIC_WRAPPER
-    else if (cmd->tx_argc > 2)
-	goto badusage;
-    else if (!strcmp(cmd->tx_argv[1], "suspend"))
-	GrDisplayStatus = DISPLAY_SUSPEND;
-    else if (!strcmp(cmd->tx_argv[1], "resume"))
-	GrDisplayStatus = DISPLAY_IDLE;
-    else
-	goto badusage;
-#else
-    else if (cmd->tx_argc >= 2)
-	goto badusage;
-#endif
-    return;
+    if (cmd->tx_argc != 1)
+    {
+	TxError("Usage: %s\n", cmd->tx_argv[0]);
+	return;
+    }
 
-badusage:
-    TxError("Usage: %s [suspend | resume]\n", cmd->tx_argv[0]);
-    return;
+    WindUpdate();
 }
 
 /*
@@ -654,8 +644,8 @@ badusage:
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windVersionCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -682,16 +672,16 @@ windVersionCmd(w, cmd)
  *
  * Results:
  *	None.
- *	In Tcl version, if supplied with the argument "get", returns
- *	the current view position.
  *
  * Side effects:
  *	The window underneath the cursor is changed.
+ *	In Tcl version, if supplied with the argument "get", the
+ *	interpreter return value is set to the current view position.
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windViewCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -755,10 +745,10 @@ windViewCmd(w, cmd)
     else if (cmd->tx_argc == 5)
     {
 	Rect r;
-	r.r_xbot = cmdParseCoord(w, cmd->tx_argv[1], FALSE, TRUE);
-        r.r_ybot = cmdParseCoord(w, cmd->tx_argv[2], FALSE, FALSE);
-        r.r_xtop = cmdParseCoord(w, cmd->tx_argv[3], FALSE, TRUE);
-        r.r_ytop = cmdParseCoord(w, cmd->tx_argv[4], FALSE, FALSE);
+	r.r_xbot = cmdParseCoord(cmd->tx_argv[1]);
+        r.r_ybot = cmdParseCoord(cmd->tx_argv[2]);
+        r.r_xtop = cmdParseCoord(cmd->tx_argv[3]);
+        r.r_ytop = cmdParseCoord(cmd->tx_argv[4]);
 
 	/* Redisplay */
 	WindMove(w, &r);
@@ -791,8 +781,8 @@ windViewCmd(w, cmd)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
+void
 windXviewCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -852,9 +842,8 @@ ViewUnexpandFunc(use, windowMask)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
-Void
+void
 windScrollBarsCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -908,9 +897,8 @@ windScrollBarsCmd(w, cmd)
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
-Void
+void
 windSendCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -986,9 +974,8 @@ typedef struct _cdwpos {
  *
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
-Void
+void
 windPositionsCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
@@ -1095,6 +1082,7 @@ windPositionsFunc(w, cdata)
  * ----------------------------------------------------------------------------
  */
 
+void
 windZoomCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
