@@ -21,7 +21,7 @@ static char rcsid[]="$Header: /ufs/repository/magic/windows/windDisp.c,v 1.3 200
 
 #include <stdio.h>
 
-#include "tcltk/tclmagic.h"
+#include "magic/tclmagic.h"
 #include "misc/magic.h"
 #include "utils/utils.h"
 #include "textio/textio.h"
@@ -76,7 +76,7 @@ bool windSomeSeparateRedisplay = FALSE;
  * ----------------------------------------------------------------------------
  */
 
-Void windCheckOnlyWindow(MagWindow **w, WindClient client)
+int windCheckOnlyWindow(MagWindow **w, WindClient client)
 {
     MagWindow *sw, *tw;
     int wct = 0;
@@ -112,6 +112,7 @@ Void windCheckOnlyWindow(MagWindow **w, WindClient client)
  * ----------------------------------------------------------------------------
  */
 
+void
 windFreeList(llr)
     LinkedRect **llr;	/* A pointer to a list of linked rectangles */
 {
@@ -145,6 +146,7 @@ windFreeList(llr)
  * ----------------------------------------------------------------------------
  */
 
+void
 windReClip()
 {
     MagWindow *w1, *w2;
@@ -358,11 +360,11 @@ windChangedFunc(area, next)
  *	Each argument must point to a different piece of memory.
  *
  * Results:
- *	Returns a bunch of rectangles describing the locations of things.
- *	See comments next to the argument list for details.
+ *	None.
  *
  * Side effects:
- *	None.
+ *	Returns a bunch of rectangles describing the locations of things.
+ *	See comments next to the argument list for details.
  * ----------------------------------------------------------------------------
  */
 
@@ -769,8 +771,6 @@ WindUpdate()
     }
 
 #ifdef MAGIC_WRAPPER
-    /* Honor the display redraw suspension state */
-    if (GrDisplayStatus == DISPLAY_SUSPEND) return;
     GrDisplayStatus = DISPLAY_IN_PROGRESS;
     SigSetTimer(0);
 #endif
