@@ -72,6 +72,7 @@ int windCurNumWindows = 0;
  * ----------------------------------------------------------------------------
  */
 
+void
 windUnlink(w)
     MagWindow *w;
 {
@@ -160,7 +161,6 @@ WindSetWindowAreas(w)
     switch ( WindPackageType )
     {
 	case WIND_X_WINDOWS:
-	case WIND_SUN_WINDOWS:
 	    /* Windows have origin at lower-left corner */
 	    w->w_allArea.r_xbot = w->w_allArea.r_ybot = 0;
 	    w->w_allArea.r_xtop = w->w_frameArea.r_xtop - w->w_frameArea.r_xbot;
@@ -179,10 +179,7 @@ WindSetWindowAreas(w)
  * ----------------------------------------------------------------------------
  * windSetWindowPosition --
  *
- *	Make sure that the window system knows that the window is located
- *	at w->w_frameArea.  Called when w->w_frame area is changed.
- *	This is a no-op if Magic is managing it's own windows, since it
- *	runs directly off of w->w_frameArea.
+ *	(deprecated function)
  *
  * Results:
  *	None.
@@ -191,19 +188,11 @@ WindSetWindowAreas(w)
  *	None.
  * ----------------------------------------------------------------------------
  */
-	/* ARGSUSED */
+
 void
 windSetWindowPosition(w)
     MagWindow *w;
 {
-    switch ( WindPackageType )
-    {
-	case WIND_SUN_WINDOWS:
-#ifdef	SUNVIEW
-	    windSunSetWindowPosition(w);
-#endif	/* SUNVIEW */
-	    break;
-    }
 }
 
 /*
@@ -259,7 +248,6 @@ WindDelete(w)
  *	windows.
  * ----------------------------------------------------------------------------
  */
- /*ARGSUSED*/
 
 MagWindow *
 WindCreate(client, frameArea, isHint, argc, argv)
@@ -326,11 +314,7 @@ WindCreate(client, frameArea, isHint, argc, argv)
     }
     else
 	w->w_frameArea = *frameArea;
-#ifdef	SUNVIEW
-    /* Don't set window positions ourselves. */
-    if ((WindPackageType == WIND_SUN_WINDOWS) && isHint)
-	GrSunFigureLocation(&w->w_frameArea);
-#endif	/* SUNVIEW */
+
     WindSetWindowAreas(w);
 
     /* now link the window in on top */
@@ -343,7 +327,7 @@ WindCreate(client, frameArea, isHint, argc, argv)
     windTopWindow = w;
 
     /* notify the client */
-    OK = ( (cr->w_create == NULL) || (*(cr->w_create))(w, argc, argv) );
+    OK = ((cr->w_create == NULL) || (*(cr->w_create))(w, argc, argv));
 
 #ifdef THREE_D
     if (strcmp(cr->w_clientName, "wind3d"))
@@ -454,11 +438,6 @@ WindUnder(w)
 	    if ( GrUnderWindowPtr )
 		(*GrUnderWindowPtr)(w);
 	    break;
-	case WIND_SUN_WINDOWS:
-#ifdef	SUNVIEW
-	    windSunUnder(w);
-#endif	/* SUNVIEW */
-	    break;
 	default:
 	    /* Mark for redisplay all the areas that this window
 	     * currently obscures.
@@ -517,12 +496,6 @@ WindOver(w)
 		(*GrOverWindowPtr)(w);
 	    break;
 	
-	case WIND_SUN_WINDOWS:
-#ifdef	SUNVIEW
-	    windSunOver(w);
-#endif	/* SUNVIEW */
-	    break;
-	
 	default:
 	    /* Mark for redisplay all of the areas of the screen that
 	     * currently obscure this window.
@@ -670,7 +643,6 @@ WindReframe(w, r, inside, move)
     switch ( WindPackageType )
     {
 	case WIND_X_WINDOWS:
-	case WIND_SUN_WINDOWS:
 	    break;
 	
 	default:
@@ -717,7 +689,6 @@ WindReframe(w, r, inside, move)
 
     switch ( WindPackageType )
     {
-	case WIND_SUN_WINDOWS:
 	case WIND_X_WINDOWS:
 	    break;
 	
@@ -864,9 +835,6 @@ WindFullScreen(w)
 	    if ( GrConfigureWindowPtr )
 		(*GrConfigureWindowPtr)(w);
 	    break;
-	case WIND_SUN_WINDOWS:
-	    WindAreaChanged(w, (Rect *) NULL);
-	    break;
 	default:
 	    WindAreaChanged((MagWindow *) NULL, (Rect *) NULL);
     }
